/*
** ###################################################################
**     Compilers:           ARM Compiler
**                          Freescale C/C++ for Embedded ARM
**                          GNU C Compiler
**                          IAR ANSI C/C++ Compiler for ARM
**
**     Reference manual:    xxx
**     Version:             rev. 1.0, 2014-05-26
**     Build:               b140528
**
**     Abstract:
**         Extension to the CMSIS register access layer header.
**
**     Copyright (c) 2014 Freescale Semiconductor, Inc.
**     All rights reserved.
**
**     Redistribution and use in source and binary forms, with or without modification,
**     are permitted provided that the following conditions are met:
**
**     o Redistributions of source code must retain the above copyright notice, this list
**       of conditions and the following disclaimer.
**
**     o Redistributions in binary form must reproduce the above copyright notice, this
**       list of conditions and the following disclaimer in the documentation and/or
**       other materials provided with the distribution.
**
**     o Neither the name of Freescale Semiconductor, Inc. nor the names of its
**       contributors may be used to endorse or promote products derived from this
**       software without specific prior written permission.
**
**     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
**     ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
**     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
**     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
**     ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
**     (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
**     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
**     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
**     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
**     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**     http:                 www.freescale.com
**     mail:                 support@freescale.com
**
**     Revisions:
**     - rev. 1.0 (2014-05-26)
**
** ###################################################################
*/

/*
 * WARNING! DO NOT EDIT THIS FILE DIRECTLY!
 *
 * This file was generated automatically and any changes may be lost.
 */
#ifndef __HW_FMC_REGISTERS_H__
#define __HW_FMC_REGISTERS_H__

#include "MK80F256.h"
#include "fsl_bitaccess.h"

/*
 * MK80F256 FMC
 *
 * Flash Memory Controller
 *
 * Registers defined in this header file:
 * - HW_FMC_PFAPR - Flash Access Protection Register
 * - HW_FMC_PFB0CR - Flash Bank 0 Control Register
 * - HW_FMC_PFB1CR - Flash Bank 1 Control Register
 * - HW_FMC_TAGVDW0Sn - Cache Tag Storage
 * - HW_FMC_TAGVDW1Sn - Cache Tag Storage
 * - HW_FMC_TAGVDW2Sn - Cache Tag Storage
 * - HW_FMC_TAGVDW3Sn - Cache Tag Storage
 * - HW_FMC_DATAW0SnUM - Cache Data Storage (uppermost word)
 * - HW_FMC_DATAW0SnMU - Cache Data Storage (mid-upper word)
 * - HW_FMC_DATAW0SnML - Cache Data Storage (mid-lower word)
 * - HW_FMC_DATAW0SnLM - Cache Data Storage (lowermost word)
 * - HW_FMC_DATAW1SnUM - Cache Data Storage (uppermost word)
 * - HW_FMC_DATAW1SnMU - Cache Data Storage (mid-upper word)
 * - HW_FMC_DATAW1SnML - Cache Data Storage (mid-lower word)
 * - HW_FMC_DATAW1SnLM - Cache Data Storage (lowermost word)
 * - HW_FMC_DATAW2SnUM - Cache Data Storage (uppermost word)
 * - HW_FMC_DATAW2SnMU - Cache Data Storage (mid-upper word)
 * - HW_FMC_DATAW2SnML - Cache Data Storage (mid-lower word)
 * - HW_FMC_DATAW2SnLM - Cache Data Storage (lowermost word)
 * - HW_FMC_DATAW3SnUM - Cache Data Storage (uppermost word)
 * - HW_FMC_DATAW3SnMU - Cache Data Storage (mid-upper word)
 * - HW_FMC_DATAW3SnML - Cache Data Storage (mid-lower word)
 * - HW_FMC_DATAW3SnLM - Cache Data Storage (lowermost word)
 *
 * - hw_fmc_t - Struct containing all module registers.
 */

#define HW_FMC_INSTANCE_COUNT (1U) /*!< Number of instances of the FMC module. */

#define HW_FMC_CACHE_COUNT (4) /*!< Number of CACHE array elements. */

/*******************************************************************************
 * HW_FMC_PFAPR - Flash Access Protection Register
 ******************************************************************************/

/*!
 * @brief HW_FMC_PFAPR - Flash Access Protection Register (RW)
 *
 * Reset value: 0x00F000FFU
 */
typedef union _hw_fmc_pfapr
{
    uint32_t U;
    struct _hw_fmc_pfapr_bitfields
    {
        uint32_t M0AP : 2; /*!< [1:0] Master 0 Access Protection */
        uint32_t M1AP : 2; /*!< [3:2] Master 1 Access Protection */
        uint32_t M2AP : 2; /*!< [5:4] Master 2 Access Protection */
        uint32_t M3AP : 2; /*!< [7:6] Master 3 Access Protection */
        uint32_t RESERVED0 : 8; /*!< [15:8] This read-only bitfield is reserved and is reset to zero. */
        uint32_t M0PFD : 1; /*!< [16] Master 0 Prefetch Disable */
        uint32_t M1PFD : 1; /*!< [17] Master 1 Prefetch Disable */
        uint32_t M2PFD : 1; /*!< [18] Master 2 Prefetch Disable */
        uint32_t M3PFD : 1; /*!< [19] Master 3 Prefetch Disable */
        uint32_t RESERVED1 : 12; /*!< [31:20] Reserved. */
    } B;
} hw_fmc_pfapr_t;

/*!
 * @name Constants and macros for entire FMC_PFAPR register
 */
/*@{*/
#define HW_FMC_PFAPR_ADDR(x)        ((x) + 0x0U)
#define HW_FMC_PFAPR(x)             (*(__IO hw_fmc_pfapr_t *) HW_FMC_PFAPR_ADDR(x))
#define HW_FMC_PFAPR_RD(x)          (HW_FMC_PFAPR(x).U)
#define HW_FMC_PFAPR_WR(x, v)       (HW_FMC_PFAPR(x).U = (v))
#define HW_FMC_PFAPR_SET(x, v)      (HW_FMC_PFAPR_WR(x, HW_FMC_PFAPR_RD(x) |  (v)))
#define HW_FMC_PFAPR_CLR(x, v)      (HW_FMC_PFAPR_WR(x, HW_FMC_PFAPR_RD(x) & ~(v)))
#define HW_FMC_PFAPR_TOG(x, v)      (HW_FMC_PFAPR_WR(x, HW_FMC_PFAPR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_PFAPR bitfields
 */

/*!
 * @name Register FMC_PFAPR, field M0AP[1:0] (RW)
 *
 * This field controls whether read and write access to the flash are allowed based on the logical
 * master number of the requesting crossbar switch master.
 *
 * Values:
 * - 00 - No access may be performed by this master
 * - 01 - Only read accesses may be performed by this master
 * - 10 - Only write accesses may be performed by this master
 * - 11 - Both read and write accesses may be performed by this master
 */
/*@{*/
#define BP_FMC_PFAPR_M0AP         (0U)      /*!< Bit position for FMC_PFAPR_M0AP. */
#define BM_FMC_PFAPR_M0AP         (0x00000003U)  /*!< Bit mask for FMC_PFAPR_M0AP. */
#define BS_FMC_PFAPR_M0AP         (2U)  /*!< Bitfield size in bits for FMC_PFAPR_M0AP. */

/*! @brief Read current value of the FMC_PFAPR_M0AP field. */
#define BR_FMC_PFAPR_M0AP(x)   (HW_FMC_PFAPR(x).B.M0AP)

/*! @brief Format value for bitfield FMC_PFAPR_M0AP. */
#define BF_FMC_PFAPR_M0AP(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_PFAPR_M0AP) & BM_FMC_PFAPR_M0AP)

/*! @brief Set the M0AP field to a new value. */
#define BW_FMC_PFAPR_M0AP(x, v)   (HW_FMC_PFAPR_WR(x, (HW_FMC_PFAPR_RD(x) & ~BM_FMC_PFAPR_M0AP) | BF_FMC_PFAPR_M0AP(v)))
/*@}*/

/*!
 * @name Register FMC_PFAPR, field M1AP[3:2] (RW)
 *
 * This field controls whether read and write access to the flash are allowed based on the logical
 * master number of the requesting crossbar switch master.
 *
 * Values:
 * - 00 - No access may be performed by this master
 * - 01 - Only read accesses may be performed by this master
 * - 10 - Only write accesses may be performed by this master
 * - 11 - Both read and write accesses may be performed by this master
 */
/*@{*/
#define BP_FMC_PFAPR_M1AP         (2U)      /*!< Bit position for FMC_PFAPR_M1AP. */
#define BM_FMC_PFAPR_M1AP         (0x0000000CU)  /*!< Bit mask for FMC_PFAPR_M1AP. */
#define BS_FMC_PFAPR_M1AP         (2U)  /*!< Bitfield size in bits for FMC_PFAPR_M1AP. */

/*! @brief Read current value of the FMC_PFAPR_M1AP field. */
#define BR_FMC_PFAPR_M1AP(x)   (HW_FMC_PFAPR(x).B.M1AP)

/*! @brief Format value for bitfield FMC_PFAPR_M1AP. */
#define BF_FMC_PFAPR_M1AP(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_PFAPR_M1AP) & BM_FMC_PFAPR_M1AP)

/*! @brief Set the M1AP field to a new value. */
#define BW_FMC_PFAPR_M1AP(x, v)   (HW_FMC_PFAPR_WR(x, (HW_FMC_PFAPR_RD(x) & ~BM_FMC_PFAPR_M1AP) | BF_FMC_PFAPR_M1AP(v)))
/*@}*/

/*!
 * @name Register FMC_PFAPR, field M2AP[5:4] (RW)
 *
 * This field controls whether read and write access to the flash are allowed based on the logical
 * master number of the requesting crossbar switch master.
 *
 * Values:
 * - 00 - No access may be performed by this master
 * - 01 - Only read accesses may be performed by this master
 * - 10 - Only write accesses may be performed by this master
 * - 11 - Both read and write accesses may be performed by this master
 */
/*@{*/
#define BP_FMC_PFAPR_M2AP         (4U)      /*!< Bit position for FMC_PFAPR_M2AP. */
#define BM_FMC_PFAPR_M2AP         (0x00000030U)  /*!< Bit mask for FMC_PFAPR_M2AP. */
#define BS_FMC_PFAPR_M2AP         (2U)  /*!< Bitfield size in bits for FMC_PFAPR_M2AP. */

/*! @brief Read current value of the FMC_PFAPR_M2AP field. */
#define BR_FMC_PFAPR_M2AP(x)   (HW_FMC_PFAPR(x).B.M2AP)

/*! @brief Format value for bitfield FMC_PFAPR_M2AP. */
#define BF_FMC_PFAPR_M2AP(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_PFAPR_M2AP) & BM_FMC_PFAPR_M2AP)

/*! @brief Set the M2AP field to a new value. */
#define BW_FMC_PFAPR_M2AP(x, v)   (HW_FMC_PFAPR_WR(x, (HW_FMC_PFAPR_RD(x) & ~BM_FMC_PFAPR_M2AP) | BF_FMC_PFAPR_M2AP(v)))
/*@}*/

/*!
 * @name Register FMC_PFAPR, field M3AP[7:6] (RW)
 *
 * This field controls whether read and write access to the flash are allowed based on the logical
 * master number of the requesting crossbar switch master.
 *
 * Values:
 * - 00 - No access may be performed by this master
 * - 01 - Only read accesses may be performed by this master
 * - 10 - Only write accesses may be performed by this master
 * - 11 - Both read and write accesses may be performed by this master
 */
/*@{*/
#define BP_FMC_PFAPR_M3AP         (6U)      /*!< Bit position for FMC_PFAPR_M3AP. */
#define BM_FMC_PFAPR_M3AP         (0x000000C0U)  /*!< Bit mask for FMC_PFAPR_M3AP. */
#define BS_FMC_PFAPR_M3AP         (2U)  /*!< Bitfield size in bits for FMC_PFAPR_M3AP. */

/*! @brief Read current value of the FMC_PFAPR_M3AP field. */
#define BR_FMC_PFAPR_M3AP(x)   (HW_FMC_PFAPR(x).B.M3AP)

/*! @brief Format value for bitfield FMC_PFAPR_M3AP. */
#define BF_FMC_PFAPR_M3AP(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_PFAPR_M3AP) & BM_FMC_PFAPR_M3AP)

/*! @brief Set the M3AP field to a new value. */
#define BW_FMC_PFAPR_M3AP(x, v)   (HW_FMC_PFAPR_WR(x, (HW_FMC_PFAPR_RD(x) & ~BM_FMC_PFAPR_M3AP) | BF_FMC_PFAPR_M3AP(v)))
/*@}*/

/*!
 * @name Register FMC_PFAPR, field M0PFD[16] (RW)
 *
 * These bits control whether prefetching is enabled based on the logical number of the requesting
 * crossbar switch master. This field is further qualified by the PFBnCR[BxDPE,BxIPE] bits.
 *
 * Values:
 * - 0 - Prefetching for this master is enabled.
 * - 1 - Prefetching for this master is disabled.
 */
/*@{*/
#define BP_FMC_PFAPR_M0PFD         (16U)      /*!< Bit position for FMC_PFAPR_M0PFD. */
#define BM_FMC_PFAPR_M0PFD         (0x00010000U)  /*!< Bit mask for FMC_PFAPR_M0PFD. */
#define BS_FMC_PFAPR_M0PFD         (1U)  /*!< Bitfield size in bits for FMC_PFAPR_M0PFD. */

/*! @brief Read current value of the FMC_PFAPR_M0PFD field. */
#define BR_FMC_PFAPR_M0PFD(x)   (HW_FMC_PFAPR(x).B.M0PFD)

/*! @brief Format value for bitfield FMC_PFAPR_M0PFD. */
#define BF_FMC_PFAPR_M0PFD(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_PFAPR_M0PFD) & BM_FMC_PFAPR_M0PFD)

/*! @brief Set the M0PFD field to a new value. */
#define BW_FMC_PFAPR_M0PFD(x, v)   (HW_FMC_PFAPR_WR(x, (HW_FMC_PFAPR_RD(x) & ~BM_FMC_PFAPR_M0PFD) | BF_FMC_PFAPR_M0PFD(v)))
/*@}*/

/*!
 * @name Register FMC_PFAPR, field M1PFD[17] (RW)
 *
 * These bits control whether prefetching is enabled based on the logical number of the requesting
 * crossbar switch master. This field is further qualified by the PFBnCR[BxDPE,BxIPE] bits.
 *
 * Values:
 * - 0 - Prefetching for this master is enabled.
 * - 1 - Prefetching for this master is disabled.
 */
/*@{*/
#define BP_FMC_PFAPR_M1PFD         (17U)      /*!< Bit position for FMC_PFAPR_M1PFD. */
#define BM_FMC_PFAPR_M1PFD         (0x00020000U)  /*!< Bit mask for FMC_PFAPR_M1PFD. */
#define BS_FMC_PFAPR_M1PFD         (1U)  /*!< Bitfield size in bits for FMC_PFAPR_M1PFD. */

/*! @brief Read current value of the FMC_PFAPR_M1PFD field. */
#define BR_FMC_PFAPR_M1PFD(x)   (HW_FMC_PFAPR(x).B.M1PFD)

/*! @brief Format value for bitfield FMC_PFAPR_M1PFD. */
#define BF_FMC_PFAPR_M1PFD(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_PFAPR_M1PFD) & BM_FMC_PFAPR_M1PFD)

/*! @brief Set the M1PFD field to a new value. */
#define BW_FMC_PFAPR_M1PFD(x, v)   (HW_FMC_PFAPR_WR(x, (HW_FMC_PFAPR_RD(x) & ~BM_FMC_PFAPR_M1PFD) | BF_FMC_PFAPR_M1PFD(v)))
/*@}*/

/*!
 * @name Register FMC_PFAPR, field M2PFD[18] (RW)
 *
 * These bits control whether prefetching is enabled based on the logical number of the requesting
 * crossbar switch master. This field is further qualified by the PFBnCR[BxDPE,BxIPE] bits.
 *
 * Values:
 * - 0 - Prefetching for this master is enabled.
 * - 1 - Prefetching for this master is disabled.
 */
/*@{*/
#define BP_FMC_PFAPR_M2PFD         (18U)      /*!< Bit position for FMC_PFAPR_M2PFD. */
#define BM_FMC_PFAPR_M2PFD         (0x00040000U)  /*!< Bit mask for FMC_PFAPR_M2PFD. */
#define BS_FMC_PFAPR_M2PFD         (1U)  /*!< Bitfield size in bits for FMC_PFAPR_M2PFD. */

/*! @brief Read current value of the FMC_PFAPR_M2PFD field. */
#define BR_FMC_PFAPR_M2PFD(x)   (HW_FMC_PFAPR(x).B.M2PFD)

/*! @brief Format value for bitfield FMC_PFAPR_M2PFD. */
#define BF_FMC_PFAPR_M2PFD(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_PFAPR_M2PFD) & BM_FMC_PFAPR_M2PFD)

/*! @brief Set the M2PFD field to a new value. */
#define BW_FMC_PFAPR_M2PFD(x, v)   (HW_FMC_PFAPR_WR(x, (HW_FMC_PFAPR_RD(x) & ~BM_FMC_PFAPR_M2PFD) | BF_FMC_PFAPR_M2PFD(v)))
/*@}*/

/*!
 * @name Register FMC_PFAPR, field M3PFD[19] (RW)
 *
 * These bits control whether prefetching is enabled based on the logical number of the requesting
 * crossbar switch master. This field is further qualified by the PFBnCR[BxDPE,BxIPE] bits.
 *
 * Values:
 * - 0 - Prefetching for this master is enabled.
 * - 1 - Prefetching for this master is disabled.
 */
/*@{*/
#define BP_FMC_PFAPR_M3PFD         (19U)      /*!< Bit position for FMC_PFAPR_M3PFD. */
#define BM_FMC_PFAPR_M3PFD         (0x00080000U)  /*!< Bit mask for FMC_PFAPR_M3PFD. */
#define BS_FMC_PFAPR_M3PFD         (1U)  /*!< Bitfield size in bits for FMC_PFAPR_M3PFD. */

/*! @brief Read current value of the FMC_PFAPR_M3PFD field. */
#define BR_FMC_PFAPR_M3PFD(x)   (HW_FMC_PFAPR(x).B.M3PFD)

/*! @brief Format value for bitfield FMC_PFAPR_M3PFD. */
#define BF_FMC_PFAPR_M3PFD(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_PFAPR_M3PFD) & BM_FMC_PFAPR_M3PFD)

/*! @brief Set the M3PFD field to a new value. */
#define BW_FMC_PFAPR_M3PFD(x, v)   (HW_FMC_PFAPR_WR(x, (HW_FMC_PFAPR_RD(x) & ~BM_FMC_PFAPR_M3PFD) | BF_FMC_PFAPR_M3PFD(v)))
/*@}*/

/*******************************************************************************
 * HW_FMC_PFB0CR - Flash Bank 0 Control Register
 ******************************************************************************/

/*!
 * @brief HW_FMC_PFB0CR - Flash Bank 0 Control Register (RW)
 *
 * Reset value: 0x3004001FU
 */
typedef union _hw_fmc_pfb0cr
{
    uint32_t U;
    struct _hw_fmc_pfb0cr_bitfields
    {
        uint32_t B0SEBE : 1; /*!< [0] Bank 0 Single Entry Buffer Enable */
        uint32_t B0IPE : 1; /*!< [1] Bank 0 Instruction Prefetch Enable */
        uint32_t B0DPE : 1; /*!< [2] Bank 0 Data Prefetch Enable */
        uint32_t B0ICE : 1; /*!< [3] Bank 0 Instruction Cache Enable */
        uint32_t B0DCE : 1; /*!< [4] Bank 0 Data Cache Enable */
        uint32_t CRCb : 3; /*!< [7:5] Cache Replacement Control */
        uint32_t RESERVED0 : 9; /*!< [16:8] Reserved. */
        uint32_t B0MW : 2; /*!< [18:17] Bank 0 Memory Width */
        uint32_t S_B_INV : 1; /*!< [19] Invalidate Prefetch Speculation Buffer */
        uint32_t CINV_WAY : 4; /*!< [23:20] Cache Invalidate Way x */
        uint32_t CLCK_WAY : 4; /*!< [27:24] Cache Lock Way x */
        uint32_t B0RWSC : 4; /*!< [31:28] Bank 0 Read Wait State Control */
    } B;
} hw_fmc_pfb0cr_t;

/*!
 * @name Constants and macros for entire FMC_PFB0CR register
 */
/*@{*/
#define HW_FMC_PFB0CR_ADDR(x)        ((x) + 0x4U)
#define HW_FMC_PFB0CR(x)             (*(__IO hw_fmc_pfb0cr_t *) HW_FMC_PFB0CR_ADDR(x))
#define HW_FMC_PFB0CR_RD(x)          (HW_FMC_PFB0CR(x).U)
#define HW_FMC_PFB0CR_WR(x, v)       (HW_FMC_PFB0CR(x).U = (v))
#define HW_FMC_PFB0CR_SET(x, v)      (HW_FMC_PFB0CR_WR(x, HW_FMC_PFB0CR_RD(x) |  (v)))
#define HW_FMC_PFB0CR_CLR(x, v)      (HW_FMC_PFB0CR_WR(x, HW_FMC_PFB0CR_RD(x) & ~(v)))
#define HW_FMC_PFB0CR_TOG(x, v)      (HW_FMC_PFB0CR_WR(x, HW_FMC_PFB0CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_PFB0CR bitfields
 */

/*!
 * @name Register FMC_PFB0CR, field B0SEBE[0] (RW)
 *
 * This bit controls whether the single entry page buffer is enabled in response to flash read
 * accesses. A high-to-low transition of this enable forces the page buffer to be invalidated.
 *
 * Values:
 * - 0 - Single entry buffer is disabled.
 * - 1 - Single entry buffer is enabled.
 */
/*@{*/
#define BP_FMC_PFB0CR_B0SEBE         (0U)      /*!< Bit position for FMC_PFB0CR_B0SEBE. */
#define BM_FMC_PFB0CR_B0SEBE         (0x00000001U)  /*!< Bit mask for FMC_PFB0CR_B0SEBE. */
#define BS_FMC_PFB0CR_B0SEBE         (1U)  /*!< Bitfield size in bits for FMC_PFB0CR_B0SEBE. */

/*! @brief Read current value of the FMC_PFB0CR_B0SEBE field. */
#define BR_FMC_PFB0CR_B0SEBE(x)   (HW_FMC_PFB0CR(x).B.B0SEBE)

/*! @brief Format value for bitfield FMC_PFB0CR_B0SEBE. */
#define BF_FMC_PFB0CR_B0SEBE(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_PFB0CR_B0SEBE) & BM_FMC_PFB0CR_B0SEBE)

/*! @brief Set the B0SEBE field to a new value. */
#define BW_FMC_PFB0CR_B0SEBE(x, v)   (HW_FMC_PFB0CR_WR(x, (HW_FMC_PFB0CR_RD(x) & ~BM_FMC_PFB0CR_B0SEBE) | BF_FMC_PFB0CR_B0SEBE(v)))
/*@}*/

/*!
 * @name Register FMC_PFB0CR, field B0IPE[1] (RW)
 *
 * This bit controls whether prefetches (or speculative accesses) are initiated in response to
 * instruction fetches.
 *
 * Values:
 * - 0 - Do not prefetch in response to instruction fetches.
 * - 1 - Enable prefetches in response to instruction fetches.
 */
/*@{*/
#define BP_FMC_PFB0CR_B0IPE         (1U)      /*!< Bit position for FMC_PFB0CR_B0IPE. */
#define BM_FMC_PFB0CR_B0IPE         (0x00000002U)  /*!< Bit mask for FMC_PFB0CR_B0IPE. */
#define BS_FMC_PFB0CR_B0IPE         (1U)  /*!< Bitfield size in bits for FMC_PFB0CR_B0IPE. */

/*! @brief Read current value of the FMC_PFB0CR_B0IPE field. */
#define BR_FMC_PFB0CR_B0IPE(x)   (HW_FMC_PFB0CR(x).B.B0IPE)

/*! @brief Format value for bitfield FMC_PFB0CR_B0IPE. */
#define BF_FMC_PFB0CR_B0IPE(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_PFB0CR_B0IPE) & BM_FMC_PFB0CR_B0IPE)

/*! @brief Set the B0IPE field to a new value. */
#define BW_FMC_PFB0CR_B0IPE(x, v)   (HW_FMC_PFB0CR_WR(x, (HW_FMC_PFB0CR_RD(x) & ~BM_FMC_PFB0CR_B0IPE) | BF_FMC_PFB0CR_B0IPE(v)))
/*@}*/

/*!
 * @name Register FMC_PFB0CR, field B0DPE[2] (RW)
 *
 * This bit controls whether prefetches (or speculative accesses) are initiated in response to data
 * references.
 *
 * Values:
 * - 0 - Do not prefetch in response to data references.
 * - 1 - Enable prefetches in response to data references.
 */
/*@{*/
#define BP_FMC_PFB0CR_B0DPE         (2U)      /*!< Bit position for FMC_PFB0CR_B0DPE. */
#define BM_FMC_PFB0CR_B0DPE         (0x00000004U)  /*!< Bit mask for FMC_PFB0CR_B0DPE. */
#define BS_FMC_PFB0CR_B0DPE         (1U)  /*!< Bitfield size in bits for FMC_PFB0CR_B0DPE. */

/*! @brief Read current value of the FMC_PFB0CR_B0DPE field. */
#define BR_FMC_PFB0CR_B0DPE(x)   (HW_FMC_PFB0CR(x).B.B0DPE)

/*! @brief Format value for bitfield FMC_PFB0CR_B0DPE. */
#define BF_FMC_PFB0CR_B0DPE(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_PFB0CR_B0DPE) & BM_FMC_PFB0CR_B0DPE)

/*! @brief Set the B0DPE field to a new value. */
#define BW_FMC_PFB0CR_B0DPE(x, v)   (HW_FMC_PFB0CR_WR(x, (HW_FMC_PFB0CR_RD(x) & ~BM_FMC_PFB0CR_B0DPE) | BF_FMC_PFB0CR_B0DPE(v)))
/*@}*/

/*!
 * @name Register FMC_PFB0CR, field B0ICE[3] (RW)
 *
 * This bit controls whether instruction fetches are loaded into the cache.
 *
 * Values:
 * - 0 - Do not cache instruction fetches.
 * - 1 - Cache instruction fetches.
 */
/*@{*/
#define BP_FMC_PFB0CR_B0ICE         (3U)      /*!< Bit position for FMC_PFB0CR_B0ICE. */
#define BM_FMC_PFB0CR_B0ICE         (0x00000008U)  /*!< Bit mask for FMC_PFB0CR_B0ICE. */
#define BS_FMC_PFB0CR_B0ICE         (1U)  /*!< Bitfield size in bits for FMC_PFB0CR_B0ICE. */

/*! @brief Read current value of the FMC_PFB0CR_B0ICE field. */
#define BR_FMC_PFB0CR_B0ICE(x)   (HW_FMC_PFB0CR(x).B.B0ICE)

/*! @brief Format value for bitfield FMC_PFB0CR_B0ICE. */
#define BF_FMC_PFB0CR_B0ICE(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_PFB0CR_B0ICE) & BM_FMC_PFB0CR_B0ICE)

/*! @brief Set the B0ICE field to a new value. */
#define BW_FMC_PFB0CR_B0ICE(x, v)   (HW_FMC_PFB0CR_WR(x, (HW_FMC_PFB0CR_RD(x) & ~BM_FMC_PFB0CR_B0ICE) | BF_FMC_PFB0CR_B0ICE(v)))
/*@}*/

/*!
 * @name Register FMC_PFB0CR, field B0DCE[4] (RW)
 *
 * This bit controls whether data references are loaded into the cache.
 *
 * Values:
 * - 0 - Do not cache data references.
 * - 1 - Cache data references.
 */
/*@{*/
#define BP_FMC_PFB0CR_B0DCE         (4U)      /*!< Bit position for FMC_PFB0CR_B0DCE. */
#define BM_FMC_PFB0CR_B0DCE         (0x00000010U)  /*!< Bit mask for FMC_PFB0CR_B0DCE. */
#define BS_FMC_PFB0CR_B0DCE         (1U)  /*!< Bitfield size in bits for FMC_PFB0CR_B0DCE. */

/*! @brief Read current value of the FMC_PFB0CR_B0DCE field. */
#define BR_FMC_PFB0CR_B0DCE(x)   (HW_FMC_PFB0CR(x).B.B0DCE)

/*! @brief Format value for bitfield FMC_PFB0CR_B0DCE. */
#define BF_FMC_PFB0CR_B0DCE(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_PFB0CR_B0DCE) & BM_FMC_PFB0CR_B0DCE)

/*! @brief Set the B0DCE field to a new value. */
#define BW_FMC_PFB0CR_B0DCE(x, v)   (HW_FMC_PFB0CR_WR(x, (HW_FMC_PFB0CR_RD(x) & ~BM_FMC_PFB0CR_B0DCE) | BF_FMC_PFB0CR_B0DCE(v)))
/*@}*/

/*!
 * @name Register FMC_PFB0CR, field CRC[7:5] (RW)
 *
 * This 3-bit field defines the replacement algorithm for accesses that are cached.
 *
 * Values:
 * - 000 - LRU replacement algorithm per set across all four ways
 * - 001 - Reserved
 * - 010 - Independent LRU with ways [0-1] for ifetches, [2-3] for data
 * - 011 - Independent LRU with ways [0-2] for ifetches, [3] for data
 * - 1xx - Reserved
 */
/*@{*/
#define BP_FMC_PFB0CR_CRC         (5U)      /*!< Bit position for FMC_PFB0CR_CRC. */
#define BM_FMC_PFB0CR_CRC         (0x000000E0U)  /*!< Bit mask for FMC_PFB0CR_CRC. */
#define BS_FMC_PFB0CR_CRC         (3U)  /*!< Bitfield size in bits for FMC_PFB0CR_CRC. */

/*! @brief Read current value of the FMC_PFB0CR_CRC field. */
#define BR_FMC_PFB0CR_CRC(x)   (HW_FMC_PFB0CR(x).B.CRC)

/*! @brief Format value for bitfield FMC_PFB0CR_CRC. */
#define BF_FMC_PFB0CR_CRC(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_PFB0CR_CRC) & BM_FMC_PFB0CR_CRC)

/*! @brief Set the CRC field to a new value. */
#define BW_FMC_PFB0CR_CRC(x, v)   (HW_FMC_PFB0CR_WR(x, (HW_FMC_PFB0CR_RD(x) & ~BM_FMC_PFB0CR_CRC) | BF_FMC_PFB0CR_CRC(v)))
/*@}*/

/*!
 * @name Register FMC_PFB0CR, field B0MW[18:17] (RO)
 *
 * This read-only field defines the width of the bank 0 memory.
 *
 * Values:
 * - 00 - 32 bits
 * - 01 - 64 bits
 * - 10 - 128 bits
 * - 11 - Reserved
 */
/*@{*/
#define BP_FMC_PFB0CR_B0MW         (17U)      /*!< Bit position for FMC_PFB0CR_B0MW. */
#define BM_FMC_PFB0CR_B0MW         (0x00060000U)  /*!< Bit mask for FMC_PFB0CR_B0MW. */
#define BS_FMC_PFB0CR_B0MW         (2U)  /*!< Bitfield size in bits for FMC_PFB0CR_B0MW. */

/*! @brief Read current value of the FMC_PFB0CR_B0MW field. */
#define BR_FMC_PFB0CR_B0MW(x)   (HW_FMC_PFB0CR(x).B.B0MW)
/*@}*/

/*!
 * @name Register FMC_PFB0CR, field S_B_INV[19] (WORZ)
 *
 * This bit determines if the FMC's prefetch speculation buffer and the single entry page buffer are
 * to be invalidated (cleared). When this bit is written, the speculation buffer and single entry
 * buffer are immediately cleared. This bit always reads as zero.
 *
 * Values:
 * - 0 - Speculation buffer and single entry buffer are not affected.
 * - 1 - Invalidate (clear) speculation buffer and single entry buffer.
 */
/*@{*/
#define BP_FMC_PFB0CR_S_B_INV         (19U)      /*!< Bit position for FMC_PFB0CR_S_B_INV. */
#define BM_FMC_PFB0CR_S_B_INV         (0x00080000U)  /*!< Bit mask for FMC_PFB0CR_S_B_INV. */
#define BS_FMC_PFB0CR_S_B_INV         (1U)  /*!< Bitfield size in bits for FMC_PFB0CR_S_B_INV. */

/*! @brief Format value for bitfield FMC_PFB0CR_S_B_INV. */
#define BF_FMC_PFB0CR_S_B_INV(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_PFB0CR_S_B_INV) & BM_FMC_PFB0CR_S_B_INV)

/*! @brief Set the S_B_INV field to a new value. */
#define BW_FMC_PFB0CR_S_B_INV(x, v)   (HW_FMC_PFB0CR_WR(x, (HW_FMC_PFB0CR_RD(x) & ~BM_FMC_PFB0CR_S_B_INV) | BF_FMC_PFB0CR_S_B_INV(v)))
/*@}*/

/*!
 * @name Register FMC_PFB0CR, field CINV_WAY[23:20] (WORZ)
 *
 * These bits determine if the given cache way is to be invalidated (cleared). When a bit within
 * this field is written, the corresponding cache way is immediately invalidated: the way's tag,
 * data, and valid contents are cleared. This field always reads as zero. Cache invalidation takes
 * precedence over locking. The cache is invalidated by system reset. System software is required to
 * maintain memory coherency when any segment of the flash memory is programmed or erased.
 * Accordingly, cache invalidations must occur after a programming or erase event is completed and
 * before the new memory image is accessed. The bit setting definitions are for each bit in the
 * field.
 *
 * Values:
 * - 0 - No cache way invalidation for the corresponding cache
 * - 1 - Invalidate cache way for the corresponding cache: clear the tag, data, and vld bits of ways selected
 */
/*@{*/
#define BP_FMC_PFB0CR_CINV_WAY         (20U)      /*!< Bit position for FMC_PFB0CR_CINV_WAY. */
#define BM_FMC_PFB0CR_CINV_WAY         (0x00F00000U)  /*!< Bit mask for FMC_PFB0CR_CINV_WAY. */
#define BS_FMC_PFB0CR_CINV_WAY         (4U)  /*!< Bitfield size in bits for FMC_PFB0CR_CINV_WAY. */

/*! @brief Format value for bitfield FMC_PFB0CR_CINV_WAY. */
#define BF_FMC_PFB0CR_CINV_WAY(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_PFB0CR_CINV_WAY) & BM_FMC_PFB0CR_CINV_WAY)

/*! @brief Set the CINV_WAY field to a new value. */
#define BW_FMC_PFB0CR_CINV_WAY(x, v)   (HW_FMC_PFB0CR_WR(x, (HW_FMC_PFB0CR_RD(x) & ~BM_FMC_PFB0CR_CINV_WAY) | BF_FMC_PFB0CR_CINV_WAY(v)))
/*@}*/

/*!
 * @name Register FMC_PFB0CR, field CLCK_WAY[27:24] (RW)
 *
 * These bits determine if the given cache way is locked such that its contents will not be
 * displaced by future misses. The bit setting definitions are for each bit in the field.
 *
 * Values:
 * - 0 - Cache way is unlocked and may be displaced
 * - 1 - Cache way is locked and its contents are not displaced
 */
/*@{*/
#define BP_FMC_PFB0CR_CLCK_WAY         (24U)      /*!< Bit position for FMC_PFB0CR_CLCK_WAY. */
#define BM_FMC_PFB0CR_CLCK_WAY         (0x0F000000U)  /*!< Bit mask for FMC_PFB0CR_CLCK_WAY. */
#define BS_FMC_PFB0CR_CLCK_WAY         (4U)  /*!< Bitfield size in bits for FMC_PFB0CR_CLCK_WAY. */

/*! @brief Read current value of the FMC_PFB0CR_CLCK_WAY field. */
#define BR_FMC_PFB0CR_CLCK_WAY(x)   (HW_FMC_PFB0CR(x).B.CLCK_WAY)

/*! @brief Format value for bitfield FMC_PFB0CR_CLCK_WAY. */
#define BF_FMC_PFB0CR_CLCK_WAY(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_PFB0CR_CLCK_WAY) & BM_FMC_PFB0CR_CLCK_WAY)

/*! @brief Set the CLCK_WAY field to a new value. */
#define BW_FMC_PFB0CR_CLCK_WAY(x, v)   (HW_FMC_PFB0CR_WR(x, (HW_FMC_PFB0CR_RD(x) & ~BM_FMC_PFB0CR_CLCK_WAY) | BF_FMC_PFB0CR_CLCK_WAY(v)))
/*@}*/

/*!
 * @name Register FMC_PFB0CR, field B0RWSC[31:28] (RO)
 *
 * This read-only field defines the number of wait states required to access the bank 0 flash
 * memory. The relationship between the read access time of the flash array (expressed in system
 * clock cycles) and RWSC is defined as: Access time of flash array [system clocks] = RWSC + 1 The
 * FMC automatically calculates this value based on the ratio of the system clock speed to the flash
 * clock speed. For example, when this ratio is 4:1, the field's value is 3h.
 */
/*@{*/
#define BP_FMC_PFB0CR_B0RWSC         (28U)      /*!< Bit position for FMC_PFB0CR_B0RWSC. */
#define BM_FMC_PFB0CR_B0RWSC         (0xF0000000U)  /*!< Bit mask for FMC_PFB0CR_B0RWSC. */
#define BS_FMC_PFB0CR_B0RWSC         (4U)  /*!< Bitfield size in bits for FMC_PFB0CR_B0RWSC. */

/*! @brief Read current value of the FMC_PFB0CR_B0RWSC field. */
#define BR_FMC_PFB0CR_B0RWSC(x)   (HW_FMC_PFB0CR(x).B.B0RWSC)
/*@}*/

/*******************************************************************************
 * HW_FMC_PFB1CR - Flash Bank 1 Control Register
 ******************************************************************************/

/*!
 * @brief HW_FMC_PFB1CR - Flash Bank 1 Control Register (RW)
 *
 * Reset value: 0x30000000U
 *
 * Note! For this device, Flash Bank 1 Control register is not functional, because there is no flash
 * bank 1; there is only flash bank 0. However, this register address is reserved.
 */
typedef union _hw_fmc_pfb1cr
{
    uint32_t U;
    struct _hw_fmc_pfb1cr_bitfields
    {
        uint32_t RESERVED5 : 32; /*!< [31:0] Reserved. */
    } B;
} hw_fmc_pfb1cr_t;

/*!
 * @name Constants and macros for entire FMC_PFB1CR register
 */
/*@{*/
#define HW_FMC_PFB1CR_ADDR(x)        ((x) + 0x8U)
#define HW_FMC_PFB1CR(x)             (*(__IO hw_fmc_pfb1cr_t *) HW_FMC_PFB1CR_ADDR(x))
#define HW_FMC_PFB1CR_RD(x)          (HW_FMC_PFB1CR(x).U)
#define HW_FMC_PFB1CR_WR(x, v)       (HW_FMC_PFB1CR(x).U = (v))
#define HW_FMC_PFB1CR_SET(x, v)      (HW_FMC_PFB1CR_WR(x, HW_FMC_PFB1CR_RD(x) |  (v)))
#define HW_FMC_PFB1CR_CLR(x, v)      (HW_FMC_PFB1CR_WR(x, HW_FMC_PFB1CR_RD(x) & ~(v)))
#define HW_FMC_PFB1CR_TOG(x, v)      (HW_FMC_PFB1CR_WR(x, HW_FMC_PFB1CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_PFB1CR bitfields
 */

/*******************************************************************************
 * HW_FMC_TAGVDW0Sn - Cache Tag Storage
 ******************************************************************************/

/*!
 * @brief HW_FMC_TAGVDW0Sn - Cache Tag Storage (RW)
 *
 * Reset value: 0x00000000U
 *
 * The 128-entry cache is a 4-way, set-associative cache with 4 sets. The ways are numbered 0-3 and
 * the sets are numbered 0-3. In TAGVDWxSy, x denotes the way, and y denotes the set. This section
 * represents tag/vld information for all sets (n=0-3) in way 0.
 */
typedef union _hw_fmc_tagvdw0sn
{
    uint32_t U;
    struct _hw_fmc_tagvdw0sn_bitfields
    {
        uint32_t VALID : 1; /*!< [0] 1-bit valid for cache entry */
        uint32_t RESERVED0 : 5; /*!< [5:1]  */
        uint32_t CACHE_TAG : 14; /*!< [19:6] 14-bit tag for cache entry */
        uint32_t RESERVED1 : 12; /*!< [31:20]  */
    } B;
} hw_fmc_tagvdw0sn_t;

/*!
 * @name Constants and macros for entire FMC_TAGVDW0Sn register
 */
/*@{*/
/*! @brief Number of instances of the FMC_TAGVDW0Sn register. */
#define HW_FMC_TAGVDW0Sn_COUNT     (4U)

#define HW_FMC_TAGVDW0Sn_ADDR(x, n)     ((x) + 0x100U + (0x4U * (n)))
#define HW_FMC_TAGVDW0Sn(x, n)          (*(__IO hw_fmc_tagvdw0sn_t *) HW_FMC_TAGVDW0Sn_ADDR(x, n))
#define HW_FMC_TAGVDW0Sn_RD(x, n)       (HW_FMC_TAGVDW0Sn(x, n).U)
#define HW_FMC_TAGVDW0Sn_WR(x, n, v)    (HW_FMC_TAGVDW0Sn(x, n).U = (v))
#define HW_FMC_TAGVDW0Sn_SET(x, n, v)   (HW_FMC_TAGVDW0Sn_WR(x, n, HW_FMC_TAGVDW0Sn_RD(x, n) |  (v)))
#define HW_FMC_TAGVDW0Sn_CLR(x, n, v)   (HW_FMC_TAGVDW0Sn_WR(x, n, HW_FMC_TAGVDW0Sn_RD(x, n) & ~(v)))
#define HW_FMC_TAGVDW0Sn_TOG(x, n, v)   (HW_FMC_TAGVDW0Sn_WR(x, n, HW_FMC_TAGVDW0Sn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_TAGVDW0Sn bitfields
 */

/*!
 * @name Register FMC_TAGVDW0Sn, field VALID[0] (RW)
 */
/*@{*/
#define BP_FMC_TAGVDW0Sn_VALID         (0U)      /*!< Bit position for FMC_TAGVDW0Sn_VALID. */
#define BM_FMC_TAGVDW0Sn_VALID         (0x00000001U)  /*!< Bit mask for FMC_TAGVDW0Sn_VALID. */
#define BS_FMC_TAGVDW0Sn_VALID         (1U)  /*!< Bitfield size in bits for FMC_TAGVDW0Sn_VALID. */

/*! @brief Read current value of the FMC_TAGVDW0Sn_VALID field. */
#define BR_FMC_TAGVDW0Sn_VALID(x, n)   (HW_FMC_TAGVDW0Sn(x, n).B.VALID)

/*! @brief Format value for bitfield FMC_TAGVDW0Sn_VALID. */
#define BF_FMC_TAGVDW0Sn_VALID(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_TAGVDW0Sn_VALID) & BM_FMC_TAGVDW0Sn_VALID)

/*! @brief Set the VALID field to a new value. */
#define BW_FMC_TAGVDW0Sn_VALID(x, n, v)   (HW_FMC_TAGVDW0Sn_WR(x, n, (HW_FMC_TAGVDW0Sn_RD(x, n) & ~BM_FMC_TAGVDW0Sn_VALID) | BF_FMC_TAGVDW0Sn_VALID(v)))
/*@}*/

/*!
 * @name Register FMC_TAGVDW0Sn, field CACHE_TAG[19:6] (RW)
 */
/*@{*/
#define BP_FMC_TAGVDW0Sn_CACHE_TAG         (6U)      /*!< Bit position for FMC_TAGVDW0Sn_CACHE_TAG. */
#define BM_FMC_TAGVDW0Sn_CACHE_TAG         (0x000FFFC0U)  /*!< Bit mask for FMC_TAGVDW0Sn_CACHE_TAG. */
#define BS_FMC_TAGVDW0Sn_CACHE_TAG         (14U)  /*!< Bitfield size in bits for FMC_TAGVDW0Sn_CACHE_TAG. */

/*! @brief Read current value of the FMC_TAGVDW0Sn_CACHE_TAG field. */
#define BR_FMC_TAGVDW0Sn_CACHE_TAG(x, n)   (HW_FMC_TAGVDW0Sn(x, n).B.CACHE_TAG)

/*! @brief Format value for bitfield FMC_TAGVDW0Sn_CACHE_TAG. */
#define BF_FMC_TAGVDW0Sn_CACHE_TAG(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_TAGVDW0Sn_CACHE_TAG) & BM_FMC_TAGVDW0Sn_CACHE_TAG)

/*! @brief Set the CACHE_TAG field to a new value. */
#define BW_FMC_TAGVDW0Sn_CACHE_TAG(x, n, v)   (HW_FMC_TAGVDW0Sn_WR(x, n, (HW_FMC_TAGVDW0Sn_RD(x, n) & ~BM_FMC_TAGVDW0Sn_CACHE_TAG) | BF_FMC_TAGVDW0Sn_CACHE_TAG(v)))
/*@}*/

/*******************************************************************************
 * HW_FMC_TAGVDW1Sn - Cache Tag Storage
 ******************************************************************************/

/*!
 * @brief HW_FMC_TAGVDW1Sn - Cache Tag Storage (RW)
 *
 * Reset value: 0x00000000U
 *
 * The 128-entry cache is a 4-way, set-associative cache with 4 sets. The ways are numbered 0-3 and
 * the sets are numbered 0-3. In TAGVDWxSy, x denotes the way, and y denotes the set. This section
 * represents tag/vld information for all sets (n=0-3) in way 1.
 */
typedef union _hw_fmc_tagvdw1sn
{
    uint32_t U;
    struct _hw_fmc_tagvdw1sn_bitfields
    {
        uint32_t VALID : 1; /*!< [0] 1-bit valid for cache entry */
        uint32_t RESERVED0 : 5; /*!< [5:1]  */
        uint32_t CACHE_TAG : 14; /*!< [19:6] 14-bit tag for cache entry */
        uint32_t RESERVED1 : 12; /*!< [31:20]  */
    } B;
} hw_fmc_tagvdw1sn_t;

/*!
 * @name Constants and macros for entire FMC_TAGVDW1Sn register
 */
/*@{*/
/*! @brief Number of instances of the FMC_TAGVDW1Sn register. */
#define HW_FMC_TAGVDW1Sn_COUNT     (4U)

#define HW_FMC_TAGVDW1Sn_ADDR(x, n)     ((x) + 0x110U + (0x4U * (n)))
#define HW_FMC_TAGVDW1Sn(x, n)          (*(__IO hw_fmc_tagvdw1sn_t *) HW_FMC_TAGVDW1Sn_ADDR(x, n))
#define HW_FMC_TAGVDW1Sn_RD(x, n)       (HW_FMC_TAGVDW1Sn(x, n).U)
#define HW_FMC_TAGVDW1Sn_WR(x, n, v)    (HW_FMC_TAGVDW1Sn(x, n).U = (v))
#define HW_FMC_TAGVDW1Sn_SET(x, n, v)   (HW_FMC_TAGVDW1Sn_WR(x, n, HW_FMC_TAGVDW1Sn_RD(x, n) |  (v)))
#define HW_FMC_TAGVDW1Sn_CLR(x, n, v)   (HW_FMC_TAGVDW1Sn_WR(x, n, HW_FMC_TAGVDW1Sn_RD(x, n) & ~(v)))
#define HW_FMC_TAGVDW1Sn_TOG(x, n, v)   (HW_FMC_TAGVDW1Sn_WR(x, n, HW_FMC_TAGVDW1Sn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_TAGVDW1Sn bitfields
 */

/*!
 * @name Register FMC_TAGVDW1Sn, field VALID[0] (RW)
 */
/*@{*/
#define BP_FMC_TAGVDW1Sn_VALID         (0U)      /*!< Bit position for FMC_TAGVDW1Sn_VALID. */
#define BM_FMC_TAGVDW1Sn_VALID         (0x00000001U)  /*!< Bit mask for FMC_TAGVDW1Sn_VALID. */
#define BS_FMC_TAGVDW1Sn_VALID         (1U)  /*!< Bitfield size in bits for FMC_TAGVDW1Sn_VALID. */

/*! @brief Read current value of the FMC_TAGVDW1Sn_VALID field. */
#define BR_FMC_TAGVDW1Sn_VALID(x, n)   (HW_FMC_TAGVDW1Sn(x, n).B.VALID)

/*! @brief Format value for bitfield FMC_TAGVDW1Sn_VALID. */
#define BF_FMC_TAGVDW1Sn_VALID(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_TAGVDW1Sn_VALID) & BM_FMC_TAGVDW1Sn_VALID)

/*! @brief Set the VALID field to a new value. */
#define BW_FMC_TAGVDW1Sn_VALID(x, n, v)   (HW_FMC_TAGVDW1Sn_WR(x, n, (HW_FMC_TAGVDW1Sn_RD(x, n) & ~BM_FMC_TAGVDW1Sn_VALID) | BF_FMC_TAGVDW1Sn_VALID(v)))
/*@}*/

/*!
 * @name Register FMC_TAGVDW1Sn, field CACHE_TAG[19:6] (RW)
 */
/*@{*/
#define BP_FMC_TAGVDW1Sn_CACHE_TAG         (6U)      /*!< Bit position for FMC_TAGVDW1Sn_CACHE_TAG. */
#define BM_FMC_TAGVDW1Sn_CACHE_TAG         (0x000FFFC0U)  /*!< Bit mask for FMC_TAGVDW1Sn_CACHE_TAG. */
#define BS_FMC_TAGVDW1Sn_CACHE_TAG         (14U)  /*!< Bitfield size in bits for FMC_TAGVDW1Sn_CACHE_TAG. */

/*! @brief Read current value of the FMC_TAGVDW1Sn_CACHE_TAG field. */
#define BR_FMC_TAGVDW1Sn_CACHE_TAG(x, n)   (HW_FMC_TAGVDW1Sn(x, n).B.CACHE_TAG)

/*! @brief Format value for bitfield FMC_TAGVDW1Sn_CACHE_TAG. */
#define BF_FMC_TAGVDW1Sn_CACHE_TAG(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_TAGVDW1Sn_CACHE_TAG) & BM_FMC_TAGVDW1Sn_CACHE_TAG)

/*! @brief Set the CACHE_TAG field to a new value. */
#define BW_FMC_TAGVDW1Sn_CACHE_TAG(x, n, v)   (HW_FMC_TAGVDW1Sn_WR(x, n, (HW_FMC_TAGVDW1Sn_RD(x, n) & ~BM_FMC_TAGVDW1Sn_CACHE_TAG) | BF_FMC_TAGVDW1Sn_CACHE_TAG(v)))
/*@}*/

/*******************************************************************************
 * HW_FMC_TAGVDW2Sn - Cache Tag Storage
 ******************************************************************************/

/*!
 * @brief HW_FMC_TAGVDW2Sn - Cache Tag Storage (RW)
 *
 * Reset value: 0x00000000U
 *
 * The 128-entry cache is a 4-way, set-associative cache with 4 sets. The ways are numbered 0-3 and
 * the sets are numbered 0-3. In TAGVDWxSy, x denotes the way, and y denotes the set. This section
 * represents tag/vld information for all sets (n=0-3) in way 2.
 */
typedef union _hw_fmc_tagvdw2sn
{
    uint32_t U;
    struct _hw_fmc_tagvdw2sn_bitfields
    {
        uint32_t VALID : 1; /*!< [0] 1-bit valid for cache entry */
        uint32_t RESERVED0 : 5; /*!< [5:1]  */
        uint32_t CACHE_TAG : 14; /*!< [19:6] 14-bit tag for cache entry */
        uint32_t RESERVED1 : 12; /*!< [31:20]  */
    } B;
} hw_fmc_tagvdw2sn_t;

/*!
 * @name Constants and macros for entire FMC_TAGVDW2Sn register
 */
/*@{*/
/*! @brief Number of instances of the FMC_TAGVDW2Sn register. */
#define HW_FMC_TAGVDW2Sn_COUNT     (4U)

#define HW_FMC_TAGVDW2Sn_ADDR(x, n)     ((x) + 0x120U + (0x4U * (n)))
#define HW_FMC_TAGVDW2Sn(x, n)          (*(__IO hw_fmc_tagvdw2sn_t *) HW_FMC_TAGVDW2Sn_ADDR(x, n))
#define HW_FMC_TAGVDW2Sn_RD(x, n)       (HW_FMC_TAGVDW2Sn(x, n).U)
#define HW_FMC_TAGVDW2Sn_WR(x, n, v)    (HW_FMC_TAGVDW2Sn(x, n).U = (v))
#define HW_FMC_TAGVDW2Sn_SET(x, n, v)   (HW_FMC_TAGVDW2Sn_WR(x, n, HW_FMC_TAGVDW2Sn_RD(x, n) |  (v)))
#define HW_FMC_TAGVDW2Sn_CLR(x, n, v)   (HW_FMC_TAGVDW2Sn_WR(x, n, HW_FMC_TAGVDW2Sn_RD(x, n) & ~(v)))
#define HW_FMC_TAGVDW2Sn_TOG(x, n, v)   (HW_FMC_TAGVDW2Sn_WR(x, n, HW_FMC_TAGVDW2Sn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_TAGVDW2Sn bitfields
 */

/*!
 * @name Register FMC_TAGVDW2Sn, field VALID[0] (RW)
 */
/*@{*/
#define BP_FMC_TAGVDW2Sn_VALID         (0U)      /*!< Bit position for FMC_TAGVDW2Sn_VALID. */
#define BM_FMC_TAGVDW2Sn_VALID         (0x00000001U)  /*!< Bit mask for FMC_TAGVDW2Sn_VALID. */
#define BS_FMC_TAGVDW2Sn_VALID         (1U)  /*!< Bitfield size in bits for FMC_TAGVDW2Sn_VALID. */

/*! @brief Read current value of the FMC_TAGVDW2Sn_VALID field. */
#define BR_FMC_TAGVDW2Sn_VALID(x, n)   (HW_FMC_TAGVDW2Sn(x, n).B.VALID)

/*! @brief Format value for bitfield FMC_TAGVDW2Sn_VALID. */
#define BF_FMC_TAGVDW2Sn_VALID(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_TAGVDW2Sn_VALID) & BM_FMC_TAGVDW2Sn_VALID)

/*! @brief Set the VALID field to a new value. */
#define BW_FMC_TAGVDW2Sn_VALID(x, n, v)   (HW_FMC_TAGVDW2Sn_WR(x, n, (HW_FMC_TAGVDW2Sn_RD(x, n) & ~BM_FMC_TAGVDW2Sn_VALID) | BF_FMC_TAGVDW2Sn_VALID(v)))
/*@}*/

/*!
 * @name Register FMC_TAGVDW2Sn, field CACHE_TAG[19:6] (RW)
 */
/*@{*/
#define BP_FMC_TAGVDW2Sn_CACHE_TAG         (6U)      /*!< Bit position for FMC_TAGVDW2Sn_CACHE_TAG. */
#define BM_FMC_TAGVDW2Sn_CACHE_TAG         (0x000FFFC0U)  /*!< Bit mask for FMC_TAGVDW2Sn_CACHE_TAG. */
#define BS_FMC_TAGVDW2Sn_CACHE_TAG         (14U)  /*!< Bitfield size in bits for FMC_TAGVDW2Sn_CACHE_TAG. */

/*! @brief Read current value of the FMC_TAGVDW2Sn_CACHE_TAG field. */
#define BR_FMC_TAGVDW2Sn_CACHE_TAG(x, n)   (HW_FMC_TAGVDW2Sn(x, n).B.CACHE_TAG)

/*! @brief Format value for bitfield FMC_TAGVDW2Sn_CACHE_TAG. */
#define BF_FMC_TAGVDW2Sn_CACHE_TAG(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_TAGVDW2Sn_CACHE_TAG) & BM_FMC_TAGVDW2Sn_CACHE_TAG)

/*! @brief Set the CACHE_TAG field to a new value. */
#define BW_FMC_TAGVDW2Sn_CACHE_TAG(x, n, v)   (HW_FMC_TAGVDW2Sn_WR(x, n, (HW_FMC_TAGVDW2Sn_RD(x, n) & ~BM_FMC_TAGVDW2Sn_CACHE_TAG) | BF_FMC_TAGVDW2Sn_CACHE_TAG(v)))
/*@}*/

/*******************************************************************************
 * HW_FMC_TAGVDW3Sn - Cache Tag Storage
 ******************************************************************************/

/*!
 * @brief HW_FMC_TAGVDW3Sn - Cache Tag Storage (RW)
 *
 * Reset value: 0x00000000U
 *
 * The 128-entry cache is a 4-way, set-associative cache with 4 sets. The ways are numbered 0-3 and
 * the sets are numbered 0-3. In TAGVDWxSy, x denotes the way, and y denotes the set. This section
 * represents tag/vld information for all sets (n=0-3) in way 3.
 */
typedef union _hw_fmc_tagvdw3sn
{
    uint32_t U;
    struct _hw_fmc_tagvdw3sn_bitfields
    {
        uint32_t VALID : 1; /*!< [0] 1-bit valid for cache entry */
        uint32_t RESERVED0 : 5; /*!< [5:1]  */
        uint32_t CACHE_TAG : 14; /*!< [19:6] 14-bit tag for cache entry */
        uint32_t RESERVED1 : 12; /*!< [31:20]  */
    } B;
} hw_fmc_tagvdw3sn_t;

/*!
 * @name Constants and macros for entire FMC_TAGVDW3Sn register
 */
/*@{*/
/*! @brief Number of instances of the FMC_TAGVDW3Sn register. */
#define HW_FMC_TAGVDW3Sn_COUNT     (4U)

#define HW_FMC_TAGVDW3Sn_ADDR(x, n)     ((x) + 0x130U + (0x4U * (n)))
#define HW_FMC_TAGVDW3Sn(x, n)          (*(__IO hw_fmc_tagvdw3sn_t *) HW_FMC_TAGVDW3Sn_ADDR(x, n))
#define HW_FMC_TAGVDW3Sn_RD(x, n)       (HW_FMC_TAGVDW3Sn(x, n).U)
#define HW_FMC_TAGVDW3Sn_WR(x, n, v)    (HW_FMC_TAGVDW3Sn(x, n).U = (v))
#define HW_FMC_TAGVDW3Sn_SET(x, n, v)   (HW_FMC_TAGVDW3Sn_WR(x, n, HW_FMC_TAGVDW3Sn_RD(x, n) |  (v)))
#define HW_FMC_TAGVDW3Sn_CLR(x, n, v)   (HW_FMC_TAGVDW3Sn_WR(x, n, HW_FMC_TAGVDW3Sn_RD(x, n) & ~(v)))
#define HW_FMC_TAGVDW3Sn_TOG(x, n, v)   (HW_FMC_TAGVDW3Sn_WR(x, n, HW_FMC_TAGVDW3Sn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_TAGVDW3Sn bitfields
 */

/*!
 * @name Register FMC_TAGVDW3Sn, field VALID[0] (RW)
 */
/*@{*/
#define BP_FMC_TAGVDW3Sn_VALID         (0U)      /*!< Bit position for FMC_TAGVDW3Sn_VALID. */
#define BM_FMC_TAGVDW3Sn_VALID         (0x00000001U)  /*!< Bit mask for FMC_TAGVDW3Sn_VALID. */
#define BS_FMC_TAGVDW3Sn_VALID         (1U)  /*!< Bitfield size in bits for FMC_TAGVDW3Sn_VALID. */

/*! @brief Read current value of the FMC_TAGVDW3Sn_VALID field. */
#define BR_FMC_TAGVDW3Sn_VALID(x, n)   (HW_FMC_TAGVDW3Sn(x, n).B.VALID)

/*! @brief Format value for bitfield FMC_TAGVDW3Sn_VALID. */
#define BF_FMC_TAGVDW3Sn_VALID(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_TAGVDW3Sn_VALID) & BM_FMC_TAGVDW3Sn_VALID)

/*! @brief Set the VALID field to a new value. */
#define BW_FMC_TAGVDW3Sn_VALID(x, n, v)   (HW_FMC_TAGVDW3Sn_WR(x, n, (HW_FMC_TAGVDW3Sn_RD(x, n) & ~BM_FMC_TAGVDW3Sn_VALID) | BF_FMC_TAGVDW3Sn_VALID(v)))
/*@}*/

/*!
 * @name Register FMC_TAGVDW3Sn, field CACHE_TAG[19:6] (RW)
 */
/*@{*/
#define BP_FMC_TAGVDW3Sn_CACHE_TAG         (6U)      /*!< Bit position for FMC_TAGVDW3Sn_CACHE_TAG. */
#define BM_FMC_TAGVDW3Sn_CACHE_TAG         (0x000FFFC0U)  /*!< Bit mask for FMC_TAGVDW3Sn_CACHE_TAG. */
#define BS_FMC_TAGVDW3Sn_CACHE_TAG         (14U)  /*!< Bitfield size in bits for FMC_TAGVDW3Sn_CACHE_TAG. */

/*! @brief Read current value of the FMC_TAGVDW3Sn_CACHE_TAG field. */
#define BR_FMC_TAGVDW3Sn_CACHE_TAG(x, n)   (HW_FMC_TAGVDW3Sn(x, n).B.CACHE_TAG)

/*! @brief Format value for bitfield FMC_TAGVDW3Sn_CACHE_TAG. */
#define BF_FMC_TAGVDW3Sn_CACHE_TAG(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_TAGVDW3Sn_CACHE_TAG) & BM_FMC_TAGVDW3Sn_CACHE_TAG)

/*! @brief Set the CACHE_TAG field to a new value. */
#define BW_FMC_TAGVDW3Sn_CACHE_TAG(x, n, v)   (HW_FMC_TAGVDW3Sn_WR(x, n, (HW_FMC_TAGVDW3Sn_RD(x, n) & ~BM_FMC_TAGVDW3Sn_CACHE_TAG) | BF_FMC_TAGVDW3Sn_CACHE_TAG(v)))
/*@}*/

/*******************************************************************************
 * HW_FMC_DATAW0SnUM - Cache Data Storage (uppermost word)
 ******************************************************************************/

/*!
 * @brief HW_FMC_DATAW0SnUM - Cache Data Storage (uppermost word) (RW)
 *
 * Reset value: 0x00000000U
 *
 * The cache of sixteen 128-bit entries is a 4-way, set-associative cache with 4 sets. The ways are
 * numbered 0-3 and the sets are numbered 0-3. In DATAWxSyUM, DATAWxSyMU, DATAWxSyML, and
 * DATAWxSyLM, x denotes the way, y denotes the set, and the final two letters identify the word: UM
 * (uppermost), MU (mid-upper), ML (mid-lower), and LM (lowermost). This section represents data for
 * the uppermost word (bits [127:96]) of all 4 sets (n=0-3) in way 0.
 */
typedef union _hw_fmc_dataw0snum
{
    uint32_t U;
    struct _hw_fmc_dataw0snum_bitfields
    {
        uint32_t DATA : 32; /*!< [31:0] Bits [127:96] of data entry */
    } B;
} hw_fmc_dataw0snum_t;

/*!
 * @name Constants and macros for entire FMC_DATAW0SnUM register
 */
/*@{*/
/*! @brief Number of instances of the FMC_DATAW0SnUM register. */
#define HW_FMC_DATAW0SnUM_COUNT     (4U)

#define HW_FMC_DATAW0SnUM_ADDR(x, n)     ((x) + 0x200U + (0x10U * (n)))
#define HW_FMC_DATAW0SnUM(x, n)          (*(__IO hw_fmc_dataw0snum_t *) HW_FMC_DATAW0SnUM_ADDR(x, n))
#define HW_FMC_DATAW0SnUM_RD(x, n)       (HW_FMC_DATAW0SnUM(x, n).U)
#define HW_FMC_DATAW0SnUM_WR(x, n, v)    (HW_FMC_DATAW0SnUM(x, n).U = (v))
#define HW_FMC_DATAW0SnUM_SET(x, n, v)   (HW_FMC_DATAW0SnUM_WR(x, n, HW_FMC_DATAW0SnUM_RD(x, n) |  (v)))
#define HW_FMC_DATAW0SnUM_CLR(x, n, v)   (HW_FMC_DATAW0SnUM_WR(x, n, HW_FMC_DATAW0SnUM_RD(x, n) & ~(v)))
#define HW_FMC_DATAW0SnUM_TOG(x, n, v)   (HW_FMC_DATAW0SnUM_WR(x, n, HW_FMC_DATAW0SnUM_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_DATAW0SnUM bitfields
 */

/*!
 * @name Register FMC_DATAW0SnUM, field DATA[31:0] (RW)
 */
/*@{*/
#define BP_FMC_DATAW0SnUM_DATA         (0U)      /*!< Bit position for FMC_DATAW0SnUM_DATA. */
#define BM_FMC_DATAW0SnUM_DATA         (0xFFFFFFFFU)  /*!< Bit mask for FMC_DATAW0SnUM_DATA. */
#define BS_FMC_DATAW0SnUM_DATA         (32U)  /*!< Bitfield size in bits for FMC_DATAW0SnUM_DATA. */

/*! @brief Read current value of the FMC_DATAW0SnUM_DATA field. */
#define BR_FMC_DATAW0SnUM_DATA(x, n)      (HW_FMC_DATAW0SnUM(x, n).U)

/*! @brief Format value for bitfield FMC_DATAW0SnUM_DATA. */
#define BF_FMC_DATAW0SnUM_DATA(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_DATAW0SnUM_DATA) & BM_FMC_DATAW0SnUM_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_FMC_DATAW0SnUM_DATA(x, n, v)   (HW_FMC_DATAW0SnUM_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_FMC_DATAW0SnMU - Cache Data Storage (mid-upper word)
 ******************************************************************************/

/*!
 * @brief HW_FMC_DATAW0SnMU - Cache Data Storage (mid-upper word) (RW)
 *
 * Reset value: 0x00000000U
 *
 * The cache of sixteen 128-bit entries is a 4-way, set-associative cache with 4 sets. The ways are
 * numbered 0-3 and the sets are numbered 0-3. In DATAWxSyUM, DATAWxSyMU, DATAWxSyML, and
 * DATAWxSyLM, x denotes the way, y denotes the set, and the final two letters identify the word: UM
 * (uppermost), MU (mid-upper), ML (mid-lower), and LM (lowermost). This section represents data for
 * the mid-upper word (bits [95:64]) of all 4 sets (n=0-3) in way 0.
 */
typedef union _hw_fmc_dataw0snmu
{
    uint32_t U;
    struct _hw_fmc_dataw0snmu_bitfields
    {
        uint32_t DATA : 32; /*!< [31:0] Bits [95:64] of data entry */
    } B;
} hw_fmc_dataw0snmu_t;

/*!
 * @name Constants and macros for entire FMC_DATAW0SnMU register
 */
/*@{*/
/*! @brief Number of instances of the FMC_DATAW0SnMU register. */
#define HW_FMC_DATAW0SnMU_COUNT     (4U)

#define HW_FMC_DATAW0SnMU_ADDR(x, n)     ((x) + 0x204U + (0x10U * (n)))
#define HW_FMC_DATAW0SnMU(x, n)          (*(__IO hw_fmc_dataw0snmu_t *) HW_FMC_DATAW0SnMU_ADDR(x, n))
#define HW_FMC_DATAW0SnMU_RD(x, n)       (HW_FMC_DATAW0SnMU(x, n).U)
#define HW_FMC_DATAW0SnMU_WR(x, n, v)    (HW_FMC_DATAW0SnMU(x, n).U = (v))
#define HW_FMC_DATAW0SnMU_SET(x, n, v)   (HW_FMC_DATAW0SnMU_WR(x, n, HW_FMC_DATAW0SnMU_RD(x, n) |  (v)))
#define HW_FMC_DATAW0SnMU_CLR(x, n, v)   (HW_FMC_DATAW0SnMU_WR(x, n, HW_FMC_DATAW0SnMU_RD(x, n) & ~(v)))
#define HW_FMC_DATAW0SnMU_TOG(x, n, v)   (HW_FMC_DATAW0SnMU_WR(x, n, HW_FMC_DATAW0SnMU_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_DATAW0SnMU bitfields
 */

/*!
 * @name Register FMC_DATAW0SnMU, field DATA[31:0] (RW)
 */
/*@{*/
#define BP_FMC_DATAW0SnMU_DATA         (0U)      /*!< Bit position for FMC_DATAW0SnMU_DATA. */
#define BM_FMC_DATAW0SnMU_DATA         (0xFFFFFFFFU)  /*!< Bit mask for FMC_DATAW0SnMU_DATA. */
#define BS_FMC_DATAW0SnMU_DATA         (32U)  /*!< Bitfield size in bits for FMC_DATAW0SnMU_DATA. */

/*! @brief Read current value of the FMC_DATAW0SnMU_DATA field. */
#define BR_FMC_DATAW0SnMU_DATA(x, n)      (HW_FMC_DATAW0SnMU(x, n).U)

/*! @brief Format value for bitfield FMC_DATAW0SnMU_DATA. */
#define BF_FMC_DATAW0SnMU_DATA(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_DATAW0SnMU_DATA) & BM_FMC_DATAW0SnMU_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_FMC_DATAW0SnMU_DATA(x, n, v)   (HW_FMC_DATAW0SnMU_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_FMC_DATAW0SnML - Cache Data Storage (mid-lower word)
 ******************************************************************************/

/*!
 * @brief HW_FMC_DATAW0SnML - Cache Data Storage (mid-lower word) (RW)
 *
 * Reset value: 0x00000000U
 *
 * The cache of sixteen 128-bit entries is a 4-way, set-associative cache with 4 sets. The ways are
 * numbered 0-3 and the sets are numbered 0-3. In DATAWxSyUM, DATAWxSyMU, DATAWxSyML, and
 * DATAWxSyLM, x denotes the way, y denotes the set, and the final two letters identify the word: UM
 * (uppermost), MU (mid-upper), ML (mid-lower), and LM (lowermost). This section represents data for
 * the mid-lower word (bits [63:32]) of all 4 sets (n=0-3) in way 0.
 */
typedef union _hw_fmc_dataw0snml
{
    uint32_t U;
    struct _hw_fmc_dataw0snml_bitfields
    {
        uint32_t DATA : 32; /*!< [31:0] Bits [63:32] of data entry */
    } B;
} hw_fmc_dataw0snml_t;

/*!
 * @name Constants and macros for entire FMC_DATAW0SnML register
 */
/*@{*/
/*! @brief Number of instances of the FMC_DATAW0SnML register. */
#define HW_FMC_DATAW0SnML_COUNT     (4U)

#define HW_FMC_DATAW0SnML_ADDR(x, n)     ((x) + 0x208U + (0x10U * (n)))
#define HW_FMC_DATAW0SnML(x, n)          (*(__IO hw_fmc_dataw0snml_t *) HW_FMC_DATAW0SnML_ADDR(x, n))
#define HW_FMC_DATAW0SnML_RD(x, n)       (HW_FMC_DATAW0SnML(x, n).U)
#define HW_FMC_DATAW0SnML_WR(x, n, v)    (HW_FMC_DATAW0SnML(x, n).U = (v))
#define HW_FMC_DATAW0SnML_SET(x, n, v)   (HW_FMC_DATAW0SnML_WR(x, n, HW_FMC_DATAW0SnML_RD(x, n) |  (v)))
#define HW_FMC_DATAW0SnML_CLR(x, n, v)   (HW_FMC_DATAW0SnML_WR(x, n, HW_FMC_DATAW0SnML_RD(x, n) & ~(v)))
#define HW_FMC_DATAW0SnML_TOG(x, n, v)   (HW_FMC_DATAW0SnML_WR(x, n, HW_FMC_DATAW0SnML_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_DATAW0SnML bitfields
 */

/*!
 * @name Register FMC_DATAW0SnML, field DATA[31:0] (RW)
 */
/*@{*/
#define BP_FMC_DATAW0SnML_DATA         (0U)      /*!< Bit position for FMC_DATAW0SnML_DATA. */
#define BM_FMC_DATAW0SnML_DATA         (0xFFFFFFFFU)  /*!< Bit mask for FMC_DATAW0SnML_DATA. */
#define BS_FMC_DATAW0SnML_DATA         (32U)  /*!< Bitfield size in bits for FMC_DATAW0SnML_DATA. */

/*! @brief Read current value of the FMC_DATAW0SnML_DATA field. */
#define BR_FMC_DATAW0SnML_DATA(x, n)      (HW_FMC_DATAW0SnML(x, n).U)

/*! @brief Format value for bitfield FMC_DATAW0SnML_DATA. */
#define BF_FMC_DATAW0SnML_DATA(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_DATAW0SnML_DATA) & BM_FMC_DATAW0SnML_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_FMC_DATAW0SnML_DATA(x, n, v)   (HW_FMC_DATAW0SnML_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_FMC_DATAW0SnLM - Cache Data Storage (lowermost word)
 ******************************************************************************/

/*!
 * @brief HW_FMC_DATAW0SnLM - Cache Data Storage (lowermost word) (RW)
 *
 * Reset value: 0x00000000U
 *
 * The cache of sixteen 128-bit entries is a 4-way, set-associative cache with 4 sets. The ways are
 * numbered 0-3 and the sets are numbered 0-3. In DATAWxSyUM, DATAWxSyMU, DATAWxSyML, and
 * DATAWxSyLM, x denotes the way, y denotes the set, and the final two letters identify the word: UM
 * (uppermost), MU (mid-upper), ML (mid-lower), and LM (lowermost). This section represents data for
 * the lowermost word (bits [31:0]) of all 4 sets (n=0-3) in way 0.
 */
typedef union _hw_fmc_dataw0snlm
{
    uint32_t U;
    struct _hw_fmc_dataw0snlm_bitfields
    {
        uint32_t DATA : 32; /*!< [31:0] Bits [31:0] of data entry */
    } B;
} hw_fmc_dataw0snlm_t;

/*!
 * @name Constants and macros for entire FMC_DATAW0SnLM register
 */
/*@{*/
/*! @brief Number of instances of the FMC_DATAW0SnLM register. */
#define HW_FMC_DATAW0SnLM_COUNT     (4U)

#define HW_FMC_DATAW0SnLM_ADDR(x, n)     ((x) + 0x20CU + (0x10U * (n)))
#define HW_FMC_DATAW0SnLM(x, n)          (*(__IO hw_fmc_dataw0snlm_t *) HW_FMC_DATAW0SnLM_ADDR(x, n))
#define HW_FMC_DATAW0SnLM_RD(x, n)       (HW_FMC_DATAW0SnLM(x, n).U)
#define HW_FMC_DATAW0SnLM_WR(x, n, v)    (HW_FMC_DATAW0SnLM(x, n).U = (v))
#define HW_FMC_DATAW0SnLM_SET(x, n, v)   (HW_FMC_DATAW0SnLM_WR(x, n, HW_FMC_DATAW0SnLM_RD(x, n) |  (v)))
#define HW_FMC_DATAW0SnLM_CLR(x, n, v)   (HW_FMC_DATAW0SnLM_WR(x, n, HW_FMC_DATAW0SnLM_RD(x, n) & ~(v)))
#define HW_FMC_DATAW0SnLM_TOG(x, n, v)   (HW_FMC_DATAW0SnLM_WR(x, n, HW_FMC_DATAW0SnLM_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_DATAW0SnLM bitfields
 */

/*!
 * @name Register FMC_DATAW0SnLM, field DATA[31:0] (RW)
 */
/*@{*/
#define BP_FMC_DATAW0SnLM_DATA         (0U)      /*!< Bit position for FMC_DATAW0SnLM_DATA. */
#define BM_FMC_DATAW0SnLM_DATA         (0xFFFFFFFFU)  /*!< Bit mask for FMC_DATAW0SnLM_DATA. */
#define BS_FMC_DATAW0SnLM_DATA         (32U)  /*!< Bitfield size in bits for FMC_DATAW0SnLM_DATA. */

/*! @brief Read current value of the FMC_DATAW0SnLM_DATA field. */
#define BR_FMC_DATAW0SnLM_DATA(x, n)      (HW_FMC_DATAW0SnLM(x, n).U)

/*! @brief Format value for bitfield FMC_DATAW0SnLM_DATA. */
#define BF_FMC_DATAW0SnLM_DATA(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_DATAW0SnLM_DATA) & BM_FMC_DATAW0SnLM_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_FMC_DATAW0SnLM_DATA(x, n, v)   (HW_FMC_DATAW0SnLM_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_FMC_DATAW1SnUM - Cache Data Storage (uppermost word)
 ******************************************************************************/

/*!
 * @brief HW_FMC_DATAW1SnUM - Cache Data Storage (uppermost word) (RW)
 *
 * Reset value: 0x00000000U
 *
 * The cache of sixteen 128-bit entries is a 4-way, set-associative cache with 4 sets. The ways are
 * numbered 0-3 and the sets are numbered 0-3. In DATAWxSyUM, DATAWxSyMU, DATAWxSyML, and
 * DATAWxSyLM, x denotes the way, y denotes the set, and the final two letters identify the word: UM
 * (uppermost), MU (mid-upper), ML (mid-lower), and LM (lowermost). This section represents data for
 * the uppermost word (bits [127:96]) of all 4 sets (n=0-3) in way 0.
 */
typedef union _hw_fmc_dataw1snum
{
    uint32_t U;
    struct _hw_fmc_dataw1snum_bitfields
    {
        uint32_t DATA : 32; /*!< [31:0] Bits [127:96] of data entry */
    } B;
} hw_fmc_dataw1snum_t;

/*!
 * @name Constants and macros for entire FMC_DATAW1SnUM register
 */
/*@{*/
/*! @brief Number of instances of the FMC_DATAW1SnUM register. */
#define HW_FMC_DATAW1SnUM_COUNT     (4U)

#define HW_FMC_DATAW1SnUM_ADDR(x, n)     ((x) + 0x240U + (0x10U * (n)))
#define HW_FMC_DATAW1SnUM(x, n)          (*(__IO hw_fmc_dataw1snum_t *) HW_FMC_DATAW1SnUM_ADDR(x, n))
#define HW_FMC_DATAW1SnUM_RD(x, n)       (HW_FMC_DATAW1SnUM(x, n).U)
#define HW_FMC_DATAW1SnUM_WR(x, n, v)    (HW_FMC_DATAW1SnUM(x, n).U = (v))
#define HW_FMC_DATAW1SnUM_SET(x, n, v)   (HW_FMC_DATAW1SnUM_WR(x, n, HW_FMC_DATAW1SnUM_RD(x, n) |  (v)))
#define HW_FMC_DATAW1SnUM_CLR(x, n, v)   (HW_FMC_DATAW1SnUM_WR(x, n, HW_FMC_DATAW1SnUM_RD(x, n) & ~(v)))
#define HW_FMC_DATAW1SnUM_TOG(x, n, v)   (HW_FMC_DATAW1SnUM_WR(x, n, HW_FMC_DATAW1SnUM_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_DATAW1SnUM bitfields
 */

/*!
 * @name Register FMC_DATAW1SnUM, field DATA[31:0] (RW)
 */
/*@{*/
#define BP_FMC_DATAW1SnUM_DATA         (0U)      /*!< Bit position for FMC_DATAW1SnUM_DATA. */
#define BM_FMC_DATAW1SnUM_DATA         (0xFFFFFFFFU)  /*!< Bit mask for FMC_DATAW1SnUM_DATA. */
#define BS_FMC_DATAW1SnUM_DATA         (32U)  /*!< Bitfield size in bits for FMC_DATAW1SnUM_DATA. */

/*! @brief Read current value of the FMC_DATAW1SnUM_DATA field. */
#define BR_FMC_DATAW1SnUM_DATA(x, n)      (HW_FMC_DATAW1SnUM(x, n).U)

/*! @brief Format value for bitfield FMC_DATAW1SnUM_DATA. */
#define BF_FMC_DATAW1SnUM_DATA(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_DATAW1SnUM_DATA) & BM_FMC_DATAW1SnUM_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_FMC_DATAW1SnUM_DATA(x, n, v)   (HW_FMC_DATAW1SnUM_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_FMC_DATAW1SnMU - Cache Data Storage (mid-upper word)
 ******************************************************************************/

/*!
 * @brief HW_FMC_DATAW1SnMU - Cache Data Storage (mid-upper word) (RW)
 *
 * Reset value: 0x00000000U
 *
 * The cache of sixteen 128-bit entries is a 4-way, set-associative cache with 4 sets. The ways are
 * numbered 0-3 and the sets are numbered 0-3. In DATAWxSyUM, DATAWxSyMU, DATAWxSyML, and
 * DATAWxSyLM, x denotes the way, y denotes the set, and the final two letters identify the word: UM
 * (uppermost), MU (mid-upper), ML (mid-lower), and LM (lowermost). This section represents data for
 * the mid-upper word (bits [95:64]) of all 4 sets (n=0-3) in way 0.
 */
typedef union _hw_fmc_dataw1snmu
{
    uint32_t U;
    struct _hw_fmc_dataw1snmu_bitfields
    {
        uint32_t DATA : 32; /*!< [31:0] Bits [95:64] of data entry */
    } B;
} hw_fmc_dataw1snmu_t;

/*!
 * @name Constants and macros for entire FMC_DATAW1SnMU register
 */
/*@{*/
/*! @brief Number of instances of the FMC_DATAW1SnMU register. */
#define HW_FMC_DATAW1SnMU_COUNT     (4U)

#define HW_FMC_DATAW1SnMU_ADDR(x, n)     ((x) + 0x244U + (0x10U * (n)))
#define HW_FMC_DATAW1SnMU(x, n)          (*(__IO hw_fmc_dataw1snmu_t *) HW_FMC_DATAW1SnMU_ADDR(x, n))
#define HW_FMC_DATAW1SnMU_RD(x, n)       (HW_FMC_DATAW1SnMU(x, n).U)
#define HW_FMC_DATAW1SnMU_WR(x, n, v)    (HW_FMC_DATAW1SnMU(x, n).U = (v))
#define HW_FMC_DATAW1SnMU_SET(x, n, v)   (HW_FMC_DATAW1SnMU_WR(x, n, HW_FMC_DATAW1SnMU_RD(x, n) |  (v)))
#define HW_FMC_DATAW1SnMU_CLR(x, n, v)   (HW_FMC_DATAW1SnMU_WR(x, n, HW_FMC_DATAW1SnMU_RD(x, n) & ~(v)))
#define HW_FMC_DATAW1SnMU_TOG(x, n, v)   (HW_FMC_DATAW1SnMU_WR(x, n, HW_FMC_DATAW1SnMU_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_DATAW1SnMU bitfields
 */

/*!
 * @name Register FMC_DATAW1SnMU, field DATA[31:0] (RW)
 */
/*@{*/
#define BP_FMC_DATAW1SnMU_DATA         (0U)      /*!< Bit position for FMC_DATAW1SnMU_DATA. */
#define BM_FMC_DATAW1SnMU_DATA         (0xFFFFFFFFU)  /*!< Bit mask for FMC_DATAW1SnMU_DATA. */
#define BS_FMC_DATAW1SnMU_DATA         (32U)  /*!< Bitfield size in bits for FMC_DATAW1SnMU_DATA. */

/*! @brief Read current value of the FMC_DATAW1SnMU_DATA field. */
#define BR_FMC_DATAW1SnMU_DATA(x, n)      (HW_FMC_DATAW1SnMU(x, n).U)

/*! @brief Format value for bitfield FMC_DATAW1SnMU_DATA. */
#define BF_FMC_DATAW1SnMU_DATA(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_DATAW1SnMU_DATA) & BM_FMC_DATAW1SnMU_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_FMC_DATAW1SnMU_DATA(x, n, v)   (HW_FMC_DATAW1SnMU_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_FMC_DATAW1SnML - Cache Data Storage (mid-lower word)
 ******************************************************************************/

/*!
 * @brief HW_FMC_DATAW1SnML - Cache Data Storage (mid-lower word) (RW)
 *
 * Reset value: 0x00000000U
 *
 * The cache of sixteen 128-bit entries is a 4-way, set-associative cache with 4 sets. The ways are
 * numbered 0-3 and the sets are numbered 0-3. In DATAWxSyUM, DATAWxSyMU, DATAWxSyML, and
 * DATAWxSyLM, x denotes the way, y denotes the set, and the final two letters identify the word: UM
 * (uppermost), MU (mid-upper), ML (mid-lower), and LM (lowermost). This section represents data for
 * the mid-lower word (bits [63:32]) of all 4 sets (n=0-3) in way 0.
 */
typedef union _hw_fmc_dataw1snml
{
    uint32_t U;
    struct _hw_fmc_dataw1snml_bitfields
    {
        uint32_t DATA : 32; /*!< [31:0] Bits [63:32] of data entry */
    } B;
} hw_fmc_dataw1snml_t;

/*!
 * @name Constants and macros for entire FMC_DATAW1SnML register
 */
/*@{*/
/*! @brief Number of instances of the FMC_DATAW1SnML register. */
#define HW_FMC_DATAW1SnML_COUNT     (4U)

#define HW_FMC_DATAW1SnML_ADDR(x, n)     ((x) + 0x248U + (0x10U * (n)))
#define HW_FMC_DATAW1SnML(x, n)          (*(__IO hw_fmc_dataw1snml_t *) HW_FMC_DATAW1SnML_ADDR(x, n))
#define HW_FMC_DATAW1SnML_RD(x, n)       (HW_FMC_DATAW1SnML(x, n).U)
#define HW_FMC_DATAW1SnML_WR(x, n, v)    (HW_FMC_DATAW1SnML(x, n).U = (v))
#define HW_FMC_DATAW1SnML_SET(x, n, v)   (HW_FMC_DATAW1SnML_WR(x, n, HW_FMC_DATAW1SnML_RD(x, n) |  (v)))
#define HW_FMC_DATAW1SnML_CLR(x, n, v)   (HW_FMC_DATAW1SnML_WR(x, n, HW_FMC_DATAW1SnML_RD(x, n) & ~(v)))
#define HW_FMC_DATAW1SnML_TOG(x, n, v)   (HW_FMC_DATAW1SnML_WR(x, n, HW_FMC_DATAW1SnML_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_DATAW1SnML bitfields
 */

/*!
 * @name Register FMC_DATAW1SnML, field DATA[31:0] (RW)
 */
/*@{*/
#define BP_FMC_DATAW1SnML_DATA         (0U)      /*!< Bit position for FMC_DATAW1SnML_DATA. */
#define BM_FMC_DATAW1SnML_DATA         (0xFFFFFFFFU)  /*!< Bit mask for FMC_DATAW1SnML_DATA. */
#define BS_FMC_DATAW1SnML_DATA         (32U)  /*!< Bitfield size in bits for FMC_DATAW1SnML_DATA. */

/*! @brief Read current value of the FMC_DATAW1SnML_DATA field. */
#define BR_FMC_DATAW1SnML_DATA(x, n)      (HW_FMC_DATAW1SnML(x, n).U)

/*! @brief Format value for bitfield FMC_DATAW1SnML_DATA. */
#define BF_FMC_DATAW1SnML_DATA(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_DATAW1SnML_DATA) & BM_FMC_DATAW1SnML_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_FMC_DATAW1SnML_DATA(x, n, v)   (HW_FMC_DATAW1SnML_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_FMC_DATAW1SnLM - Cache Data Storage (lowermost word)
 ******************************************************************************/

/*!
 * @brief HW_FMC_DATAW1SnLM - Cache Data Storage (lowermost word) (RW)
 *
 * Reset value: 0x00000000U
 *
 * The cache of sixteen 128-bit entries is a 4-way, set-associative cache with 4 sets. The ways are
 * numbered 0-3 and the sets are numbered 0-3. In DATAWxSyUM, DATAWxSyMU, DATAWxSyML, and
 * DATAWxSyLM, x denotes the way, y denotes the set, and the final two letters identify the word: UM
 * (uppermost), MU (mid-upper), ML (mid-lower), and LM (lowermost). This section represents data for
 * the lowermost word (bits [31:0]) of all 4 sets (n=0-3) in way 0.
 */
typedef union _hw_fmc_dataw1snlm
{
    uint32_t U;
    struct _hw_fmc_dataw1snlm_bitfields
    {
        uint32_t DATA : 32; /*!< [31:0] Bits [31:0] of data entry */
    } B;
} hw_fmc_dataw1snlm_t;

/*!
 * @name Constants and macros for entire FMC_DATAW1SnLM register
 */
/*@{*/
/*! @brief Number of instances of the FMC_DATAW1SnLM register. */
#define HW_FMC_DATAW1SnLM_COUNT     (4U)

#define HW_FMC_DATAW1SnLM_ADDR(x, n)     ((x) + 0x24CU + (0x10U * (n)))
#define HW_FMC_DATAW1SnLM(x, n)          (*(__IO hw_fmc_dataw1snlm_t *) HW_FMC_DATAW1SnLM_ADDR(x, n))
#define HW_FMC_DATAW1SnLM_RD(x, n)       (HW_FMC_DATAW1SnLM(x, n).U)
#define HW_FMC_DATAW1SnLM_WR(x, n, v)    (HW_FMC_DATAW1SnLM(x, n).U = (v))
#define HW_FMC_DATAW1SnLM_SET(x, n, v)   (HW_FMC_DATAW1SnLM_WR(x, n, HW_FMC_DATAW1SnLM_RD(x, n) |  (v)))
#define HW_FMC_DATAW1SnLM_CLR(x, n, v)   (HW_FMC_DATAW1SnLM_WR(x, n, HW_FMC_DATAW1SnLM_RD(x, n) & ~(v)))
#define HW_FMC_DATAW1SnLM_TOG(x, n, v)   (HW_FMC_DATAW1SnLM_WR(x, n, HW_FMC_DATAW1SnLM_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_DATAW1SnLM bitfields
 */

/*!
 * @name Register FMC_DATAW1SnLM, field DATA[31:0] (RW)
 */
/*@{*/
#define BP_FMC_DATAW1SnLM_DATA         (0U)      /*!< Bit position for FMC_DATAW1SnLM_DATA. */
#define BM_FMC_DATAW1SnLM_DATA         (0xFFFFFFFFU)  /*!< Bit mask for FMC_DATAW1SnLM_DATA. */
#define BS_FMC_DATAW1SnLM_DATA         (32U)  /*!< Bitfield size in bits for FMC_DATAW1SnLM_DATA. */

/*! @brief Read current value of the FMC_DATAW1SnLM_DATA field. */
#define BR_FMC_DATAW1SnLM_DATA(x, n)      (HW_FMC_DATAW1SnLM(x, n).U)

/*! @brief Format value for bitfield FMC_DATAW1SnLM_DATA. */
#define BF_FMC_DATAW1SnLM_DATA(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_DATAW1SnLM_DATA) & BM_FMC_DATAW1SnLM_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_FMC_DATAW1SnLM_DATA(x, n, v)   (HW_FMC_DATAW1SnLM_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_FMC_DATAW2SnUM - Cache Data Storage (uppermost word)
 ******************************************************************************/

/*!
 * @brief HW_FMC_DATAW2SnUM - Cache Data Storage (uppermost word) (RW)
 *
 * Reset value: 0x00000000U
 *
 * The cache of sixteen 128-bit entries is a 4-way, set-associative cache with 4 sets. The ways are
 * numbered 0-3 and the sets are numbered 0-3. In DATAWxSyUM, DATAWxSyMU, DATAWxSyML, and
 * DATAWxSyLM, x denotes the way, y denotes the set, and the final two letters identify the word: UM
 * (uppermost), MU (mid-upper), ML (mid-lower), and LM (lowermost). This section represents data for
 * the uppermost word (bits [127:96]) of all 4 sets (n=0-3) in way 0.
 */
typedef union _hw_fmc_dataw2snum
{
    uint32_t U;
    struct _hw_fmc_dataw2snum_bitfields
    {
        uint32_t DATA : 32; /*!< [31:0] Bits [127:96] of data entry */
    } B;
} hw_fmc_dataw2snum_t;

/*!
 * @name Constants and macros for entire FMC_DATAW2SnUM register
 */
/*@{*/
/*! @brief Number of instances of the FMC_DATAW2SnUM register. */
#define HW_FMC_DATAW2SnUM_COUNT     (4U)

#define HW_FMC_DATAW2SnUM_ADDR(x, n)     ((x) + 0x280U + (0x10U * (n)))
#define HW_FMC_DATAW2SnUM(x, n)          (*(__IO hw_fmc_dataw2snum_t *) HW_FMC_DATAW2SnUM_ADDR(x, n))
#define HW_FMC_DATAW2SnUM_RD(x, n)       (HW_FMC_DATAW2SnUM(x, n).U)
#define HW_FMC_DATAW2SnUM_WR(x, n, v)    (HW_FMC_DATAW2SnUM(x, n).U = (v))
#define HW_FMC_DATAW2SnUM_SET(x, n, v)   (HW_FMC_DATAW2SnUM_WR(x, n, HW_FMC_DATAW2SnUM_RD(x, n) |  (v)))
#define HW_FMC_DATAW2SnUM_CLR(x, n, v)   (HW_FMC_DATAW2SnUM_WR(x, n, HW_FMC_DATAW2SnUM_RD(x, n) & ~(v)))
#define HW_FMC_DATAW2SnUM_TOG(x, n, v)   (HW_FMC_DATAW2SnUM_WR(x, n, HW_FMC_DATAW2SnUM_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_DATAW2SnUM bitfields
 */

/*!
 * @name Register FMC_DATAW2SnUM, field DATA[31:0] (RW)
 */
/*@{*/
#define BP_FMC_DATAW2SnUM_DATA         (0U)      /*!< Bit position for FMC_DATAW2SnUM_DATA. */
#define BM_FMC_DATAW2SnUM_DATA         (0xFFFFFFFFU)  /*!< Bit mask for FMC_DATAW2SnUM_DATA. */
#define BS_FMC_DATAW2SnUM_DATA         (32U)  /*!< Bitfield size in bits for FMC_DATAW2SnUM_DATA. */

/*! @brief Read current value of the FMC_DATAW2SnUM_DATA field. */
#define BR_FMC_DATAW2SnUM_DATA(x, n)      (HW_FMC_DATAW2SnUM(x, n).U)

/*! @brief Format value for bitfield FMC_DATAW2SnUM_DATA. */
#define BF_FMC_DATAW2SnUM_DATA(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_DATAW2SnUM_DATA) & BM_FMC_DATAW2SnUM_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_FMC_DATAW2SnUM_DATA(x, n, v)   (HW_FMC_DATAW2SnUM_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_FMC_DATAW2SnMU - Cache Data Storage (mid-upper word)
 ******************************************************************************/

/*!
 * @brief HW_FMC_DATAW2SnMU - Cache Data Storage (mid-upper word) (RW)
 *
 * Reset value: 0x00000000U
 *
 * The cache of sixteen 128-bit entries is a 4-way, set-associative cache with 4 sets. The ways are
 * numbered 0-3 and the sets are numbered 0-3. In DATAWxSyUM, DATAWxSyMU, DATAWxSyML, and
 * DATAWxSyLM, x denotes the way, y denotes the set, and the final two letters identify the word: UM
 * (uppermost), MU (mid-upper), ML (mid-lower), and LM (lowermost). This section represents data for
 * the mid-upper word (bits [95:64]) of all 4 sets (n=0-3) in way 0.
 */
typedef union _hw_fmc_dataw2snmu
{
    uint32_t U;
    struct _hw_fmc_dataw2snmu_bitfields
    {
        uint32_t DATA : 32; /*!< [31:0] Bits [95:64] of data entry */
    } B;
} hw_fmc_dataw2snmu_t;

/*!
 * @name Constants and macros for entire FMC_DATAW2SnMU register
 */
/*@{*/
/*! @brief Number of instances of the FMC_DATAW2SnMU register. */
#define HW_FMC_DATAW2SnMU_COUNT     (4U)

#define HW_FMC_DATAW2SnMU_ADDR(x, n)     ((x) + 0x284U + (0x10U * (n)))
#define HW_FMC_DATAW2SnMU(x, n)          (*(__IO hw_fmc_dataw2snmu_t *) HW_FMC_DATAW2SnMU_ADDR(x, n))
#define HW_FMC_DATAW2SnMU_RD(x, n)       (HW_FMC_DATAW2SnMU(x, n).U)
#define HW_FMC_DATAW2SnMU_WR(x, n, v)    (HW_FMC_DATAW2SnMU(x, n).U = (v))
#define HW_FMC_DATAW2SnMU_SET(x, n, v)   (HW_FMC_DATAW2SnMU_WR(x, n, HW_FMC_DATAW2SnMU_RD(x, n) |  (v)))
#define HW_FMC_DATAW2SnMU_CLR(x, n, v)   (HW_FMC_DATAW2SnMU_WR(x, n, HW_FMC_DATAW2SnMU_RD(x, n) & ~(v)))
#define HW_FMC_DATAW2SnMU_TOG(x, n, v)   (HW_FMC_DATAW2SnMU_WR(x, n, HW_FMC_DATAW2SnMU_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_DATAW2SnMU bitfields
 */

/*!
 * @name Register FMC_DATAW2SnMU, field DATA[31:0] (RW)
 */
/*@{*/
#define BP_FMC_DATAW2SnMU_DATA         (0U)      /*!< Bit position for FMC_DATAW2SnMU_DATA. */
#define BM_FMC_DATAW2SnMU_DATA         (0xFFFFFFFFU)  /*!< Bit mask for FMC_DATAW2SnMU_DATA. */
#define BS_FMC_DATAW2SnMU_DATA         (32U)  /*!< Bitfield size in bits for FMC_DATAW2SnMU_DATA. */

/*! @brief Read current value of the FMC_DATAW2SnMU_DATA field. */
#define BR_FMC_DATAW2SnMU_DATA(x, n)      (HW_FMC_DATAW2SnMU(x, n).U)

/*! @brief Format value for bitfield FMC_DATAW2SnMU_DATA. */
#define BF_FMC_DATAW2SnMU_DATA(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_DATAW2SnMU_DATA) & BM_FMC_DATAW2SnMU_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_FMC_DATAW2SnMU_DATA(x, n, v)   (HW_FMC_DATAW2SnMU_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_FMC_DATAW2SnML - Cache Data Storage (mid-lower word)
 ******************************************************************************/

/*!
 * @brief HW_FMC_DATAW2SnML - Cache Data Storage (mid-lower word) (RW)
 *
 * Reset value: 0x00000000U
 *
 * The cache of sixteen 128-bit entries is a 4-way, set-associative cache with 4 sets. The ways are
 * numbered 0-3 and the sets are numbered 0-3. In DATAWxSyUM, DATAWxSyMU, DATAWxSyML, and
 * DATAWxSyLM, x denotes the way, y denotes the set, and the final two letters identify the word: UM
 * (uppermost), MU (mid-upper), ML (mid-lower), and LM (lowermost). This section represents data for
 * the mid-lower word (bits [63:32]) of all 4 sets (n=0-3) in way 0.
 */
typedef union _hw_fmc_dataw2snml
{
    uint32_t U;
    struct _hw_fmc_dataw2snml_bitfields
    {
        uint32_t DATA : 32; /*!< [31:0] Bits [63:32] of data entry */
    } B;
} hw_fmc_dataw2snml_t;

/*!
 * @name Constants and macros for entire FMC_DATAW2SnML register
 */
/*@{*/
/*! @brief Number of instances of the FMC_DATAW2SnML register. */
#define HW_FMC_DATAW2SnML_COUNT     (4U)

#define HW_FMC_DATAW2SnML_ADDR(x, n)     ((x) + 0x288U + (0x10U * (n)))
#define HW_FMC_DATAW2SnML(x, n)          (*(__IO hw_fmc_dataw2snml_t *) HW_FMC_DATAW2SnML_ADDR(x, n))
#define HW_FMC_DATAW2SnML_RD(x, n)       (HW_FMC_DATAW2SnML(x, n).U)
#define HW_FMC_DATAW2SnML_WR(x, n, v)    (HW_FMC_DATAW2SnML(x, n).U = (v))
#define HW_FMC_DATAW2SnML_SET(x, n, v)   (HW_FMC_DATAW2SnML_WR(x, n, HW_FMC_DATAW2SnML_RD(x, n) |  (v)))
#define HW_FMC_DATAW2SnML_CLR(x, n, v)   (HW_FMC_DATAW2SnML_WR(x, n, HW_FMC_DATAW2SnML_RD(x, n) & ~(v)))
#define HW_FMC_DATAW2SnML_TOG(x, n, v)   (HW_FMC_DATAW2SnML_WR(x, n, HW_FMC_DATAW2SnML_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_DATAW2SnML bitfields
 */

/*!
 * @name Register FMC_DATAW2SnML, field DATA[31:0] (RW)
 */
/*@{*/
#define BP_FMC_DATAW2SnML_DATA         (0U)      /*!< Bit position for FMC_DATAW2SnML_DATA. */
#define BM_FMC_DATAW2SnML_DATA         (0xFFFFFFFFU)  /*!< Bit mask for FMC_DATAW2SnML_DATA. */
#define BS_FMC_DATAW2SnML_DATA         (32U)  /*!< Bitfield size in bits for FMC_DATAW2SnML_DATA. */

/*! @brief Read current value of the FMC_DATAW2SnML_DATA field. */
#define BR_FMC_DATAW2SnML_DATA(x, n)      (HW_FMC_DATAW2SnML(x, n).U)

/*! @brief Format value for bitfield FMC_DATAW2SnML_DATA. */
#define BF_FMC_DATAW2SnML_DATA(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_DATAW2SnML_DATA) & BM_FMC_DATAW2SnML_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_FMC_DATAW2SnML_DATA(x, n, v)   (HW_FMC_DATAW2SnML_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_FMC_DATAW2SnLM - Cache Data Storage (lowermost word)
 ******************************************************************************/

/*!
 * @brief HW_FMC_DATAW2SnLM - Cache Data Storage (lowermost word) (RW)
 *
 * Reset value: 0x00000000U
 *
 * The cache of sixteen 128-bit entries is a 4-way, set-associative cache with 4 sets. The ways are
 * numbered 0-3 and the sets are numbered 0-3. In DATAWxSyUM, DATAWxSyMU, DATAWxSyML, and
 * DATAWxSyLM, x denotes the way, y denotes the set, and the final two letters identify the word: UM
 * (uppermost), MU (mid-upper), ML (mid-lower), and LM (lowermost). This section represents data for
 * the lowermost word (bits [31:0]) of all 4 sets (n=0-3) in way 0.
 */
typedef union _hw_fmc_dataw2snlm
{
    uint32_t U;
    struct _hw_fmc_dataw2snlm_bitfields
    {
        uint32_t DATA : 32; /*!< [31:0] Bits [31:0] of data entry */
    } B;
} hw_fmc_dataw2snlm_t;

/*!
 * @name Constants and macros for entire FMC_DATAW2SnLM register
 */
/*@{*/
/*! @brief Number of instances of the FMC_DATAW2SnLM register. */
#define HW_FMC_DATAW2SnLM_COUNT     (4U)

#define HW_FMC_DATAW2SnLM_ADDR(x, n)     ((x) + 0x28CU + (0x10U * (n)))
#define HW_FMC_DATAW2SnLM(x, n)          (*(__IO hw_fmc_dataw2snlm_t *) HW_FMC_DATAW2SnLM_ADDR(x, n))
#define HW_FMC_DATAW2SnLM_RD(x, n)       (HW_FMC_DATAW2SnLM(x, n).U)
#define HW_FMC_DATAW2SnLM_WR(x, n, v)    (HW_FMC_DATAW2SnLM(x, n).U = (v))
#define HW_FMC_DATAW2SnLM_SET(x, n, v)   (HW_FMC_DATAW2SnLM_WR(x, n, HW_FMC_DATAW2SnLM_RD(x, n) |  (v)))
#define HW_FMC_DATAW2SnLM_CLR(x, n, v)   (HW_FMC_DATAW2SnLM_WR(x, n, HW_FMC_DATAW2SnLM_RD(x, n) & ~(v)))
#define HW_FMC_DATAW2SnLM_TOG(x, n, v)   (HW_FMC_DATAW2SnLM_WR(x, n, HW_FMC_DATAW2SnLM_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_DATAW2SnLM bitfields
 */

/*!
 * @name Register FMC_DATAW2SnLM, field DATA[31:0] (RW)
 */
/*@{*/
#define BP_FMC_DATAW2SnLM_DATA         (0U)      /*!< Bit position for FMC_DATAW2SnLM_DATA. */
#define BM_FMC_DATAW2SnLM_DATA         (0xFFFFFFFFU)  /*!< Bit mask for FMC_DATAW2SnLM_DATA. */
#define BS_FMC_DATAW2SnLM_DATA         (32U)  /*!< Bitfield size in bits for FMC_DATAW2SnLM_DATA. */

/*! @brief Read current value of the FMC_DATAW2SnLM_DATA field. */
#define BR_FMC_DATAW2SnLM_DATA(x, n)      (HW_FMC_DATAW2SnLM(x, n).U)

/*! @brief Format value for bitfield FMC_DATAW2SnLM_DATA. */
#define BF_FMC_DATAW2SnLM_DATA(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_DATAW2SnLM_DATA) & BM_FMC_DATAW2SnLM_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_FMC_DATAW2SnLM_DATA(x, n, v)   (HW_FMC_DATAW2SnLM_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_FMC_DATAW3SnUM - Cache Data Storage (uppermost word)
 ******************************************************************************/

/*!
 * @brief HW_FMC_DATAW3SnUM - Cache Data Storage (uppermost word) (RW)
 *
 * Reset value: 0x00000000U
 *
 * The cache of sixteen 128-bit entries is a 4-way, set-associative cache with 4 sets. The ways are
 * numbered 0-3 and the sets are numbered 0-3. In DATAWxSyUM, DATAWxSyMU, DATAWxSyML, and
 * DATAWxSyLM, x denotes the way, y denotes the set, and the final two letters identify the word: UM
 * (uppermost), MU (mid-upper), ML (mid-lower), and LM (lowermost). This section represents data for
 * the uppermost word (bits [127:96]) of all 4 sets (n=0-3) in way 0.
 */
typedef union _hw_fmc_dataw3snum
{
    uint32_t U;
    struct _hw_fmc_dataw3snum_bitfields
    {
        uint32_t DATA : 32; /*!< [31:0] Bits [127:96] of data entry */
    } B;
} hw_fmc_dataw3snum_t;

/*!
 * @name Constants and macros for entire FMC_DATAW3SnUM register
 */
/*@{*/
/*! @brief Number of instances of the FMC_DATAW3SnUM register. */
#define HW_FMC_DATAW3SnUM_COUNT     (4U)

#define HW_FMC_DATAW3SnUM_ADDR(x, n)     ((x) + 0x2C0U + (0x10U * (n)))
#define HW_FMC_DATAW3SnUM(x, n)          (*(__IO hw_fmc_dataw3snum_t *) HW_FMC_DATAW3SnUM_ADDR(x, n))
#define HW_FMC_DATAW3SnUM_RD(x, n)       (HW_FMC_DATAW3SnUM(x, n).U)
#define HW_FMC_DATAW3SnUM_WR(x, n, v)    (HW_FMC_DATAW3SnUM(x, n).U = (v))
#define HW_FMC_DATAW3SnUM_SET(x, n, v)   (HW_FMC_DATAW3SnUM_WR(x, n, HW_FMC_DATAW3SnUM_RD(x, n) |  (v)))
#define HW_FMC_DATAW3SnUM_CLR(x, n, v)   (HW_FMC_DATAW3SnUM_WR(x, n, HW_FMC_DATAW3SnUM_RD(x, n) & ~(v)))
#define HW_FMC_DATAW3SnUM_TOG(x, n, v)   (HW_FMC_DATAW3SnUM_WR(x, n, HW_FMC_DATAW3SnUM_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_DATAW3SnUM bitfields
 */

/*!
 * @name Register FMC_DATAW3SnUM, field DATA[31:0] (RW)
 */
/*@{*/
#define BP_FMC_DATAW3SnUM_DATA         (0U)      /*!< Bit position for FMC_DATAW3SnUM_DATA. */
#define BM_FMC_DATAW3SnUM_DATA         (0xFFFFFFFFU)  /*!< Bit mask for FMC_DATAW3SnUM_DATA. */
#define BS_FMC_DATAW3SnUM_DATA         (32U)  /*!< Bitfield size in bits for FMC_DATAW3SnUM_DATA. */

/*! @brief Read current value of the FMC_DATAW3SnUM_DATA field. */
#define BR_FMC_DATAW3SnUM_DATA(x, n)      (HW_FMC_DATAW3SnUM(x, n).U)

/*! @brief Format value for bitfield FMC_DATAW3SnUM_DATA. */
#define BF_FMC_DATAW3SnUM_DATA(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_DATAW3SnUM_DATA) & BM_FMC_DATAW3SnUM_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_FMC_DATAW3SnUM_DATA(x, n, v)   (HW_FMC_DATAW3SnUM_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_FMC_DATAW3SnMU - Cache Data Storage (mid-upper word)
 ******************************************************************************/

/*!
 * @brief HW_FMC_DATAW3SnMU - Cache Data Storage (mid-upper word) (RW)
 *
 * Reset value: 0x00000000U
 *
 * The cache of sixteen 128-bit entries is a 4-way, set-associative cache with 4 sets. The ways are
 * numbered 0-3 and the sets are numbered 0-3 . In DATAWxSyUM, DATAWxSyMU, DATAWxSyML, and
 * DATAWxSyLM, x denotes the way, y denotes the set, and the final two letters identify the word: UM
 * (uppermost), MU (mid-upper), ML (mid-lower), and LM (lowermost). This section represents data for
 * the mid-upper word (bits [95:64]) of all 4 sets (n=0-3) in way 0.
 */
typedef union _hw_fmc_dataw3snmu
{
    uint32_t U;
    struct _hw_fmc_dataw3snmu_bitfields
    {
        uint32_t DATA : 32; /*!< [31:0] Bits [95:64] of data entry */
    } B;
} hw_fmc_dataw3snmu_t;

/*!
 * @name Constants and macros for entire FMC_DATAW3SnMU register
 */
/*@{*/
/*! @brief Number of instances of the FMC_DATAW3SnMU register. */
#define HW_FMC_DATAW3SnMU_COUNT     (4U)

#define HW_FMC_DATAW3SnMU_ADDR(x, n)     ((x) + 0x2C4U + (0x10U * (n)))
#define HW_FMC_DATAW3SnMU(x, n)          (*(__IO hw_fmc_dataw3snmu_t *) HW_FMC_DATAW3SnMU_ADDR(x, n))
#define HW_FMC_DATAW3SnMU_RD(x, n)       (HW_FMC_DATAW3SnMU(x, n).U)
#define HW_FMC_DATAW3SnMU_WR(x, n, v)    (HW_FMC_DATAW3SnMU(x, n).U = (v))
#define HW_FMC_DATAW3SnMU_SET(x, n, v)   (HW_FMC_DATAW3SnMU_WR(x, n, HW_FMC_DATAW3SnMU_RD(x, n) |  (v)))
#define HW_FMC_DATAW3SnMU_CLR(x, n, v)   (HW_FMC_DATAW3SnMU_WR(x, n, HW_FMC_DATAW3SnMU_RD(x, n) & ~(v)))
#define HW_FMC_DATAW3SnMU_TOG(x, n, v)   (HW_FMC_DATAW3SnMU_WR(x, n, HW_FMC_DATAW3SnMU_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_DATAW3SnMU bitfields
 */

/*!
 * @name Register FMC_DATAW3SnMU, field DATA[31:0] (RW)
 */
/*@{*/
#define BP_FMC_DATAW3SnMU_DATA         (0U)      /*!< Bit position for FMC_DATAW3SnMU_DATA. */
#define BM_FMC_DATAW3SnMU_DATA         (0xFFFFFFFFU)  /*!< Bit mask for FMC_DATAW3SnMU_DATA. */
#define BS_FMC_DATAW3SnMU_DATA         (32U)  /*!< Bitfield size in bits for FMC_DATAW3SnMU_DATA. */

/*! @brief Read current value of the FMC_DATAW3SnMU_DATA field. */
#define BR_FMC_DATAW3SnMU_DATA(x, n)      (HW_FMC_DATAW3SnMU(x, n).U)

/*! @brief Format value for bitfield FMC_DATAW3SnMU_DATA. */
#define BF_FMC_DATAW3SnMU_DATA(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_DATAW3SnMU_DATA) & BM_FMC_DATAW3SnMU_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_FMC_DATAW3SnMU_DATA(x, n, v)   (HW_FMC_DATAW3SnMU_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_FMC_DATAW3SnML - Cache Data Storage (mid-lower word)
 ******************************************************************************/

/*!
 * @brief HW_FMC_DATAW3SnML - Cache Data Storage (mid-lower word) (RW)
 *
 * Reset value: 0x00000000U
 *
 * The cache of sixteen 128-bit entries is a 4-way, set-associative cache with 4 sets. The ways are
 * numbered 0-3 and the sets are numbered 0-3 . In DATAWxSyUM, DATAWxSyMU, DATAWxSyML, and
 * DATAWxSyLM, x denotes the way, y denotes the set, and the final two letters identify the word: UM
 * (uppermost), MU (mid-upper), ML (mid-lower), and LM (lowermost). This section represents data for
 * the mid-lower word (bits [63:32]) of all 4 sets (n=0-3) in way 0.
 */
typedef union _hw_fmc_dataw3snml
{
    uint32_t U;
    struct _hw_fmc_dataw3snml_bitfields
    {
        uint32_t DATA : 32; /*!< [31:0] Bits [63:32] of data entry */
    } B;
} hw_fmc_dataw3snml_t;

/*!
 * @name Constants and macros for entire FMC_DATAW3SnML register
 */
/*@{*/
/*! @brief Number of instances of the FMC_DATAW3SnML register. */
#define HW_FMC_DATAW3SnML_COUNT     (4U)

#define HW_FMC_DATAW3SnML_ADDR(x, n)     ((x) + 0x2C8U + (0x10U * (n)))
#define HW_FMC_DATAW3SnML(x, n)          (*(__IO hw_fmc_dataw3snml_t *) HW_FMC_DATAW3SnML_ADDR(x, n))
#define HW_FMC_DATAW3SnML_RD(x, n)       (HW_FMC_DATAW3SnML(x, n).U)
#define HW_FMC_DATAW3SnML_WR(x, n, v)    (HW_FMC_DATAW3SnML(x, n).U = (v))
#define HW_FMC_DATAW3SnML_SET(x, n, v)   (HW_FMC_DATAW3SnML_WR(x, n, HW_FMC_DATAW3SnML_RD(x, n) |  (v)))
#define HW_FMC_DATAW3SnML_CLR(x, n, v)   (HW_FMC_DATAW3SnML_WR(x, n, HW_FMC_DATAW3SnML_RD(x, n) & ~(v)))
#define HW_FMC_DATAW3SnML_TOG(x, n, v)   (HW_FMC_DATAW3SnML_WR(x, n, HW_FMC_DATAW3SnML_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_DATAW3SnML bitfields
 */

/*!
 * @name Register FMC_DATAW3SnML, field DATA[31:0] (RW)
 */
/*@{*/
#define BP_FMC_DATAW3SnML_DATA         (0U)      /*!< Bit position for FMC_DATAW3SnML_DATA. */
#define BM_FMC_DATAW3SnML_DATA         (0xFFFFFFFFU)  /*!< Bit mask for FMC_DATAW3SnML_DATA. */
#define BS_FMC_DATAW3SnML_DATA         (32U)  /*!< Bitfield size in bits for FMC_DATAW3SnML_DATA. */

/*! @brief Read current value of the FMC_DATAW3SnML_DATA field. */
#define BR_FMC_DATAW3SnML_DATA(x, n)      (HW_FMC_DATAW3SnML(x, n).U)

/*! @brief Format value for bitfield FMC_DATAW3SnML_DATA. */
#define BF_FMC_DATAW3SnML_DATA(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_DATAW3SnML_DATA) & BM_FMC_DATAW3SnML_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_FMC_DATAW3SnML_DATA(x, n, v)   (HW_FMC_DATAW3SnML_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_FMC_DATAW3SnLM - Cache Data Storage (lowermost word)
 ******************************************************************************/

/*!
 * @brief HW_FMC_DATAW3SnLM - Cache Data Storage (lowermost word) (RW)
 *
 * Reset value: 0x00000000U
 *
 * The cache of sixteen 128-bit entries is a 4-way, set-associative cache with 4 sets. The ways are
 * numbered 0-3 and the sets are numbered 0-3 . In DATAWxSyUM, DATAWxSyMU, DATAWxSyML, and
 * DATAWxSyLM, x denotes the way, y denotes the set, and the final two letters identify the word: UM
 * (uppermost), MU (mid-upper), ML (mid-lower), and LM (lowermost). This section represents data for
 * the lowermost word (bits [31:0]) of all 44 sets (n=0-3) in way 0.
 */
typedef union _hw_fmc_dataw3snlm
{
    uint32_t U;
    struct _hw_fmc_dataw3snlm_bitfields
    {
        uint32_t DATA : 32; /*!< [31:0] Bits [31:0] of data entry */
    } B;
} hw_fmc_dataw3snlm_t;

/*!
 * @name Constants and macros for entire FMC_DATAW3SnLM register
 */
/*@{*/
/*! @brief Number of instances of the FMC_DATAW3SnLM register. */
#define HW_FMC_DATAW3SnLM_COUNT     (4U)

#define HW_FMC_DATAW3SnLM_ADDR(x, n)     ((x) + 0x2CCU + (0x10U * (n)))
#define HW_FMC_DATAW3SnLM(x, n)          (*(__IO hw_fmc_dataw3snlm_t *) HW_FMC_DATAW3SnLM_ADDR(x, n))
#define HW_FMC_DATAW3SnLM_RD(x, n)       (HW_FMC_DATAW3SnLM(x, n).U)
#define HW_FMC_DATAW3SnLM_WR(x, n, v)    (HW_FMC_DATAW3SnLM(x, n).U = (v))
#define HW_FMC_DATAW3SnLM_SET(x, n, v)   (HW_FMC_DATAW3SnLM_WR(x, n, HW_FMC_DATAW3SnLM_RD(x, n) |  (v)))
#define HW_FMC_DATAW3SnLM_CLR(x, n, v)   (HW_FMC_DATAW3SnLM_WR(x, n, HW_FMC_DATAW3SnLM_RD(x, n) & ~(v)))
#define HW_FMC_DATAW3SnLM_TOG(x, n, v)   (HW_FMC_DATAW3SnLM_WR(x, n, HW_FMC_DATAW3SnLM_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual FMC_DATAW3SnLM bitfields
 */

/*!
 * @name Register FMC_DATAW3SnLM, field DATA[31:0] (RW)
 */
/*@{*/
#define BP_FMC_DATAW3SnLM_DATA         (0U)      /*!< Bit position for FMC_DATAW3SnLM_DATA. */
#define BM_FMC_DATAW3SnLM_DATA         (0xFFFFFFFFU)  /*!< Bit mask for FMC_DATAW3SnLM_DATA. */
#define BS_FMC_DATAW3SnLM_DATA         (32U)  /*!< Bitfield size in bits for FMC_DATAW3SnLM_DATA. */

/*! @brief Read current value of the FMC_DATAW3SnLM_DATA field. */
#define BR_FMC_DATAW3SnLM_DATA(x, n)      (HW_FMC_DATAW3SnLM(x, n).U)

/*! @brief Format value for bitfield FMC_DATAW3SnLM_DATA. */
#define BF_FMC_DATAW3SnLM_DATA(v)      ((uint32_t)((uint32_t)(v) << BP_FMC_DATAW3SnLM_DATA) & BM_FMC_DATAW3SnLM_DATA)

/*! @brief Set the DATA field to a new value. */
#define BW_FMC_DATAW3SnLM_DATA(x, n, v)   (HW_FMC_DATAW3SnLM_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * hw_fmc_t - module struct
 ******************************************************************************/
/*!
 * @brief All FMC module registers.
 */
#pragma pack(1)
typedef struct _hw_fmc
{
    __IO hw_fmc_pfapr_t PFAPR; /*!< [0x0] Flash Access Protection Register */
    __IO hw_fmc_pfb0cr_t PFB0CR; /*!< [0x4] Flash Bank 0 Control Register */
    __IO hw_fmc_pfb1cr_t PFB1CR; /*!< [0x8] Flash Bank 1 Control Register */
         uint32_t _reserved0[61];
    __IO hw_fmc_tagvdw0sn_t TAGVDW0Sn[4]; /*!< [0x100] Cache Tag Storage */
    __IO hw_fmc_tagvdw1sn_t TAGVDW1Sn[4]; /*!< [0x110] Cache Tag Storage */
    __IO hw_fmc_tagvdw2sn_t TAGVDW2Sn[4]; /*!< [0x120] Cache Tag Storage */
    __IO hw_fmc_tagvdw3sn_t TAGVDW3Sn[4]; /*!< [0x130] Cache Tag Storage */
         uint32_t _reserved1[48];
         struct {
             __IO hw_fmc_dataw0snum_t DATAW0SnUM; /*!< [0x200] Cache Data Storage (uppermost word) */
             __IO hw_fmc_dataw0snmu_t DATAW0SnMU; /*!< [0x204] Cache Data Storage (mid-upper word) */
             __IO hw_fmc_dataw0snml_t DATAW0SnML; /*!< [0x208] Cache Data Storage (mid-lower word) */
             __IO hw_fmc_dataw0snlm_t DATAW0SnLM; /*!< [0x20C] Cache Data Storage (lowermost word) */
         } CACHE1[4];
         struct {
             __IO hw_fmc_dataw1snum_t DATAW1SnUM; /*!< [0x240] Cache Data Storage (uppermost word) */
             __IO hw_fmc_dataw1snmu_t DATAW1SnMU; /*!< [0x244] Cache Data Storage (mid-upper word) */
             __IO hw_fmc_dataw1snml_t DATAW1SnML; /*!< [0x248] Cache Data Storage (mid-lower word) */
             __IO hw_fmc_dataw1snlm_t DATAW1SnLM; /*!< [0x24C] Cache Data Storage (lowermost word) */
         } CACHE2[4];
         struct {
             __IO hw_fmc_dataw2snum_t DATAW2SnUM; /*!< [0x280] Cache Data Storage (uppermost word) */
             __IO hw_fmc_dataw2snmu_t DATAW2SnMU; /*!< [0x284] Cache Data Storage (mid-upper word) */
             __IO hw_fmc_dataw2snml_t DATAW2SnML; /*!< [0x288] Cache Data Storage (mid-lower word) */
             __IO hw_fmc_dataw2snlm_t DATAW2SnLM; /*!< [0x28C] Cache Data Storage (lowermost word) */
         } CACHE3[4];
         struct {
             __IO hw_fmc_dataw3snum_t DATAW3SnUM; /*!< [0x2C0] Cache Data Storage (uppermost word) */
             __IO hw_fmc_dataw3snmu_t DATAW3SnMU; /*!< [0x2C4] Cache Data Storage (mid-upper word) */
             __IO hw_fmc_dataw3snml_t DATAW3SnML; /*!< [0x2C8] Cache Data Storage (mid-lower word) */
             __IO hw_fmc_dataw3snlm_t DATAW3SnLM; /*!< [0x2CC] Cache Data Storage (lowermost word) */
         } CACHE4[4];
} hw_fmc_t;
#pragma pack()


/*! @brief Macro to access all FMC registers. */
/*! @param x FMC module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_FMC(FMC0_BASE)</code>. */
#define HW_FMC(x)      (*(hw_fmc_t *)(x))

#endif /* __HW_FMC_REGISTERS_H__ */
/* v30/140722/1.3.1 */
/* EOF */
