/*
** ###################################################################
**     Compilers:           ARM Compiler
**                          Freescale C/C++ for Embedded ARM
**                          GNU C Compiler
**                          IAR ANSI C/C++ Compiler for ARM
**
**     Reference manual:    xxx
**     Version:             rev. 1.0, 2014-05-26
**     Build:               b140528
**
**     Abstract:
**         Extension to the CMSIS register access layer header.
**
**     Copyright (c) 2014 Freescale Semiconductor, Inc.
**     All rights reserved.
**
**     Redistribution and use in source and binary forms, with or without modification,
**     are permitted provided that the following conditions are met:
**
**     o Redistributions of source code must retain the above copyright notice, this list
**       of conditions and the following disclaimer.
**
**     o Redistributions in binary form must reproduce the above copyright notice, this
**       list of conditions and the following disclaimer in the documentation and/or
**       other materials provided with the distribution.
**
**     o Neither the name of Freescale Semiconductor, Inc. nor the names of its
**       contributors may be used to endorse or promote products derived from this
**       software without specific prior written permission.
**
**     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
**     ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
**     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
**     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
**     ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
**     (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
**     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
**     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
**     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
**     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**     http:                 www.freescale.com
**     mail:                 support@freescale.com
**
**     Revisions:
**     - rev. 1.0 (2014-05-26)
**
** ###################################################################
*/

/*
 * WARNING! DO NOT EDIT THIS FILE DIRECTLY!
 *
 * This file was generated automatically and any changes may be lost.
 */
#ifndef __HW_CAU_REGISTERS_H__
#define __HW_CAU_REGISTERS_H__

#include "MK80F256.h"
#include "fsl_bitaccess.h"

/*
 * MK80F256 CAU
 *
 * Cryptographic Acceleration Unit
 *
 * Registers defined in this header file:
 * - HW_CAU_CASR - Status Register
 * - HW_CAU_CAA - Accumulator
 * - HW_CAU_CAn - General Purpose Register
 *
 * - hw_cau_t - Struct containing all module registers.
 */

#define HW_CAU_INSTANCE_COUNT (1U) /*!< Number of instances of the CAU module. */

/*******************************************************************************
 * HW_CAU_CASR - Status Register
 ******************************************************************************/

/*!
 * @brief HW_CAU_CASR - Status Register (RW)
 *
 * Reset value: 0x20000000U
 *
 * CASR contains the status and configuration for the CAU.
 */
typedef union _hw_cau_casr
{
    uint32_t U;
    struct _hw_cau_casr_bitfields
    {
        uint32_t IC : 1; /*!< [0] Illegal Command */
        uint32_t DPE : 1; /*!< [1] DES Parity Error */
        uint32_t RESERVED0 : 26; /*!< [27:2] Reserved, must be cleared. */
        uint32_t VER : 4; /*!< [31:28] CAU Version */
    } B;
} hw_cau_casr_t;

/*!
 * @name Constants and macros for entire CAU_CASR register
 */
/*@{*/
#define HW_CAU_CASR_ADDR(x)        ((x) + 0x0U)
#define HW_CAU_CASR(x)             (*(__IO hw_cau_casr_t *) HW_CAU_CASR_ADDR(x))
#define HW_CAU_CASR_RD(x)          (HW_CAU_CASR(x).U)
#define HW_CAU_CASR_WR(x, v)       (HW_CAU_CASR(x).U = (v))
#define HW_CAU_CASR_SET(x, v)      (HW_CAU_CASR_WR(x, HW_CAU_CASR_RD(x) |  (v)))
#define HW_CAU_CASR_CLR(x, v)      (HW_CAU_CASR_WR(x, HW_CAU_CASR_RD(x) & ~(v)))
#define HW_CAU_CASR_TOG(x, v)      (HW_CAU_CASR_WR(x, HW_CAU_CASR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAU_CASR bitfields
 */

/*!
 * @name Register CAU_CASR, field IC[0] (RW)
 *
 * Indicates an illegal instruction has been executed.
 *
 * Values:
 * - 0 - No illegal commands issued.
 * - 1 - Illegal command issued.
 */
/*@{*/
#define BP_CAU_CASR_IC         (0U)      /*!< Bit position for CAU_CASR_IC. */
#define BM_CAU_CASR_IC         (0x00000001U)  /*!< Bit mask for CAU_CASR_IC. */
#define BS_CAU_CASR_IC         (1U)  /*!< Bitfield size in bits for CAU_CASR_IC. */

/*! @brief Read current value of the CAU_CASR_IC field. */
#define BR_CAU_CASR_IC(x)   (HW_CAU_CASR(x).B.IC)

/*! @brief Format value for bitfield CAU_CASR_IC. */
#define BF_CAU_CASR_IC(v)      ((uint32_t)((uint32_t)(v) << BP_CAU_CASR_IC) & BM_CAU_CASR_IC)

/*! @brief Set the IC field to a new value. */
#define BW_CAU_CASR_IC(x, v)   (HW_CAU_CASR_WR(x, (HW_CAU_CASR_RD(x) & ~BM_CAU_CASR_IC) | BF_CAU_CASR_IC(v)))
/*@}*/

/*!
 * @name Register CAU_CASR, field DPE[1] (RW)
 *
 * Indicates whether the DES parity error is detected.
 *
 * Values:
 * - 0 - No error detected.
 * - 1 - DES key parity error detected.
 */
/*@{*/
#define BP_CAU_CASR_DPE         (1U)      /*!< Bit position for CAU_CASR_DPE. */
#define BM_CAU_CASR_DPE         (0x00000002U)  /*!< Bit mask for CAU_CASR_DPE. */
#define BS_CAU_CASR_DPE         (1U)  /*!< Bitfield size in bits for CAU_CASR_DPE. */

/*! @brief Read current value of the CAU_CASR_DPE field. */
#define BR_CAU_CASR_DPE(x)   (HW_CAU_CASR(x).B.DPE)

/*! @brief Format value for bitfield CAU_CASR_DPE. */
#define BF_CAU_CASR_DPE(v)      ((uint32_t)((uint32_t)(v) << BP_CAU_CASR_DPE) & BM_CAU_CASR_DPE)

/*! @brief Set the DPE field to a new value. */
#define BW_CAU_CASR_DPE(x, v)   (HW_CAU_CASR_WR(x, (HW_CAU_CASR_RD(x) & ~BM_CAU_CASR_DPE) | BF_CAU_CASR_DPE(v)))
/*@}*/

/*!
 * @name Register CAU_CASR, field VER[31:28] (RO)
 *
 * Indicates CAU version.
 *
 * Values:
 * - 0x1 - Initial CAU version.
 * - 0x2 - Second version, added support for SHA-256 algorithm (This is the value on this device).
 */
/*@{*/
#define BP_CAU_CASR_VER         (28U)      /*!< Bit position for CAU_CASR_VER. */
#define BM_CAU_CASR_VER         (0xF0000000U)  /*!< Bit mask for CAU_CASR_VER. */
#define BS_CAU_CASR_VER         (4U)  /*!< Bitfield size in bits for CAU_CASR_VER. */

/*! @brief Read current value of the CAU_CASR_VER field. */
#define BR_CAU_CASR_VER(x)   (HW_CAU_CASR(x).B.VER)
/*@}*/

/*******************************************************************************
 * HW_CAU_CAA - Accumulator
 ******************************************************************************/

/*!
 * @brief HW_CAU_CAA - Accumulator (RW)
 *
 * Reset value: 0x00000000U
 *
 * Commands use the CAU accumulator for storage of results and as an operand for the cryptographic
 * algorithms.
 */
typedef union _hw_cau_caa
{
    uint32_t U;
    struct _hw_cau_caa_bitfields
    {
        uint32_t ACC : 32; /*!< [31:0] Accumulator */
    } B;
} hw_cau_caa_t;

/*!
 * @name Constants and macros for entire CAU_CAA register
 */
/*@{*/
#define HW_CAU_CAA_ADDR(x)        ((x) + 0x1U)
#define HW_CAU_CAA(x)             (*(__IO hw_cau_caa_t *) HW_CAU_CAA_ADDR(x))
#define HW_CAU_CAA_RD(x)          (HW_CAU_CAA(x).U)
#define HW_CAU_CAA_WR(x, v)       (HW_CAU_CAA(x).U = (v))
#define HW_CAU_CAA_SET(x, v)      (HW_CAU_CAA_WR(x, HW_CAU_CAA_RD(x) |  (v)))
#define HW_CAU_CAA_CLR(x, v)      (HW_CAU_CAA_WR(x, HW_CAU_CAA_RD(x) & ~(v)))
#define HW_CAU_CAA_TOG(x, v)      (HW_CAU_CAA_WR(x, HW_CAU_CAA_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAU_CAA bitfields
 */

/*!
 * @name Register CAU_CAA, field ACC[31:0] (RW)
 *
 * Stores results of various CAU commands.
 */
/*@{*/
#define BP_CAU_CAA_ACC         (0U)      /*!< Bit position for CAU_CAA_ACC. */
#define BM_CAU_CAA_ACC         (0xFFFFFFFFU)  /*!< Bit mask for CAU_CAA_ACC. */
#define BS_CAU_CAA_ACC         (32U)  /*!< Bitfield size in bits for CAU_CAA_ACC. */

/*! @brief Read current value of the CAU_CAA_ACC field. */
#define BR_CAU_CAA_ACC(x)      (HW_CAU_CAA(x).U)

/*! @brief Format value for bitfield CAU_CAA_ACC. */
#define BF_CAU_CAA_ACC(v)      ((uint32_t)((uint32_t)(v) << BP_CAU_CAA_ACC) & BM_CAU_CAA_ACC)

/*! @brief Set the ACC field to a new value. */
#define BW_CAU_CAA_ACC(x, v)   (HW_CAU_CAA_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_CAU_CAn - General Purpose Register
 ******************************************************************************/

/*!
 * @brief HW_CAU_CAn - General Purpose Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The General Purpose Register is used in the CAU commands for storage of results and as operands
 * for various cryptographic algorithms.
 */
typedef union _hw_cau_can
{
    uint32_t U;
    struct _hw_cau_can_bitfields
    {
        uint32_t CAN : 32; /*!< [31:0] General Purpose Registers */
    } B;
} hw_cau_can_t;

/*!
 * @name Constants and macros for entire CAU_CAn register
 */
/*@{*/
/*! @brief Number of instances of the CAU_CAn register. */
#define HW_CAU_CAn_COUNT     (9U)

#define HW_CAU_CAn_ADDR(x, n)     ((x) + 0x2U + (0x4U * (n)))
#define HW_CAU_CAn(x, n)          (*(__IO hw_cau_can_t *) HW_CAU_CAn_ADDR(x, n))
#define HW_CAU_CAn_RD(x, n)       (HW_CAU_CAn(x, n).U)
#define HW_CAU_CAn_WR(x, n, v)    (HW_CAU_CAn(x, n).U = (v))
#define HW_CAU_CAn_SET(x, n, v)   (HW_CAU_CAn_WR(x, n, HW_CAU_CAn_RD(x, n) |  (v)))
#define HW_CAU_CAn_CLR(x, n, v)   (HW_CAU_CAn_WR(x, n, HW_CAU_CAn_RD(x, n) & ~(v)))
#define HW_CAU_CAn_TOG(x, n, v)   (HW_CAU_CAn_WR(x, n, HW_CAU_CAn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual CAU_CAn bitfields
 */

/*!
 * @name Register CAU_CAn, field CAN[31:0] (RW)
 *
 * Used by the CAU commands. Some cryptographic operations work with specific registers.
 */
/*@{*/
#define BP_CAU_CAn_CAN         (0U)      /*!< Bit position for CAU_CAn_CAN. */
#define BM_CAU_CAn_CAN         (0xFFFFFFFFU)  /*!< Bit mask for CAU_CAn_CAN. */
#define BS_CAU_CAn_CAN         (32U)  /*!< Bitfield size in bits for CAU_CAn_CAN. */

/*! @brief Read current value of the CAU_CAn_CAN field. */
#define BR_CAU_CAn_CAN(x, n)      (HW_CAU_CAn(x, n).U)

/*! @brief Format value for bitfield CAU_CAn_CAN. */
#define BF_CAU_CAn_CAN(v)      ((uint32_t)((uint32_t)(v) << BP_CAU_CAn_CAN) & BM_CAU_CAn_CAN)

/*! @brief Set the CAN field to a new value. */
#define BW_CAU_CAn_CAN(x, n, v)   (HW_CAU_CAn_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * hw_cau_t - module struct
 ******************************************************************************/
/*!
 * @brief All CAU module registers.
 */
#pragma pack(1)
typedef struct _hw_cau
{
    __IO hw_cau_casr_t CASR; /*!< [0x0] Status Register */
    __IO hw_cau_caa_t CAA; /*!< [0x1] Accumulator */
    __IO hw_cau_can_t CAn[9]; /*!< [0x2] General Purpose Register */
} hw_cau_t;
#pragma pack()


/*! @brief Macro to access all CAU registers. */
/*! @param x CAU module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_CAU(CAU0_BASE)</code>. */
#define HW_CAU(x)      (*(hw_cau_t *)(x))

#endif /* __HW_CAU_REGISTERS_H__ */
/* v30/140722/1.3.1 */
/* EOF */
