/*
** ###################################################################
**     Compilers:           ARM Compiler
**                          Freescale C/C++ for Embedded ARM
**                          GNU C Compiler
**                          IAR ANSI C/C++ Compiler for ARM
**
**     Reference manual:    xxx
**     Version:             rev. 1.0, 2014-05-26
**     Build:               b140528
**
**     Abstract:
**         Extension to the CMSIS register access layer header.
**
**     Copyright (c) 2014 Freescale Semiconductor, Inc.
**     All rights reserved.
**
**     Redistribution and use in source and binary forms, with or without modification,
**     are permitted provided that the following conditions are met:
**
**     o Redistributions of source code must retain the above copyright notice, this list
**       of conditions and the following disclaimer.
**
**     o Redistributions in binary form must reproduce the above copyright notice, this
**       list of conditions and the following disclaimer in the documentation and/or
**       other materials provided with the distribution.
**
**     o Neither the name of Freescale Semiconductor, Inc. nor the names of its
**       contributors may be used to endorse or promote products derived from this
**       software without specific prior written permission.
**
**     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
**     ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
**     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
**     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
**     ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
**     (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
**     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
**     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
**     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
**     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**     http:                 www.freescale.com
**     mail:                 support@freescale.com
**
**     Revisions:
**     - rev. 1.0 (2014-05-26)
**
** ###################################################################
*/

/*
 * WARNING! DO NOT EDIT THIS FILE DIRECTLY!
 *
 * This file was generated automatically and any changes may be lost.
 */
#ifndef __HW_OTFAD_REGISTERS_H__
#define __HW_OTFAD_REGISTERS_H__

#include "MK80F256.h"
#include "fsl_bitaccess.h"

/*
 * MK80F256 OTFAD
 *
 * OTFAD
 *
 * Registers defined in this header file:
 * - HW_OTFAD_CR - Control
 * - HW_OTFAD_SR - Status
 * - HW_OTFAD_CRC - Cyclic Redundancy Check
 * - HW_OTFAD_CTXn_AES_KEY_W0 - AES Key Word0
 * - HW_OTFAD_CTXn_AES_KEY_W1 - AES Key Word1
 * - HW_OTFAD_CTXn_AES_KEY_W2 - AES Key Word2
 * - HW_OTFAD_CTXn_AES_KEY_W3 - AES Key Word3
 * - HW_OTFAD_CTXn_CTR_W0 - AES Counter Word0
 * - HW_OTFAD_CTXn_CTR_W1 - AES Counter Word1
 * - HW_OTFAD_CTXn_RGD_W0 - AES Region Descriptor Word0
 * - HW_OTFAD_CTXn_RGD_W1 - AES Region Descriptor Word1
 *
 * - hw_otfad_t - Struct containing all module registers.
 */

#define HW_OTFAD_INSTANCE_COUNT (1U) /*!< Number of instances of the OTFAD module. */

#define HW_OTFAD_AES_COUNT (4) /*!< Number of AES array elements. */

/*******************************************************************************
 * HW_OTFAD_CR - Control
 ******************************************************************************/

/*!
 * @brief HW_OTFAD_CR - Control (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register defines the operating configuration of the OTFAD including a global enable
 * indicator.There are 2 register bits in the CR that control the OTFAD configuration. These bits
 * (GE, RRAE) are generated based on both the contents of the CR plus static input configuration
 * signals. For both bits, the contents of the CR flag is logically summed (OR’d) with the static
 * input configuration signals to form the actual control used by the OTFAD. Reads of the CR return
 * the logical summation of these configuration controls. Additionally, the global enable is only
 * cleared by a power-on reset (POR); for all other reset events, the contents of these bits is
 * unaffected – the exception is the RRAE register flag, which is always cleared at reset. Entry
 * into the LDM or SVM modes also clears both indicators. For more details, see Section 1.5.1,
 * “OTFAD Configuration Details”.
 */
typedef union _hw_otfad_cr
{
    uint32_t U;
    struct _hw_otfad_cr_bitfields
    {
        uint32_t RESERVED0 : 2; /*!< [1:0] Reserved. */
        uint32_t FSVM : 1; /*!< [2] Force Security Violation Mode */
        uint32_t FLDM : 1; /*!< [3] Force Logically Disabled Mode */
        uint32_t RESERVED2 : 3; /*!< [6:4] Reserved. */
        uint32_t RRAE : 1; /*!< [7] Restricted Register Access Enable */
        uint32_t RESERVED3 : 8; /*!< [15:8]  */
        uint32_t CCTX : 2; /*!< [17:16] Crc ConTeXt */
        uint32_t RESERVED4 : 2; /*!< [19:18]  */
        uint32_t CRCE : 1; /*!< [20] CRC Enable */
        uint32_t CRCI : 1; /*!< [21] CRC Initialization */
        uint32_t RESERVED5 : 9; /*!< [30:22]  */
        uint32_t GE : 1; /*!< [31] Global OTFAD Enable */
    } B;
} hw_otfad_cr_t;

/*!
 * @name Constants and macros for entire OTFAD_CR register
 */
/*@{*/
#define HW_OTFAD_CR_ADDR(x)        ((x) + 0xC00U)
#define HW_OTFAD_CR(x)             (*(__IO hw_otfad_cr_t *) HW_OTFAD_CR_ADDR(x))
#define HW_OTFAD_CR_RD(x)          (HW_OTFAD_CR(x).U)
#define HW_OTFAD_CR_WR(x, v)       (HW_OTFAD_CR(x).U = (v))
#define HW_OTFAD_CR_SET(x, v)      (HW_OTFAD_CR_WR(x, HW_OTFAD_CR_RD(x) |  (v)))
#define HW_OTFAD_CR_CLR(x, v)      (HW_OTFAD_CR_WR(x, HW_OTFAD_CR_RD(x) & ~(v)))
#define HW_OTFAD_CR_TOG(x, v)      (HW_OTFAD_CR_WR(x, HW_OTFAD_CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OTFAD_CR bitfields
 */

/*!
 * @name Register OTFAD_CR, field FSVM[2] (RW)
 *
 * This bit is intended to provide a mechanism for software testing of entry into the Security
 * Violation Mode (SVM). This indicator is sticky; once set, it remains asserted until the next
 * system reset, when it is cleared.
 *
 * Values:
 * - 0 - No effect on the operating mode.
 * - 1 - Force entry into SVM after a write with this data bit set and the data bit associated with FLDM
 *     cleared. SR[MODE] signals the operating mode.
 */
/*@{*/
#define BP_OTFAD_CR_FSVM         (2U)      /*!< Bit position for OTFAD_CR_FSVM. */
#define BM_OTFAD_CR_FSVM         (0x00000004U)  /*!< Bit mask for OTFAD_CR_FSVM. */
#define BS_OTFAD_CR_FSVM         (1U)  /*!< Bitfield size in bits for OTFAD_CR_FSVM. */

/*! @brief Read current value of the OTFAD_CR_FSVM field. */
#define BR_OTFAD_CR_FSVM(x)   (HW_OTFAD_CR(x).B.FSVM)

/*! @brief Format value for bitfield OTFAD_CR_FSVM. */
#define BF_OTFAD_CR_FSVM(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CR_FSVM) & BM_OTFAD_CR_FSVM)

/*! @brief Set the FSVM field to a new value. */
#define BW_OTFAD_CR_FSVM(x, v)   (HW_OTFAD_CR_WR(x, (HW_OTFAD_CR_RD(x) & ~BM_OTFAD_CR_FSVM) | BF_OTFAD_CR_FSVM(v)))
/*@}*/

/*!
 * @name Register OTFAD_CR, field FLDM[3] (RW)
 *
 * This bit is intended to provide a mechanism for software testing of entry into the Logically
 * Disabled Mode (LDM). This indicator is sticky; once set, it remains asserted until the next
 * system reset, when it is cleared.
 *
 * Values:
 * - 0 - No effect on the operating mode.
 * - 1 - Force entry into LDM after a write with this data bit set. SR[MODE] signals the operating mode.
 */
/*@{*/
#define BP_OTFAD_CR_FLDM         (3U)      /*!< Bit position for OTFAD_CR_FLDM. */
#define BM_OTFAD_CR_FLDM         (0x00000008U)  /*!< Bit mask for OTFAD_CR_FLDM. */
#define BS_OTFAD_CR_FLDM         (1U)  /*!< Bitfield size in bits for OTFAD_CR_FLDM. */

/*! @brief Read current value of the OTFAD_CR_FLDM field. */
#define BR_OTFAD_CR_FLDM(x)   (HW_OTFAD_CR(x).B.FLDM)

/*! @brief Format value for bitfield OTFAD_CR_FLDM. */
#define BF_OTFAD_CR_FLDM(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CR_FLDM) & BM_OTFAD_CR_FLDM)

/*! @brief Set the FLDM field to a new value. */
#define BW_OTFAD_CR_FLDM(x, v)   (HW_OTFAD_CR_WR(x, (HW_OTFAD_CR_RD(x) & ~BM_OTFAD_CR_FLDM) | BF_OTFAD_CR_FLDM(v)))
/*@}*/

/*!
 * @name Register OTFAD_CR, field RRAE[7] (RW)
 *
 * The configuration control is the logical summation of the register bit and the static input
 * configuration signal and this value is returned on CR reads. It is also reflected in the SR[RRAM]
 * flag.If either this register or the static configuration input is asserted, only the CR, SR and
 * CRC registers can be accessed; attempted accesses of all other registers are treated as RAZ/WI
 * (read-as-zero/write-ignore). This indicator is sticky; once set, it remains asserted until the
 * next system reset, when it is cleared. It is also cleared by entry into the LDM or SVM modes.
 *
 * Values:
 * - 0 - Register access is fully enabled. The OTFAD programming model registers can be accessed “normally”.
 * - 1 - Register access is restricted and only the CR, SR and CRC can be accessed; others are treated as
 *     RAZ/WI.
 */
/*@{*/
#define BP_OTFAD_CR_RRAE         (7U)      /*!< Bit position for OTFAD_CR_RRAE. */
#define BM_OTFAD_CR_RRAE         (0x00000080U)  /*!< Bit mask for OTFAD_CR_RRAE. */
#define BS_OTFAD_CR_RRAE         (1U)  /*!< Bitfield size in bits for OTFAD_CR_RRAE. */

/*! @brief Read current value of the OTFAD_CR_RRAE field. */
#define BR_OTFAD_CR_RRAE(x)   (HW_OTFAD_CR(x).B.RRAE)

/*! @brief Format value for bitfield OTFAD_CR_RRAE. */
#define BF_OTFAD_CR_RRAE(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CR_RRAE) & BM_OTFAD_CR_RRAE)

/*! @brief Set the RRAE field to a new value. */
#define BW_OTFAD_CR_RRAE(x, v)   (HW_OTFAD_CR_WR(x, (HW_OTFAD_CR_RD(x) & ~BM_OTFAD_CR_RRAE) | BF_OTFAD_CR_RRAE(v)))
/*@}*/

/*!
 * @name Register OTFAD_CR, field CCTX[17:16] (RW)
 *
 * This 2-bit field defines which context has its CRC check enabled when CR[CRCE] = 1.
 *
 * Values:
 * - 00 - Enable CTX0 CRC check.
 * - 01 - Enable CTX1 CRC check.
 * - 10 - Enable CTX2 CRC check.
 * - 11 - Enable CTX3 CRC check.
 */
/*@{*/
#define BP_OTFAD_CR_CCTX         (16U)      /*!< Bit position for OTFAD_CR_CCTX. */
#define BM_OTFAD_CR_CCTX         (0x00030000U)  /*!< Bit mask for OTFAD_CR_CCTX. */
#define BS_OTFAD_CR_CCTX         (2U)  /*!< Bitfield size in bits for OTFAD_CR_CCTX. */

/*! @brief Read current value of the OTFAD_CR_CCTX field. */
#define BR_OTFAD_CR_CCTX(x)   (HW_OTFAD_CR(x).B.CCTX)

/*! @brief Format value for bitfield OTFAD_CR_CCTX. */
#define BF_OTFAD_CR_CCTX(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CR_CCTX) & BM_OTFAD_CR_CCTX)

/*! @brief Set the CCTX field to a new value. */
#define BW_OTFAD_CR_CCTX(x, v)   (HW_OTFAD_CR_WR(x, (HW_OTFAD_CR_RD(x) & ~BM_OTFAD_CR_CCTX) | BF_OTFAD_CR_CCTX(v)))
/*@}*/

/*!
 * @name Register OTFAD_CR, field CRCE[20] (RW)
 *
 * This bit controls if the standard 32-bit Ethernet cyclic redundancy check (CRC) for a given
 * context is enabled. It is cleared by entry into the LDM or SVM modes.
 *
 * Values:
 * - 0 - CRC-32 is disabled.
 * - 1 - CRC-32 for the context defined by CR[CCTRX] is enabled.
 */
/*@{*/
#define BP_OTFAD_CR_CRCE         (20U)      /*!< Bit position for OTFAD_CR_CRCE. */
#define BM_OTFAD_CR_CRCE         (0x00100000U)  /*!< Bit mask for OTFAD_CR_CRCE. */
#define BS_OTFAD_CR_CRCE         (1U)  /*!< Bitfield size in bits for OTFAD_CR_CRCE. */

/*! @brief Read current value of the OTFAD_CR_CRCE field. */
#define BR_OTFAD_CR_CRCE(x)   (HW_OTFAD_CR(x).B.CRCE)

/*! @brief Format value for bitfield OTFAD_CR_CRCE. */
#define BF_OTFAD_CR_CRCE(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CR_CRCE) & BM_OTFAD_CR_CRCE)

/*! @brief Set the CRCE field to a new value. */
#define BW_OTFAD_CR_CRCE(x, v)   (HW_OTFAD_CR_WR(x, (HW_OTFAD_CR_RD(x) & ~BM_OTFAD_CR_CRCE) | BF_OTFAD_CR_CRCE(v)))
/*@}*/

/*!
 * @name Register OTFAD_CR, field CRCI[21] (WORZ)
 *
 * When set, this bit forces an initialization of the CRC data register to all ones. This bit always
 * reads as zero.
 *
 * Values:
 * - 0 - CRC data register is unaffected.
 * - 1 - CRC data register is immediately initialized after a write with this data bit set.
 */
/*@{*/
#define BP_OTFAD_CR_CRCI         (21U)      /*!< Bit position for OTFAD_CR_CRCI. */
#define BM_OTFAD_CR_CRCI         (0x00200000U)  /*!< Bit mask for OTFAD_CR_CRCI. */
#define BS_OTFAD_CR_CRCI         (1U)  /*!< Bitfield size in bits for OTFAD_CR_CRCI. */

/*! @brief Format value for bitfield OTFAD_CR_CRCI. */
#define BF_OTFAD_CR_CRCI(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CR_CRCI) & BM_OTFAD_CR_CRCI)

/*! @brief Set the CRCI field to a new value. */
#define BW_OTFAD_CR_CRCI(x, v)   (HW_OTFAD_CR_WR(x, (HW_OTFAD_CR_RD(x) & ~BM_OTFAD_CR_CRCI) | BF_OTFAD_CR_CRCI(v)))
/*@}*/

/*!
 * @name Register OTFAD_CR, field GE[31] (RW)
 *
 * This bit enables the OTFAD operation. The configuration control is the logical summation of the
 * register bit and the static input configuration signal and this value is returned on CR
 * reads.This register is cleared on power-on reset; it is unaffected by other reset events. It is
 * also cleared by entry into the LDM or SVM modes.
 *
 * Values:
 * - 0 - OTFAD is disabled, and bypasses all data fetched by the QuadSPI.
 * - 1 - OTFAD is enabled, and processes data fetched by the QuadSPI as defined by the hardware
 *     configuration.
 */
/*@{*/
#define BP_OTFAD_CR_GE         (31U)      /*!< Bit position for OTFAD_CR_GE. */
#define BM_OTFAD_CR_GE         (0x80000000U)  /*!< Bit mask for OTFAD_CR_GE. */
#define BS_OTFAD_CR_GE         (1U)  /*!< Bitfield size in bits for OTFAD_CR_GE. */

/*! @brief Read current value of the OTFAD_CR_GE field. */
#define BR_OTFAD_CR_GE(x)   (HW_OTFAD_CR(x).B.GE)

/*! @brief Format value for bitfield OTFAD_CR_GE. */
#define BF_OTFAD_CR_GE(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CR_GE) & BM_OTFAD_CR_GE)

/*! @brief Set the GE field to a new value. */
#define BW_OTFAD_CR_GE(x, v)   (HW_OTFAD_CR_WR(x, (HW_OTFAD_CR_RD(x) & ~BM_OTFAD_CR_GE) | BF_OTFAD_CR_GE(v)))
/*@}*/

/*******************************************************************************
 * HW_OTFAD_SR - Status
 ******************************************************************************/

/*!
 * @brief HW_OTFAD_SR - Status (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides OTFAD status information.
 */
typedef union _hw_otfad_sr
{
    uint32_t U;
    struct _hw_otfad_sr_bitfields
    {
        uint32_t RESERVED0 : 1; /*!< [0]  */
        uint32_t MDPCP : 1; /*!< [1] MDPC Present */
        uint32_t MODE : 2; /*!< [3:2] operating MODE */
        uint32_t NCTX : 4; /*!< [7:4] Number of ConTeXts */
        uint32_t RESERVED3 : 16; /*!< [23:8] Reserved. */
        uint32_t HRL : 4; /*!< [27:24] Hardware Revision Level */
        uint32_t RRAM : 1; /*!< [28] Restricted Register Access Mode */
        uint32_t GEM : 1; /*!< [29] Global Enable Mode */
        uint32_t RESERVED4 : 2; /*!< [31:30] Reserved. */
    } B;
} hw_otfad_sr_t;

/*!
 * @name Constants and macros for entire OTFAD_SR register
 */
/*@{*/
#define HW_OTFAD_SR_ADDR(x)        ((x) + 0xC04U)
#define HW_OTFAD_SR(x)             (*(__IO hw_otfad_sr_t *) HW_OTFAD_SR_ADDR(x))
#define HW_OTFAD_SR_RD(x)          (HW_OTFAD_SR(x).U)
#define HW_OTFAD_SR_WR(x, v)       (HW_OTFAD_SR(x).U = (v))
#define HW_OTFAD_SR_SET(x, v)      (HW_OTFAD_SR_WR(x, HW_OTFAD_SR_RD(x) |  (v)))
#define HW_OTFAD_SR_CLR(x, v)      (HW_OTFAD_SR_WR(x, HW_OTFAD_SR_RD(x) & ~(v)))
#define HW_OTFAD_SR_TOG(x, v)      (HW_OTFAD_SR_WR(x, HW_OTFAD_SR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OTFAD_SR bitfields
 */

/*!
 * @name Register OTFAD_SR, field MDPCP[1] (RO)
 *
 * This read-only field signals the presense of the Multi-Demensional Parity Checker. For this
 * device, it always has the value 0.
 */
/*@{*/
#define BP_OTFAD_SR_MDPCP         (1U)      /*!< Bit position for OTFAD_SR_MDPCP. */
#define BM_OTFAD_SR_MDPCP         (0x00000002U)  /*!< Bit mask for OTFAD_SR_MDPCP. */
#define BS_OTFAD_SR_MDPCP         (1U)  /*!< Bitfield size in bits for OTFAD_SR_MDPCP. */

/*! @brief Read current value of the OTFAD_SR_MDPCP field. */
#define BR_OTFAD_SR_MDPCP(x)   (HW_OTFAD_SR(x).B.MDPCP)
/*@}*/

/*!
 * @name Register OTFAD_SR, field MODE[3:2] (RO)
 *
 * This 2-bit read-only field specifies the OTFAD’s operating mode. Input configuration and control
 * signals force entry from normal model (NRM) into one of the two special operating modes (LDM,
 * SVM). See Section 1.1.4, “Modes of Operation” for more details.
 *
 * Values:
 * - 00 - Operating in Normal mode (NRM)
 * - 01 - Unused (reserved)
 * - 10 - Operating in Security Violation Mode (SVM)
 * - 11 - Operating in Logically Disabled Mode (LDM)
 */
/*@{*/
#define BP_OTFAD_SR_MODE         (2U)      /*!< Bit position for OTFAD_SR_MODE. */
#define BM_OTFAD_SR_MODE         (0x0000000CU)  /*!< Bit mask for OTFAD_SR_MODE. */
#define BS_OTFAD_SR_MODE         (2U)  /*!< Bitfield size in bits for OTFAD_SR_MODE. */

/*! @brief Read current value of the OTFAD_SR_MODE field. */
#define BR_OTFAD_SR_MODE(x)   (HW_OTFAD_SR(x).B.MODE)
/*@}*/

/*!
 * @name Register OTFAD_SR, field NCTX[7:4] (RO)
 *
 * This 4-bit read-only field signals the number of implemented hardware contexts. It reads as 4.
 */
/*@{*/
#define BP_OTFAD_SR_NCTX         (4U)      /*!< Bit position for OTFAD_SR_NCTX. */
#define BM_OTFAD_SR_NCTX         (0x000000F0U)  /*!< Bit mask for OTFAD_SR_NCTX. */
#define BS_OTFAD_SR_NCTX         (4U)  /*!< Bitfield size in bits for OTFAD_SR_NCTX. */

/*! @brief Read current value of the OTFAD_SR_NCTX field. */
#define BR_OTFAD_SR_NCTX(x)   (HW_OTFAD_SR(x).B.NCTX)
/*@}*/

/*!
 * @name Register OTFAD_SR, field HRL[27:24] (RO)
 *
 * This field reads as zero.
 */
/*@{*/
#define BP_OTFAD_SR_HRL         (24U)      /*!< Bit position for OTFAD_SR_HRL. */
#define BM_OTFAD_SR_HRL         (0x0F000000U)  /*!< Bit mask for OTFAD_SR_HRL. */
#define BS_OTFAD_SR_HRL         (4U)  /*!< Bitfield size in bits for OTFAD_SR_HRL. */

/*! @brief Read current value of the OTFAD_SR_HRL field. */
#define BR_OTFAD_SR_HRL(x)   (HW_OTFAD_SR(x).B.HRL)
/*@}*/

/*!
 * @name Register OTFAD_SR, field RRAM[28] (RO)
 *
 * This read-only indicator signals that accesses to the slave peripheral bus are operating in a
 * restricted mode, where only the CR, SR and CRC registers can be referenced. This access mode can
 * be defined by the assertion of CR[RRAE] = 1 or a static configuration input. Attempted accesses
 * to other registers are treated as RAZ/WI. This flag is identical to the read value of CR[RRAE].
 *
 * Values:
 * - 0 - Register access is fully enabled. The OTFAD programming model registers can be accessed “normally”.
 * - 1 - Register access is restricted and only the CR, SR and CRC can be accessed; others are treated as
 *     RAZ/WI.
 */
/*@{*/
#define BP_OTFAD_SR_RRAM         (28U)      /*!< Bit position for OTFAD_SR_RRAM. */
#define BM_OTFAD_SR_RRAM         (0x10000000U)  /*!< Bit mask for OTFAD_SR_RRAM. */
#define BS_OTFAD_SR_RRAM         (1U)  /*!< Bitfield size in bits for OTFAD_SR_RRAM. */

/*! @brief Read current value of the OTFAD_SR_RRAM field. */
#define BR_OTFAD_SR_RRAM(x)   (HW_OTFAD_SR(x).B.RRAM)
/*@}*/

/*!
 * @name Register OTFAD_SR, field GEM[29] (RO)
 *
 * This read-only indicator signals the global enabled/disabled state of the OTFAD. It is the
 * logical summation of the CR[GE] register bit and a static input configuration signal. This flag
 * is identical to the read value of CR[GE].
 *
 * Values:
 * - 0 - OTFAD is disabled, and bypasses all data fetched by the QuadSPI.
 * - 1 - OTFAD is enabled, and processes data fetched by the QuadSPI as defined by the hardware
 *     configuration.
 */
/*@{*/
#define BP_OTFAD_SR_GEM         (29U)      /*!< Bit position for OTFAD_SR_GEM. */
#define BM_OTFAD_SR_GEM         (0x20000000U)  /*!< Bit mask for OTFAD_SR_GEM. */
#define BS_OTFAD_SR_GEM         (1U)  /*!< Bitfield size in bits for OTFAD_SR_GEM. */

/*! @brief Read current value of the OTFAD_SR_GEM field. */
#define BR_OTFAD_SR_GEM(x)   (HW_OTFAD_SR(x).B.GEM)
/*@}*/

/*******************************************************************************
 * HW_OTFAD_CRC - Cyclic Redundancy Check
 ******************************************************************************/

/*!
 * @brief HW_OTFAD_CRC - Cyclic Redundancy Check (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CRC register is the data register used during OTFAD cyclic redundancy check operations.The
 * CRC implements the standard 32-bit “Ethernet” polynomial, commonly expressed as 0x04C1_1DB7 or
 * mathematically as x32 + x26 + x23 + x22 + x16 + x12 + x11 + x10 + x8 + x7 + x5 + x4 + x2 + x +
 * 1.The OTFAD supports optional CRC calculations during key blob processing and/or for a selected
 * context. For all uses, the data being checked is the plaintext output, processed as a little
 * endian array of 8-bit bytes. It must be accessed sequentially from the lowest address to the
 * highest address.For CRC checking on a selected context, the hardware must be configured by
 * writing the CR[CRCI = 1, CRCE = 1, CCTX = n] bit fields. This initializes the CRC to 0xFFFF_FFFF,
 * enables it and selects context n as the data source. See Section 1.6.3, “Context CRC” for
 * additional information.It should also be noted that the CRC hardware implements a data pipeline
 * and the CRC register is not updated with its final value until 2 cycles after the last input data
 * is presented to the OTFAD. For typical system use cases, this exposed pipeline time is not be
 * visible to reads of this register on the slave peripheral bus.
 */
typedef union _hw_otfad_crc
{
    uint32_t U;
    struct _hw_otfad_crc_bitfields
    {
        uint32_t CRCD : 32; /*!< [31:0] CRC DATA. */
    } B;
} hw_otfad_crc_t;

/*!
 * @name Constants and macros for entire OTFAD_CRC register
 */
/*@{*/
#define HW_OTFAD_CRC_ADDR(x)        ((x) + 0xC08U)
#define HW_OTFAD_CRC(x)             (*(__IO hw_otfad_crc_t *) HW_OTFAD_CRC_ADDR(x))
#define HW_OTFAD_CRC_RD(x)          (HW_OTFAD_CRC(x).U)
#define HW_OTFAD_CRC_WR(x, v)       (HW_OTFAD_CRC(x).U = (v))
#define HW_OTFAD_CRC_SET(x, v)      (HW_OTFAD_CRC_WR(x, HW_OTFAD_CRC_RD(x) |  (v)))
#define HW_OTFAD_CRC_CLR(x, v)      (HW_OTFAD_CRC_WR(x, HW_OTFAD_CRC_RD(x) & ~(v)))
#define HW_OTFAD_CRC_TOG(x, v)      (HW_OTFAD_CRC_WR(x, HW_OTFAD_CRC_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OTFAD_CRC bitfields
 */

/*!
 * @name Register OTFAD_CRC, field CRCD[31:0] (RW)
 */
/*@{*/
#define BP_OTFAD_CRC_CRCD         (0U)      /*!< Bit position for OTFAD_CRC_CRCD. */
#define BM_OTFAD_CRC_CRCD         (0xFFFFFFFFU)  /*!< Bit mask for OTFAD_CRC_CRCD. */
#define BS_OTFAD_CRC_CRCD         (32U)  /*!< Bitfield size in bits for OTFAD_CRC_CRCD. */

/*! @brief Read current value of the OTFAD_CRC_CRCD field. */
#define BR_OTFAD_CRC_CRCD(x)      (HW_OTFAD_CRC(x).U)

/*! @brief Format value for bitfield OTFAD_CRC_CRCD. */
#define BF_OTFAD_CRC_CRCD(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CRC_CRCD) & BM_OTFAD_CRC_CRCD)

/*! @brief Set the CRCD field to a new value. */
#define BW_OTFAD_CRC_CRCD(x, v)   (HW_OTFAD_CRC_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_OTFAD_CTXn_AES_KEY_W0 - AES Key Word0
 ******************************************************************************/

/*!
 * @brief HW_OTFAD_CTXn_AES_KEY_W0 - AES Key Word0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CTXn_KEY_W0 (n=0-3) registers provide W0 (32 bits) of a 2-dimensional data structure for
 * local OTFAD storage of the 128-bit key for context “n”.There are four consecutive memory-mapped
 * register words containing the key used for the AES calculations associated with the given
 * context. The programming model view of the CTXn_KEY_Wm registers is a little-endian 16-element
 * byte data array, while the 128-bit key is defined as the concatenation of {A0, A1, A2,..., A14,
 * A15}.
 */
typedef union _hw_otfad_ctxn_aes_key_w0
{
    uint32_t U;
    struct _hw_otfad_ctxn_aes_key_w0_bitfields
    {
        uint32_t W0KEY : 32; /*!< [31:0] AES Key */
    } B;
} hw_otfad_ctxn_aes_key_w0_t;

/*!
 * @name Constants and macros for entire OTFAD_CTXn_AES_KEY_W0 register
 */
/*@{*/
/*! @brief Number of instances of the OTFAD_CTXn_AES_KEY_W0 register. */
#define HW_OTFAD_CTXn_AES_KEY_W0_COUNT     (4U)

#define HW_OTFAD_CTXn_AES_KEY_W0_ADDR(x, n)     ((x) + 0xD00U + (0x40U * (n)))
#define HW_OTFAD_CTXn_AES_KEY_W0(x, n)          (*(__IO hw_otfad_ctxn_aes_key_w0_t *) HW_OTFAD_CTXn_AES_KEY_W0_ADDR(x, n))
#define HW_OTFAD_CTXn_AES_KEY_W0_RD(x, n)       (HW_OTFAD_CTXn_AES_KEY_W0(x, n).U)
#define HW_OTFAD_CTXn_AES_KEY_W0_WR(x, n, v)    (HW_OTFAD_CTXn_AES_KEY_W0(x, n).U = (v))
#define HW_OTFAD_CTXn_AES_KEY_W0_SET(x, n, v)   (HW_OTFAD_CTXn_AES_KEY_W0_WR(x, n, HW_OTFAD_CTXn_AES_KEY_W0_RD(x, n) |  (v)))
#define HW_OTFAD_CTXn_AES_KEY_W0_CLR(x, n, v)   (HW_OTFAD_CTXn_AES_KEY_W0_WR(x, n, HW_OTFAD_CTXn_AES_KEY_W0_RD(x, n) & ~(v)))
#define HW_OTFAD_CTXn_AES_KEY_W0_TOG(x, n, v)   (HW_OTFAD_CTXn_AES_KEY_W0_WR(x, n, HW_OTFAD_CTXn_AES_KEY_W0_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OTFAD_CTXn_AES_KEY_W0 bitfields
 */

/*!
 * @name Register OTFAD_CTXn_AES_KEY_W0, field W0KEY[31:0] (RW)
 *
 * The key is typically loaded as the corresponding key blob is unwrapped; alternatively, if
 * enabled, it can be written using the slave peripheral bus. The four consecutive little-endian
 * memory-mapped registers provide 128 bits of key storage.Word0: KEY[31:0][A03, A02, A01,
 * A00]Word1: KEY[31:0][A07, A06, A05, A04]Word2: KEY[31:0][A11, A10, A09, A08]Word3: KEY[31:0][A15,
 * A14, A13, A12]
 */
/*@{*/
#define BP_OTFAD_CTXn_AES_KEY_W0_W0KEY         (0U)      /*!< Bit position for OTFAD_CTXn_AES_KEY_W0_W0KEY. */
#define BM_OTFAD_CTXn_AES_KEY_W0_W0KEY         (0xFFFFFFFFU)  /*!< Bit mask for OTFAD_CTXn_AES_KEY_W0_W0KEY. */
#define BS_OTFAD_CTXn_AES_KEY_W0_W0KEY         (32U)  /*!< Bitfield size in bits for OTFAD_CTXn_AES_KEY_W0_W0KEY. */

/*! @brief Read current value of the OTFAD_CTXn_AES_KEY_W0_W0KEY field. */
#define BR_OTFAD_CTXn_AES_KEY_W0_W0KEY(x, n)      (HW_OTFAD_CTXn_AES_KEY_W0(x, n).U)

/*! @brief Format value for bitfield OTFAD_CTXn_AES_KEY_W0_W0KEY. */
#define BF_OTFAD_CTXn_AES_KEY_W0_W0KEY(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CTXn_AES_KEY_W0_W0KEY) & BM_OTFAD_CTXn_AES_KEY_W0_W0KEY)

/*! @brief Set the W0KEY field to a new value. */
#define BW_OTFAD_CTXn_AES_KEY_W0_W0KEY(x, n, v)   (HW_OTFAD_CTXn_AES_KEY_W0_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_OTFAD_CTXn_AES_KEY_W1 - AES Key Word1
 ******************************************************************************/

/*!
 * @brief HW_OTFAD_CTXn_AES_KEY_W1 - AES Key Word1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CTXn_KEY_W1 (n=0-3) registers provide W1(32 bits) of a 2-dimensional data structure for local
 * OTFAD storage of the 128-bit key for context “n”.There are four consecutive memory-mapped
 * register words containing the key used for the AES calculations associated with the given
 * context. The programming model view of the CTXn_KEY_Wm registers is a little-endian 16-element
 * byte data array, while the 128-bit key is defined as the concatenation of {A0, A1, A2,..., A14,
 * A15}.
 */
typedef union _hw_otfad_ctxn_aes_key_w1
{
    uint32_t U;
    struct _hw_otfad_ctxn_aes_key_w1_bitfields
    {
        uint32_t W1KEY : 32; /*!< [31:0] AES Key */
    } B;
} hw_otfad_ctxn_aes_key_w1_t;

/*!
 * @name Constants and macros for entire OTFAD_CTXn_AES_KEY_W1 register
 */
/*@{*/
/*! @brief Number of instances of the OTFAD_CTXn_AES_KEY_W1 register. */
#define HW_OTFAD_CTXn_AES_KEY_W1_COUNT     (4U)

#define HW_OTFAD_CTXn_AES_KEY_W1_ADDR(x, n)     ((x) + 0xD04U + (0x40U * (n)))
#define HW_OTFAD_CTXn_AES_KEY_W1(x, n)          (*(__IO hw_otfad_ctxn_aes_key_w1_t *) HW_OTFAD_CTXn_AES_KEY_W1_ADDR(x, n))
#define HW_OTFAD_CTXn_AES_KEY_W1_RD(x, n)       (HW_OTFAD_CTXn_AES_KEY_W1(x, n).U)
#define HW_OTFAD_CTXn_AES_KEY_W1_WR(x, n, v)    (HW_OTFAD_CTXn_AES_KEY_W1(x, n).U = (v))
#define HW_OTFAD_CTXn_AES_KEY_W1_SET(x, n, v)   (HW_OTFAD_CTXn_AES_KEY_W1_WR(x, n, HW_OTFAD_CTXn_AES_KEY_W1_RD(x, n) |  (v)))
#define HW_OTFAD_CTXn_AES_KEY_W1_CLR(x, n, v)   (HW_OTFAD_CTXn_AES_KEY_W1_WR(x, n, HW_OTFAD_CTXn_AES_KEY_W1_RD(x, n) & ~(v)))
#define HW_OTFAD_CTXn_AES_KEY_W1_TOG(x, n, v)   (HW_OTFAD_CTXn_AES_KEY_W1_WR(x, n, HW_OTFAD_CTXn_AES_KEY_W1_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OTFAD_CTXn_AES_KEY_W1 bitfields
 */

/*!
 * @name Register OTFAD_CTXn_AES_KEY_W1, field W1KEY[31:0] (RW)
 *
 * The key is typically loaded as the corresponding key blob is unwrapped; alternatively, if
 * enabled, it can be written using the slave peripheral bus. The four consecutive little-endian
 * memory-mapped registers provide 128 bits of key storage.Word0: KEY[31:0][A03, A02, A01,
 * A00]Word1: KEY[31:0][A07, A06, A05, A04]Word2: KEY[31:0][A11, A10, A09, A08]Word3: KEY[31:0][A15,
 * A14, A13, A12]
 */
/*@{*/
#define BP_OTFAD_CTXn_AES_KEY_W1_W1KEY         (0U)      /*!< Bit position for OTFAD_CTXn_AES_KEY_W1_W1KEY. */
#define BM_OTFAD_CTXn_AES_KEY_W1_W1KEY         (0xFFFFFFFFU)  /*!< Bit mask for OTFAD_CTXn_AES_KEY_W1_W1KEY. */
#define BS_OTFAD_CTXn_AES_KEY_W1_W1KEY         (32U)  /*!< Bitfield size in bits for OTFAD_CTXn_AES_KEY_W1_W1KEY. */

/*! @brief Read current value of the OTFAD_CTXn_AES_KEY_W1_W1KEY field. */
#define BR_OTFAD_CTXn_AES_KEY_W1_W1KEY(x, n)      (HW_OTFAD_CTXn_AES_KEY_W1(x, n).U)

/*! @brief Format value for bitfield OTFAD_CTXn_AES_KEY_W1_W1KEY. */
#define BF_OTFAD_CTXn_AES_KEY_W1_W1KEY(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CTXn_AES_KEY_W1_W1KEY) & BM_OTFAD_CTXn_AES_KEY_W1_W1KEY)

/*! @brief Set the W1KEY field to a new value. */
#define BW_OTFAD_CTXn_AES_KEY_W1_W1KEY(x, n, v)   (HW_OTFAD_CTXn_AES_KEY_W1_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_OTFAD_CTXn_AES_KEY_W2 - AES Key Word2
 ******************************************************************************/

/*!
 * @brief HW_OTFAD_CTXn_AES_KEY_W2 - AES Key Word2 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CTXn_KEY_W2 (n=0-3) registers provide W2(32 bits) of a 2-dimensional data structure for local
 * OTFAD storage of the 128-bit key for context “n”.There are four consecutive memory-mapped
 * register words containing the key used for the AES calculations associated with the given
 * context. The programming model view of the CTXn_KEY_Wm registers is a little-endian 16-element
 * byte data array, while the 128-bit key is defined as the concatenation of {A0, A1, A2,..., A14,
 * A15}.
 */
typedef union _hw_otfad_ctxn_aes_key_w2
{
    uint32_t U;
    struct _hw_otfad_ctxn_aes_key_w2_bitfields
    {
        uint32_t W2KEY : 32; /*!< [31:0] AES Key */
    } B;
} hw_otfad_ctxn_aes_key_w2_t;

/*!
 * @name Constants and macros for entire OTFAD_CTXn_AES_KEY_W2 register
 */
/*@{*/
/*! @brief Number of instances of the OTFAD_CTXn_AES_KEY_W2 register. */
#define HW_OTFAD_CTXn_AES_KEY_W2_COUNT     (4U)

#define HW_OTFAD_CTXn_AES_KEY_W2_ADDR(x, n)     ((x) + 0xD08U + (0x40U * (n)))
#define HW_OTFAD_CTXn_AES_KEY_W2(x, n)          (*(__IO hw_otfad_ctxn_aes_key_w2_t *) HW_OTFAD_CTXn_AES_KEY_W2_ADDR(x, n))
#define HW_OTFAD_CTXn_AES_KEY_W2_RD(x, n)       (HW_OTFAD_CTXn_AES_KEY_W2(x, n).U)
#define HW_OTFAD_CTXn_AES_KEY_W2_WR(x, n, v)    (HW_OTFAD_CTXn_AES_KEY_W2(x, n).U = (v))
#define HW_OTFAD_CTXn_AES_KEY_W2_SET(x, n, v)   (HW_OTFAD_CTXn_AES_KEY_W2_WR(x, n, HW_OTFAD_CTXn_AES_KEY_W2_RD(x, n) |  (v)))
#define HW_OTFAD_CTXn_AES_KEY_W2_CLR(x, n, v)   (HW_OTFAD_CTXn_AES_KEY_W2_WR(x, n, HW_OTFAD_CTXn_AES_KEY_W2_RD(x, n) & ~(v)))
#define HW_OTFAD_CTXn_AES_KEY_W2_TOG(x, n, v)   (HW_OTFAD_CTXn_AES_KEY_W2_WR(x, n, HW_OTFAD_CTXn_AES_KEY_W2_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OTFAD_CTXn_AES_KEY_W2 bitfields
 */

/*!
 * @name Register OTFAD_CTXn_AES_KEY_W2, field W2KEY[31:0] (RW)
 *
 * The key is typically loaded as the corresponding key blob is unwrapped; alternatively, if
 * enabled, it can be writtenusing the slave peripheral bus. The four consecutive little-endian
 * memory-mapped registers provide 128 bits of key storage.Word0: KEY[31:0][A03, A02, A01,
 * A00]Word1: KEY[31:0][A07, A06, A05, A04]Word2: KEY[31:0][A11, A10, A09, A08]Word3: KEY[31:0][A15,
 * A14, A13, A12]
 */
/*@{*/
#define BP_OTFAD_CTXn_AES_KEY_W2_W2KEY         (0U)      /*!< Bit position for OTFAD_CTXn_AES_KEY_W2_W2KEY. */
#define BM_OTFAD_CTXn_AES_KEY_W2_W2KEY         (0xFFFFFFFFU)  /*!< Bit mask for OTFAD_CTXn_AES_KEY_W2_W2KEY. */
#define BS_OTFAD_CTXn_AES_KEY_W2_W2KEY         (32U)  /*!< Bitfield size in bits for OTFAD_CTXn_AES_KEY_W2_W2KEY. */

/*! @brief Read current value of the OTFAD_CTXn_AES_KEY_W2_W2KEY field. */
#define BR_OTFAD_CTXn_AES_KEY_W2_W2KEY(x, n)      (HW_OTFAD_CTXn_AES_KEY_W2(x, n).U)

/*! @brief Format value for bitfield OTFAD_CTXn_AES_KEY_W2_W2KEY. */
#define BF_OTFAD_CTXn_AES_KEY_W2_W2KEY(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CTXn_AES_KEY_W2_W2KEY) & BM_OTFAD_CTXn_AES_KEY_W2_W2KEY)

/*! @brief Set the W2KEY field to a new value. */
#define BW_OTFAD_CTXn_AES_KEY_W2_W2KEY(x, n, v)   (HW_OTFAD_CTXn_AES_KEY_W2_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_OTFAD_CTXn_AES_KEY_W3 - AES Key Word3
 ******************************************************************************/

/*!
 * @brief HW_OTFAD_CTXn_AES_KEY_W3 - AES Key Word3 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CTXn_KEY_W3 (n=0-3) registers provide W3(32 bits) of a 2-dimensional data structure for local
 * OTFAD storage of the 128-bit key for context “n”.There are four consecutive memory-mapped
 * register words containing the key used for the AES calculations associated with the given
 * context. The programming model view of the CTXn_KEY_Wm registers is a little-endian 16-element
 * byte data array, while the 128-bit key is defined as the concatenation of {A0, A1, A2,..., A14,
 * A15}.
 */
typedef union _hw_otfad_ctxn_aes_key_w3
{
    uint32_t U;
    struct _hw_otfad_ctxn_aes_key_w3_bitfields
    {
        uint32_t W3KEY : 32; /*!< [31:0] AES Key */
    } B;
} hw_otfad_ctxn_aes_key_w3_t;

/*!
 * @name Constants and macros for entire OTFAD_CTXn_AES_KEY_W3 register
 */
/*@{*/
/*! @brief Number of instances of the OTFAD_CTXn_AES_KEY_W3 register. */
#define HW_OTFAD_CTXn_AES_KEY_W3_COUNT     (4U)

#define HW_OTFAD_CTXn_AES_KEY_W3_ADDR(x, n)     ((x) + 0xD0CU + (0x40U * (n)))
#define HW_OTFAD_CTXn_AES_KEY_W3(x, n)          (*(__IO hw_otfad_ctxn_aes_key_w3_t *) HW_OTFAD_CTXn_AES_KEY_W3_ADDR(x, n))
#define HW_OTFAD_CTXn_AES_KEY_W3_RD(x, n)       (HW_OTFAD_CTXn_AES_KEY_W3(x, n).U)
#define HW_OTFAD_CTXn_AES_KEY_W3_WR(x, n, v)    (HW_OTFAD_CTXn_AES_KEY_W3(x, n).U = (v))
#define HW_OTFAD_CTXn_AES_KEY_W3_SET(x, n, v)   (HW_OTFAD_CTXn_AES_KEY_W3_WR(x, n, HW_OTFAD_CTXn_AES_KEY_W3_RD(x, n) |  (v)))
#define HW_OTFAD_CTXn_AES_KEY_W3_CLR(x, n, v)   (HW_OTFAD_CTXn_AES_KEY_W3_WR(x, n, HW_OTFAD_CTXn_AES_KEY_W3_RD(x, n) & ~(v)))
#define HW_OTFAD_CTXn_AES_KEY_W3_TOG(x, n, v)   (HW_OTFAD_CTXn_AES_KEY_W3_WR(x, n, HW_OTFAD_CTXn_AES_KEY_W3_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OTFAD_CTXn_AES_KEY_W3 bitfields
 */

/*!
 * @name Register OTFAD_CTXn_AES_KEY_W3, field W3KEY[31:0] (RW)
 *
 * The key is typically loaded as the corresponding key blob is unwrapped; alternatively, if
 * enabled, it can be written using the slave peripheral bus. The four consecutive little-endian
 * memory-mapped registers provide 128 bits of key storage.Word0: KEY[31:0][A03, A02, A01,
 * A00]Word1: KEY[31:0][A07, A06, A05, A04]Word2: KEY[31:0][A11, A10, A09, A08]Word3: KEY[31:0][A15,
 * A14, A13, A12]
 */
/*@{*/
#define BP_OTFAD_CTXn_AES_KEY_W3_W3KEY         (0U)      /*!< Bit position for OTFAD_CTXn_AES_KEY_W3_W3KEY. */
#define BM_OTFAD_CTXn_AES_KEY_W3_W3KEY         (0xFFFFFFFFU)  /*!< Bit mask for OTFAD_CTXn_AES_KEY_W3_W3KEY. */
#define BS_OTFAD_CTXn_AES_KEY_W3_W3KEY         (32U)  /*!< Bitfield size in bits for OTFAD_CTXn_AES_KEY_W3_W3KEY. */

/*! @brief Read current value of the OTFAD_CTXn_AES_KEY_W3_W3KEY field. */
#define BR_OTFAD_CTXn_AES_KEY_W3_W3KEY(x, n)      (HW_OTFAD_CTXn_AES_KEY_W3(x, n).U)

/*! @brief Format value for bitfield OTFAD_CTXn_AES_KEY_W3_W3KEY. */
#define BF_OTFAD_CTXn_AES_KEY_W3_W3KEY(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CTXn_AES_KEY_W3_W3KEY) & BM_OTFAD_CTXn_AES_KEY_W3_W3KEY)

/*! @brief Set the W3KEY field to a new value. */
#define BW_OTFAD_CTXn_AES_KEY_W3_W3KEY(x, n, v)   (HW_OTFAD_CTXn_AES_KEY_W3_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_OTFAD_CTXn_CTR_W0 - AES Counter Word0
 ******************************************************************************/

/*!
 * @brief HW_OTFAD_CTXn_CTR_W0 - AES Counter Word0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CTXn_CTR_W0 registers provide 32 bits of Word0 of a 2-dimensional data structure for local
 * OTFAD storage of 64 bits of the counter value for context “n”. There are two consecutive memory-
 * mapped register words defining the upper 96 bits of the counter used for the AES calculations
 * associated with the given context.The programming model view of the CTXn_CTR_Wm registers is a
 * little-endian 8-element byte data array.The entire 128-bit counter value is defined as the
 * concatenation of four 32-bit values:CTR[127–0] = {CTR_W0[C0...C3], CTR_W1[C4...C7],
 * CTR_W0[C0...C3] ^ CTR_W1[C4...C7], systemAddress[31–4], 0h}
 */
typedef union _hw_otfad_ctxn_ctr_w0
{
    uint32_t U;
    struct _hw_otfad_ctxn_ctr_w0_bitfields
    {
        uint32_t W0CTR : 32; /*!< [31:0] CounTeR */
    } B;
} hw_otfad_ctxn_ctr_w0_t;

/*!
 * @name Constants and macros for entire OTFAD_CTXn_CTR_W0 register
 */
/*@{*/
/*! @brief Number of instances of the OTFAD_CTXn_CTR_W0 register. */
#define HW_OTFAD_CTXn_CTR_W0_COUNT     (4U)

#define HW_OTFAD_CTXn_CTR_W0_ADDR(x, n)     ((x) + 0xD10U + (0x40U * (n)))
#define HW_OTFAD_CTXn_CTR_W0(x, n)          (*(__IO hw_otfad_ctxn_ctr_w0_t *) HW_OTFAD_CTXn_CTR_W0_ADDR(x, n))
#define HW_OTFAD_CTXn_CTR_W0_RD(x, n)       (HW_OTFAD_CTXn_CTR_W0(x, n).U)
#define HW_OTFAD_CTXn_CTR_W0_WR(x, n, v)    (HW_OTFAD_CTXn_CTR_W0(x, n).U = (v))
#define HW_OTFAD_CTXn_CTR_W0_SET(x, n, v)   (HW_OTFAD_CTXn_CTR_W0_WR(x, n, HW_OTFAD_CTXn_CTR_W0_RD(x, n) |  (v)))
#define HW_OTFAD_CTXn_CTR_W0_CLR(x, n, v)   (HW_OTFAD_CTXn_CTR_W0_WR(x, n, HW_OTFAD_CTXn_CTR_W0_RD(x, n) & ~(v)))
#define HW_OTFAD_CTXn_CTR_W0_TOG(x, n, v)   (HW_OTFAD_CTXn_CTR_W0_WR(x, n, HW_OTFAD_CTXn_CTR_W0_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OTFAD_CTXn_CTR_W0 bitfields
 */

/*!
 * @name Register OTFAD_CTXn_CTR_W0, field W0CTR[31:0] (RW)
 *
 * The upper 64 bits of the counter are typically loaded as the corresponding key blob is unwrapped;
 * alternatively, if enabled, it can be written using the slave peripheral bus. The two consecutive
 * memory-mapped registers directly provide the upper 64 bits of counter storage.Word0:
 * CTR[31:0][C3, C2, C1, C0]Word1: CTR]31:0][C7, C6, C5, C4]The third 32-bit portion of the CTR is
 * formed by exclusive-or’ing the upper 64 bits of the counter as two 32-bit values, while the
 * least-significant portion of the counter is the 32-bit 0-modulo-16 byte system address of the
 * external flash memory.CTR[C0...C15] = {CTR[C0...C7], CTR[C0...C3] ^ CTR[C4...C7],
 * systemAddress[31–4], 0h}
 */
/*@{*/
#define BP_OTFAD_CTXn_CTR_W0_W0CTR         (0U)      /*!< Bit position for OTFAD_CTXn_CTR_W0_W0CTR. */
#define BM_OTFAD_CTXn_CTR_W0_W0CTR         (0xFFFFFFFFU)  /*!< Bit mask for OTFAD_CTXn_CTR_W0_W0CTR. */
#define BS_OTFAD_CTXn_CTR_W0_W0CTR         (32U)  /*!< Bitfield size in bits for OTFAD_CTXn_CTR_W0_W0CTR. */

/*! @brief Read current value of the OTFAD_CTXn_CTR_W0_W0CTR field. */
#define BR_OTFAD_CTXn_CTR_W0_W0CTR(x, n)      (HW_OTFAD_CTXn_CTR_W0(x, n).U)

/*! @brief Format value for bitfield OTFAD_CTXn_CTR_W0_W0CTR. */
#define BF_OTFAD_CTXn_CTR_W0_W0CTR(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CTXn_CTR_W0_W0CTR) & BM_OTFAD_CTXn_CTR_W0_W0CTR)

/*! @brief Set the W0CTR field to a new value. */
#define BW_OTFAD_CTXn_CTR_W0_W0CTR(x, n, v)   (HW_OTFAD_CTXn_CTR_W0_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_OTFAD_CTXn_CTR_W1 - AES Counter Word1
 ******************************************************************************/

/*!
 * @brief HW_OTFAD_CTXn_CTR_W1 - AES Counter Word1 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CTXn_CTR_W1 registers provide 32 bits of Word1 of a 2-dimensional data structure for local
 * OTFAD storage of 64 bits of the counter value for context “n”. There are two consecutive memory-
 * mapped register words ( defining the upper 96 bits of the counter used for the AES calculations
 * associated with the given context.The programming model view of the CTXn_CTR_Wm registers is a
 * little-endian 8-element byte data array.The entire 128-bit counter value is defined as the
 * concatenation of four 32-bit values:CTR[127–0] = {CTR_W0[C0...C3], CTR_W1[C4...C7],
 * CTR_W0[C0...C3] ^ CTR_W1[C4...C7], systemAddress[31–4], 0h}
 */
typedef union _hw_otfad_ctxn_ctr_w1
{
    uint32_t U;
    struct _hw_otfad_ctxn_ctr_w1_bitfields
    {
        uint32_t W1CTR : 32; /*!< [31:0] CounTeR */
    } B;
} hw_otfad_ctxn_ctr_w1_t;

/*!
 * @name Constants and macros for entire OTFAD_CTXn_CTR_W1 register
 */
/*@{*/
/*! @brief Number of instances of the OTFAD_CTXn_CTR_W1 register. */
#define HW_OTFAD_CTXn_CTR_W1_COUNT     (4U)

#define HW_OTFAD_CTXn_CTR_W1_ADDR(x, n)     ((x) + 0xD14U + (0x40U * (n)))
#define HW_OTFAD_CTXn_CTR_W1(x, n)          (*(__IO hw_otfad_ctxn_ctr_w1_t *) HW_OTFAD_CTXn_CTR_W1_ADDR(x, n))
#define HW_OTFAD_CTXn_CTR_W1_RD(x, n)       (HW_OTFAD_CTXn_CTR_W1(x, n).U)
#define HW_OTFAD_CTXn_CTR_W1_WR(x, n, v)    (HW_OTFAD_CTXn_CTR_W1(x, n).U = (v))
#define HW_OTFAD_CTXn_CTR_W1_SET(x, n, v)   (HW_OTFAD_CTXn_CTR_W1_WR(x, n, HW_OTFAD_CTXn_CTR_W1_RD(x, n) |  (v)))
#define HW_OTFAD_CTXn_CTR_W1_CLR(x, n, v)   (HW_OTFAD_CTXn_CTR_W1_WR(x, n, HW_OTFAD_CTXn_CTR_W1_RD(x, n) & ~(v)))
#define HW_OTFAD_CTXn_CTR_W1_TOG(x, n, v)   (HW_OTFAD_CTXn_CTR_W1_WR(x, n, HW_OTFAD_CTXn_CTR_W1_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OTFAD_CTXn_CTR_W1 bitfields
 */

/*!
 * @name Register OTFAD_CTXn_CTR_W1, field W1CTR[31:0] (RW)
 *
 * The upper 64 bits of the counter are typically loaded as the corresponding key blob is unwrapped;
 * alternatively, if enabled, it can be written using the slave peripheral bus. The two consecutive
 * memory-mapped registers directly provide the upper 64 bits of counter storage.Word0:
 * CTR[31:0][C3, C2, C1, C0]Word1: CTR]31:0][C7, C6, C5, C4]The third 32-bit portion of the CTR is
 * formed by exclusive-or’ing the upper 64 bits of the counter as two 32-bit values, while the
 * least-significant portion of the counter is the 32-bit 0-modulo-16 byte system address of the
 * external flash memory.CTR[C0...C15] = {CTR[C0...C7], CTR[C0...C3] ^ CTR[C4...C7],
 * systemAddress[31–4], 0h}
 */
/*@{*/
#define BP_OTFAD_CTXn_CTR_W1_W1CTR         (0U)      /*!< Bit position for OTFAD_CTXn_CTR_W1_W1CTR. */
#define BM_OTFAD_CTXn_CTR_W1_W1CTR         (0xFFFFFFFFU)  /*!< Bit mask for OTFAD_CTXn_CTR_W1_W1CTR. */
#define BS_OTFAD_CTXn_CTR_W1_W1CTR         (32U)  /*!< Bitfield size in bits for OTFAD_CTXn_CTR_W1_W1CTR. */

/*! @brief Read current value of the OTFAD_CTXn_CTR_W1_W1CTR field. */
#define BR_OTFAD_CTXn_CTR_W1_W1CTR(x, n)      (HW_OTFAD_CTXn_CTR_W1(x, n).U)

/*! @brief Format value for bitfield OTFAD_CTXn_CTR_W1_W1CTR. */
#define BF_OTFAD_CTXn_CTR_W1_W1CTR(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CTXn_CTR_W1_W1CTR) & BM_OTFAD_CTXn_CTR_W1_W1CTR)

/*! @brief Set the W1CTR field to a new value. */
#define BW_OTFAD_CTXn_CTR_W1_W1CTR(x, n, v)   (HW_OTFAD_CTXn_CTR_W1_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_OTFAD_CTXn_RGD_W0 - AES Region Descriptor Word0
 ******************************************************************************/

/*!
 * @brief HW_OTFAD_CTXn_RGD_W0 - AES Region Descriptor Word0 (RW)
 *
 * Reset value: 0x00000000U
 *
 * The CTXn_RGD_W0 registers provide 32 bits of Word0 of a 2-dimensional data structure for local
 * OTFAD storage of 64 bits of memory region descriptor for context “n”. There are two consecutive
 * memory-mapped register words defining the starting and ending addresses for the external flash
 * memory region associated with the given context. CTXn_RGD_W0 provides the start address.Each
 * memory region context defines a specified section of external flash memory associated with the
 * given context and its associated 128-bit key and 128-bit counter values.The context memory
 * regions are defined as modulo-1024 bytes to match the AMBA-AHB protocol requirement that no
 * bursting transfer cross that boundary. As a result, no AHB command, either single transfer, or
 * any type of wrapping or incrementing burst, can cross any 1 Kbyte boundary. This means that any
 * AHB transfer is limited to a single context for purposes of AES decryption.
 */
typedef union _hw_otfad_ctxn_rgd_w0
{
    uint32_t U;
    struct _hw_otfad_ctxn_rgd_w0_bitfields
    {
        uint32_t RESERVED0 : 10; /*!< [9:0]  */
        uint32_t SRTADDR : 22; /*!< [31:10] Start Address */
    } B;
} hw_otfad_ctxn_rgd_w0_t;

/*!
 * @name Constants and macros for entire OTFAD_CTXn_RGD_W0 register
 */
/*@{*/
/*! @brief Number of instances of the OTFAD_CTXn_RGD_W0 register. */
#define HW_OTFAD_CTXn_RGD_W0_COUNT     (4U)

#define HW_OTFAD_CTXn_RGD_W0_ADDR(x, n)     ((x) + 0xD18U + (0x40U * (n)))
#define HW_OTFAD_CTXn_RGD_W0(x, n)          (*(__IO hw_otfad_ctxn_rgd_w0_t *) HW_OTFAD_CTXn_RGD_W0_ADDR(x, n))
#define HW_OTFAD_CTXn_RGD_W0_RD(x, n)       (HW_OTFAD_CTXn_RGD_W0(x, n).U)
#define HW_OTFAD_CTXn_RGD_W0_WR(x, n, v)    (HW_OTFAD_CTXn_RGD_W0(x, n).U = (v))
#define HW_OTFAD_CTXn_RGD_W0_SET(x, n, v)   (HW_OTFAD_CTXn_RGD_W0_WR(x, n, HW_OTFAD_CTXn_RGD_W0_RD(x, n) |  (v)))
#define HW_OTFAD_CTXn_RGD_W0_CLR(x, n, v)   (HW_OTFAD_CTXn_RGD_W0_WR(x, n, HW_OTFAD_CTXn_RGD_W0_RD(x, n) & ~(v)))
#define HW_OTFAD_CTXn_RGD_W0_TOG(x, n, v)   (HW_OTFAD_CTXn_RGD_W0_WR(x, n, HW_OTFAD_CTXn_RGD_W0_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OTFAD_CTXn_RGD_W0 bitfields
 */

/*!
 * @name Register OTFAD_CTXn_RGD_W0, field SRTADDR[31:10] (RW)
 *
 * This field defines the most significant bits of the 0-modulo-1024 byte start address of the
 * memory region for context n.
 */
/*@{*/
#define BP_OTFAD_CTXn_RGD_W0_SRTADDR         (10U)      /*!< Bit position for OTFAD_CTXn_RGD_W0_SRTADDR. */
#define BM_OTFAD_CTXn_RGD_W0_SRTADDR         (0xFFFFFC00U)  /*!< Bit mask for OTFAD_CTXn_RGD_W0_SRTADDR. */
#define BS_OTFAD_CTXn_RGD_W0_SRTADDR         (22U)  /*!< Bitfield size in bits for OTFAD_CTXn_RGD_W0_SRTADDR. */

/*! @brief Read current value of the OTFAD_CTXn_RGD_W0_SRTADDR field. */
#define BR_OTFAD_CTXn_RGD_W0_SRTADDR(x, n)   (HW_OTFAD_CTXn_RGD_W0(x, n).B.SRTADDR)

/*! @brief Format value for bitfield OTFAD_CTXn_RGD_W0_SRTADDR. */
#define BF_OTFAD_CTXn_RGD_W0_SRTADDR(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CTXn_RGD_W0_SRTADDR) & BM_OTFAD_CTXn_RGD_W0_SRTADDR)

/*! @brief Set the SRTADDR field to a new value. */
#define BW_OTFAD_CTXn_RGD_W0_SRTADDR(x, n, v)   (HW_OTFAD_CTXn_RGD_W0_WR(x, n, (HW_OTFAD_CTXn_RGD_W0_RD(x, n) & ~BM_OTFAD_CTXn_RGD_W0_SRTADDR) | BF_OTFAD_CTXn_RGD_W0_SRTADDR(v)))
/*@}*/

/*******************************************************************************
 * HW_OTFAD_CTXn_RGD_W1 - AES Region Descriptor Word1
 ******************************************************************************/

/*!
 * @brief HW_OTFAD_CTXn_RGD_W1 - AES Region Descriptor Word1 (RW)
 *
 * Reset value: 0x000003F8U
 *
 * The CTXn_RGD_W1 registers provide 32 bits of Word1 of a 2-dimensional data structure for local
 * OTFAD storage of 64 bits of memory region descriptor for context “n”. There are two consecutive
 * memory-mapped register words defining the starting and ending addresses for the external flash
 * memory region associated with the given context. CTXn_RGD_W1 provides the end address.Each memory
 * region context defines a specified section of external flash memory associated with the given
 * context and its associated 128-bit key and 128-bit counter values.The context memory regions are
 * defined as modulo-1024 bytes to match the AMBA-AHB protocol requirement that no bursting transfer
 * cross that boundary. As a result, no AHB command, either single transfer, or any type of wrapping
 * or incrementing burst, can cross any 1 Kbyte boundary. This means that any AHB transfer is
 * limited to a single context for purposes of AES decryption.
 */
typedef union _hw_otfad_ctxn_rgd_w1
{
    uint32_t U;
    struct _hw_otfad_ctxn_rgd_w1_bitfields
    {
        uint32_t VLD : 1; /*!< [0] VaLiD */
        uint32_t ADE : 1; /*!< [1] Aes Decryption Enable. */
        uint32_t RO : 1; /*!< [2] Read-Only */
        uint32_t RESERVED0 : 7; /*!< [9:3]  */
        uint32_t ENDADDR : 22; /*!< [31:10] End Address */
    } B;
} hw_otfad_ctxn_rgd_w1_t;

/*!
 * @name Constants and macros for entire OTFAD_CTXn_RGD_W1 register
 */
/*@{*/
/*! @brief Number of instances of the OTFAD_CTXn_RGD_W1 register. */
#define HW_OTFAD_CTXn_RGD_W1_COUNT     (4U)

#define HW_OTFAD_CTXn_RGD_W1_ADDR(x, n)     ((x) + 0xD1CU + (0x40U * (n)))
#define HW_OTFAD_CTXn_RGD_W1(x, n)          (*(__IO hw_otfad_ctxn_rgd_w1_t *) HW_OTFAD_CTXn_RGD_W1_ADDR(x, n))
#define HW_OTFAD_CTXn_RGD_W1_RD(x, n)       (HW_OTFAD_CTXn_RGD_W1(x, n).U)
#define HW_OTFAD_CTXn_RGD_W1_WR(x, n, v)    (HW_OTFAD_CTXn_RGD_W1(x, n).U = (v))
#define HW_OTFAD_CTXn_RGD_W1_SET(x, n, v)   (HW_OTFAD_CTXn_RGD_W1_WR(x, n, HW_OTFAD_CTXn_RGD_W1_RD(x, n) |  (v)))
#define HW_OTFAD_CTXn_RGD_W1_CLR(x, n, v)   (HW_OTFAD_CTXn_RGD_W1_WR(x, n, HW_OTFAD_CTXn_RGD_W1_RD(x, n) & ~(v)))
#define HW_OTFAD_CTXn_RGD_W1_TOG(x, n, v)   (HW_OTFAD_CTXn_RGD_W1_WR(x, n, HW_OTFAD_CTXn_RGD_W1_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual OTFAD_CTXn_RGD_W1 bitfields
 */

/*!
 * @name Register OTFAD_CTXn_RGD_W1, field VLD[0] (RW)
 *
 * This bit signals if the context is valid or not.
 *
 * Values:
 * - 0 - Context is invalid.
 * - 1 - Context is valid.
 */
/*@{*/
#define BP_OTFAD_CTXn_RGD_W1_VLD         (0U)      /*!< Bit position for OTFAD_CTXn_RGD_W1_VLD. */
#define BM_OTFAD_CTXn_RGD_W1_VLD         (0x00000001U)  /*!< Bit mask for OTFAD_CTXn_RGD_W1_VLD. */
#define BS_OTFAD_CTXn_RGD_W1_VLD         (1U)  /*!< Bitfield size in bits for OTFAD_CTXn_RGD_W1_VLD. */

/*! @brief Read current value of the OTFAD_CTXn_RGD_W1_VLD field. */
#define BR_OTFAD_CTXn_RGD_W1_VLD(x, n)   (HW_OTFAD_CTXn_RGD_W1(x, n).B.VLD)

/*! @brief Format value for bitfield OTFAD_CTXn_RGD_W1_VLD. */
#define BF_OTFAD_CTXn_RGD_W1_VLD(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CTXn_RGD_W1_VLD) & BM_OTFAD_CTXn_RGD_W1_VLD)

/*! @brief Set the VLD field to a new value. */
#define BW_OTFAD_CTXn_RGD_W1_VLD(x, n, v)   (HW_OTFAD_CTXn_RGD_W1_WR(x, n, (HW_OTFAD_CTXn_RGD_W1_RD(x, n) & ~BM_OTFAD_CTXn_RGD_W1_VLD) | BF_OTFAD_CTXn_RGD_W1_VLD(v)))
/*@}*/

/*!
 * @name Register OTFAD_CTXn_RGD_W1, field ADE[1] (RW)
 *
 * For accesses hitting in a valid context, this bit indicates if the fetched data is to be
 * decrypted or simply bypassed.
 *
 * Values:
 * - 0 - Bypass the fetched data.
 * - 1 - Perform the CTR-AES128 mode decryption on the fetched data.
 */
/*@{*/
#define BP_OTFAD_CTXn_RGD_W1_ADE         (1U)      /*!< Bit position for OTFAD_CTXn_RGD_W1_ADE. */
#define BM_OTFAD_CTXn_RGD_W1_ADE         (0x00000002U)  /*!< Bit mask for OTFAD_CTXn_RGD_W1_ADE. */
#define BS_OTFAD_CTXn_RGD_W1_ADE         (1U)  /*!< Bitfield size in bits for OTFAD_CTXn_RGD_W1_ADE. */

/*! @brief Read current value of the OTFAD_CTXn_RGD_W1_ADE field. */
#define BR_OTFAD_CTXn_RGD_W1_ADE(x, n)   (HW_OTFAD_CTXn_RGD_W1(x, n).B.ADE)

/*! @brief Format value for bitfield OTFAD_CTXn_RGD_W1_ADE. */
#define BF_OTFAD_CTXn_RGD_W1_ADE(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CTXn_RGD_W1_ADE) & BM_OTFAD_CTXn_RGD_W1_ADE)

/*! @brief Set the ADE field to a new value. */
#define BW_OTFAD_CTXn_RGD_W1_ADE(x, n, v)   (HW_OTFAD_CTXn_RGD_W1_WR(x, n, (HW_OTFAD_CTXn_RGD_W1_RD(x, n) & ~BM_OTFAD_CTXn_RGD_W1_ADE) | BF_OTFAD_CTXn_RGD_W1_ADE(v)))
/*@}*/

/*!
 * @name Register OTFAD_CTXn_RGD_W1, field RO[2] (RW)
 *
 * This bit signals that the entire set of context registers (CTXn_KEY_W[0-3], CTXn_CTR_W[0-1],
 * CTXn_RGD_W[0-1] are read-only and cannot be modified. This bit is sticky and remains asserted
 * until the next system reset. SR[RRAM] provides another level of register access control and is
 * independent of the RO indicator.
 *
 * Values:
 * - 0 - The context registers can be accessed normally (as defined by SR[RRAM]).
 * - 1 - The context registers are read-only and accesses may be further restricted based on SR[RRAM].
 */
/*@{*/
#define BP_OTFAD_CTXn_RGD_W1_RO         (2U)      /*!< Bit position for OTFAD_CTXn_RGD_W1_RO. */
#define BM_OTFAD_CTXn_RGD_W1_RO         (0x00000004U)  /*!< Bit mask for OTFAD_CTXn_RGD_W1_RO. */
#define BS_OTFAD_CTXn_RGD_W1_RO         (1U)  /*!< Bitfield size in bits for OTFAD_CTXn_RGD_W1_RO. */

/*! @brief Read current value of the OTFAD_CTXn_RGD_W1_RO field. */
#define BR_OTFAD_CTXn_RGD_W1_RO(x, n)   (HW_OTFAD_CTXn_RGD_W1(x, n).B.RO)

/*! @brief Format value for bitfield OTFAD_CTXn_RGD_W1_RO. */
#define BF_OTFAD_CTXn_RGD_W1_RO(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CTXn_RGD_W1_RO) & BM_OTFAD_CTXn_RGD_W1_RO)

/*! @brief Set the RO field to a new value. */
#define BW_OTFAD_CTXn_RGD_W1_RO(x, n, v)   (HW_OTFAD_CTXn_RGD_W1_WR(x, n, (HW_OTFAD_CTXn_RGD_W1_RD(x, n) & ~BM_OTFAD_CTXn_RGD_W1_RO) | BF_OTFAD_CTXn_RGD_W1_RO(v)))
/*@}*/

/*!
 * @name Register OTFAD_CTXn_RGD_W1, field ENDADDR[31:10] (RW)
 *
 * This field defines the most significant bits of the 1023-modulo-1024 byte end address of the
 * memory region for context n.
 */
/*@{*/
#define BP_OTFAD_CTXn_RGD_W1_ENDADDR         (10U)      /*!< Bit position for OTFAD_CTXn_RGD_W1_ENDADDR. */
#define BM_OTFAD_CTXn_RGD_W1_ENDADDR         (0xFFFFFC00U)  /*!< Bit mask for OTFAD_CTXn_RGD_W1_ENDADDR. */
#define BS_OTFAD_CTXn_RGD_W1_ENDADDR         (22U)  /*!< Bitfield size in bits for OTFAD_CTXn_RGD_W1_ENDADDR. */

/*! @brief Read current value of the OTFAD_CTXn_RGD_W1_ENDADDR field. */
#define BR_OTFAD_CTXn_RGD_W1_ENDADDR(x, n)   (HW_OTFAD_CTXn_RGD_W1(x, n).B.ENDADDR)

/*! @brief Format value for bitfield OTFAD_CTXn_RGD_W1_ENDADDR. */
#define BF_OTFAD_CTXn_RGD_W1_ENDADDR(v)      ((uint32_t)((uint32_t)(v) << BP_OTFAD_CTXn_RGD_W1_ENDADDR) & BM_OTFAD_CTXn_RGD_W1_ENDADDR)

/*! @brief Set the ENDADDR field to a new value. */
#define BW_OTFAD_CTXn_RGD_W1_ENDADDR(x, n, v)   (HW_OTFAD_CTXn_RGD_W1_WR(x, n, (HW_OTFAD_CTXn_RGD_W1_RD(x, n) & ~BM_OTFAD_CTXn_RGD_W1_ENDADDR) | BF_OTFAD_CTXn_RGD_W1_ENDADDR(v)))
/*@}*/

/*******************************************************************************
 * hw_otfad_t - module struct
 ******************************************************************************/
/*!
 * @brief All OTFAD module registers.
 */
#pragma pack(1)
typedef struct _hw_otfad
{
         uint32_t _reserved0[768];
    __IO hw_otfad_cr_t CR; /*!< [0xC00] Control */
    __IO hw_otfad_sr_t SR; /*!< [0xC04] Status */
    __IO hw_otfad_crc_t CRC_; /*!< [0xC08] Cyclic Redundancy Check */
         uint32_t _reserved1[61];
         struct {
             __IO hw_otfad_ctxn_aes_key_w0_t CTXn_AES_KEY_W0; /*!< [0xD00] AES Key Word0 */
             __IO hw_otfad_ctxn_aes_key_w1_t CTXn_AES_KEY_W1; /*!< [0xD04] AES Key Word1 */
             __IO hw_otfad_ctxn_aes_key_w2_t CTXn_AES_KEY_W2; /*!< [0xD08] AES Key Word2 */
             __IO hw_otfad_ctxn_aes_key_w3_t CTXn_AES_KEY_W3; /*!< [0xD0C] AES Key Word3 */
             __IO hw_otfad_ctxn_ctr_w0_t CTXn_CTR_W0; /*!< [0xD10] AES Counter Word0 */
             __IO hw_otfad_ctxn_ctr_w1_t CTXn_CTR_W1; /*!< [0xD14] AES Counter Word1 */
             __IO hw_otfad_ctxn_rgd_w0_t CTXn_RGD_W0; /*!< [0xD18] AES Region Descriptor Word0 */
             __IO hw_otfad_ctxn_rgd_w1_t CTXn_RGD_W1; /*!< [0xD1C] AES Region Descriptor Word1 */
                  uint32_t _reserved2[8];
         } AES[4];
} hw_otfad_t;
#pragma pack()


/*! @brief Macro to access all OTFAD registers. */
/*! @param x OTFAD module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_OTFAD(OTFAD0_BASE)</code>. */
#define HW_OTFAD(x)      (*(hw_otfad_t *)(x))

#endif /* __HW_OTFAD_REGISTERS_H__ */
/* v30/140722/1.3.1 */
/* EOF */
