/*
 * Copyright (c) 2013, Freescale Semiconductor, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice, this list
 *   of conditions and the following disclaimer.
 *
 * o Redistributions in binary form must reproduce the above copyright notice, this
 *   list of conditions and the following disclaimer in the documentation and/or
 *   other materials provided with the distribution.
 *
 * o Neither the name of Freescale Semiconductor, Inc. nor the names of its
 *   contributors may be used to endorse or promote products derived from this
 *   software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#ifndef __QSPI_H__
#define __QSPI_H__

#include "memory.h"
#include "fsl_platform_status.h"
/*******************************************************************************
 * Definitions
 ******************************************************************************/
#define QSPI_READ_SEQ_ID            0
#define COMAND_SEQ_LEN              128
#define quadspi_config_address      0x100
#define FLASH_BASE_ADDR             0x20000000
#define AHB_BFCR_DUMMY_MASTER_ID    0xe
#define ARDB (*(volatile unsigned int *) 0x67000000)
#define quadspi0_base_address       0x68000000
#define TRUE                         1

typedef enum _qspiflash_is_parallel
{
    kQspiMode_non_parallel = 0,
    kQspiMode_parallel = 1
}qspiflash_is_parallel;

typedef enum _qspiflash_type
{
    kQspiType_single = 0,
    kQspiType_dual = 1,
    kQspiType_quad = 2
}qspiflash_type;


typedef enum _qspiflash_property {
    kQspiFlashProperty_PageSize,
    kQspiFlashProperty_TotalFlashSize,
    kQspiFlashProperty_SectorSize,
    kQspiFlashProperty_HighFreq
} qspiflash_property_t;

typedef enum _qspiflash_status
{
    kStatus_QspiFlashSizeError = MAKE_STATUS(kStatusGroup_QuadSPIDriver, 0),
    kStatus_QspiFlashAlignmentError = MAKE_STATUS(kStatusGroup_QuadSPIDriver, 1),
    kStatus_QspiFlashAddressError = MAKE_STATUS(kStatusGroup_QuadSPIDriver, 2),

    kStatus_QspiFlashCommandFailure = MAKE_STATUS(kStatusGroup_QuadSPIDriver, 3),
    kStatus_QspiFlashUnknownProperty = MAKE_STATUS(kStatusGroup_QuadSPIDriver, 4)
}qspiflash_status_t;

#pragma pack(1)
typedef struct __sflash_configuration_parameter
{
  uint32_t dqs_loopback;              //Sets DQS LoopBack Mode to enable Dummy Pad MCR[24]
 // uint32_t idle_signal_drive_flashA_2;//idle stage drive strength
 // uint32_t idle_signal_drive_flashA_3;//idle stage drive strength
 // uint32_t idle_signal_drive_flashB_2;//idle stage drive strength
 // uint32_t idle_signal_drive_flashB_3;//idle stage drive strength
  /*TBD: Take CS hold and setup time in terms of ns*/
  uint32_t cs_hold_time;              //CS hold time in terms of serial clock.(for example 1 serial clock cyle)
  uint32_t cs_setup_time;             //CS setup time in terms of serial clock.(for example 1 serial clock cyle)
  uint32_t sflash_A1_size;            //interms of Bytes
  uint32_t sflash_A2_size;            //interms of Bytes
  uint32_t sflash_B1_size;            //interms of Bytes
  uint32_t sflash_B2_size;            //interms of Bytes
  uint32_t sclk_freq;                 //In  00 - 24MHz, 01 - 48MHz, 10 - 96MHz,(only for SDR Mode)
  //uint32_t prefetch_size;             //In number of words.
  uint8_t sflash_type;               //0-Single,1--Dual 2--Quad
  uint8_t sflash_port;               //0--Only Port-A,1--Both PortA and PortB
  uint8_t ddr_mode_enable;          //Enable DDR mode if set to TRUE
  uint8_t dqs_enable;               //Enable DQS mode if set to TRUE.
  uint8_t parallel_mode_enable;     //Enable Individual or parrallel mode.
  uint8_t portA_cs1;
  uint8_t portB_cs1;
  uint8_t fsphs;
  uint8_t fsdly;
  uint8_t ddrsmp;
  uint16_t  command_seq[COMAND_SEQ_LEN]; //set of seq to perform optimum read on SFLASH as as per vendor SFLASH
  uint16_t pagesize;
  uint16_t sectorsize;
}qspi_config_t,*SFLASH_CONFIGURATION_PARAM_PTR;

#define byte_swap32(word) \
  ( ((word&0x000000FF) << 24)|            \
  ((word&0x0000FF00) << 8) |            \
  ((word&0x00FF0000) >> 8) |            \
  ((word&0xFF000000) >> 24)  )

status_t quadspi_get_property(qspiflash_property_t whichProperty, uint32_t * value);
status_t quadspi_program(uint32_t src, uint32_t size, const uint8_t * base );
status_t quadspi_mem_read(uint32_t address, uint32_t length, uint8_t * buffer);
status_t quadspi_init(void);
void quadspi_serial_clock_disable();
extern  void quadspi_iomux_configuration(qspiflash_type type, qspiflash_is_parallel is_parallel);
void quadspi_erase_all();
void quadspi_erase_sector(uint32_t address);
void config_ahb_buffer();
#endif

