/*
 * Copyright (c) 2013, Freescale Semiconductor, Inc.
 * All rights reserved.
 *
 * Redistribution and use in source and binary forms, with or without modification,
 * are permitted provided that the following conditions are met:
 *
 * o Redistributions of source code must retain the above copyright notice, this list
 *   of conditions and the following disclaimer.
 *
 * o Redistributions in binary form must reproduce the above copyright notice, this
 *   list of conditions and the following disclaimer in the documentation and/or
 *   other materials provided with the distribution.
 *
 * o Neither the name of Freescale Semiconductor, Inc. nor the names of its
 *   contributors may be used to endorse or promote products derived from this
 *   software without specific prior written permission.
 *
 * THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
 * ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
 * WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
 * DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
 * ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
 * (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
 * LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
 * ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
 * (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
 * SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
 */

#include "fsl_platform_common.h"  // needed for debug_printf
#include "fsl_platform_status.h"
#include "fsl_device_registers.h"
#include "qspi.h"

#define FLASH_BASE_ADR	0x68000000
////////////////////////////////////////////////////////////////////////////////
//!
//! @brief Calls the qspi unit test
//!
//! This function initializes the QSPI module and do erase-program-read verify
//!
//!
//!
//! @return kStatus_Success
//!
////////////////////////////////////////////////////////////////////////////////
static void quadspi_serial_clock_disable()
{

   HW_QUADSPI_MCR_SET(QUADSPI0_BASE,BM_QUADSPI_MCR_MDIS);
}

static void quadspi_serial_clock_configure()
{
    HW_QUADSPI_SOCCR_CLR(QUADSPI0_BASE, 0x7);
    HW_QUADSPI_SOCCR_SET(QUADSPI0_BASE, 0x4);  //choose IRC48M as the clock source for qspi

}
void configure_quad_spi_controller_for_test()
{


//    uint32_t smpr;

    /* Reset TX/RX FIFO/BUFFER */
    HW_QUADSPI_MCR_SET(QUADSPI0_BASE, BM_QUADSPI_MCR_CLR_TXF);
    HW_QUADSPI_MCR_SET(QUADSPI0_BASE, BM_QUADSPI_MCR_CLR_RXF);



    /* Program Sampling Parameters , using defualt */
//    smpr = HW_QUADSPI_SMPR_RD(QUADSPI0_BASE);
//    smpr &= ~(BM_QUADSPI_SMPR_DDRSMP|BM_QUADSPI_SMPR_FSDLY | BM_QUADSPI_SMPR_FSPHS );
//    smpr |= (((qspiflash_config_param.fsdly &BM_QUADSPI_SMPR_FSDLY) << BP_QUADSPI_SMPR_FSDLY) |
//    ((qspiflash_config_param.fsphs &  BM_QUADSPI_SMPR_FSPHS) <<  BP_QUADSPI_SMPR_FSPHS) |
//    ((qspiflash_config_param.ddrsmp & BM_QUADSPI_SMPR_DDRSMP) << BP_QUADSPI_SMPR_DDRSMP));
//    HW_QUADSPI_SMPR_WR(QUADSPI0_BASE, smpr);



    /* Setup SFLASH hold and setup time */
//    HW_QUADSPI_FLSHCR_SET(QUADSPI0_BASE, (qspiflash_config_param.cs_hold_time) << BP_QUADSPI_FLSHCR_TCSH);
//    HW_QUADSPI_FLSHCR_SET(QUADSPI0_BASE, (qspiflash_config_param.cs_setup_time) << BP_QUADSPI_FLSHCR_TCSS);

    HW_QUADSPI_SFA1AD_WR(QUADSPI0_BASE, 0x69000000);// for test
    HW_QUADSPI_SFA2AD_WR(QUADSPI0_BASE, 0x69000000);
    HW_QUADSPI_SFB1AD_WR(QUADSPI0_BASE, 0x69000000);
    HW_QUADSPI_SFB2AD_WR(QUADSPI0_BASE, 0x69000000);


    /* Configure and Enable SCLK*/
    quadspi_serial_clock_configure();

    /*Enable QuadSPI module */
    HW_QUADSPI_MCR_CLR(QUADSPI0_BASE, BM_QUADSPI_MCR_MDIS);
    return;

}


void configure_lut_for_test()
{
    HW_QUADSPI_LUTn_WR(QUADSPI0_BASE,0,0x0A1804EB);
    HW_QUADSPI_LUTn_WR(QUADSPI0_BASE,1,0x0E0412A5);
    HW_QUADSPI_LUTn_WR(QUADSPI0_BASE,2,0x24011E80);

    HW_QUADSPI_LUTn_WR(QUADSPI0_BASE,4,0x406);
    HW_QUADSPI_LUTn_WR(QUADSPI0_BASE,8,0x460);
    HW_QUADSPI_LUTn_WR(QUADSPI0_BASE,12,0x1c010405);
    HW_QUADSPI_LUTn_WR(QUADSPI0_BASE,16, 0x08180402);
    HW_QUADSPI_LUTn_WR(QUADSPI0_BASE,17, 0x2004);
}

void quadspi_clock_enable()
{
//    HW_SIM_SOPT3_SET(SIM_BASE, SIM_SOPT3_QSPIEN_MASK);
    HW_SIM_SCGC2_SET(SIM_BASE, SIM_SCGC2_QSPI_MASK);
}

static void configure_quadspi_for_test()
{
    quadspi_clock_enable();
    /* Disable QSPI Module */

    HW_QUADSPI_MCR_SET(QUADSPI0_BASE,BM_QUADSPI_MCR_MDIS);


    /* Disable QSPI Serial Clock */
    quadspi_serial_clock_disable();

   // quadspi_serial_clock_configure();

    /* initialization for AHB Buffer Access */
    config_ahb_buffer();

    /*Enable QuadSPI module */
   // HW_QUADSPI_MCR_CLR(QUADSPI0_BASE, BM_QUADSPI_MCR_MDIS);
    /* QUADSPI IOMUX config */
    quadspi_iomux_configuration(kQspiType_single,kQspiMode_non_parallel);

    /*Program the look up table with flash sequence command*/
    configure_lut_for_test();

    /*Configure QuadSPI controller*/
    configure_quad_spi_controller_for_test();

    return;

}




status_t qspi_test()
{
    uint32_t size = 0x8;
    uint8_t prog_data[8] = {0x1, 0x2, 0x3, 0x4, 0x5, 0x6, 0x7, 0x8};
    uint8_t buffer[8];
    uint32_t status = kStatus_Fail;
    configure_quadspi_for_test();
   // quadspi_iomux_configuration(kQspiType_single,kQspiMode_non_parallel);
    quadspi_erase_all();
    quadspi_program((uint32_t)prog_data, size, (uint8_t const *)FLASH_BASE_ADR);
    quadspi_mem_read(FLASH_BASE_ADR, 8, (uint8_t *)buffer);
    int i;
    for(i=0;i<8;i++)
    { if (prog_data[i] != buffer[i])
      break;
    }
    if (i == 8)
      status = kStatus_Success;

    return status;
}
/* This function is called for configurating pinmux for qspi module
 * This function only supports switching default mode on specified pins
 * If the isParallel parameter is used to determine which group of QSPI interface should be configured.
 */
void quadspi_iomux_configuration(qspiflash_type type, qspiflash_is_parallel is_parallel)
{

    BW_PORT_PCRn_MUX(PORTE_BASE, 1, 5); //QSPI0A_SCLK is ALT5 for pin PTE1
    BW_PORT_PCRn_MUX(PORTE_BASE, 2, 5); //QSPI0A_DATA0 is ALT5 for pin PTE2
    BW_PORT_PCRn_MUX(PORTE_BASE, 4, 5); //QSPI0A_DATA1 is ALT5 for pin PTE4

    if(type == kQspiType_quad)
    {
        BW_PORT_PCRn_MUX(PORTE_BASE, 0, 5); //QSPI0A_DATA3 is ALT5 for pin PTE0
        BW_PORT_PCRn_MUX(PORTE_BASE, 3, 5); //QSPI0A_DATA2 is ALT5 for pin PTE3
    }
    BW_PORT_PCRn_MUX(PORTE_BASE, 5, 5); //QSPI0A_SS0_B is ALT5 for pin PTE5

    if (is_parallel == kQspiMode_parallel)
    {
        BW_PORT_PCRn_MUX(PORTE_BASE,  7, 5); //QSPI0B_SCLK is ALT5 for pin PTE7
        BW_PORT_PCRn_MUX(PORTE_BASE,  8, 5); //QSPI0B_DATA0 is ALT5 for pin PTE8
        BW_PORT_PCRn_MUX(PORTE_BASE, 10, 5); //QSPI0B_DATA1 is ALT5 for pin PTE10

        if(type == kQspiType_quad)
        {
            BW_PORT_PCRn_MUX(PORTE_BASE, 9, 5); //QSPI0B_DATA2 is ALT5 for pin PTE9
            BW_PORT_PCRn_MUX(PORTE_BASE, 6, 5); //QSPI0B_DATA3 is ALT5 for pin PTE6
        }
        BW_PORT_PCRn_MUX(PORTE_BASE, 11, 5); //QSPI0B_SS0_B is ALT5 for pin PTE11
    }
}



////////////////////////////////////////////////////////////////////////////////
// EOF
////////////////////////////////////////////////////////////////////////////////
