/*
** ###################################################################
**     Compilers:           ARM Compiler
**                          Freescale C/C++ for Embedded ARM
**                          GNU C Compiler
**                          GNU C Compiler - CodeSourcery Sourcery G++
**                          IAR ANSI C/C++ Compiler for ARM
**
**     Reference manual:    MKV4xRM Rev.0 Draft A 01/2014
**     Version:             rev. 0.1, 2014-01-27
**
**     Abstract:
**         CMSIS Peripheral Access Layer for MK80F256
**
**     Copyright: 1997 - 2014 Freescale Semiconductor, Inc.
**     All rights reserved.
**
**     Redistribution and use in source and binary forms, with or without modification,
**     are permitted provided that the following conditions are met:
**
**     o Redistributions of source code must retain the above copyright notice, this list
**       of conditions and the following disclaimer.
**
**     o Redistributions in binary form must reproduce the above copyright notice, this
**       list of conditions and the following disclaimer in the documentation and/or
**       other materials provided with the distribution.
**
**     o Neither the name of Freescale Semiconductor, Inc. nor the names of its
**       contributors may be used to endorse or promote products derived from this
**       software without specific prior written permission.
**
**     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
**     ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
**     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
**     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
**     ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
**     (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
**     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
**     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
**     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
**     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**     http:                 www.freescale.com
**     mail:                 support@freescale.com
**
**     Revisions:
**     - rev. 0.1 (2014-01-27)
**         Initial version.
**
** ###################################################################
*/

/*!
 * @file MK80F256.h
 * @version 0.1
 * @date 2014-01-27
 * @brief CMSIS Peripheral Access Layer for MK80F256
 *
 * CMSIS Peripheral Access Layer for MK80F256
 */


/* ----------------------------------------------------------------------------
   -- MCU activation
   ---------------------------------------------------------------------------- */

/* Prevention from multiple including the same memory map */
#if !defined(MK80F256_H_)  /* Check if memory map has not been already included */
#define MK80F256_H_
#define MCU_MK80F256

/* Check if another memory map has not been also included */
#if (defined(MCU_ACTIVE))
  #error MK80F256 memory map: There is already included another memory map. Only one memory map can be included.
#endif /* (defined(MCU_ACTIVE)) */
#define MCU_ACTIVE

#include <stdint.h>

/** Memory map major version (memory maps with equal major version number are
 * compatible) */
#define MCU_MEM_MAP_VERSION 0x0000u
/** Memory map minor version */
#define MCU_MEM_MAP_VERSION_MINOR 0x0001u

/* ----------------------------------------------------------------------------
   -- Interrupt vector numbers
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup Interrupt_vector_numbers Interrupt vector numbers
 * @{
 */

/** Interrupt Number Definitions */
#define NUMBER_OF_INT_VECTORS 116                /**< Number of interrupts in the Vector table */

typedef enum IRQn {
  /* Core interrupts */
  NonMaskableInt_IRQn          = -14,              /**< Non Maskable Interrupt */
  HardFault_IRQn               = -13,              /**< Cortex-M4 SV Hard Fault Interrupt */
  MemoryManagement_IRQn        = -12,              /**< Cortex-M4 Memory Management Interrupt */
  BusFault_IRQn                = -11,              /**< Cortex-M4 Bus Fault Interrupt */
  UsageFault_IRQn              = -10,              /**< Cortex-M4 Usage Fault Interrupt */
  SVCall_IRQn                  = -5,               /**< Cortex-M4 SV Call Interrupt */
  DebugMonitor_IRQn            = -4,               /**< Cortex-M4 Debug Monitor Interrupt */
  PendSV_IRQn                  = -2,               /**< Cortex-M4 Pend SV Interrupt */
  SysTick_IRQn                 = -1,               /**< Cortex-M4 System Tick Interrupt */

  /* Device specific interrupts */
  DMA0_IRQn                    = 0,                /**< DMA channel 0, 16 transfer complete */
  DMA1_IRQn                    = 1,                /**< DMA channel 1, 17 transfer complete */
  DMA2_IRQn                    = 2,                /**< DMA channel 2, 18 transfer complete */
  DMA3_IRQn                    = 3,                /**< DMA channel 3, 19 transfer complete */
  DMA4_IRQn                    = 4,                /**< DMA channel 4, 20 transfer complete */
  DMA5_IRQn                    = 5,                /**< DMA channel 5, 21 transfer complete */
  DMA6_IRQn                    = 6,                /**< DMA channel 6, 22 transfer complete */
  DMA7_IRQn                    = 7,                /**< DMA channel 7, 23 transfer complete */
  DMA8_IRQn                    = 8,                /**< DMA channel 8, 24 transfer complete */
  DMA9_IRQn                    = 9,                /**< DMA channel 9, 25 transfer complete */
  DMA10_IRQn                   = 10,               /**< DMA channel 10, 26 transfer complete */
  DMA11_IRQn                   = 11,               /**< DMA channel 11, 27 transfer complete */
  DMA12_IRQn                   = 12,               /**< DMA channel 12, 28 transfer complete */
  DMA13_IRQn                   = 13,               /**< DMA channel 13, 29 transfer complete */
  DMA14_IRQn                   = 14,               /**< DMA channel 14, 30 transfer complete */
  DMA15_IRQn                   = 15,               /**< DMA channel 15, 31 transfer complete */
  DMA_Error_IRQn               = 16,               /**< DMA error interrupt channels 0-1531 */
  MCM_IRQn                     = 17,               /**< MCM interrupt */
  FTFA_IRQn                    = 18,               /**< Command complete */
  FTFA_Collision_IRQn          = 19,               /**< Read collision */
  PMC_IRQn                     = 20,               /**< Low-voltage detect, low-voltage warning */
  LLWU_IRQn                    = 21,               /**< Low Leakage Wakeup */
  WDOG_EWM_IRQn                = 22,               /**< Both watchdog modules share this interrupt */
  Reserved39_IRQn              = 23,               /**< Reserved interrupt */
  I2C0_IRQn                    = 24,               /**< I2C0 */
  I2C1_IRQn                    = 25,               /**< I2C1 */
  SPI0_IRQn                    = 26,               /**< SPI0 */
  SPI1_IRQn                    = 27,               /**< SPI1 */
  Reserved44_IRQn              = 28,               /**< Reserved interrupt */
  Reserved45_IRQn              = 29,               /**< Reserved interrupt */
  LPUART0_IRQn                 = 30,               /**< LPUART0 status sources */
  LPUART1_IRQn                 = 31,               /**< LPUART1 status sources */
  LPUART2_IRQn                 = 32,               /**< LPUART2 status sources */
  LPUART3_IRQn                 = 33,               /**< LPUART3 status sources */
  LPUART4_IRQn                 = 34,               /**< LPUART4 status sources */
  Reserved51_IRQn              = 35,               /**< Reserved interrupt */
  Reserved52_IRQn              = 36,               /**< Reserved interrupt */
  Reserved53_IRQn              = 37,               /**< Reserved interrupt */
  ADC_ERR_IRQn                 = 38,               /**< ADC_ERR A and B ( zero cross, high/low limit) */
  ADCA_IRQn                    = 39,               /**< ADCA Scan complete */
  CMP0_IRQn                    = 40,               /**< CMP0 */
  CMP1_IRQn                    = 41,               /**< CMP1 */
  Reserved58_IRQn              = 42,               /**< Reserved interrupt */
  Reserved59_IRQn              = 43,               /**< Reserved interrupt */
  Reserved60_IRQn              = 44,               /**< Reserved interrupt */
  Reserved61_IRQn              = 45,               /**< Reserved interrupt */
  Reserved62_IRQn              = 46,               /**< Reserved interrupt */
  Reserved63_IRQn              = 47,               /**< Reserved interrupt */
  PIT0_IRQn                    = 48,               /**< PIT Channel 0 */
  PIT1_IRQn                    = 49,               /**< PIT Channel 1 */
  PIT2_IRQn                    = 50,               /**< PIT Channel 2 */
  PIT3_IRQn                    = 51,               /**< PIT Channel 3 */
  PDB0_IRQn                    = 52,               /**< PDB0 */
  USB0_IRQn                    = 53,               /**< USB0 interrupt */
  XBARA_IRQn                   = 54,               /**< XBARA */
  PDB1_IRQn                    = 55,               /**< PDB1 */
  Reserved72_IRQn              = 56,               /**< Reserved interrupt */
  MCG_IRQn                     = 57,               /**< MCG */
  LPTMR_IRQn                   = 58,               /**< LPTMR */
  PORTA_IRQn                   = 59,               /**< Pin detect (Port A) */
  PORTB_IRQn                   = 60,               /**< Pin detect (Port B) */
  PORTC_IRQn                   = 61,               /**< Pin detect (Port C) */
  PORTD_IRQn                   = 62,               /**< Pin detect (Port D) */
  PORTE_IRQn                   = 63,               /**< Pin detect (Port E) */
  SWI_IRQn                     = 64,               /**< Software */
  SPI2_IRQn                    = 27,               /**< SPI2 */
  ENC_COMPARE_IRQn             = 66,               /**< ENC Compare */
  ENC_HOME_DOG_IRQn            = 67,               /**< ENC Home */
  ENC_WDOG_IRQn                = 68,               /**< ENC Watchdog/Simultaneous A and B change */
  ENC_INDEX_IRQn               = 69,               /**< ENC Index/Roll over/Roll Under */
  CMP2_IRQn                    = 70,               /**< CMP2 */
  Reserved87_IRQn              = 71,               /**< Reserved interrupt */
  Reserved88_IRQn              = 72,               /**< Reserved interrupt */
  ADCB_IRQn                    = 73,               /**< ADCB Scan complete */
  Reserved90_IRQn              = 74,               /**< Reserved interrupt */
  CAN0_ORed_Message_buffer_IRQn = 75,              /**< FLexCAN0 OR'ed Message buffer (0-15) */
  CAN0_Bus_Off_IRQn            = 76,               /**< FLexCAN0 Bus Off */
  CAN0_Error_IRQn              = 77,               /**< FLexCAN0 Error */
  CAN0_Tx_Warning_IRQn         = 78,               /**< FLexCAN0 Transmit Warning */
  CAN0_Rx_Warning_IRQn         = 79,               /**< FLexCAN0 Receive Warning */
  CAN0_Wake_Up_IRQn            = 80,               /**< FLexCAN0 Wake Up */
  PWMA_CMP0_IRQn               = 81,               /**< eFlexPWM submodule 0 Compare */
  PWMA_RELOAD0_IRQn            = 82,               /**< eFlexPWM submodule 0 Reload */
  PWMA_CMP1_IRQn               = 83,               /**< eFlexPWM submodule 1 Compare */
  PWMA_RELOAD1_IRQn            = 84,               /**< eFlexPWM submodule 1 Reload */
  PWMA_CMP2_IRQn               = 85,               /**< eFlexPWM submodule 2 Compare */
  PWMA_RELOAD2_IRQn            = 86,               /**< eFlexPWM submodule 2 Reload */
  PWMA_CMP3_IRQn               = 87,               /**< eFlexPWM submodule 3 Compare */
  PWMA_RELOAD3_IRQn            = 88,               /**< eFlexPWM submodule 3 Reload */
  PWMA_CAP_IRQn                = 89,               /**< eFlexPWM all input captures */
  PWMA_RERR_IRQn               = 90,               /**< eFlexPWM reload error */
  PWMA_FAULT_IRQn              = 91,               /**< eFlexPWM Fault */
  CMP3_IRQn                    = 92,               /**< CMP3 */
  Reserved109_IRQn             = 93,               /**< Reserved interrupt */
  CAN1_ORed_Message_buffer_IRQn = 94,              /**< FLexCAN1 OR'ed Message buffer (0-15) */
  CAN1_Bus_Off_IRQn            = 95,               /**< FLexCAN1 Bus Off */
  CAN1_Error_IRQn              = 96,               /**< FLexCAN1 Error */
  CAN1_Tx_Warning_IRQn         = 97,               /**< FLexCAN1 Transmit Warning */
  CAN1_Rx_Warning_IRQn         = 98,               /**< FLexCAN1 Receive Warning */
  CAN1_Wake_Up_IRQn            = 99                /**< FLexCAN1 Wake Up */
} IRQn_Type;

/*!
 * @}
 */ /* end of group Interrupt_vector_numbers */


/* ----------------------------------------------------------------------------
   -- Cortex M4 Core Configuration
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup Cortex_Core_Configuration Cortex M4 Core Configuration
 * @{
 */

#define __MPU_PRESENT                  0         /**< Defines if an MPU is present or not */
#define __NVIC_PRIO_BITS               4         /**< Number of priority bits implemented in the NVIC */
#define __Vendor_SysTickConfig         0         /**< Vendor specific implementation of SysTickConfig is defined */
#define __FPU_PRESENT                  0         /**< Defines if an FPU is present or not */

#include "core_cm4.h"                  /* Core Peripheral Access Layer */
#include "system_MK80F256.h"           /* Device specific configuration file */

/*!
 * @}
 */ /* end of group Cortex_Core_Configuration */


/* ----------------------------------------------------------------------------
   -- Device Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup Peripheral_access_layer Device Peripheral Access Layer
 * @{
 */


/* ----------------------------------------------------------------------------
   -- CRC Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CRC_Peripheral_Access_Layer CRC Peripheral Access Layer
 * @{
 */

/** CRC - Register Layout Typedef */
typedef struct {
  __IO uint32_t DATA;                              /**< CRC Data register, offset: 0x0 */
  __IO uint32_t GPOLY;                             /**< CRC Polynomial register, offset: 0x4 */
  __IO uint32_t CTRL;                              /**< CRC Control register, offset: 0x8 */
} CRC_Type, *CRC_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- CRC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CRC_Register_Accessor_Macros CRC - Register accessor macros
 * @{
 */


/* CRC - Register accessors */
#define CRC_DATA_REG(base)                       ((base)->DATA)
#define CRC_GPOLY_REG(base)                      ((base)->GPOLY)
#define CRC_CTRL_REG(base)                       ((base)->CTRL)

/*!
 * @}
 */ /* end of group CRC_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- CRC Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CRC_Register_Masks CRC Register Masks
 * @{
 */

/* DATA Bit Fields */
#define CRC_DATA_LL_MASK                         0xFFu
#define CRC_DATA_LL_SHIFT                        0
#define CRC_DATA_LL(x)                           (((uint32_t)(((uint32_t)(x))<<CRC_DATA_LL_SHIFT))&CRC_DATA_LL_MASK)
#define CRC_DATA_LU_MASK                         0xFF00u
#define CRC_DATA_LU_SHIFT                        8
#define CRC_DATA_LU(x)                           (((uint32_t)(((uint32_t)(x))<<CRC_DATA_LU_SHIFT))&CRC_DATA_LU_MASK)
#define CRC_DATA_HL_MASK                         0xFF0000u
#define CRC_DATA_HL_SHIFT                        16
#define CRC_DATA_HL(x)                           (((uint32_t)(((uint32_t)(x))<<CRC_DATA_HL_SHIFT))&CRC_DATA_HL_MASK)
#define CRC_DATA_HU_MASK                         0xFF000000u
#define CRC_DATA_HU_SHIFT                        24
#define CRC_DATA_HU(x)                           (((uint32_t)(((uint32_t)(x))<<CRC_DATA_HU_SHIFT))&CRC_DATA_HU_MASK)
/* GPOLY Bit Fields */
#define CRC_GPOLY_LOW_MASK                       0xFFFFu
#define CRC_GPOLY_LOW_SHIFT                      0
#define CRC_GPOLY_LOW(x)                         (((uint32_t)(((uint32_t)(x))<<CRC_GPOLY_LOW_SHIFT))&CRC_GPOLY_LOW_MASK)
#define CRC_GPOLY_HIGH_MASK                      0xFFFF0000u
#define CRC_GPOLY_HIGH_SHIFT                     16
#define CRC_GPOLY_HIGH(x)                        (((uint32_t)(((uint32_t)(x))<<CRC_GPOLY_HIGH_SHIFT))&CRC_GPOLY_HIGH_MASK)
/* CTRL Bit Fields */
#define CRC_CTRL_TCRC_MASK                       0x1000000u
#define CRC_CTRL_TCRC_SHIFT                      24
#define CRC_CTRL_WAS_MASK                        0x2000000u
#define CRC_CTRL_WAS_SHIFT                       25
#define CRC_CTRL_FXOR_MASK                       0x4000000u
#define CRC_CTRL_FXOR_SHIFT                      26
#define CRC_CTRL_TOTR_MASK                       0x30000000u
#define CRC_CTRL_TOTR_SHIFT                      28
#define CRC_CTRL_TOTR(x)                         (((uint32_t)(((uint32_t)(x))<<CRC_CTRL_TOTR_SHIFT))&CRC_CTRL_TOTR_MASK)
#define CRC_CTRL_TOT_MASK                        0xC0000000u
#define CRC_CTRL_TOT_SHIFT                       30
#define CRC_CTRL_TOT(x)                          (((uint32_t)(((uint32_t)(x))<<CRC_CTRL_TOT_SHIFT))&CRC_CTRL_TOT_MASK)

/*!
 * @}
 */ /* end of group CRC_Register_Masks */


/* CRC - Peripheral instance base addresses */
/** Peripheral CRC base address */
#define CRC_BASE                                (0x40032000u)
/** Peripheral CRC base pointer */
#define CRC                                     ((CRC_Type *)CRC_BASE)
#define CRC_BASE_PTR                            (CRC)
/** Array initializer of CRC peripheral base addresses */
#define CRC_BASE_ADDRS                           { CRC_BASE }
/** Array initializer of CRC peripheral base pointers */
#define CRC_BASE_PTRS                            { CRC }
/** Interrupt vectors for the CRC peripheral type */
#define CRC_IRQS                                 { CRC_IRQn }

/* ----------------------------------------------------------------------------
   -- CRC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CRC_Register_Accessor_Macros CRC - Register accessor macros
 * @{
 */


/* CRC - Register instance definitions */
/* CRC */
#define CRC_DATA                                 CRC_DATA_REG(CRC)
#define CRC_GPOLY                                CRC_GPOLY_REG(CRC)
#define CRC_CTRL                                 CRC_CTRL_REG(CRC)

/* CRC - Register array accessors */

/*!
 * @}
 */ /* end of group CRC_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group CRC_Peripheral_Access_Layer */


/* ----------------------------------------------------------------------------
   -- FMC Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup FMC_Peripheral_Access_Layer FMC Peripheral Access Layer
 * @{
 */

/** FMC - Register Layout Typedef */
typedef struct {
  __IO uint32_t PFAPR;                             /**< Flash Access Protection Register, offset: 0x0 */
  __IO uint32_t PFB0CR;                            /**< Flash Bank 0 Control Register, offset: 0x4 */
  __IO uint32_t PFB1CR;                            /**< Flash Bank 1 Control Register, offset: 0x8 */
       uint32_t RESERVED_0[61];
  __IO uint32_t TAGVDW0S[4];                       /**< Cache Tag Storage, array offset: 0x100, array step: 0x4 */
  __IO uint32_t TAGVDW1S[4];                       /**< Cache Tag Storage, array offset: 0x110, array step: 0x4 */
  __IO uint32_t TAGVDW2S[4];                       /**< Cache Tag Storage, array offset: 0x120, array step: 0x4 */
  __IO uint32_t TAGVDW3S[4];                       /**< Cache Tag Storage, array offset: 0x130, array step: 0x4 */
       uint32_t RESERVED_1[48];
       struct {
           __IO uint32_t DATAW0SUM; /**< Cache Data Storage (uppermost word), array offset: 0x200 */
           __IO uint32_t DATAW0SMU; /**< Cache Data Storage (mid-upper word), array offset: 0x204 */
           __IO uint32_t DATAW0SML; /**< Cache Data Storage (mid-lower word), array offset: 0x208 */
           __IO uint32_t DATAW0SLM; /**< Cache Data Storage (lowermost word), array offset: 0x20C */
       } CACHE1[4];
       struct {
           __IO uint32_t DATAW1SUM; /**< Cache Data Storage (uppermost word), array offset: 0x240 */
           __IO uint32_t DATAW1SMU; /**< Cache Data Storage (mid-upper word), array offset: 0x244 */
           __IO uint32_t DATAW1SML; /**< Cache Data Storage (mid-lower word), array offset: 0x248 */
           __IO uint32_t DATAW1SLM; /**< Cache Data Storage (lowermost word), array offset: 0x24C */
       } CACHE2[4];
       struct {
           __IO uint32_t DATAW2SUM; /**< Cache Data Storage (uppermost word), array offset: 0x280 */
           __IO uint32_t DATAW2SMU; /**< Cache Data Storage (mid-upper word), array offset: 0x284 */
           __IO uint32_t DATAW2SML; /**< Cache Data Storage (mid-lower word), array offset: 0x288 */
           __IO uint32_t DATAW2SLM; /**< Cache Data Storage (lowermost word), array offset: 0x28C */
       } CACHE3[4];
       struct {
           __IO uint32_t DATAW3SUM; /**< Cache Data Storage (uppermost word), array offset: 0x2C0 */
           __IO uint32_t DATAW3SMU; /**< Cache Data Storage (mid-upper word), array offset: 0x2C4 */
           __IO uint32_t DATAW3SML; /**< Cache Data Storage (mid-lower word), array offset: 0x2C8 */
           __IO uint32_t DATAW3SLM; /**< Cache Data Storage (lowermost word), array offset: 0x2CC */
       } CACHE4[4];
} FMC_Type, *FMC_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- FMC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup FMC_Register_Accessor_Macros FMC - Register accessor macros
 * @{
 */


/* FMC - Register accessors */
#define FMC_PFAPR_REG(base)                      ((base)->PFAPR)
#define FMC_PFB0CR_REG(base)                     ((base)->PFB0CR)
#define FMC_PFB1CR_REG(base)                     ((base)->PFB1CR)
#define FMC_TAGVDW0S_REG(base,index)             ((base)->TAGVDW0S[index])
#define FMC_TAGVDW1S_REG(base,index)             ((base)->TAGVDW1S[index])
#define FMC_TAGVDW2S_REG(base,index)             ((base)->TAGVDW2S[index])
#define FMC_TAGVDW3S_REG(base,index)             ((base)->TAGVDW3S[index])
#define FMC_DATAW0SUM_REG(base,index)            ((base)->DATAW0SUM[index])
#define FMC_DATAW0SMU_REG(base,index)            ((base)->DATAW0SMU[index])
#define FMC_DATAW0SML_REG(base,index)            ((base)->DATAW0SML[index])
#define FMC_DATAW0SLM_REG(base,index)            ((base)->DATAW0SLM[index])
#define FMC_DATAW1SUM_REG(base,index)            ((base)->DATAW1SUM[index])
#define FMC_DATAW1SMU_REG(base,index)            ((base)->DATAW1SMU[index])
#define FMC_DATAW1SML_REG(base,index)            ((base)->DATAW1SML[index])
#define FMC_DATAW1SLM_REG(base,index)            ((base)->DATAW1SLM[index])
#define FMC_DATAW2SUM_REG(base,index)            ((base)->DATAW2SUM[index])
#define FMC_DATAW2SMU_REG(base,index)            ((base)->DATAW2SMU[index])
#define FMC_DATAW2SML_REG(base,index)            ((base)->DATAW2SML[index])
#define FMC_DATAW2SLM_REG(base,index)            ((base)->DATAW2SLM[index])
#define FMC_DATAW3SUM_REG(base,index)            ((base)->DATAW3SUM[index])
#define FMC_DATAW3SMU_REG(base,index)            ((base)->DATAW3SMU[index])
#define FMC_DATAW3SML_REG(base,index)            ((base)->DATAW3SML[index])
#define FMC_DATAW3SLM_REG(base,index)            ((base)->DATAW3SLM[index])

/*!
 * @}
 */ /* end of group FMC_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- FMC Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup FMC_Register_Masks FMC Register Masks
 * @{
 */

/* PFAPR Bit Fields */
#define FMC_PFAPR_M0AP_MASK                      0x3u
#define FMC_PFAPR_M0AP_SHIFT                     0
#define FMC_PFAPR_M0AP(x)                        (((uint32_t)(((uint32_t)(x))<<FMC_PFAPR_M0AP_SHIFT))&FMC_PFAPR_M0AP_MASK)
#define FMC_PFAPR_M1AP_MASK                      0xCu
#define FMC_PFAPR_M1AP_SHIFT                     2
#define FMC_PFAPR_M1AP(x)                        (((uint32_t)(((uint32_t)(x))<<FMC_PFAPR_M1AP_SHIFT))&FMC_PFAPR_M1AP_MASK)
#define FMC_PFAPR_M2AP_MASK                      0x30u
#define FMC_PFAPR_M2AP_SHIFT                     4
#define FMC_PFAPR_M2AP(x)                        (((uint32_t)(((uint32_t)(x))<<FMC_PFAPR_M2AP_SHIFT))&FMC_PFAPR_M2AP_MASK)
#define FMC_PFAPR_M3AP_MASK                      0xC0u
#define FMC_PFAPR_M3AP_SHIFT                     6
#define FMC_PFAPR_M3AP(x)                        (((uint32_t)(((uint32_t)(x))<<FMC_PFAPR_M3AP_SHIFT))&FMC_PFAPR_M3AP_MASK)
#define FMC_PFAPR_M0PFD_MASK                     0x10000u
#define FMC_PFAPR_M0PFD_SHIFT                    16
#define FMC_PFAPR_M1PFD_MASK                     0x20000u
#define FMC_PFAPR_M1PFD_SHIFT                    17
#define FMC_PFAPR_M2PFD_MASK                     0x40000u
#define FMC_PFAPR_M2PFD_SHIFT                    18
#define FMC_PFAPR_M3PFD_MASK                     0x80000u
#define FMC_PFAPR_M3PFD_SHIFT                    19
/* PFB0CR Bit Fields */
#define FMC_PFB0CR_B0SEBE_MASK                   0x1u
#define FMC_PFB0CR_B0SEBE_SHIFT                  0
#define FMC_PFB0CR_B0IPE_MASK                    0x2u
#define FMC_PFB0CR_B0IPE_SHIFT                   1
#define FMC_PFB0CR_B0DPE_MASK                    0x4u
#define FMC_PFB0CR_B0DPE_SHIFT                   2
#define FMC_PFB0CR_B0ICE_MASK                    0x8u
#define FMC_PFB0CR_B0ICE_SHIFT                   3
#define FMC_PFB0CR_B0DCE_MASK                    0x10u
#define FMC_PFB0CR_B0DCE_SHIFT                   4
#define FMC_PFB0CR_CRC_MASK                      0xE0u
#define FMC_PFB0CR_CRC_SHIFT                     5
#define FMC_PFB0CR_CRC(x)                        (((uint32_t)(((uint32_t)(x))<<FMC_PFB0CR_CRC_SHIFT))&FMC_PFB0CR_CRC_MASK)
#define FMC_PFB0CR_B0MW_MASK                     0x60000u
#define FMC_PFB0CR_B0MW_SHIFT                    17
#define FMC_PFB0CR_B0MW(x)                       (((uint32_t)(((uint32_t)(x))<<FMC_PFB0CR_B0MW_SHIFT))&FMC_PFB0CR_B0MW_MASK)
#define FMC_PFB0CR_S_B_INV_MASK                  0x80000u
#define FMC_PFB0CR_S_B_INV_SHIFT                 19
#define FMC_PFB0CR_CINV_WAY_MASK                 0xF00000u
#define FMC_PFB0CR_CINV_WAY_SHIFT                20
#define FMC_PFB0CR_CINV_WAY(x)                   (((uint32_t)(((uint32_t)(x))<<FMC_PFB0CR_CINV_WAY_SHIFT))&FMC_PFB0CR_CINV_WAY_MASK)
#define FMC_PFB0CR_CLCK_WAY_MASK                 0xF000000u
#define FMC_PFB0CR_CLCK_WAY_SHIFT                24
#define FMC_PFB0CR_CLCK_WAY(x)                   (((uint32_t)(((uint32_t)(x))<<FMC_PFB0CR_CLCK_WAY_SHIFT))&FMC_PFB0CR_CLCK_WAY_MASK)
#define FMC_PFB0CR_B0RWSC_MASK                   0xF0000000u
#define FMC_PFB0CR_B0RWSC_SHIFT                  28
#define FMC_PFB0CR_B0RWSC(x)                     (((uint32_t)(((uint32_t)(x))<<FMC_PFB0CR_B0RWSC_SHIFT))&FMC_PFB0CR_B0RWSC_MASK)
/* PFB1CR Bit Fields */
/* TAGVDW0S Bit Fields */
#define FMC_TAGVDW0S_VALID_MASK                  0x1u
#define FMC_TAGVDW0S_VALID_SHIFT                 0
#define FMC_TAGVDW0S_CACHE_TAG_MASK              0xFFFC0u
#define FMC_TAGVDW0S_CACHE_TAG_SHIFT             6
#define FMC_TAGVDW0S_CACHE_TAG(x)                (((uint32_t)(((uint32_t)(x))<<FMC_TAGVDW0S_CACHE_TAG_SHIFT))&FMC_TAGVDW0S_CACHE_TAG_MASK)
/* TAGVDW1S Bit Fields */
#define FMC_TAGVDW1S_VALID_MASK                  0x1u
#define FMC_TAGVDW1S_VALID_SHIFT                 0
#define FMC_TAGVDW1S_CACHE_TAG_MASK              0xFFFC0u
#define FMC_TAGVDW1S_CACHE_TAG_SHIFT             6
#define FMC_TAGVDW1S_CACHE_TAG(x)                (((uint32_t)(((uint32_t)(x))<<FMC_TAGVDW1S_CACHE_TAG_SHIFT))&FMC_TAGVDW1S_CACHE_TAG_MASK)
/* TAGVDW2S Bit Fields */
#define FMC_TAGVDW2S_VALID_MASK                  0x1u
#define FMC_TAGVDW2S_VALID_SHIFT                 0
#define FMC_TAGVDW2S_CACHE_TAG_MASK              0xFFFC0u
#define FMC_TAGVDW2S_CACHE_TAG_SHIFT             6
#define FMC_TAGVDW2S_CACHE_TAG(x)                (((uint32_t)(((uint32_t)(x))<<FMC_TAGVDW2S_CACHE_TAG_SHIFT))&FMC_TAGVDW2S_CACHE_TAG_MASK)
/* TAGVDW3S Bit Fields */
#define FMC_TAGVDW3S_VALID_MASK                  0x1u
#define FMC_TAGVDW3S_VALID_SHIFT                 0
#define FMC_TAGVDW3S_CACHE_TAG_MASK              0xFFFC0u
#define FMC_TAGVDW3S_CACHE_TAG_SHIFT             6
#define FMC_TAGVDW3S_CACHE_TAG(x)                (((uint32_t)(((uint32_t)(x))<<FMC_TAGVDW3S_CACHE_TAG_SHIFT))&FMC_TAGVDW3S_CACHE_TAG_MASK)
/* DATAW0SUM Bit Fields */
#define FMC_DATAW0SUM_DATA_MASK                  0xFFFFFFFFu
#define FMC_DATAW0SUM_DATA_SHIFT                 0
#define FMC_DATAW0SUM_DATA(x)                    (((uint32_t)(((uint32_t)(x))<<FMC_DATAW0SUM_DATA_SHIFT))&FMC_DATAW0SUM_DATA_MASK)
/* DATAW0SMU Bit Fields */
#define FMC_DATAW0SMU_DATA_MASK                  0xFFFFFFFFu
#define FMC_DATAW0SMU_DATA_SHIFT                 0
#define FMC_DATAW0SMU_DATA(x)                    (((uint32_t)(((uint32_t)(x))<<FMC_DATAW0SMU_DATA_SHIFT))&FMC_DATAW0SMU_DATA_MASK)
/* DATAW0SML Bit Fields */
#define FMC_DATAW0SML_DATA_MASK                  0xFFFFFFFFu
#define FMC_DATAW0SML_DATA_SHIFT                 0
#define FMC_DATAW0SML_DATA(x)                    (((uint32_t)(((uint32_t)(x))<<FMC_DATAW0SML_DATA_SHIFT))&FMC_DATAW0SML_DATA_MASK)
/* DATAW0SLM Bit Fields */
#define FMC_DATAW0SLM_DATA_MASK                  0xFFFFFFFFu
#define FMC_DATAW0SLM_DATA_SHIFT                 0
#define FMC_DATAW0SLM_DATA(x)                    (((uint32_t)(((uint32_t)(x))<<FMC_DATAW0SLM_DATA_SHIFT))&FMC_DATAW0SLM_DATA_MASK)
/* DATAW1SUM Bit Fields */
#define FMC_DATAW1SUM_DATA_MASK                  0xFFFFFFFFu
#define FMC_DATAW1SUM_DATA_SHIFT                 0
#define FMC_DATAW1SUM_DATA(x)                    (((uint32_t)(((uint32_t)(x))<<FMC_DATAW1SUM_DATA_SHIFT))&FMC_DATAW1SUM_DATA_MASK)
/* DATAW1SMU Bit Fields */
#define FMC_DATAW1SMU_DATA_MASK                  0xFFFFFFFFu
#define FMC_DATAW1SMU_DATA_SHIFT                 0
#define FMC_DATAW1SMU_DATA(x)                    (((uint32_t)(((uint32_t)(x))<<FMC_DATAW1SMU_DATA_SHIFT))&FMC_DATAW1SMU_DATA_MASK)
/* DATAW1SML Bit Fields */
#define FMC_DATAW1SML_DATA_MASK                  0xFFFFFFFFu
#define FMC_DATAW1SML_DATA_SHIFT                 0
#define FMC_DATAW1SML_DATA(x)                    (((uint32_t)(((uint32_t)(x))<<FMC_DATAW1SML_DATA_SHIFT))&FMC_DATAW1SML_DATA_MASK)
/* DATAW1SLM Bit Fields */
#define FMC_DATAW1SLM_DATA_MASK                  0xFFFFFFFFu
#define FMC_DATAW1SLM_DATA_SHIFT                 0
#define FMC_DATAW1SLM_DATA(x)                    (((uint32_t)(((uint32_t)(x))<<FMC_DATAW1SLM_DATA_SHIFT))&FMC_DATAW1SLM_DATA_MASK)
/* DATAW2SUM Bit Fields */
#define FMC_DATAW2SUM_DATA_MASK                  0xFFFFFFFFu
#define FMC_DATAW2SUM_DATA_SHIFT                 0
#define FMC_DATAW2SUM_DATA(x)                    (((uint32_t)(((uint32_t)(x))<<FMC_DATAW2SUM_DATA_SHIFT))&FMC_DATAW2SUM_DATA_MASK)
/* DATAW2SMU Bit Fields */
#define FMC_DATAW2SMU_DATA_MASK                  0xFFFFFFFFu
#define FMC_DATAW2SMU_DATA_SHIFT                 0
#define FMC_DATAW2SMU_DATA(x)                    (((uint32_t)(((uint32_t)(x))<<FMC_DATAW2SMU_DATA_SHIFT))&FMC_DATAW2SMU_DATA_MASK)
/* DATAW2SML Bit Fields */
#define FMC_DATAW2SML_DATA_MASK                  0xFFFFFFFFu
#define FMC_DATAW2SML_DATA_SHIFT                 0
#define FMC_DATAW2SML_DATA(x)                    (((uint32_t)(((uint32_t)(x))<<FMC_DATAW2SML_DATA_SHIFT))&FMC_DATAW2SML_DATA_MASK)
/* DATAW2SLM Bit Fields */
#define FMC_DATAW2SLM_DATA_MASK                  0xFFFFFFFFu
#define FMC_DATAW2SLM_DATA_SHIFT                 0
#define FMC_DATAW2SLM_DATA(x)                    (((uint32_t)(((uint32_t)(x))<<FMC_DATAW2SLM_DATA_SHIFT))&FMC_DATAW2SLM_DATA_MASK)
/* DATAW3SUM Bit Fields */
#define FMC_DATAW3SUM_DATA_MASK                  0xFFFFFFFFu
#define FMC_DATAW3SUM_DATA_SHIFT                 0
#define FMC_DATAW3SUM_DATA(x)                    (((uint32_t)(((uint32_t)(x))<<FMC_DATAW3SUM_DATA_SHIFT))&FMC_DATAW3SUM_DATA_MASK)
/* DATAW3SMU Bit Fields */
#define FMC_DATAW3SMU_DATA_MASK                  0xFFFFFFFFu
#define FMC_DATAW3SMU_DATA_SHIFT                 0
#define FMC_DATAW3SMU_DATA(x)                    (((uint32_t)(((uint32_t)(x))<<FMC_DATAW3SMU_DATA_SHIFT))&FMC_DATAW3SMU_DATA_MASK)
/* DATAW3SML Bit Fields */
#define FMC_DATAW3SML_DATA_MASK                  0xFFFFFFFFu
#define FMC_DATAW3SML_DATA_SHIFT                 0
#define FMC_DATAW3SML_DATA(x)                    (((uint32_t)(((uint32_t)(x))<<FMC_DATAW3SML_DATA_SHIFT))&FMC_DATAW3SML_DATA_MASK)
/* DATAW3SLM Bit Fields */
#define FMC_DATAW3SLM_DATA_MASK                  0xFFFFFFFFu
#define FMC_DATAW3SLM_DATA_SHIFT                 0
#define FMC_DATAW3SLM_DATA(x)                    (((uint32_t)(((uint32_t)(x))<<FMC_DATAW3SLM_DATA_SHIFT))&FMC_DATAW3SLM_DATA_MASK)

/*!
 * @}
 */ /* end of group FMC_Register_Masks */


/* FMC - Peripheral instance base addresses */
/** Peripheral FMC base address */
#define FMC_BASE                                (0x4001F000u)
/** Peripheral FMC base pointer */
#define FMC                                     ((FMC_Type *)FMC_BASE)
#define FMC_BASE_PTR                            (FMC)
/** Array initializer of FMC peripheral base addresses */
#define FMC_BASE_ADDRS                           { FMC_BASE }
/** Array initializer of FMC peripheral base pointers */
#define FMC_BASE_PTRS                            { FMC }
/** Interrupt vectors for the FMC peripheral type */
#define FMC_IRQS                                 { FMC_IRQn }

/* ----------------------------------------------------------------------------
   -- FMC - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup FMC_Register_Accessor_Macros FMC - Register accessor macros
 * @{
 */


/* FMC - Register instance definitions */
/* FMC */
#define FMC_PFAPR                                FMC_PFAPR_REG(FMC)
#define FMC_PFB0CR                               FMC_PFB0CR_REG(FMC)
#define FMC_PFB1CR                               FMC_PFB1CR_REG(FMC)
#define FMC_TAGVDW0S0                            FMC_TAGVDW0S_REG(FMC,0)
#define FMC_TAGVDW0S1                            FMC_TAGVDW0S_REG(FMC,1)
#define FMC_TAGVDW0S2                            FMC_TAGVDW0S_REG(FMC,2)
#define FMC_TAGVDW0S3                            FMC_TAGVDW0S_REG(FMC,3)
#define FMC_TAGVDW1S0                            FMC_TAGVDW1S_REG(FMC,0)
#define FMC_TAGVDW1S1                            FMC_TAGVDW1S_REG(FMC,1)
#define FMC_TAGVDW1S2                            FMC_TAGVDW1S_REG(FMC,2)
#define FMC_TAGVDW1S3                            FMC_TAGVDW1S_REG(FMC,3)
#define FMC_TAGVDW2S0                            FMC_TAGVDW2S_REG(FMC,0)
#define FMC_TAGVDW2S1                            FMC_TAGVDW2S_REG(FMC,1)
#define FMC_TAGVDW2S2                            FMC_TAGVDW2S_REG(FMC,2)
#define FMC_TAGVDW2S3                            FMC_TAGVDW2S_REG(FMC,3)
#define FMC_TAGVDW3S0                            FMC_TAGVDW3S_REG(FMC,0)
#define FMC_TAGVDW3S1                            FMC_TAGVDW3S_REG(FMC,1)
#define FMC_TAGVDW3S2                            FMC_TAGVDW3S_REG(FMC,2)
#define FMC_TAGVDW3S3                            FMC_TAGVDW3S_REG(FMC,3)
#define FMC_DATAW0S0UM                           FMC_DATAW0SUM_REG(FMC,0)
#define FMC_DATAW0S1UM                           FMC_DATAW0SUM_REG(FMC,1)
#define FMC_DATAW0S2UM                           FMC_DATAW0SUM_REG(FMC,2)
#define FMC_DATAW0S3UM                           FMC_DATAW0SUM_REG(FMC,3)
#define FMC_DATAW0S0MU                           FMC_DATAW0SMU_REG(FMC,0)
#define FMC_DATAW0S1MU                           FMC_DATAW0SMU_REG(FMC,1)
#define FMC_DATAW0S2MU                           FMC_DATAW0SMU_REG(FMC,2)
#define FMC_DATAW0S3MU                           FMC_DATAW0SMU_REG(FMC,3)
#define FMC_DATAW0S0ML                           FMC_DATAW0SML_REG(FMC,0)
#define FMC_DATAW0S1ML                           FMC_DATAW0SML_REG(FMC,1)
#define FMC_DATAW0S2ML                           FMC_DATAW0SML_REG(FMC,2)
#define FMC_DATAW0S3ML                           FMC_DATAW0SML_REG(FMC,3)
#define FMC_DATAW0S0LM                           FMC_DATAW0SLM_REG(FMC,0)
#define FMC_DATAW0S1LM                           FMC_DATAW0SLM_REG(FMC,1)
#define FMC_DATAW0S2LM                           FMC_DATAW0SLM_REG(FMC,2)
#define FMC_DATAW0S3LM                           FMC_DATAW0SLM_REG(FMC,3)
#define FMC_DATAW1S0UM                           FMC_DATAW1SUM_REG(FMC,0)
#define FMC_DATAW1S1UM                           FMC_DATAW1SUM_REG(FMC,1)
#define FMC_DATAW1S2UM                           FMC_DATAW1SUM_REG(FMC,2)
#define FMC_DATAW1S3UM                           FMC_DATAW1SUM_REG(FMC,3)
#define FMC_DATAW1S0MU                           FMC_DATAW1SMU_REG(FMC,0)
#define FMC_DATAW1S1MU                           FMC_DATAW1SMU_REG(FMC,1)
#define FMC_DATAW1S2MU                           FMC_DATAW1SMU_REG(FMC,2)
#define FMC_DATAW1S3MU                           FMC_DATAW1SMU_REG(FMC,3)
#define FMC_DATAW1S0ML                           FMC_DATAW1SML_REG(FMC,0)
#define FMC_DATAW1S1ML                           FMC_DATAW1SML_REG(FMC,1)
#define FMC_DATAW1S2ML                           FMC_DATAW1SML_REG(FMC,2)
#define FMC_DATAW1S3ML                           FMC_DATAW1SML_REG(FMC,3)
#define FMC_DATAW1S0LM                           FMC_DATAW1SLM_REG(FMC,0)
#define FMC_DATAW1S1LM                           FMC_DATAW1SLM_REG(FMC,1)
#define FMC_DATAW1S2LM                           FMC_DATAW1SLM_REG(FMC,2)
#define FMC_DATAW1S3LM                           FMC_DATAW1SLM_REG(FMC,3)
#define FMC_DATAW2S0UM                           FMC_DATAW2SUM_REG(FMC,0)
#define FMC_DATAW2S1UM                           FMC_DATAW2SUM_REG(FMC,1)
#define FMC_DATAW2S2UM                           FMC_DATAW2SUM_REG(FMC,2)
#define FMC_DATAW2S3UM                           FMC_DATAW2SUM_REG(FMC,3)
#define FMC_DATAW2S0MU                           FMC_DATAW2SMU_REG(FMC,0)
#define FMC_DATAW2S1MU                           FMC_DATAW2SMU_REG(FMC,1)
#define FMC_DATAW2S2MU                           FMC_DATAW2SMU_REG(FMC,2)
#define FMC_DATAW2S3MU                           FMC_DATAW2SMU_REG(FMC,3)
#define FMC_DATAW2S0ML                           FMC_DATAW2SML_REG(FMC,0)
#define FMC_DATAW2S1ML                           FMC_DATAW2SML_REG(FMC,1)
#define FMC_DATAW2S2ML                           FMC_DATAW2SML_REG(FMC,2)
#define FMC_DATAW2S3ML                           FMC_DATAW2SML_REG(FMC,3)
#define FMC_DATAW2S0LM                           FMC_DATAW2SLM_REG(FMC,0)
#define FMC_DATAW2S1LM                           FMC_DATAW2SLM_REG(FMC,1)
#define FMC_DATAW2S2LM                           FMC_DATAW2SLM_REG(FMC,2)
#define FMC_DATAW2S3LM                           FMC_DATAW2SLM_REG(FMC,3)
#define FMC_DATAW3S0UM                           FMC_DATAW3SUM_REG(FMC,0)
#define FMC_DATAW3S1UM                           FMC_DATAW3SUM_REG(FMC,1)
#define FMC_DATAW3S2UM                           FMC_DATAW3SUM_REG(FMC,2)
#define FMC_DATAW3S3UM                           FMC_DATAW3SUM_REG(FMC,3)
#define FMC_DATAW3S0MU                           FMC_DATAW3SMU_REG(FMC,0)
#define FMC_DATAW3S1MU                           FMC_DATAW3SMU_REG(FMC,1)
#define FMC_DATAW3S2MU                           FMC_DATAW3SMU_REG(FMC,2)
#define FMC_DATAW3S3MU                           FMC_DATAW3SMU_REG(FMC,3)
#define FMC_DATAW3S0ML                           FMC_DATAW3SML_REG(FMC,0)
#define FMC_DATAW3S1ML                           FMC_DATAW3SML_REG(FMC,1)
#define FMC_DATAW3S2ML                           FMC_DATAW3SML_REG(FMC,2)
#define FMC_DATAW3S3ML                           FMC_DATAW3SML_REG(FMC,3)
#define FMC_DATAW3S0LM                           FMC_DATAW3SLM_REG(FMC,0)
#define FMC_DATAW3S1LM                           FMC_DATAW3SLM_REG(FMC,1)
#define FMC_DATAW3S2LM                           FMC_DATAW3SLM_REG(FMC,2)
#define FMC_DATAW3S3LM                           FMC_DATAW3SLM_REG(FMC,3)

/* FMC - Register array accessors */
#define FMC_TAGVDW0S(index)                      FMC_TAGVDW0S_REG(FMC,index)
#define FMC_TAGVDW1S(index)                      FMC_TAGVDW1S_REG(FMC,index)
#define FMC_TAGVDW2S(index)                      FMC_TAGVDW2S_REG(FMC,index)
#define FMC_TAGVDW3S(index)                      FMC_TAGVDW3S_REG(FMC,index)
#define FMC_DATAW0SUM(index)                     FMC_DATAW0SUM_REG(FMC,index)
#define FMC_DATAW0SMU(index)                     FMC_DATAW0SMU_REG(FMC,index)
#define FMC_DATAW0SML(index)                     FMC_DATAW0SML_REG(FMC,index)
#define FMC_DATAW0SLM(index)                     FMC_DATAW0SLM_REG(FMC,index)
#define FMC_DATAW1SUM(index)                     FMC_DATAW1SUM_REG(FMC,index)
#define FMC_DATAW1SMU(index)                     FMC_DATAW1SMU_REG(FMC,index)
#define FMC_DATAW1SML(index)                     FMC_DATAW1SML_REG(FMC,index)
#define FMC_DATAW1SLM(index)                     FMC_DATAW1SLM_REG(FMC,index)
#define FMC_DATAW2SUM(index)                     FMC_DATAW2SUM_REG(FMC,index)
#define FMC_DATAW2SMU(index)                     FMC_DATAW2SMU_REG(FMC,index)
#define FMC_DATAW2SML(index)                     FMC_DATAW2SML_REG(FMC,index)
#define FMC_DATAW2SLM(index)                     FMC_DATAW2SLM_REG(FMC,index)
#define FMC_DATAW3SUM(index)                     FMC_DATAW3SUM_REG(FMC,index)
#define FMC_DATAW3SMU(index)                     FMC_DATAW3SMU_REG(FMC,index)
#define FMC_DATAW3SML(index)                     FMC_DATAW3SML_REG(FMC,index)
#define FMC_DATAW3SLM(index)                     FMC_DATAW3SLM_REG(FMC,index)

/*!
 * @}
 */ /* end of group FMC_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group FMC_Peripheral_Access_Layer */


/* ----------------------------------------------------------------------------
   -- FTFA Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup FTFA_Peripheral_Access_Layer FTFA Peripheral Access Layer
 * @{
 */

/** FTFA - Register Layout Typedef */
typedef struct {
  __IO uint8_t FSTAT;                              /**< Flash Status Register, offset: 0x0 */
  __IO uint8_t FCNFG;                              /**< Flash Configuration Register, offset: 0x1 */
  __I  uint8_t FSEC;                               /**< Flash Security Register, offset: 0x2 */
  __I  uint8_t FOPT;                               /**< Flash Option Register, offset: 0x3 */
  __IO uint8_t FCCOB3;                             /**< Flash Common Command Object Registers, offset: 0x4 */
  __IO uint8_t FCCOB2;                             /**< Flash Common Command Object Registers, offset: 0x5 */
  __IO uint8_t FCCOB1;                             /**< Flash Common Command Object Registers, offset: 0x6 */
  __IO uint8_t FCCOB0;                             /**< Flash Common Command Object Registers, offset: 0x7 */
  __IO uint8_t FCCOB7;                             /**< Flash Common Command Object Registers, offset: 0x8 */
  __IO uint8_t FCCOB6;                             /**< Flash Common Command Object Registers, offset: 0x9 */
  __IO uint8_t FCCOB5;                             /**< Flash Common Command Object Registers, offset: 0xA */
  __IO uint8_t FCCOB4;                             /**< Flash Common Command Object Registers, offset: 0xB */
  __IO uint8_t FCCOBB;                             /**< Flash Common Command Object Registers, offset: 0xC */
  __IO uint8_t FCCOBA;                             /**< Flash Common Command Object Registers, offset: 0xD */
  __IO uint8_t FCCOB9;                             /**< Flash Common Command Object Registers, offset: 0xE */
  __IO uint8_t FCCOB8;                             /**< Flash Common Command Object Registers, offset: 0xF */
  __IO uint8_t FPROT3;                             /**< Program Flash Protection Registers, offset: 0x10 */
  __IO uint8_t FPROT2;                             /**< Program Flash Protection Registers, offset: 0x11 */
  __IO uint8_t FPROT1;                             /**< Program Flash Protection Registers, offset: 0x12 */
  __IO uint8_t FPROT0;                             /**< Program Flash Protection Registers, offset: 0x13 */
       uint32_t RESERVED_0;
  __I  uint8_t XACCH3;                             /**< Execute-only Access Registers, offset: 0x18 */
  __I  uint8_t XACCH2;                             /**< Execute-only Access Registers, offset: 0x19 */
  __I  uint8_t XACCH1;                             /**< Execute-only Access Registers, offset: 0x1A */
  __I  uint8_t XACCH0;                             /**< Execute-only Access Registers, offset: 0x1B */
  __I  uint8_t XACCL3;                             /**< Execute-only Access Registers, offset: 0x1C */
  __I  uint8_t XACCL2;                             /**< Execute-only Access Registers, offset: 0x1D */
  __I  uint8_t XACCL1;                             /**< Execute-only Access Registers, offset: 0x1E */
  __I  uint8_t XACCL0;                             /**< Execute-only Access Registers, offset: 0x1F */
  __I  uint8_t SACCH3;                             /**< Supervisor-only Access Registers, offset: 0x20 */
  __I  uint8_t SACCH2;                             /**< Supervisor-only Access Registers, offset: 0x21 */
  __I  uint8_t SACCH1;                             /**< Supervisor-only Access Registers, offset: 0x22 */
  __I  uint8_t SACCH0;                             /**< Supervisor-only Access Registers, offset: 0x23 */
  __I  uint8_t SACCL3;                             /**< Supervisor-only Access Registers, offset: 0x24 */
  __I  uint8_t SACCL2;                             /**< Supervisor-only Access Registers, offset: 0x25 */
  __I  uint8_t SACCL1;                             /**< Supervisor-only Access Registers, offset: 0x26 */
  __I  uint8_t SACCL0;                             /**< Supervisor-only Access Registers, offset: 0x27 */
  __I  uint8_t FACSS;                              /**< Flash Access Segment Size Register, offset: 0x28 */
       uint8_t RESERVED_1[2];
  __I  uint8_t FACSN;                              /**< Flash Access Segment Number Register, offset: 0x2B */
} FTFA_Type, *FTFA_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- FTFA - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup FTFA_Register_Accessor_Macros FTFA - Register accessor macros
 * @{
 */


/* FTFA - Register accessors */
#define FTFA_FSTAT_REG(base)                     ((base)->FSTAT)
#define FTFA_FCNFG_REG(base)                     ((base)->FCNFG)
#define FTFA_FSEC_REG(base)                      ((base)->FSEC)
#define FTFA_FOPT_REG(base)                      ((base)->FOPT)
#define FTFA_FCCOB3_REG(base)                    ((base)->FCCOB3)
#define FTFA_FCCOB2_REG(base)                    ((base)->FCCOB2)
#define FTFA_FCCOB1_REG(base)                    ((base)->FCCOB1)
#define FTFA_FCCOB0_REG(base)                    ((base)->FCCOB0)
#define FTFA_FCCOB7_REG(base)                    ((base)->FCCOB7)
#define FTFA_FCCOB6_REG(base)                    ((base)->FCCOB6)
#define FTFA_FCCOB5_REG(base)                    ((base)->FCCOB5)
#define FTFA_FCCOB4_REG(base)                    ((base)->FCCOB4)
#define FTFA_FCCOBB_REG(base)                    ((base)->FCCOBB)
#define FTFA_FCCOBA_REG(base)                    ((base)->FCCOBA)
#define FTFA_FCCOB9_REG(base)                    ((base)->FCCOB9)
#define FTFA_FCCOB8_REG(base)                    ((base)->FCCOB8)
#define FTFA_FPROT3_REG(base)                    ((base)->FPROT3)
#define FTFA_FPROT2_REG(base)                    ((base)->FPROT2)
#define FTFA_FPROT1_REG(base)                    ((base)->FPROT1)
#define FTFA_FPROT0_REG(base)                    ((base)->FPROT0)
#define FTFA_XACCH3_REG(base)                    ((base)->XACCH3)
#define FTFA_XACCH2_REG(base)                    ((base)->XACCH2)
#define FTFA_XACCH1_REG(base)                    ((base)->XACCH1)
#define FTFA_XACCH0_REG(base)                    ((base)->XACCH0)
#define FTFA_XACCL3_REG(base)                    ((base)->XACCL3)
#define FTFA_XACCL2_REG(base)                    ((base)->XACCL2)
#define FTFA_XACCL1_REG(base)                    ((base)->XACCL1)
#define FTFA_XACCL0_REG(base)                    ((base)->XACCL0)
#define FTFA_SACCH3_REG(base)                    ((base)->SACCH3)
#define FTFA_SACCH2_REG(base)                    ((base)->SACCH2)
#define FTFA_SACCH1_REG(base)                    ((base)->SACCH1)
#define FTFA_SACCH0_REG(base)                    ((base)->SACCH0)
#define FTFA_SACCL3_REG(base)                    ((base)->SACCL3)
#define FTFA_SACCL2_REG(base)                    ((base)->SACCL2)
#define FTFA_SACCL1_REG(base)                    ((base)->SACCL1)
#define FTFA_SACCL0_REG(base)                    ((base)->SACCL0)
#define FTFA_FACSS_REG(base)                     ((base)->FACSS)
#define FTFA_FACSN_REG(base)                     ((base)->FACSN)

/*!
 * @}
 */ /* end of group FTFA_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- FTFA Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup FTFA_Register_Masks FTFA Register Masks
 * @{
 */

/* FSTAT Bit Fields */
#define FTFA_FSTAT_MGSTAT0_MASK                  0x1u
#define FTFA_FSTAT_MGSTAT0_SHIFT                 0
#define FTFA_FSTAT_FPVIOL_MASK                   0x10u
#define FTFA_FSTAT_FPVIOL_SHIFT                  4
#define FTFA_FSTAT_ACCERR_MASK                   0x20u
#define FTFA_FSTAT_ACCERR_SHIFT                  5
#define FTFA_FSTAT_RDCOLERR_MASK                 0x40u
#define FTFA_FSTAT_RDCOLERR_SHIFT                6
#define FTFA_FSTAT_CCIF_MASK                     0x80u
#define FTFA_FSTAT_CCIF_SHIFT                    7
/* FCNFG Bit Fields */
#define FTFA_FCNFG_ERSSUSP_MASK                  0x10u
#define FTFA_FCNFG_ERSSUSP_SHIFT                 4
#define FTFA_FCNFG_ERSAREQ_MASK                  0x20u
#define FTFA_FCNFG_ERSAREQ_SHIFT                 5
#define FTFA_FCNFG_RDCOLLIE_MASK                 0x40u
#define FTFA_FCNFG_RDCOLLIE_SHIFT                6
#define FTFA_FCNFG_CCIE_MASK                     0x80u
#define FTFA_FCNFG_CCIE_SHIFT                    7
/* FSEC Bit Fields */
#define FTFA_FSEC_SEC_MASK                       0x3u
#define FTFA_FSEC_SEC_SHIFT                      0
#define FTFA_FSEC_SEC(x)                         (((uint8_t)(((uint8_t)(x))<<FTFA_FSEC_SEC_SHIFT))&FTFA_FSEC_SEC_MASK)
#define FTFA_FSEC_FSLACC_MASK                    0xCu
#define FTFA_FSEC_FSLACC_SHIFT                   2
#define FTFA_FSEC_FSLACC(x)                      (((uint8_t)(((uint8_t)(x))<<FTFA_FSEC_FSLACC_SHIFT))&FTFA_FSEC_FSLACC_MASK)
#define FTFA_FSEC_MEEN_MASK                      0x30u
#define FTFA_FSEC_MEEN_SHIFT                     4
#define FTFA_FSEC_MEEN(x)                        (((uint8_t)(((uint8_t)(x))<<FTFA_FSEC_MEEN_SHIFT))&FTFA_FSEC_MEEN_MASK)
#define FTFA_FSEC_KEYEN_MASK                     0xC0u
#define FTFA_FSEC_KEYEN_SHIFT                    6
#define FTFA_FSEC_KEYEN(x)                       (((uint8_t)(((uint8_t)(x))<<FTFA_FSEC_KEYEN_SHIFT))&FTFA_FSEC_KEYEN_MASK)
/* FOPT Bit Fields */
#define FTFA_FOPT_OPT_MASK                       0xFFu
#define FTFA_FOPT_OPT_SHIFT                      0
#define FTFA_FOPT_OPT(x)                         (((uint8_t)(((uint8_t)(x))<<FTFA_FOPT_OPT_SHIFT))&FTFA_FOPT_OPT_MASK)
/* FCCOB3 Bit Fields */
#define FTFA_FCCOB3_CCOBN_MASK                   0xFFu
#define FTFA_FCCOB3_CCOBN_SHIFT                  0
#define FTFA_FCCOB3_CCOBN(x)                     (((uint8_t)(((uint8_t)(x))<<FTFA_FCCOB3_CCOBN_SHIFT))&FTFA_FCCOB3_CCOBN_MASK)
/* FCCOB2 Bit Fields */
#define FTFA_FCCOB2_CCOBN_MASK                   0xFFu
#define FTFA_FCCOB2_CCOBN_SHIFT                  0
#define FTFA_FCCOB2_CCOBN(x)                     (((uint8_t)(((uint8_t)(x))<<FTFA_FCCOB2_CCOBN_SHIFT))&FTFA_FCCOB2_CCOBN_MASK)
/* FCCOB1 Bit Fields */
#define FTFA_FCCOB1_CCOBN_MASK                   0xFFu
#define FTFA_FCCOB1_CCOBN_SHIFT                  0
#define FTFA_FCCOB1_CCOBN(x)                     (((uint8_t)(((uint8_t)(x))<<FTFA_FCCOB1_CCOBN_SHIFT))&FTFA_FCCOB1_CCOBN_MASK)
/* FCCOB0 Bit Fields */
#define FTFA_FCCOB0_CCOBN_MASK                   0xFFu
#define FTFA_FCCOB0_CCOBN_SHIFT                  0
#define FTFA_FCCOB0_CCOBN(x)                     (((uint8_t)(((uint8_t)(x))<<FTFA_FCCOB0_CCOBN_SHIFT))&FTFA_FCCOB0_CCOBN_MASK)
/* FCCOB7 Bit Fields */
#define FTFA_FCCOB7_CCOBN_MASK                   0xFFu
#define FTFA_FCCOB7_CCOBN_SHIFT                  0
#define FTFA_FCCOB7_CCOBN(x)                     (((uint8_t)(((uint8_t)(x))<<FTFA_FCCOB7_CCOBN_SHIFT))&FTFA_FCCOB7_CCOBN_MASK)
/* FCCOB6 Bit Fields */
#define FTFA_FCCOB6_CCOBN_MASK                   0xFFu
#define FTFA_FCCOB6_CCOBN_SHIFT                  0
#define FTFA_FCCOB6_CCOBN(x)                     (((uint8_t)(((uint8_t)(x))<<FTFA_FCCOB6_CCOBN_SHIFT))&FTFA_FCCOB6_CCOBN_MASK)
/* FCCOB5 Bit Fields */
#define FTFA_FCCOB5_CCOBN_MASK                   0xFFu
#define FTFA_FCCOB5_CCOBN_SHIFT                  0
#define FTFA_FCCOB5_CCOBN(x)                     (((uint8_t)(((uint8_t)(x))<<FTFA_FCCOB5_CCOBN_SHIFT))&FTFA_FCCOB5_CCOBN_MASK)
/* FCCOB4 Bit Fields */
#define FTFA_FCCOB4_CCOBN_MASK                   0xFFu
#define FTFA_FCCOB4_CCOBN_SHIFT                  0
#define FTFA_FCCOB4_CCOBN(x)                     (((uint8_t)(((uint8_t)(x))<<FTFA_FCCOB4_CCOBN_SHIFT))&FTFA_FCCOB4_CCOBN_MASK)
/* FCCOBB Bit Fields */
#define FTFA_FCCOBB_CCOBN_MASK                   0xFFu
#define FTFA_FCCOBB_CCOBN_SHIFT                  0
#define FTFA_FCCOBB_CCOBN(x)                     (((uint8_t)(((uint8_t)(x))<<FTFA_FCCOBB_CCOBN_SHIFT))&FTFA_FCCOBB_CCOBN_MASK)
/* FCCOBA Bit Fields */
#define FTFA_FCCOBA_CCOBN_MASK                   0xFFu
#define FTFA_FCCOBA_CCOBN_SHIFT                  0
#define FTFA_FCCOBA_CCOBN(x)                     (((uint8_t)(((uint8_t)(x))<<FTFA_FCCOBA_CCOBN_SHIFT))&FTFA_FCCOBA_CCOBN_MASK)
/* FCCOB9 Bit Fields */
#define FTFA_FCCOB9_CCOBN_MASK                   0xFFu
#define FTFA_FCCOB9_CCOBN_SHIFT                  0
#define FTFA_FCCOB9_CCOBN(x)                     (((uint8_t)(((uint8_t)(x))<<FTFA_FCCOB9_CCOBN_SHIFT))&FTFA_FCCOB9_CCOBN_MASK)
/* FCCOB8 Bit Fields */
#define FTFA_FCCOB8_CCOBN_MASK                   0xFFu
#define FTFA_FCCOB8_CCOBN_SHIFT                  0
#define FTFA_FCCOB8_CCOBN(x)                     (((uint8_t)(((uint8_t)(x))<<FTFA_FCCOB8_CCOBN_SHIFT))&FTFA_FCCOB8_CCOBN_MASK)
/* FPROT3 Bit Fields */
#define FTFA_FPROT3_PROT_MASK                    0xFFu
#define FTFA_FPROT3_PROT_SHIFT                   0
#define FTFA_FPROT3_PROT(x)                      (((uint8_t)(((uint8_t)(x))<<FTFA_FPROT3_PROT_SHIFT))&FTFA_FPROT3_PROT_MASK)
/* FPROT2 Bit Fields */
#define FTFA_FPROT2_PROT_MASK                    0xFFu
#define FTFA_FPROT2_PROT_SHIFT                   0
#define FTFA_FPROT2_PROT(x)                      (((uint8_t)(((uint8_t)(x))<<FTFA_FPROT2_PROT_SHIFT))&FTFA_FPROT2_PROT_MASK)
/* FPROT1 Bit Fields */
#define FTFA_FPROT1_PROT_MASK                    0xFFu
#define FTFA_FPROT1_PROT_SHIFT                   0
#define FTFA_FPROT1_PROT(x)                      (((uint8_t)(((uint8_t)(x))<<FTFA_FPROT1_PROT_SHIFT))&FTFA_FPROT1_PROT_MASK)
/* FPROT0 Bit Fields */
#define FTFA_FPROT0_PROT_MASK                    0xFFu
#define FTFA_FPROT0_PROT_SHIFT                   0
#define FTFA_FPROT0_PROT(x)                      (((uint8_t)(((uint8_t)(x))<<FTFA_FPROT0_PROT_SHIFT))&FTFA_FPROT0_PROT_MASK)
/* XACCH3 Bit Fields */
#define FTFA_XACCH3_XA_MASK                      0xFFu
#define FTFA_XACCH3_XA_SHIFT                     0
#define FTFA_XACCH3_XA(x)                        (((uint8_t)(((uint8_t)(x))<<FTFA_XACCH3_XA_SHIFT))&FTFA_XACCH3_XA_MASK)
/* XACCH2 Bit Fields */
#define FTFA_XACCH2_XA_MASK                      0xFFu
#define FTFA_XACCH2_XA_SHIFT                     0
#define FTFA_XACCH2_XA(x)                        (((uint8_t)(((uint8_t)(x))<<FTFA_XACCH2_XA_SHIFT))&FTFA_XACCH2_XA_MASK)
/* XACCH1 Bit Fields */
#define FTFA_XACCH1_XA_MASK                      0xFFu
#define FTFA_XACCH1_XA_SHIFT                     0
#define FTFA_XACCH1_XA(x)                        (((uint8_t)(((uint8_t)(x))<<FTFA_XACCH1_XA_SHIFT))&FTFA_XACCH1_XA_MASK)
/* XACCH0 Bit Fields */
#define FTFA_XACCH0_XA_MASK                      0xFFu
#define FTFA_XACCH0_XA_SHIFT                     0
#define FTFA_XACCH0_XA(x)                        (((uint8_t)(((uint8_t)(x))<<FTFA_XACCH0_XA_SHIFT))&FTFA_XACCH0_XA_MASK)
/* XACCL3 Bit Fields */
#define FTFA_XACCL3_XA_MASK                      0xFFu
#define FTFA_XACCL3_XA_SHIFT                     0
#define FTFA_XACCL3_XA(x)                        (((uint8_t)(((uint8_t)(x))<<FTFA_XACCL3_XA_SHIFT))&FTFA_XACCL3_XA_MASK)
/* XACCL2 Bit Fields */
#define FTFA_XACCL2_XA_MASK                      0xFFu
#define FTFA_XACCL2_XA_SHIFT                     0
#define FTFA_XACCL2_XA(x)                        (((uint8_t)(((uint8_t)(x))<<FTFA_XACCL2_XA_SHIFT))&FTFA_XACCL2_XA_MASK)
/* XACCL1 Bit Fields */
#define FTFA_XACCL1_XA_MASK                      0xFFu
#define FTFA_XACCL1_XA_SHIFT                     0
#define FTFA_XACCL1_XA(x)                        (((uint8_t)(((uint8_t)(x))<<FTFA_XACCL1_XA_SHIFT))&FTFA_XACCL1_XA_MASK)
/* XACCL0 Bit Fields */
#define FTFA_XACCL0_XA_MASK                      0xFFu
#define FTFA_XACCL0_XA_SHIFT                     0
#define FTFA_XACCL0_XA(x)                        (((uint8_t)(((uint8_t)(x))<<FTFA_XACCL0_XA_SHIFT))&FTFA_XACCL0_XA_MASK)
/* SACCH3 Bit Fields */
#define FTFA_SACCH3_SA_MASK                      0xFFu
#define FTFA_SACCH3_SA_SHIFT                     0
#define FTFA_SACCH3_SA(x)                        (((uint8_t)(((uint8_t)(x))<<FTFA_SACCH3_SA_SHIFT))&FTFA_SACCH3_SA_MASK)
/* SACCH2 Bit Fields */
#define FTFA_SACCH2_SA_MASK                      0xFFu
#define FTFA_SACCH2_SA_SHIFT                     0
#define FTFA_SACCH2_SA(x)                        (((uint8_t)(((uint8_t)(x))<<FTFA_SACCH2_SA_SHIFT))&FTFA_SACCH2_SA_MASK)
/* SACCH1 Bit Fields */
#define FTFA_SACCH1_SA_MASK                      0xFFu
#define FTFA_SACCH1_SA_SHIFT                     0
#define FTFA_SACCH1_SA(x)                        (((uint8_t)(((uint8_t)(x))<<FTFA_SACCH1_SA_SHIFT))&FTFA_SACCH1_SA_MASK)
/* SACCH0 Bit Fields */
#define FTFA_SACCH0_SA_MASK                      0xFFu
#define FTFA_SACCH0_SA_SHIFT                     0
#define FTFA_SACCH0_SA(x)                        (((uint8_t)(((uint8_t)(x))<<FTFA_SACCH0_SA_SHIFT))&FTFA_SACCH0_SA_MASK)
/* SACCL3 Bit Fields */
#define FTFA_SACCL3_SA_MASK                      0xFFu
#define FTFA_SACCL3_SA_SHIFT                     0
#define FTFA_SACCL3_SA(x)                        (((uint8_t)(((uint8_t)(x))<<FTFA_SACCL3_SA_SHIFT))&FTFA_SACCL3_SA_MASK)
/* SACCL2 Bit Fields */
#define FTFA_SACCL2_SA_MASK                      0xFFu
#define FTFA_SACCL2_SA_SHIFT                     0
#define FTFA_SACCL2_SA(x)                        (((uint8_t)(((uint8_t)(x))<<FTFA_SACCL2_SA_SHIFT))&FTFA_SACCL2_SA_MASK)
/* SACCL1 Bit Fields */
#define FTFA_SACCL1_SA_MASK                      0xFFu
#define FTFA_SACCL1_SA_SHIFT                     0
#define FTFA_SACCL1_SA(x)                        (((uint8_t)(((uint8_t)(x))<<FTFA_SACCL1_SA_SHIFT))&FTFA_SACCL1_SA_MASK)
/* SACCL0 Bit Fields */
#define FTFA_SACCL0_SA_MASK                      0xFFu
#define FTFA_SACCL0_SA_SHIFT                     0
#define FTFA_SACCL0_SA(x)                        (((uint8_t)(((uint8_t)(x))<<FTFA_SACCL0_SA_SHIFT))&FTFA_SACCL0_SA_MASK)
/* FACSS Bit Fields */
#define FTFA_FACSS_SGSIZE_MASK                   0xFFu
#define FTFA_FACSS_SGSIZE_SHIFT                  0
#define FTFA_FACSS_SGSIZE(x)                     (((uint8_t)(((uint8_t)(x))<<FTFA_FACSS_SGSIZE_SHIFT))&FTFA_FACSS_SGSIZE_MASK)
/* FACSN Bit Fields */
#define FTFA_FACSN_NUMSG_MASK                    0xFFu
#define FTFA_FACSN_NUMSG_SHIFT                   0
#define FTFA_FACSN_NUMSG(x)                      (((uint8_t)(((uint8_t)(x))<<FTFA_FACSN_NUMSG_SHIFT))&FTFA_FACSN_NUMSG_MASK)

/*!
 * @}
 */ /* end of group FTFA_Register_Masks */


/* FTFA - Peripheral instance base addresses */
/** Array initializer of FTFA peripheral base addresses */
#define FTFA_BASE                                (0x40020000u)
/** Peripheral FTFA base pointer */
#define FTFA                                     ((FTFA_Type *)FTFA_BASE)
#define FTFA_BASE_PTR                            (FTFA)
#define FTFA_BASE_ADDRS                           { FTFA_BASE }
/** Array initializer of FTFA peripheral base pointers */
#define FTFA_BASE_PTRS                            { FTFA }
/** Interrupt vectors for the FTFA peripheral type */
#define FTFA_IRQS                                 {  }

/* ----------------------------------------------------------------------------
   -- FTFA - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup FTFA_Register_Accessor_Macros FTFA - Register accessor macros
 * @{
 */


/* FTFA - Register instance definitions */

/* FTFA - Register array accessors */

/*!
 * @}
 */ /* end of group FTFA_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group FTFA_Peripheral_Access_Layer */


/* ----------------------------------------------------------------------------
   -- GPIO Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPIO_Peripheral_Access_Layer GPIO Peripheral Access Layer
 * @{
 */

/** GPIO - Register Layout Typedef */
typedef struct {
  __IO uint32_t PDOR;                              /**< Port Data Output Register, offset: 0x0 */
  __O  uint32_t PSOR;                              /**< Port Set Output Register, offset: 0x4 */
  __O  uint32_t PCOR;                              /**< Port Clear Output Register, offset: 0x8 */
  __O  uint32_t PTOR;                              /**< Port Toggle Output Register, offset: 0xC */
  __I  uint32_t PDIR;                              /**< Port Data Input Register, offset: 0x10 */
  __IO uint32_t PDDR;                              /**< Port Data Direction Register, offset: 0x14 */
} GPIO_Type, *GPIO_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- GPIO - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPIO_Register_Accessor_Macros GPIO - Register accessor macros
 * @{
 */


/* GPIO - Register accessors */
#define GPIO_PDOR_REG(base)                      ((base)->PDOR)
#define GPIO_PSOR_REG(base)                      ((base)->PSOR)
#define GPIO_PCOR_REG(base)                      ((base)->PCOR)
#define GPIO_PTOR_REG(base)                      ((base)->PTOR)
#define GPIO_PDIR_REG(base)                      ((base)->PDIR)
#define GPIO_PDDR_REG(base)                      ((base)->PDDR)

/*!
 * @}
 */ /* end of group GPIO_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- GPIO Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPIO_Register_Masks GPIO Register Masks
 * @{
 */

/* PDOR Bit Fields */
#define GPIO_PDOR_PDO_MASK                       0xFFFFFFFFu
#define GPIO_PDOR_PDO_SHIFT                      0
#define GPIO_PDOR_PDO(x)                         (((uint32_t)(((uint32_t)(x))<<GPIO_PDOR_PDO_SHIFT))&GPIO_PDOR_PDO_MASK)
/* PSOR Bit Fields */
#define GPIO_PSOR_PTSO_MASK                      0xFFFFFFFFu
#define GPIO_PSOR_PTSO_SHIFT                     0
#define GPIO_PSOR_PTSO(x)                        (((uint32_t)(((uint32_t)(x))<<GPIO_PSOR_PTSO_SHIFT))&GPIO_PSOR_PTSO_MASK)
/* PCOR Bit Fields */
#define GPIO_PCOR_PTCO_MASK                      0xFFFFFFFFu
#define GPIO_PCOR_PTCO_SHIFT                     0
#define GPIO_PCOR_PTCO(x)                        (((uint32_t)(((uint32_t)(x))<<GPIO_PCOR_PTCO_SHIFT))&GPIO_PCOR_PTCO_MASK)
/* PTOR Bit Fields */
#define GPIO_PTOR_PTTO_MASK                      0xFFFFFFFFu
#define GPIO_PTOR_PTTO_SHIFT                     0
#define GPIO_PTOR_PTTO(x)                        (((uint32_t)(((uint32_t)(x))<<GPIO_PTOR_PTTO_SHIFT))&GPIO_PTOR_PTTO_MASK)
/* PDIR Bit Fields */
#define GPIO_PDIR_PDI_MASK                       0xFFFFFFFFu
#define GPIO_PDIR_PDI_SHIFT                      0
#define GPIO_PDIR_PDI(x)                         (((uint32_t)(((uint32_t)(x))<<GPIO_PDIR_PDI_SHIFT))&GPIO_PDIR_PDI_MASK)
/* PDDR Bit Fields */
#define GPIO_PDDR_PDD_MASK                       0xFFFFFFFFu
#define GPIO_PDDR_PDD_SHIFT                      0
#define GPIO_PDDR_PDD(x)                         (((uint32_t)(((uint32_t)(x))<<GPIO_PDDR_PDD_SHIFT))&GPIO_PDDR_PDD_MASK)

/*!
 * @}
 */ /* end of group GPIO_Register_Masks */


/* GPIO - Peripheral instance base addresses */
/** Peripheral PTA base address */
#define PTA_BASE                                 (0x400FF000u)
/** Peripheral PTA base pointer */
#define PTA                                      ((GPIO_Type *)PTA_BASE)
#define PTA_BASE_PTR                             (PTA)
/** Peripheral PTB base address */
#define PTB_BASE                                 (0x400FF040u)
/** Peripheral PTB base pointer */
#define PTB                                      ((GPIO_Type *)PTB_BASE)
#define PTB_BASE_PTR                             (PTB)
/** Peripheral PTC base address */
#define PTC_BASE                                 (0x400FF080u)
/** Peripheral PTC base pointer */
#define PTC                                      ((GPIO_Type *)PTC_BASE)
#define PTC_BASE_PTR                             (PTC)
/** Peripheral PTD base address */
#define PTD_BASE                                 (0x400FF0C0u)
/** Peripheral PTD base pointer */
#define PTD                                      ((GPIO_Type *)PTD_BASE)
#define PTD_BASE_PTR                             (PTD)
/** Peripheral PTE base address */
#define PTE_BASE                                 (0x400FF100u)
/** Peripheral PTE base pointer */
#define PTE                                      ((GPIO_Type *)PTE_BASE)
#define PTE_BASE_PTR                             (PTE)
/** Array initializer of GPIO peripheral base addresses */
#define GPIO_BASE_ADDRS                          { PTA_BASE, PTB_BASE, PTC_BASE, PTD_BASE, PTE_BASE }
/** Array initializer of GPIO peripheral base pointers */
#define GPIO_BASE_PTRS                           { PTA, PTB, PTC, PTD, PTE }
/** Interrupt vectors for the GPIO peripheral type */
#define GPIO_IRQS                                 { GPIOA_IRQn, GPIOB_IRQn, GPIOC_IRQn, GPIOD_IRQn, GPIOE_IRQn }

/* ----------------------------------------------------------------------------
   -- GPIO - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup GPIO_Register_Accessor_Macros GPIO - Register accessor macros
 * @{
 */


/* GPIO - Register instance definitions */
/* PTA */
#define GPIOA_PDOR                               GPIO_PDOR_REG(PTA)
#define GPIOA_PSOR                               GPIO_PSOR_REG(PTA)
#define GPIOA_PCOR                               GPIO_PCOR_REG(PTA)
#define GPIOA_PTOR                               GPIO_PTOR_REG(PTA)
#define GPIOA_PDIR                               GPIO_PDIR_REG(PTA)
#define GPIOA_PDDR                               GPIO_PDDR_REG(PTA)
/* PTB */
#define GPIOB_PDOR                               GPIO_PDOR_REG(PTB)
#define GPIOB_PSOR                               GPIO_PSOR_REG(PTB)
#define GPIOB_PCOR                               GPIO_PCOR_REG(PTB)
#define GPIOB_PTOR                               GPIO_PTOR_REG(PTB)
#define GPIOB_PDIR                               GPIO_PDIR_REG(PTB)
#define GPIOB_PDDR                               GPIO_PDDR_REG(PTB)
/* PTC */
#define GPIOC_PDOR                               GPIO_PDOR_REG(PTC)
#define GPIOC_PSOR                               GPIO_PSOR_REG(PTC)
#define GPIOC_PCOR                               GPIO_PCOR_REG(PTC)
#define GPIOC_PTOR                               GPIO_PTOR_REG(PTC)
#define GPIOC_PDIR                               GPIO_PDIR_REG(PTC)
#define GPIOC_PDDR                               GPIO_PDDR_REG(PTC)
/* PTD */
#define GPIOD_PDOR                               GPIO_PDOR_REG(PTD)
#define GPIOD_PSOR                               GPIO_PSOR_REG(PTD)
#define GPIOD_PCOR                               GPIO_PCOR_REG(PTD)
#define GPIOD_PTOR                               GPIO_PTOR_REG(PTD)
#define GPIOD_PDIR                               GPIO_PDIR_REG(PTD)
#define GPIOD_PDDR                               GPIO_PDDR_REG(PTD)
/* PTE */
#define GPIOE_PDOR                               GPIO_PDOR_REG(PTE)
#define GPIOE_PSOR                               GPIO_PSOR_REG(PTE)
#define GPIOE_PCOR                               GPIO_PCOR_REG(PTE)
#define GPIOE_PTOR                               GPIO_PTOR_REG(PTE)
#define GPIOE_PDIR                               GPIO_PDIR_REG(PTE)
#define GPIOE_PDDR                               GPIO_PDDR_REG(PTE)

/* GPIO - Register array accessors */

/*!
 * @}
 */ /* end of group GPIO_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group GPIO_Peripheral_Access_Layer */


/* ----------------------------------------------------------------------------
   -- I2C Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup I2C_Peripheral_Access_Layer I2C Peripheral Access Layer
 * @{
 */

/** I2C - Register Layout Typedef */
typedef struct {
  __IO uint8_t A1;                                 /**< I2C Address Register 1, offset: 0x0 */
  __IO uint8_t F;                                  /**< I2C Frequency Divider register, offset: 0x1 */
  __IO uint8_t C1;                                 /**< I2C Control Register 1, offset: 0x2 */
  __IO uint8_t S;                                  /**< I2C Status register, offset: 0x3 */
  __IO uint8_t D;                                  /**< I2C Data I/O register, offset: 0x4 */
  __IO uint8_t C2;                                 /**< I2C Control Register 2, offset: 0x5 */
  __IO uint8_t FLT;                                /**< I2C Programmable Input Glitch Filter Register, offset: 0x6 */
  __IO uint8_t RA;                                 /**< I2C Range Address register, offset: 0x7 */
  __IO uint8_t SMB;                                /**< I2C SMBus Control and Status register, offset: 0x8 */
  __IO uint8_t A2;                                 /**< I2C Address Register 2, offset: 0x9 */
  __IO uint8_t SLTH;                               /**< I2C SCL Low Timeout Register High, offset: 0xA */
  __IO uint8_t SLTL;                               /**< I2C SCL Low Timeout Register Low, offset: 0xB */
} I2C_Type, *I2C_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- I2C - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup I2C_Register_Accessor_Macros I2C - Register accessor macros
 * @{
 */


/* I2C - Register accessors */
#define I2C_A1_REG(base)                         ((base)->A1)
#define I2C_F_REG(base)                          ((base)->F)
#define I2C_C1_REG(base)                         ((base)->C1)
#define I2C_S_REG(base)                          ((base)->S)
#define I2C_D_REG(base)                          ((base)->D)
#define I2C_C2_REG(base)                         ((base)->C2)
#define I2C_FLT_REG(base)                        ((base)->FLT)
#define I2C_RA_REG(base)                         ((base)->RA)
#define I2C_SMB_REG(base)                        ((base)->SMB)
#define I2C_A2_REG(base)                         ((base)->A2)
#define I2C_SLTH_REG(base)                       ((base)->SLTH)
#define I2C_SLTL_REG(base)                       ((base)->SLTL)

/*!
 * @}
 */ /* end of group I2C_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- I2C Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup I2C_Register_Masks I2C Register Masks
 * @{
 */

/* A1 Bit Fields */
#define I2C_A1_AD_MASK                           0xFEu
#define I2C_A1_AD_SHIFT                          1
#define I2C_A1_AD(x)                             (((uint8_t)(((uint8_t)(x))<<I2C_A1_AD_SHIFT))&I2C_A1_AD_MASK)
/* F Bit Fields */
#define I2C_F_ICR_MASK                           0x3Fu
#define I2C_F_ICR_SHIFT                          0
#define I2C_F_ICR(x)                             (((uint8_t)(((uint8_t)(x))<<I2C_F_ICR_SHIFT))&I2C_F_ICR_MASK)
#define I2C_F_MULT_MASK                          0xC0u
#define I2C_F_MULT_SHIFT                         6
#define I2C_F_MULT(x)                            (((uint8_t)(((uint8_t)(x))<<I2C_F_MULT_SHIFT))&I2C_F_MULT_MASK)
/* C1 Bit Fields */
#define I2C_C1_DMAEN_MASK                        0x1u
#define I2C_C1_DMAEN_SHIFT                       0
#define I2C_C1_WUEN_MASK                         0x2u
#define I2C_C1_WUEN_SHIFT                        1
#define I2C_C1_RSTA_MASK                         0x4u
#define I2C_C1_RSTA_SHIFT                        2
#define I2C_C1_TXAK_MASK                         0x8u
#define I2C_C1_TXAK_SHIFT                        3
#define I2C_C1_TX_MASK                           0x10u
#define I2C_C1_TX_SHIFT                          4
#define I2C_C1_MST_MASK                          0x20u
#define I2C_C1_MST_SHIFT                         5
#define I2C_C1_IICIE_MASK                        0x40u
#define I2C_C1_IICIE_SHIFT                       6
#define I2C_C1_IICEN_MASK                        0x80u
#define I2C_C1_IICEN_SHIFT                       7
/* S Bit Fields */
#define I2C_S_RXAK_MASK                          0x1u
#define I2C_S_RXAK_SHIFT                         0
#define I2C_S_IICIF_MASK                         0x2u
#define I2C_S_IICIF_SHIFT                        1
#define I2C_S_SRW_MASK                           0x4u
#define I2C_S_SRW_SHIFT                          2
#define I2C_S_RAM_MASK                           0x8u
#define I2C_S_RAM_SHIFT                          3
#define I2C_S_ARBL_MASK                          0x10u
#define I2C_S_ARBL_SHIFT                         4
#define I2C_S_BUSY_MASK                          0x20u
#define I2C_S_BUSY_SHIFT                         5
#define I2C_S_IAAS_MASK                          0x40u
#define I2C_S_IAAS_SHIFT                         6
#define I2C_S_TCF_MASK                           0x80u
#define I2C_S_TCF_SHIFT                          7
/* D Bit Fields */
#define I2C_D_DATA_MASK                          0xFFu
#define I2C_D_DATA_SHIFT                         0
#define I2C_D_DATA(x)                            (((uint8_t)(((uint8_t)(x))<<I2C_D_DATA_SHIFT))&I2C_D_DATA_MASK)
/* C2 Bit Fields */
#define I2C_C2_AD_MASK                           0x7u
#define I2C_C2_AD_SHIFT                          0
#define I2C_C2_AD(x)                             (((uint8_t)(((uint8_t)(x))<<I2C_C2_AD_SHIFT))&I2C_C2_AD_MASK)
#define I2C_C2_RMEN_MASK                         0x8u
#define I2C_C2_RMEN_SHIFT                        3
#define I2C_C2_SBRC_MASK                         0x10u
#define I2C_C2_SBRC_SHIFT                        4
#define I2C_C2_HDRS_MASK                         0x20u
#define I2C_C2_HDRS_SHIFT                        5
#define I2C_C2_ADEXT_MASK                        0x40u
#define I2C_C2_ADEXT_SHIFT                       6
#define I2C_C2_GCAEN_MASK                        0x80u
#define I2C_C2_GCAEN_SHIFT                       7
/* FLT Bit Fields */
#define I2C_FLT_FLT_MASK                         0xFu
#define I2C_FLT_FLT_SHIFT                        0
#define I2C_FLT_FLT(x)                           (((uint8_t)(((uint8_t)(x))<<I2C_FLT_FLT_SHIFT))&I2C_FLT_FLT_MASK)
#define I2C_FLT_STARTF_MASK                      0x10u
#define I2C_FLT_STARTF_SHIFT                     4
#define I2C_FLT_SSIE_MASK                        0x20u
#define I2C_FLT_SSIE_SHIFT                       5
#define I2C_FLT_STOPF_MASK                       0x40u
#define I2C_FLT_STOPF_SHIFT                      6
#define I2C_FLT_SHEN_MASK                        0x80u
#define I2C_FLT_SHEN_SHIFT                       7
/* RA Bit Fields */
#define I2C_RA_RAD_MASK                          0xFEu
#define I2C_RA_RAD_SHIFT                         1
#define I2C_RA_RAD(x)                            (((uint8_t)(((uint8_t)(x))<<I2C_RA_RAD_SHIFT))&I2C_RA_RAD_MASK)
/* SMB Bit Fields */
#define I2C_SMB_SHTF2IE_MASK                     0x1u
#define I2C_SMB_SHTF2IE_SHIFT                    0
#define I2C_SMB_SHTF2_MASK                       0x2u
#define I2C_SMB_SHTF2_SHIFT                      1
#define I2C_SMB_SHTF1_MASK                       0x4u
#define I2C_SMB_SHTF1_SHIFT                      2
#define I2C_SMB_SLTF_MASK                        0x8u
#define I2C_SMB_SLTF_SHIFT                       3
#define I2C_SMB_TCKSEL_MASK                      0x10u
#define I2C_SMB_TCKSEL_SHIFT                     4
#define I2C_SMB_SIICAEN_MASK                     0x20u
#define I2C_SMB_SIICAEN_SHIFT                    5
#define I2C_SMB_ALERTEN_MASK                     0x40u
#define I2C_SMB_ALERTEN_SHIFT                    6
#define I2C_SMB_FACK_MASK                        0x80u
#define I2C_SMB_FACK_SHIFT                       7
/* A2 Bit Fields */
#define I2C_A2_SAD_MASK                          0xFEu
#define I2C_A2_SAD_SHIFT                         1
#define I2C_A2_SAD(x)                            (((uint8_t)(((uint8_t)(x))<<I2C_A2_SAD_SHIFT))&I2C_A2_SAD_MASK)
/* SLTH Bit Fields */
#define I2C_SLTH_SSLT_MASK                       0xFFu
#define I2C_SLTH_SSLT_SHIFT                      0
#define I2C_SLTH_SSLT(x)                         (((uint8_t)(((uint8_t)(x))<<I2C_SLTH_SSLT_SHIFT))&I2C_SLTH_SSLT_MASK)
/* SLTL Bit Fields */
#define I2C_SLTL_SSLT_MASK                       0xFFu
#define I2C_SLTL_SSLT_SHIFT                      0
#define I2C_SLTL_SSLT(x)                         (((uint8_t)(((uint8_t)(x))<<I2C_SLTL_SSLT_SHIFT))&I2C_SLTL_SSLT_MASK)

/*!
 * @}
 */ /* end of group I2C_Register_Masks */


/* I2C - Peripheral instance base addresses */
/** Peripheral I2C0 base address */
#define I2C0_BASE                                (0x40066000u)
/** Peripheral I2C0 base pointer */
#define I2C0                                     ((I2C_Type *)I2C0_BASE)
#define I2C0_BASE_PTR                            (I2C0)
/** Peripheral I2C1 base address */
#define I2C1_BASE                                (0x40067000u)
/** Peripheral I2C1 base pointer */
#define I2C1                                     ((I2C_Type *)I2C1_BASE)
#define I2C1_BASE_PTR                            (I2C1)
/** Peripheral I2C2 base address */
#define I2C2_BASE                                (0x400E5000u)
/** Peripheral I2C2 base pointer */
#define I2C2                                     ((I2C_Type *)I2C2_BASE)
#define I2C2_BASE_PTR                            (I2C2)
/** Peripheral I2C3 base address */
#define I2C3_BASE                                (0x400E6000u)
/** Peripheral I2C3 base pointer */
#define I2C3                                     ((I2C_Type *)I2C3_BASE)
#define I2C3_BASE_PTR                            (I2C3)
/** Array initializer of I2C peripheral base addresses */
#define I2C_BASE_ADDRS                           { I2C0_BASE, I2C1_BASE, I2C2_BASE, I2C3_BASE }
/** Array initializer of I2C peripheral base pointers */
#define I2C_BASE_PTRS                            { I2C0, I2C1, I2C2, I2C3 }
/** Interrupt vectors for the I2C peripheral type */
#define I2C_IRQS                                 { I2C0_IRQn, I2C1_IRQn, I2C2_IRQn, I2C3_IRQn }

/* ----------------------------------------------------------------------------
   -- I2C - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup I2C_Register_Accessor_Macros I2C - Register accessor macros
 * @{
 */


/* I2C - Register instance definitions */
/* I2C0 */
#define I2C0_A1                                  I2C_A1_REG(I2C0)
#define I2C0_F                                   I2C_F_REG(I2C0)
#define I2C0_C1                                  I2C_C1_REG(I2C0)
#define I2C0_S                                   I2C_S_REG(I2C0)
#define I2C0_D                                   I2C_D_REG(I2C0)
#define I2C0_C2                                  I2C_C2_REG(I2C0)
#define I2C0_FLT                                 I2C_FLT_REG(I2C0)
#define I2C0_RA                                  I2C_RA_REG(I2C0)
#define I2C0_SMB                                 I2C_SMB_REG(I2C0)
#define I2C0_A2                                  I2C_A2_REG(I2C0)
#define I2C0_SLTH                                I2C_SLTH_REG(I2C0)
#define I2C0_SLTL                                I2C_SLTL_REG(I2C0)
/* I2C1 */
#define I2C1_A1                                  I2C_A1_REG(I2C1)
#define I2C1_F                                   I2C_F_REG(I2C1)
#define I2C1_C1                                  I2C_C1_REG(I2C1)
#define I2C1_S                                   I2C_S_REG(I2C1)
#define I2C1_D                                   I2C_D_REG(I2C1)
#define I2C1_C2                                  I2C_C2_REG(I2C1)
#define I2C1_FLT                                 I2C_FLT_REG(I2C1)
#define I2C1_RA                                  I2C_RA_REG(I2C1)
#define I2C1_SMB                                 I2C_SMB_REG(I2C1)
#define I2C1_A2                                  I2C_A2_REG(I2C1)
#define I2C1_SLTH                                I2C_SLTH_REG(I2C1)
#define I2C1_SLTL                                I2C_SLTL_REG(I2C1)
/* I2C2 */
#define I2C2_A1                                  I2C_A1_REG(I2C2)
#define I2C2_F                                   I2C_F_REG(I2C2)
#define I2C2_C1                                  I2C_C1_REG(I2C2)
#define I2C2_S                                   I2C_S_REG(I2C2)
#define I2C2_D                                   I2C_D_REG(I2C2)
#define I2C2_C2                                  I2C_C2_REG(I2C2)
#define I2C2_FLT                                 I2C_FLT_REG(I2C2)
#define I2C2_RA                                  I2C_RA_REG(I2C2)
#define I2C2_SMB                                 I2C_SMB_REG(I2C2)
#define I2C2_A2                                  I2C_A2_REG(I2C2)
#define I2C2_SLTH                                I2C_SLTH_REG(I2C2)
#define I2C2_SLTL                                I2C_SLTL_REG(I2C2)
/* I2C3 */
#define I2C3_A1                                  I2C_A1_REG(I2C3)
#define I2C3_F                                   I2C_F_REG(I2C3)
#define I2C3_C1                                  I2C_C1_REG(I2C3)
#define I2C3_S                                   I2C_S_REG(I2C3)
#define I2C3_D                                   I2C_D_REG(I2C3)
#define I2C3_C2                                  I2C_C2_REG(I2C3)
#define I2C3_FLT                                 I2C_FLT_REG(I2C3)
#define I2C3_RA                                  I2C_RA_REG(I2C3)
#define I2C3_SMB                                 I2C_SMB_REG(I2C3)
#define I2C3_A2                                  I2C_A2_REG(I2C3)
#define I2C3_SLTH                                I2C_SLTH_REG(I2C3)
#define I2C3_SLTL                                I2C_SLTL_REG(I2C3)

/* I2C - Register array accessors */

/*!
 * @}
 */ /* end of group I2C_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group I2C_Peripheral_Access_Layer */


/* ----------------------------------------------------------------------------
   -- LPUART Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup LPUART_Peripheral_Access_Layer LPUART Peripheral Access Layer
 * @{
 */

/** LPUART - Register Layout Typedef */
typedef struct {
  __IO uint32_t BAUD;                              /**< LPUART Baud Rate Register, offset: 0x0 */
  __IO uint32_t STAT;                              /**< LPUART Status Register, offset: 0x4 */
  __IO uint32_t CTRL;                              /**< LPUART Control Register, offset: 0x8 */
  __IO uint32_t DATA;                              /**< LPUART Data Register, offset: 0xC */
  __IO uint32_t MATCH;                             /**< LPUART Match Address Register, offset: 0x10 */
  __IO uint32_t MODIR;                             /**< LPUART Modem IrDA Register, offset: 0x14 */
} LPUART_Type, *LPUART_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- LPUART - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup LPUART_Register_Accessor_Macros LPUART - Register accessor macros
 * @{
 */


/* LPUART - Register accessors */
#define LPUART_BAUD_REG(base)                    ((base)->BAUD)
#define LPUART_STAT_REG(base)                    ((base)->STAT)
#define LPUART_CTRL_REG(base)                    ((base)->CTRL)
#define LPUART_DATA_REG(base)                    ((base)->DATA)
#define LPUART_MATCH_REG(base)                   ((base)->MATCH)
#define LPUART_MODIR_REG(base)                   ((base)->MODIR)

/*!
 * @}
 */ /* end of group LPUART_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- LPUART Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup LPUART_Register_Masks LPUART Register Masks
 * @{
 */

/* BAUD Bit Fields */
#define LPUART_BAUD_SBR_MASK                     0x1FFFu
#define LPUART_BAUD_SBR_SHIFT                    0
#define LPUART_BAUD_SBR(x)                       (((uint32_t)(((uint32_t)(x))<<LPUART_BAUD_SBR_SHIFT))&LPUART_BAUD_SBR_MASK)
#define LPUART_BAUD_SBNS_MASK                    0x2000u
#define LPUART_BAUD_SBNS_SHIFT                   13
#define LPUART_BAUD_RXEDGIE_MASK                 0x4000u
#define LPUART_BAUD_RXEDGIE_SHIFT                14
#define LPUART_BAUD_LBKDIE_MASK                  0x8000u
#define LPUART_BAUD_LBKDIE_SHIFT                 15
#define LPUART_BAUD_RESYNCDIS_MASK               0x10000u
#define LPUART_BAUD_RESYNCDIS_SHIFT              16
#define LPUART_BAUD_BOTHEDGE_MASK                0x20000u
#define LPUART_BAUD_BOTHEDGE_SHIFT               17
#define LPUART_BAUD_MATCFG_MASK                  0xC0000u
#define LPUART_BAUD_MATCFG_SHIFT                 18
#define LPUART_BAUD_MATCFG(x)                    (((uint32_t)(((uint32_t)(x))<<LPUART_BAUD_MATCFG_SHIFT))&LPUART_BAUD_MATCFG_MASK)
#define LPUART_BAUD_RDMAE_MASK                   0x200000u
#define LPUART_BAUD_RDMAE_SHIFT                  21
#define LPUART_BAUD_TDMAE_MASK                   0x800000u
#define LPUART_BAUD_TDMAE_SHIFT                  23
#define LPUART_BAUD_OSR_MASK                     0x1F000000u
#define LPUART_BAUD_OSR_SHIFT                    24
#define LPUART_BAUD_OSR(x)                       (((uint32_t)(((uint32_t)(x))<<LPUART_BAUD_OSR_SHIFT))&LPUART_BAUD_OSR_MASK)
#define LPUART_BAUD_M10_MASK                     0x20000000u
#define LPUART_BAUD_M10_SHIFT                    29
#define LPUART_BAUD_MAEN2_MASK                   0x40000000u
#define LPUART_BAUD_MAEN2_SHIFT                  30
#define LPUART_BAUD_MAEN1_MASK                   0x80000000u
#define LPUART_BAUD_MAEN1_SHIFT                  31
/* STAT Bit Fields */
#define LPUART_STAT_MA2F_MASK                    0x4000u
#define LPUART_STAT_MA2F_SHIFT                   14
#define LPUART_STAT_MA1F_MASK                    0x8000u
#define LPUART_STAT_MA1F_SHIFT                   15
#define LPUART_STAT_PF_MASK                      0x10000u
#define LPUART_STAT_PF_SHIFT                     16
#define LPUART_STAT_FE_MASK                      0x20000u
#define LPUART_STAT_FE_SHIFT                     17
#define LPUART_STAT_NF_MASK                      0x40000u
#define LPUART_STAT_NF_SHIFT                     18
#define LPUART_STAT_OR_MASK                      0x80000u
#define LPUART_STAT_OR_SHIFT                     19
#define LPUART_STAT_IDLE_MASK                    0x100000u
#define LPUART_STAT_IDLE_SHIFT                   20
#define LPUART_STAT_RDRF_MASK                    0x200000u
#define LPUART_STAT_RDRF_SHIFT                   21
#define LPUART_STAT_TC_MASK                      0x400000u
#define LPUART_STAT_TC_SHIFT                     22
#define LPUART_STAT_TDRE_MASK                    0x800000u
#define LPUART_STAT_TDRE_SHIFT                   23
#define LPUART_STAT_RAF_MASK                     0x1000000u
#define LPUART_STAT_RAF_SHIFT                    24
#define LPUART_STAT_LBKDE_MASK                   0x2000000u
#define LPUART_STAT_LBKDE_SHIFT                  25
#define LPUART_STAT_BRK13_MASK                   0x4000000u
#define LPUART_STAT_BRK13_SHIFT                  26
#define LPUART_STAT_RWUID_MASK                   0x8000000u
#define LPUART_STAT_RWUID_SHIFT                  27
#define LPUART_STAT_RXINV_MASK                   0x10000000u
#define LPUART_STAT_RXINV_SHIFT                  28
#define LPUART_STAT_MSBF_MASK                    0x20000000u
#define LPUART_STAT_MSBF_SHIFT                   29
#define LPUART_STAT_RXEDGIF_MASK                 0x40000000u
#define LPUART_STAT_RXEDGIF_SHIFT                30
#define LPUART_STAT_LBKDIF_MASK                  0x80000000u
#define LPUART_STAT_LBKDIF_SHIFT                 31
/* CTRL Bit Fields */
#define LPUART_CTRL_PT_MASK                      0x1u
#define LPUART_CTRL_PT_SHIFT                     0
#define LPUART_CTRL_PE_MASK                      0x2u
#define LPUART_CTRL_PE_SHIFT                     1
#define LPUART_CTRL_ILT_MASK                     0x4u
#define LPUART_CTRL_ILT_SHIFT                    2
#define LPUART_CTRL_WAKE_MASK                    0x8u
#define LPUART_CTRL_WAKE_SHIFT                   3
#define LPUART_CTRL_M_MASK                       0x10u
#define LPUART_CTRL_M_SHIFT                      4
#define LPUART_CTRL_RSRC_MASK                    0x20u
#define LPUART_CTRL_RSRC_SHIFT                   5
#define LPUART_CTRL_DOZEEN_MASK                  0x40u
#define LPUART_CTRL_DOZEEN_SHIFT                 6
#define LPUART_CTRL_LOOPS_MASK                   0x80u
#define LPUART_CTRL_LOOPS_SHIFT                  7
#define LPUART_CTRL_IDLECFG_MASK                 0x700u
#define LPUART_CTRL_IDLECFG_SHIFT                8
#define LPUART_CTRL_IDLECFG(x)                   (((uint32_t)(((uint32_t)(x))<<LPUART_CTRL_IDLECFG_SHIFT))&LPUART_CTRL_IDLECFG_MASK)
#define LPUART_CTRL_MA2IE_MASK                   0x4000u
#define LPUART_CTRL_MA2IE_SHIFT                  14
#define LPUART_CTRL_MA1IE_MASK                   0x8000u
#define LPUART_CTRL_MA1IE_SHIFT                  15
#define LPUART_CTRL_SBK_MASK                     0x10000u
#define LPUART_CTRL_SBK_SHIFT                    16
#define LPUART_CTRL_RWU_MASK                     0x20000u
#define LPUART_CTRL_RWU_SHIFT                    17
#define LPUART_CTRL_RE_MASK                      0x40000u
#define LPUART_CTRL_RE_SHIFT                     18
#define LPUART_CTRL_TE_MASK                      0x80000u
#define LPUART_CTRL_TE_SHIFT                     19
#define LPUART_CTRL_ILIE_MASK                    0x100000u
#define LPUART_CTRL_ILIE_SHIFT                   20
#define LPUART_CTRL_RIE_MASK                     0x200000u
#define LPUART_CTRL_RIE_SHIFT                    21
#define LPUART_CTRL_TCIE_MASK                    0x400000u
#define LPUART_CTRL_TCIE_SHIFT                   22
#define LPUART_CTRL_TIE_MASK                     0x800000u
#define LPUART_CTRL_TIE_SHIFT                    23
#define LPUART_CTRL_PEIE_MASK                    0x1000000u
#define LPUART_CTRL_PEIE_SHIFT                   24
#define LPUART_CTRL_FEIE_MASK                    0x2000000u
#define LPUART_CTRL_FEIE_SHIFT                   25
#define LPUART_CTRL_NEIE_MASK                    0x4000000u
#define LPUART_CTRL_NEIE_SHIFT                   26
#define LPUART_CTRL_ORIE_MASK                    0x8000000u
#define LPUART_CTRL_ORIE_SHIFT                   27
#define LPUART_CTRL_TXINV_MASK                   0x10000000u
#define LPUART_CTRL_TXINV_SHIFT                  28
#define LPUART_CTRL_TXDIR_MASK                   0x20000000u
#define LPUART_CTRL_TXDIR_SHIFT                  29
#define LPUART_CTRL_R9T8_MASK                    0x40000000u
#define LPUART_CTRL_R9T8_SHIFT                   30
#define LPUART_CTRL_R8T9_MASK                    0x80000000u
#define LPUART_CTRL_R8T9_SHIFT                   31
/* DATA Bit Fields */
#define LPUART_DATA_R0T0_MASK                    0x1u
#define LPUART_DATA_R0T0_SHIFT                   0
#define LPUART_DATA_R1T1_MASK                    0x2u
#define LPUART_DATA_R1T1_SHIFT                   1
#define LPUART_DATA_R2T2_MASK                    0x4u
#define LPUART_DATA_R2T2_SHIFT                   2
#define LPUART_DATA_R3T3_MASK                    0x8u
#define LPUART_DATA_R3T3_SHIFT                   3
#define LPUART_DATA_R4T4_MASK                    0x10u
#define LPUART_DATA_R4T4_SHIFT                   4
#define LPUART_DATA_R5T5_MASK                    0x20u
#define LPUART_DATA_R5T5_SHIFT                   5
#define LPUART_DATA_R6T6_MASK                    0x40u
#define LPUART_DATA_R6T6_SHIFT                   6
#define LPUART_DATA_R7T7_MASK                    0x80u
#define LPUART_DATA_R7T7_SHIFT                   7
#define LPUART_DATA_R8T8_MASK                    0x100u
#define LPUART_DATA_R8T8_SHIFT                   8
#define LPUART_DATA_R9T9_MASK                    0x200u
#define LPUART_DATA_R9T9_SHIFT                   9
#define LPUART_DATA_IDLINE_MASK                  0x800u
#define LPUART_DATA_IDLINE_SHIFT                 11
#define LPUART_DATA_RXEMPT_MASK                  0x1000u
#define LPUART_DATA_RXEMPT_SHIFT                 12
#define LPUART_DATA_FRETSC_MASK                  0x2000u
#define LPUART_DATA_FRETSC_SHIFT                 13
#define LPUART_DATA_PARITYE_MASK                 0x4000u
#define LPUART_DATA_PARITYE_SHIFT                14
#define LPUART_DATA_NOISY_MASK                   0x8000u
#define LPUART_DATA_NOISY_SHIFT                  15
/* MATCH Bit Fields */
#define LPUART_MATCH_MA1_MASK                    0x3FFu
#define LPUART_MATCH_MA1_SHIFT                   0
#define LPUART_MATCH_MA1(x)                      (((uint32_t)(((uint32_t)(x))<<LPUART_MATCH_MA1_SHIFT))&LPUART_MATCH_MA1_MASK)
#define LPUART_MATCH_MA2_MASK                    0x3FF0000u
#define LPUART_MATCH_MA2_SHIFT                   16
#define LPUART_MATCH_MA2(x)                      (((uint32_t)(((uint32_t)(x))<<LPUART_MATCH_MA2_SHIFT))&LPUART_MATCH_MA2_MASK)
/* MODIR Bit Fields */
#define LPUART_MODIR_TXCTSE_MASK                 0x1u
#define LPUART_MODIR_TXCTSE_SHIFT                0
#define LPUART_MODIR_TXRTSE_MASK                 0x2u
#define LPUART_MODIR_TXRTSE_SHIFT                1
#define LPUART_MODIR_TXRTSPOL_MASK               0x4u
#define LPUART_MODIR_TXRTSPOL_SHIFT              2
#define LPUART_MODIR_RXRTSE_MASK                 0x8u
#define LPUART_MODIR_RXRTSE_SHIFT                3
#define LPUART_MODIR_TXCTSC_MASK                 0x10u
#define LPUART_MODIR_TXCTSC_SHIFT                4
#define LPUART_MODIR_TXCTSSRC_MASK               0x20u
#define LPUART_MODIR_TXCTSSRC_SHIFT              5
#define LPUART_MODIR_TNP_MASK                    0x30000u
#define LPUART_MODIR_TNP_SHIFT                   16
#define LPUART_MODIR_TNP(x)                      (((uint32_t)(((uint32_t)(x))<<LPUART_MODIR_TNP_SHIFT))&LPUART_MODIR_TNP_MASK)
#define LPUART_MODIR_IREN_MASK                   0x40000u
#define LPUART_MODIR_IREN_SHIFT                  18

/*!
 * @}
 */ /* end of group LPUART_Register_Masks */


/* LPUART - Peripheral instance base addresses */
/** Peripheral LPUART0 base address */
#define LPUART0_BASE                                (0x400C4000u)
/** Peripheral LPUART0 base pointer */
#define LPUART0                                     ((LPUART_Type *)LPUART0_BASE)
#define LPUART0_BASE_PTR                            (LPUART0)
/** Peripheral LPUART1 base address */
#define LPUART1_BASE                                (0x400C5000u)
/** Peripheral LPUART1 base pointer */
#define LPUART1                                     ((LPUART_Type *)LPUART1_BASE)
#define LPUART1_BASE_PTR                            (LPUART1)
/** Peripheral LPUART2 base address */
#define LPUART2_BASE                                (0x400C6000u)
/** Peripheral LPUART2 base pointer */
#define LPUART2                                     ((LPUART_Type *)LPUART2_BASE)
#define LPUART2_BASE_PTR                            (LPUART2)
/** Peripheral LPUART3 base address */
#define LPUART3_BASE                                (0x400C7000u)
/** Peripheral LPUART3 base pointer */
#define LPUART3                                     ((LPUART_Type *)LPUART3_BASE)
#define LPUART3_BASE_PTR                            (LPUART3)
/** Peripheral LPUART4 base address */
#define LPUART4_BASE                                (0x400D6000u)
/** Peripheral LPUART4 base pointer */
#define LPUART4                                     ((LPUART_Type *)LPUART4_BASE)
#define LPUART4_BASE_PTR                            (LPUART4)
/** Array initializer of LPUART peripheral base addresses */
#define LPUART_BASE_ADDRS                           { LPUART0_BASE, LPUART1_BASE, LPUART2_BASE, LPUART3_BASE, LPUART4_BASE }
/** Array initializer of LPUART peripheral base pointers */
#define LPUART_BASE_PTRS                            { LPUART0, LPUART1, LPUART2, LPUART3, LPUART4 }
/** Interrupt vectors for the LPUART peripheral type */
#define LPUART_IRQS                                 { LPUART0_IRQn, LPUART1_IRQn, LPUART2_IRQn, LPUART3_IRQn, LPUART4_IRQn }

/* ----------------------------------------------------------------------------
   -- LPUART - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup LPUART_Register_Accessor_Macros LPUART - Register accessor macros
 * @{
 */


/* LPUART - Register instance definitions */
/* LPUART0 */
#define LPUART0_BAUD                             LPUART_BAUD_REG(LPUART0)
#define LPUART0_STAT                             LPUART_STAT_REG(LPUART0)
#define LPUART0_CTRL                             LPUART_CTRL_REG(LPUART0)
#define LPUART0_DATA                             LPUART_DATA_REG(LPUART0)
#define LPUART0_MATCH                            LPUART_MATCH_REG(LPUART0)
#define LPUART0_MODIR                            LPUART_MODIR_REG(LPUART0)
/* LPUART1 */
#define LPUART1_BAUD                             LPUART_BAUD_REG(LPUART1)
#define LPUART1_STAT                             LPUART_STAT_REG(LPUART1)
#define LPUART1_CTRL                             LPUART_CTRL_REG(LPUART1)
#define LPUART1_DATA                             LPUART_DATA_REG(LPUART1)
#define LPUART1_MATCH                            LPUART_MATCH_REG(LPUART1)
#define LPUART1_MODIR                            LPUART_MODIR_REG(LPUART1)
/* LPUART2 */
#define LPUART2_BAUD                             LPUART_BAUD_REG(LPUART2)
#define LPUART2_STAT                             LPUART_STAT_REG(LPUART2)
#define LPUART2_CTRL                             LPUART_CTRL_REG(LPUART2)
#define LPUART2_DATA                             LPUART_DATA_REG(LPUART2)
#define LPUART2_MATCH                            LPUART_MATCH_REG(LPUART2)
#define LPUART2_MODIR                            LPUART_MODIR_REG(LPUART2)
/* LPUART3 */
#define LPUART3_BAUD                             LPUART_BAUD_REG(LPUART3)
#define LPUART3_STAT                             LPUART_STAT_REG(LPUART3)
#define LPUART3_CTRL                             LPUART_CTRL_REG(LPUART3)
#define LPUART3_DATA                             LPUART_DATA_REG(LPUART3)
#define LPUART3_MATCH                            LPUART_MATCH_REG(LPUART3)
#define LPUART3_MODIR                            LPUART_MODIR_REG(LPUART3)
/* LPUART4 */
#define LPUART4_BAUD                             LPUART_BAUD_REG(LPUART4)
#define LPUART4_STAT                             LPUART_STAT_REG(LPUART4)
#define LPUART4_CTRL                             LPUART_CTRL_REG(LPUART4)
#define LPUART4_DATA                             LPUART_DATA_REG(LPUART4)
#define LPUART4_MATCH                            LPUART_MATCH_REG(LPUART4)
#define LPUART4_MODIR                            LPUART_MODIR_REG(LPUART4)

/* LPUART - Register array accessors */

/*!
 * @}
 */ /* end of group LPUART_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group LPUART_Peripheral_Access_Layer */


/* ----------------------------------------------------------------------------
   -- LTC_K80 Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup LTC_K80_Peripheral_Access_Layer LTC_K80 Peripheral Access Layer
 * @{
 */

/** LTC_K80 - Register Layout Typedef */
typedef struct {
  __IO uint32_t LTCMR;                             /**< LTC Mode Register (non-public-key use), offset: 0x0 */
  __IO uint32_t LTCMR_PK;                          /**< LTC Mode Register (PublicKey), offset: 0x0 */
       uint32_t RESERVED_0;
  __IO uint32_t LTCKSR;                            /**< LTC Key Size Register, offset: 0x8 */
       uint32_t RESERVED_1;
  __IO uint32_t LTCDSR;                            /**< LTC Data Size Register, offset: 0x10 */
       uint32_t RESERVED_2;
  __IO uint32_t LTCICVSR;                          /**< LTC ICV Size Register, offset: 0x18 */
       uint32_t RESERVED_3[5];
  __IO uint32_t LTCCOM;                            /**< LTC Command Register, offset: 0x30 */
  __IO uint32_t LTCCTL;                            /**< LTC Control Register, offset: 0x34 */
       uint32_t RESERVED_4[2];
  __IO uint32_t LTCCWR;                            /**< LTC Clear Written Register, offset: 0x40 */
       uint32_t RESERVED_5;
  __IO uint32_t LTCSTA;                            /**< LTC Status Register, offset: 0x48 */
  __IO uint32_t LTCESTA;                           /**< LTC Error Status Register, offset: 0x4C */
       uint32_t RESERVED_6[2];
  __IO uint32_t LTCAADSZR;                         /**< LTC AAD Size Register, offset: 0x58 */
       uint32_t RESERVED_7;
  __IO uint32_t LTCIVSZR;                          /**< LTC IV Size Register, offset: 0x60 */
       uint32_t RESERVED_8;
  __O  uint32_t LTCDPAMSR;                         /**< LTC DPA Mask Seed Register, offset: 0x68 */
       uint32_t RESERVED_9[5];
  __IO uint32_t LPKASZR;                           /**< LTC PKHA A Size Register, offset: 0x80 */
       uint32_t RESERVED_10;
  __IO uint32_t LPKBSZR;                           /**< LTC PKHA B Size Register, offset: 0x88 */
       uint32_t RESERVED_11;
  __IO uint32_t LPKNSZR;                           /**< LTC PKHA N Size Register, offset: 0x90 */
       uint32_t RESERVED_12;
  __IO uint32_t LPKESZR;                           /**< LTC PKHA E Size Register, offset: 0x98 */
       uint32_t RESERVED_13[25];
  __IO uint32_t LTCCTXR_0;                         /**< LTC Context Register, offset: 0x100 */
  __IO uint32_t LTCCTXR_1;                         /**< LTC Context Register, offset: 0x104 */
  __IO uint32_t LTCCTXR_2;                         /**< LTC Context Register, offset: 0x108 */
  __IO uint32_t LTCCTXR_3;                         /**< LTC Context Register, offset: 0x10C */
  __IO uint32_t LTCCTXR_4;                         /**< LTC Context Register, offset: 0x110 */
  __IO uint32_t LTCCTXR_5;                         /**< LTC Context Register, offset: 0x114 */
  __IO uint32_t LTCCTXR_6;                         /**< LTC Context Register, offset: 0x118 */
  __IO uint32_t LTCCTXR_7;                         /**< LTC Context Register, offset: 0x11C */
  __IO uint32_t LTCCTXR_8;                         /**< LTC Context Register, offset: 0x120 */
  __IO uint32_t LTCCTXR_9;                         /**< LTC Context Register, offset: 0x124 */
  __IO uint32_t LTCCTXR_10;                        /**< LTC Context Register, offset: 0x128 */
  __IO uint32_t LTCCTXR_11;                        /**< LTC Context Register, offset: 0x12C */
  __IO uint32_t LTCCTXR_12;                        /**< LTC Context Register, offset: 0x130 */
  __IO uint32_t LTCCTXR_13;                        /**< LTC Context Register, offset: 0x134 */
  __IO uint32_t LTCCTXR_14;                        /**< LTC Context Register, offset: 0x138 */
  __IO uint32_t LTCCTXR_15;                        /**< LTC Context Register, offset: 0x13C */
       uint32_t RESERVED_14[48];
  __IO uint32_t LTCKEYR_0;                         /**< LTC Key Registers, offset: 0x200 */
  __IO uint32_t LTCKEYR_1;                         /**< LTC Key Registers, offset: 0x204 */
  __IO uint32_t LTCKEYR_2;                         /**< LTC Key Registers, offset: 0x208 */
  __IO uint32_t LTCKEYR_3;                         /**< LTC Key Registers, offset: 0x20C */
  __IO uint32_t LTCKEYR_4;                         /**< LTC Key Registers, offset: 0x210 */
  __IO uint32_t LTCKEYR_5;                         /**< LTC Key Registers, offset: 0x214 */
  __IO uint32_t LTCKEYR_6;                         /**< LTC Key Registers, offset: 0x218 */
  __IO uint32_t LTCKEYR_7;                         /**< LTC Key Registers, offset: 0x21C */
       uint32_t RESERVED_15[180];
  __I  uint32_t LTCVID1;                           /**< LTC Version ID Register, offset: 0x4F0 */
       uint32_t RESERVED_16;
  __IO uint32_t CHAVID;                            /**< CHA Version ID Register, offset: 0x4F8 */
       uint32_t RESERVED_17[177];
  __IO uint32_t LTCFIFOSTA;                        /**< LTC FIFO Status Register, offset: 0x7C0 */
       uint32_t RESERVED_18[7];
  __O  uint32_t LTCIFIFO;                          /**< LTC Input Data FIFO, offset: 0x7E0 */
       uint32_t RESERVED_19[3];
  __I  uint32_t LTCOFIFO;                          /**< LTC Output Data FIFO, offset: 0x7F0 */
       uint32_t RESERVED_20[3];
  __IO uint32_t LPKA0_0;                           /**< LTC PKHA A0 Register, offset: 0x800 */
  __IO uint32_t LPKA0_1;                           /**< LTC PKHA A0 Register, offset: 0x804 */
  __IO uint32_t LPKA0_2;                           /**< LTC PKHA A0 Register, offset: 0x808 */
  __IO uint32_t LPKA0_3;                           /**< LTC PKHA A0 Register, offset: 0x80C */
  __IO uint32_t LPKA0_4;                           /**< LTC PKHA A0 Register, offset: 0x810 */
  __IO uint32_t LPKA0_5;                           /**< LTC PKHA A0 Register, offset: 0x814 */
  __IO uint32_t LPKA0_6;                           /**< LTC PKHA A0 Register, offset: 0x818 */
  __IO uint32_t LPKA0_7;                           /**< LTC PKHA A0 Register, offset: 0x81C */
  __IO uint32_t LPKA0_8;                           /**< LTC PKHA A0 Register, offset: 0x820 */
  __IO uint32_t LPKA0_9;                           /**< LTC PKHA A0 Register, offset: 0x824 */
  __IO uint32_t LPKA0_10;                          /**< LTC PKHA A0 Register, offset: 0x828 */
  __IO uint32_t LPKA0_11;                          /**< LTC PKHA A0 Register, offset: 0x82C */
  __IO uint32_t LPKA0_12;                          /**< LTC PKHA A0 Register, offset: 0x830 */
  __IO uint32_t LPKA0_13;                          /**< LTC PKHA A0 Register, offset: 0x834 */
  __IO uint32_t LPKA0_14;                          /**< LTC PKHA A0 Register, offset: 0x838 */
  __IO uint32_t LPKA0_15;                          /**< LTC PKHA A0 Register, offset: 0x83C */
  __IO uint32_t LPKA1_0;                           /**< LTC PKHA A1 Register, offset: 0x840 */
  __IO uint32_t LPKA1_1;                           /**< LTC PKHA A1 Register, offset: 0x844 */
  __IO uint32_t LPKA1_2;                           /**< LTC PKHA A1 Register, offset: 0x848 */
  __IO uint32_t LPKA1_3;                           /**< LTC PKHA A1 Register, offset: 0x84C */
  __IO uint32_t LPKA1_4;                           /**< LTC PKHA A1 Register, offset: 0x850 */
  __IO uint32_t LPKA1_5;                           /**< LTC PKHA A1 Register, offset: 0x854 */
  __IO uint32_t LPKA1_6;                           /**< LTC PKHA A1 Register, offset: 0x858 */
  __IO uint32_t LPKA1_7;                           /**< LTC PKHA A1 Register, offset: 0x85C */
  __IO uint32_t LPKA1_8;                           /**< LTC PKHA A1 Register, offset: 0x860 */
  __IO uint32_t LPKA1_9;                           /**< LTC PKHA A1 Register, offset: 0x864 */
  __IO uint32_t LPKA1_10;                          /**< LTC PKHA A1 Register, offset: 0x868 */
  __IO uint32_t LPKA1_11;                          /**< LTC PKHA A1 Register, offset: 0x86C */
  __IO uint32_t LPKA1_12;                          /**< LTC PKHA A1 Register, offset: 0x870 */
  __IO uint32_t LPKA1_13;                          /**< LTC PKHA A1 Register, offset: 0x874 */
  __IO uint32_t LPKA1_14;                          /**< LTC PKHA A1 Register, offset: 0x878 */
  __IO uint32_t LPKA1_15;                          /**< LTC PKHA A1 Register, offset: 0x87C */
  __IO uint32_t LPKA2_0;                           /**< LTC PKHA A2 Register, offset: 0x880 */
  __IO uint32_t LPKA2_1;                           /**< LTC PKHA A2 Register, offset: 0x884 */
  __IO uint32_t LPKA2_2;                           /**< LTC PKHA A2 Register, offset: 0x888 */
  __IO uint32_t LPKA2_3;                           /**< LTC PKHA A2 Register, offset: 0x88C */
  __IO uint32_t LPKA2_4;                           /**< LTC PKHA A2 Register, offset: 0x890 */
  __IO uint32_t LPKA2_5;                           /**< LTC PKHA A2 Register, offset: 0x894 */
  __IO uint32_t LPKA2_6;                           /**< LTC PKHA A2 Register, offset: 0x898 */
  __IO uint32_t LPKA2_7;                           /**< LTC PKHA A2 Register, offset: 0x89C */
  __IO uint32_t LPKA2_8;                           /**< LTC PKHA A2 Register, offset: 0x8A0 */
  __IO uint32_t LPKA2_9;                           /**< LTC PKHA A2 Register, offset: 0x8A4 */
  __IO uint32_t LPKA2_10;                          /**< LTC PKHA A2 Register, offset: 0x8A8 */
  __IO uint32_t LPKA2_11;                          /**< LTC PKHA A2 Register, offset: 0x8AC */
  __IO uint32_t LPKA2_12;                          /**< LTC PKHA A2 Register, offset: 0x8B0 */
  __IO uint32_t LPKA2_13;                          /**< LTC PKHA A2 Register, offset: 0x8B4 */
  __IO uint32_t LPKA2_14;                          /**< LTC PKHA A2 Register, offset: 0x8B8 */
  __IO uint32_t LPKA2_15;                          /**< LTC PKHA A2 Register, offset: 0x8BC */
  __IO uint32_t LPKA3_0;                           /**< LTC PKHA A3 Register, offset: 0x8C0 */
  __IO uint32_t LPKA3_1;                           /**< LTC PKHA A3 Register, offset: 0x8C4 */
  __IO uint32_t LPKA3_2;                           /**< LTC PKHA A3 Register, offset: 0x8C8 */
  __IO uint32_t LPKA3_3;                           /**< LTC PKHA A3 Register, offset: 0x8CC */
  __IO uint32_t LPKA3_4;                           /**< LTC PKHA A3 Register, offset: 0x8D0 */
  __IO uint32_t LPKA3_5;                           /**< LTC PKHA A3 Register, offset: 0x8D4 */
  __IO uint32_t LPKA3_6;                           /**< LTC PKHA A3 Register, offset: 0x8D8 */
  __IO uint32_t LPKA3_7;                           /**< LTC PKHA A3 Register, offset: 0x8DC */
  __IO uint32_t LPKA3_8;                           /**< LTC PKHA A3 Register, offset: 0x8E0 */
  __IO uint32_t LPKA3_9;                           /**< LTC PKHA A3 Register, offset: 0x8E4 */
  __IO uint32_t LPKA3_10;                          /**< LTC PKHA A3 Register, offset: 0x8E8 */
  __IO uint32_t LPKA3_11;                          /**< LTC PKHA A3 Register, offset: 0x8EC */
  __IO uint32_t LPKA3_12;                          /**< LTC PKHA A3 Register, offset: 0x8F0 */
  __IO uint32_t LPKA3_13;                          /**< LTC PKHA A3 Register, offset: 0x8F4 */
  __IO uint32_t LPKA3_14;                          /**< LTC PKHA A3 Register, offset: 0x8F8 */
  __IO uint32_t LPKA3_15;                          /**< LTC PKHA A3 Register, offset: 0x8FC */
       uint32_t RESERVED_21[64];
  __IO uint32_t LPKB0_0;                           /**< LTC PKHA B0 Register, offset: 0xA00 */
  __IO uint32_t LPKB0_1;                           /**< LTC PKHA B0 Register, offset: 0xA04 */
  __IO uint32_t LPKB0_2;                           /**< LTC PKHA B0 Register, offset: 0xA08 */
  __IO uint32_t LPKB0_3;                           /**< LTC PKHA B0 Register, offset: 0xA0C */
  __IO uint32_t LPKB0_4;                           /**< LTC PKHA B0 Register, offset: 0xA10 */
  __IO uint32_t LPKB0_5;                           /**< LTC PKHA B0 Register, offset: 0xA14 */
  __IO uint32_t LPKB0_6;                           /**< LTC PKHA B0 Register, offset: 0xA18 */
  __IO uint32_t LPKB0_7;                           /**< LTC PKHA B0 Register, offset: 0xA1C */
  __IO uint32_t LPKB0_8;                           /**< LTC PKHA B0 Register, offset: 0xA20 */
  __IO uint32_t LPKB0_9;                           /**< LTC PKHA B0 Register, offset: 0xA24 */
  __IO uint32_t LPKB0_10;                          /**< LTC PKHA B0 Register, offset: 0xA28 */
  __IO uint32_t LPKB0_11;                          /**< LTC PKHA B0 Register, offset: 0xA2C */
  __IO uint32_t LPKB0_12;                          /**< LTC PKHA B0 Register, offset: 0xA30 */
  __IO uint32_t LPKB0_13;                          /**< LTC PKHA B0 Register, offset: 0xA34 */
  __IO uint32_t LPKB0_14;                          /**< LTC PKHA B0 Register, offset: 0xA38 */
  __IO uint32_t LPKB0_15;                          /**< LTC PKHA B0 Register, offset: 0xA3C */
  __IO uint32_t LPKB1_0;                           /**< LTC PKHA B1 Register, offset: 0xA40 */
  __IO uint32_t LPKB1_1;                           /**< LTC PKHA B1 Register, offset: 0xA44 */
  __IO uint32_t LPKB1_2;                           /**< LTC PKHA B1 Register, offset: 0xA48 */
  __IO uint32_t LPKB1_3;                           /**< LTC PKHA B1 Register, offset: 0xA4C */
  __IO uint32_t LPKB1_4;                           /**< LTC PKHA B1 Register, offset: 0xA50 */
  __IO uint32_t LPKB1_5;                           /**< LTC PKHA B1 Register, offset: 0xA54 */
  __IO uint32_t LPKB1_6;                           /**< LTC PKHA B1 Register, offset: 0xA58 */
  __IO uint32_t LPKB1_7;                           /**< LTC PKHA B1 Register, offset: 0xA5C */
  __IO uint32_t LPKB1_8;                           /**< LTC PKHA B1 Register, offset: 0xA60 */
  __IO uint32_t LPKB1_9;                           /**< LTC PKHA B1 Register, offset: 0xA64 */
  __IO uint32_t LPKB1_10;                          /**< LTC PKHA B1 Register, offset: 0xA68 */
  __IO uint32_t LPKB1_11;                          /**< LTC PKHA B1 Register, offset: 0xA6C */
  __IO uint32_t LPKB1_12;                          /**< LTC PKHA B1 Register, offset: 0xA70 */
  __IO uint32_t LPKB1_13;                          /**< LTC PKHA B1 Register, offset: 0xA74 */
  __IO uint32_t LPKB1_14;                          /**< LTC PKHA B1 Register, offset: 0xA78 */
  __IO uint32_t LPKB1_15;                          /**< LTC PKHA B1 Register, offset: 0xA7C */
  __IO uint32_t LPKB2_0;                           /**< LTC PKHA B2 Register, offset: 0xA80 */
  __IO uint32_t LPKB2_1;                           /**< LTC PKHA B2 Register, offset: 0xA84 */
  __IO uint32_t LPKB2_2;                           /**< LTC PKHA B2 Register, offset: 0xA88 */
  __IO uint32_t LPKB2_3;                           /**< LTC PKHA B2 Register, offset: 0xA8C */
  __IO uint32_t LPKB2_4;                           /**< LTC PKHA B2 Register, offset: 0xA90 */
  __IO uint32_t LPKB2_5;                           /**< LTC PKHA B2 Register, offset: 0xA94 */
  __IO uint32_t LPKB2_6;                           /**< LTC PKHA B2 Register, offset: 0xA98 */
  __IO uint32_t LPKB2_7;                           /**< LTC PKHA B2 Register, offset: 0xA9C */
  __IO uint32_t LPKB2_8;                           /**< LTC PKHA B2 Register, offset: 0xAA0 */
  __IO uint32_t LPKB2_9;                           /**< LTC PKHA B2 Register, offset: 0xAA4 */
  __IO uint32_t LPKB2_10;                          /**< LTC PKHA B2 Register, offset: 0xAA8 */
  __IO uint32_t LPKB2_11;                          /**< LTC PKHA B2 Register, offset: 0xAAC */
  __IO uint32_t LPKB2_12;                          /**< LTC PKHA B2 Register, offset: 0xAB0 */
  __IO uint32_t LPKB2_13;                          /**< LTC PKHA B2 Register, offset: 0xAB4 */
  __IO uint32_t LPKB2_14;                          /**< LTC PKHA B2 Register, offset: 0xAB8 */
  __IO uint32_t LPKB2_15;                          /**< LTC PKHA B2 Register, offset: 0xABC */
  __IO uint32_t LPKB3_0;                           /**< LTC PKHA B3 Register, offset: 0xAC0 */
  __IO uint32_t LPKB3_1;                           /**< LTC PKHA B3 Register, offset: 0xAC4 */
  __IO uint32_t LPKB3_2;                           /**< LTC PKHA B3 Register, offset: 0xAC8 */
  __IO uint32_t LPKB3_3;                           /**< LTC PKHA B3 Register, offset: 0xACC */
  __IO uint32_t LPKB3_4;                           /**< LTC PKHA B3 Register, offset: 0xAD0 */
  __IO uint32_t LPKB3_5;                           /**< LTC PKHA B3 Register, offset: 0xAD4 */
  __IO uint32_t LPKB3_6;                           /**< LTC PKHA B3 Register, offset: 0xAD8 */
  __IO uint32_t LPKB3_7;                           /**< LTC PKHA B3 Register, offset: 0xADC */
  __IO uint32_t LPKB3_8;                           /**< LTC PKHA B3 Register, offset: 0xAE0 */
  __IO uint32_t LPKB3_9;                           /**< LTC PKHA B3 Register, offset: 0xAE4 */
  __IO uint32_t LPKB3_10;                          /**< LTC PKHA B3 Register, offset: 0xAE8 */
  __IO uint32_t LPKB3_11;                          /**< LTC PKHA B3 Register, offset: 0xAEC */
  __IO uint32_t LPKB3_12;                          /**< LTC PKHA B3 Register, offset: 0xAF0 */
  __IO uint32_t LPKB3_13;                          /**< LTC PKHA B3 Register, offset: 0xAF4 */
  __IO uint32_t LPKB3_14;                          /**< LTC PKHA B3 Register, offset: 0xAF8 */
  __IO uint32_t LPKB3_15;                          /**< LTC PKHA B3 Register, offset: 0xAFC */
       uint32_t RESERVED_22[64];
  __IO uint32_t LPKN0_0;                           /**< LTC PKHA N0 Register, offset: 0xC00 */
  __IO uint32_t LPKN0_1;                           /**< LTC PKHA N0 Register, offset: 0xC04 */
  __IO uint32_t LPKN0_2;                           /**< LTC PKHA N0 Register, offset: 0xC08 */
  __IO uint32_t LPKN0_3;                           /**< LTC PKHA N0 Register, offset: 0xC0C */
  __IO uint32_t LPKN0_4;                           /**< LTC PKHA N0 Register, offset: 0xC10 */
  __IO uint32_t LPKN0_5;                           /**< LTC PKHA N0 Register, offset: 0xC14 */
  __IO uint32_t LPKN0_6;                           /**< LTC PKHA N0 Register, offset: 0xC18 */
  __IO uint32_t LPKN0_7;                           /**< LTC PKHA N0 Register, offset: 0xC1C */
  __IO uint32_t LPKN0_8;                           /**< LTC PKHA N0 Register, offset: 0xC20 */
  __IO uint32_t LPKN0_9;                           /**< LTC PKHA N0 Register, offset: 0xC24 */
  __IO uint32_t LPKN0_10;                          /**< LTC PKHA N0 Register, offset: 0xC28 */
  __IO uint32_t LPKN0_11;                          /**< LTC PKHA N0 Register, offset: 0xC2C */
  __IO uint32_t LPKN0_12;                          /**< LTC PKHA N0 Register, offset: 0xC30 */
  __IO uint32_t LPKN0_13;                          /**< LTC PKHA N0 Register, offset: 0xC34 */
  __IO uint32_t LPKN0_14;                          /**< LTC PKHA N0 Register, offset: 0xC38 */
  __IO uint32_t LPKN0_15;                          /**< LTC PKHA N0 Register, offset: 0xC3C */
  __IO uint32_t LPKN1_0;                           /**< LTC PKHA N1 Register, offset: 0xC40 */
  __IO uint32_t LPKN1_1;                           /**< LTC PKHA N1 Register, offset: 0xC44 */
  __IO uint32_t LPKN1_2;                           /**< LTC PKHA N1 Register, offset: 0xC48 */
  __IO uint32_t LPKN1_3;                           /**< LTC PKHA N1 Register, offset: 0xC4C */
  __IO uint32_t LPKN1_4;                           /**< LTC PKHA N1 Register, offset: 0xC50 */
  __IO uint32_t LPKN1_5;                           /**< LTC PKHA N1 Register, offset: 0xC54 */
  __IO uint32_t LPKN1_6;                           /**< LTC PKHA N1 Register, offset: 0xC58 */
  __IO uint32_t LPKN1_7;                           /**< LTC PKHA N1 Register, offset: 0xC5C */
  __IO uint32_t LPKN1_8;                           /**< LTC PKHA N1 Register, offset: 0xC60 */
  __IO uint32_t LPKN1_9;                           /**< LTC PKHA N1 Register, offset: 0xC64 */
  __IO uint32_t LPKN1_10;                          /**< LTC PKHA N1 Register, offset: 0xC68 */
  __IO uint32_t LPKN1_11;                          /**< LTC PKHA N1 Register, offset: 0xC6C */
  __IO uint32_t LPKN1_12;                          /**< LTC PKHA N1 Register, offset: 0xC70 */
  __IO uint32_t LPKN1_13;                          /**< LTC PKHA N1 Register, offset: 0xC74 */
  __IO uint32_t LPKN1_14;                          /**< LTC PKHA N1 Register, offset: 0xC78 */
  __IO uint32_t LPKN1_15;                          /**< LTC PKHA N1 Register, offset: 0xC7C */
  __IO uint32_t LPKN2_0;                           /**< LTC PKHA N2 Register, offset: 0xC80 */
  __IO uint32_t LPKN2_1;                           /**< LTC PKHA N2 Register, offset: 0xC84 */
  __IO uint32_t LPKN2_2;                           /**< LTC PKHA N2 Register, offset: 0xC88 */
  __IO uint32_t LPKN2_3;                           /**< LTC PKHA N2 Register, offset: 0xC8C */
  __IO uint32_t LPKN2_4;                           /**< LTC PKHA N2 Register, offset: 0xC90 */
  __IO uint32_t LPKN2_5;                           /**< LTC PKHA N2 Register, offset: 0xC94 */
  __IO uint32_t LPKN2_6;                           /**< LTC PKHA N2 Register, offset: 0xC98 */
  __IO uint32_t LPKN2_7;                           /**< LTC PKHA N2 Register, offset: 0xC9C */
  __IO uint32_t LPKN2_8;                           /**< LTC PKHA N2 Register, offset: 0xCA0 */
  __IO uint32_t LPKN2_9;                           /**< LTC PKHA N2 Register, offset: 0xCA4 */
  __IO uint32_t LPKN2_10;                          /**< LTC PKHA N2 Register, offset: 0xCA8 */
  __IO uint32_t LPKN2_11;                          /**< LTC PKHA N2 Register, offset: 0xCAC */
  __IO uint32_t LPKN2_12;                          /**< LTC PKHA N2 Register, offset: 0xCB0 */
  __IO uint32_t LPKN2_13;                          /**< LTC PKHA N2 Register, offset: 0xCB4 */
  __IO uint32_t LPKN2_14;                          /**< LTC PKHA N2 Register, offset: 0xCB8 */
  __IO uint32_t LPKN2_15;                          /**< LTC PKHA N2 Register, offset: 0xCBC */
  __IO uint32_t LPKN3_0;                           /**< LTC PKHA N3 Register, offset: 0xCC0 */
  __IO uint32_t LPKN3_1;                           /**< LTC PKHA N3 Register, offset: 0xCC4 */
  __IO uint32_t LPKN3_2;                           /**< LTC PKHA N3 Register, offset: 0xCC8 */
  __IO uint32_t LPKN3_3;                           /**< LTC PKHA N3 Register, offset: 0xCCC */
  __IO uint32_t LPKN3_4;                           /**< LTC PKHA N3 Register, offset: 0xCD0 */
  __IO uint32_t LPKN3_5;                           /**< LTC PKHA N3 Register, offset: 0xCD4 */
  __IO uint32_t LPKN3_6;                           /**< LTC PKHA N3 Register, offset: 0xCD8 */
  __IO uint32_t LPKN3_7;                           /**< LTC PKHA N3 Register, offset: 0xCDC */
  __IO uint32_t LPKN3_8;                           /**< LTC PKHA N3 Register, offset: 0xCE0 */
  __IO uint32_t LPKN3_9;                           /**< LTC PKHA N3 Register, offset: 0xCE4 */
  __IO uint32_t LPKN3_10;                          /**< LTC PKHA N3 Register, offset: 0xCE8 */
  __IO uint32_t LPKN3_11;                          /**< LTC PKHA N3 Register, offset: 0xCEC */
  __IO uint32_t LPKN3_12;                          /**< LTC PKHA N3 Register, offset: 0xCF0 */
  __IO uint32_t LPKN3_13;                          /**< LTC PKHA N3 Register, offset: 0xCF4 */
  __IO uint32_t LPKN3_14;                          /**< LTC PKHA N3 Register, offset: 0xCF8 */
  __IO uint32_t LPKN3_15;                          /**< LTC PKHA N3 Register, offset: 0xCFC */
       uint32_t RESERVED_23[64];
  __O  uint32_t LPKE_0;                            /**< LTC PKHA E Register, offset: 0xE00 */
  __O  uint32_t LPKE_1;                            /**< LTC PKHA E Register, offset: 0xE04 */
  __O  uint32_t LPKE_2;                            /**< LTC PKHA E Register, offset: 0xE08 */
  __O  uint32_t LPKE_3;                            /**< LTC PKHA E Register, offset: 0xE0C */
  __O  uint32_t LPKE_4;                            /**< LTC PKHA E Register, offset: 0xE10 */
  __O  uint32_t LPKE_5;                            /**< LTC PKHA E Register, offset: 0xE14 */
  __O  uint32_t LPKE_6;                            /**< LTC PKHA E Register, offset: 0xE18 */
  __O  uint32_t LPKE_7;                            /**< LTC PKHA E Register, offset: 0xE1C */
  __O  uint32_t LPKE_8;                            /**< LTC PKHA E Register, offset: 0xE20 */
  __O  uint32_t LPKE_9;                            /**< LTC PKHA E Register, offset: 0xE24 */
  __O  uint32_t LPKE_10;                           /**< LTC PKHA E Register, offset: 0xE28 */
  __O  uint32_t LPKE_11;                           /**< LTC PKHA E Register, offset: 0xE2C */
  __O  uint32_t LPKE_12;                           /**< LTC PKHA E Register, offset: 0xE30 */
  __O  uint32_t LPKE_13;                           /**< LTC PKHA E Register, offset: 0xE34 */
  __O  uint32_t LPKE_14;                           /**< LTC PKHA E Register, offset: 0xE38 */
  __O  uint32_t LPKE_15;                           /**< LTC PKHA E Register, offset: 0xE3C */
  __O  uint32_t LPKE_16;                           /**< LTC PKHA E Register, offset: 0xE40 */
  __O  uint32_t LPKE_17;                           /**< LTC PKHA E Register, offset: 0xE44 */
  __O  uint32_t LPKE_18;                           /**< LTC PKHA E Register, offset: 0xE48 */
  __O  uint32_t LPKE_19;                           /**< LTC PKHA E Register, offset: 0xE4C */
  __O  uint32_t LPKE_20;                           /**< LTC PKHA E Register, offset: 0xE50 */
  __O  uint32_t LPKE_21;                           /**< LTC PKHA E Register, offset: 0xE54 */
  __O  uint32_t LPKE_22;                           /**< LTC PKHA E Register, offset: 0xE58 */
  __O  uint32_t LPKE_23;                           /**< LTC PKHA E Register, offset: 0xE5C */
  __O  uint32_t LPKE_24;                           /**< LTC PKHA E Register, offset: 0xE60 */
  __O  uint32_t LPKE_25;                           /**< LTC PKHA E Register, offset: 0xE64 */
  __O  uint32_t LPKE_26;                           /**< LTC PKHA E Register, offset: 0xE68 */
  __O  uint32_t LPKE_27;                           /**< LTC PKHA E Register, offset: 0xE6C */
  __O  uint32_t LPKE_28;                           /**< LTC PKHA E Register, offset: 0xE70 */
  __O  uint32_t LPKE_29;                           /**< LTC PKHA E Register, offset: 0xE74 */
  __O  uint32_t LPKE_30;                           /**< LTC PKHA E Register, offset: 0xE78 */
  __O  uint32_t LPKE_31;                           /**< LTC PKHA E Register, offset: 0xE7C */
  __O  uint32_t LPKE_32;                           /**< LTC PKHA E Register, offset: 0xE80 */
  __O  uint32_t LPKE_33;                           /**< LTC PKHA E Register, offset: 0xE84 */
  __O  uint32_t LPKE_34;                           /**< LTC PKHA E Register, offset: 0xE88 */
  __O  uint32_t LPKE_35;                           /**< LTC PKHA E Register, offset: 0xE8C */
  __O  uint32_t LPKE_36;                           /**< LTC PKHA E Register, offset: 0xE90 */
  __O  uint32_t LPKE_37;                           /**< LTC PKHA E Register, offset: 0xE94 */
  __O  uint32_t LPKE_38;                           /**< LTC PKHA E Register, offset: 0xE98 */
  __O  uint32_t LPKE_39;                           /**< LTC PKHA E Register, offset: 0xE9C */
  __O  uint32_t LPKE_40;                           /**< LTC PKHA E Register, offset: 0xEA0 */
  __O  uint32_t LPKE_41;                           /**< LTC PKHA E Register, offset: 0xEA4 */
  __O  uint32_t LPKE_42;                           /**< LTC PKHA E Register, offset: 0xEA8 */
  __O  uint32_t LPKE_43;                           /**< LTC PKHA E Register, offset: 0xEAC */
  __O  uint32_t LPKE_44;                           /**< LTC PKHA E Register, offset: 0xEB0 */
  __O  uint32_t LPKE_45;                           /**< LTC PKHA E Register, offset: 0xEB4 */
  __O  uint32_t LPKE_46;                           /**< LTC PKHA E Register, offset: 0xEB8 */
  __O  uint32_t LPKE_47;                           /**< LTC PKHA E Register, offset: 0xEBC */
  __O  uint32_t LPKE_48;                           /**< LTC PKHA E Register, offset: 0xEC0 */
  __O  uint32_t LPKE_49;                           /**< LTC PKHA E Register, offset: 0xEC4 */
  __O  uint32_t LPKE_50;                           /**< LTC PKHA E Register, offset: 0xEC8 */
  __O  uint32_t LPKE_51;                           /**< LTC PKHA E Register, offset: 0xECC */
  __O  uint32_t LPKE_52;                           /**< LTC PKHA E Register, offset: 0xED0 */
  __O  uint32_t LPKE_53;                           /**< LTC PKHA E Register, offset: 0xED4 */
  __O  uint32_t LPKE_54;                           /**< LTC PKHA E Register, offset: 0xED8 */
  __O  uint32_t LPKE_55;                           /**< LTC PKHA E Register, offset: 0xEDC */
  __O  uint32_t LPKE_56;                           /**< LTC PKHA E Register, offset: 0xEE0 */
  __O  uint32_t LPKE_57;                           /**< LTC PKHA E Register, offset: 0xEE4 */
  __O  uint32_t LPKE_58;                           /**< LTC PKHA E Register, offset: 0xEE8 */
  __O  uint32_t LPKE_59;                           /**< LTC PKHA E Register, offset: 0xEEC */
  __O  uint32_t LPKE_60;                           /**< LTC PKHA E Register, offset: 0xEF0 */
  __O  uint32_t LPKE_61;                           /**< LTC PKHA E Register, offset: 0xEF4 */
  __O  uint32_t LPKE_62;                           /**< LTC PKHA E Register, offset: 0xEF8 */
  __O  uint32_t LPKE_63;                           /**< LTC PKHA E Register, offset: 0xEFC */
} LTC_K80_Type, *LTC_K80_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- LTC_K80 - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup LTC_K80_Register_Accessor_Macros LTC_K80 - Register accessor macros
 * @{
 */


/* LTC_K80 - Register accessors */
#define LTC_K80_LTCMR_REG(base)                  ((base)->LTCMR)
#define LTC_K80_LTCMR_PK_REG(base)               ((base)->LTCMR_PK)
#define LTC_K80_LTCKSR_REG(base)                 ((base)->LTCKSR)
#define LTC_K80_LTCDSR_REG(base)                 ((base)->LTCDSR)
#define LTC_K80_LTCICVSR_REG(base)               ((base)->LTCICVSR)
#define LTC_K80_LTCCOM_REG(base)                 ((base)->LTCCOM)
#define LTC_K80_LTCCTL_REG(base)                 ((base)->LTCCTL)
#define LTC_K80_LTCCWR_REG(base)                 ((base)->LTCCWR)
#define LTC_K80_LTCSTA_REG(base)                 ((base)->LTCSTA)
#define LTC_K80_LTCESTA_REG(base)                ((base)->LTCESTA)
#define LTC_K80_LTCAADSZR_REG(base)              ((base)->LTCAADSZR)
#define LTC_K80_LTCIVSZR_REG(base)               ((base)->LTCIVSZR)
#define LTC_K80_LTCDPAMSR_REG(base)              ((base)->LTCDPAMSR)
#define LTC_K80_LPKASZR_REG(base)                ((base)->LPKASZR)
#define LTC_K80_LPKBSZR_REG(base)                ((base)->LPKBSZR)
#define LTC_K80_LPKNSZR_REG(base)                ((base)->LPKNSZR)
#define LTC_K80_LPKESZR_REG(base)                ((base)->LPKESZR)
#define LTC_K80_LTCCTXR_0_REG(base)              ((base)->LTCCTXR_0)
#define LTC_K80_LTCCTXR_1_REG(base)              ((base)->LTCCTXR_1)
#define LTC_K80_LTCCTXR_2_REG(base)              ((base)->LTCCTXR_2)
#define LTC_K80_LTCCTXR_3_REG(base)              ((base)->LTCCTXR_3)
#define LTC_K80_LTCCTXR_4_REG(base)              ((base)->LTCCTXR_4)
#define LTC_K80_LTCCTXR_5_REG(base)              ((base)->LTCCTXR_5)
#define LTC_K80_LTCCTXR_6_REG(base)              ((base)->LTCCTXR_6)
#define LTC_K80_LTCCTXR_7_REG(base)              ((base)->LTCCTXR_7)
#define LTC_K80_LTCCTXR_8_REG(base)              ((base)->LTCCTXR_8)
#define LTC_K80_LTCCTXR_9_REG(base)              ((base)->LTCCTXR_9)
#define LTC_K80_LTCCTXR_10_REG(base)             ((base)->LTCCTXR_10)
#define LTC_K80_LTCCTXR_11_REG(base)             ((base)->LTCCTXR_11)
#define LTC_K80_LTCCTXR_12_REG(base)             ((base)->LTCCTXR_12)
#define LTC_K80_LTCCTXR_13_REG(base)             ((base)->LTCCTXR_13)
#define LTC_K80_LTCCTXR_14_REG(base)             ((base)->LTCCTXR_14)
#define LTC_K80_LTCCTXR_15_REG(base)             ((base)->LTCCTXR_15)
#define LTC_K80_LTCKEYR_0_REG(base)              ((base)->LTCKEYR_0)
#define LTC_K80_LTCKEYR_1_REG(base)              ((base)->LTCKEYR_1)
#define LTC_K80_LTCKEYR_2_REG(base)              ((base)->LTCKEYR_2)
#define LTC_K80_LTCKEYR_3_REG(base)              ((base)->LTCKEYR_3)
#define LTC_K80_LTCKEYR_4_REG(base)              ((base)->LTCKEYR_4)
#define LTC_K80_LTCKEYR_5_REG(base)              ((base)->LTCKEYR_5)
#define LTC_K80_LTCKEYR_6_REG(base)              ((base)->LTCKEYR_6)
#define LTC_K80_LTCKEYR_7_REG(base)              ((base)->LTCKEYR_7)
#define LTC_K80_LTCVID1_REG(base)                ((base)->LTCVID1)
#define LTC_K80_CHAVID_REG(base)                 ((base)->CHAVID)
#define LTC_K80_LTCFIFOSTA_REG(base)             ((base)->LTCFIFOSTA)
#define LTC_K80_LTCIFIFO_REG(base)               ((base)->LTCIFIFO)
#define LTC_K80_LTCOFIFO_REG(base)               ((base)->LTCOFIFO)
#define LTC_K80_LPKA0_0_REG(base)                ((base)->LPKA0_0)
#define LTC_K80_LPKA0_1_REG(base)                ((base)->LPKA0_1)
#define LTC_K80_LPKA0_2_REG(base)                ((base)->LPKA0_2)
#define LTC_K80_LPKA0_3_REG(base)                ((base)->LPKA0_3)
#define LTC_K80_LPKA0_4_REG(base)                ((base)->LPKA0_4)
#define LTC_K80_LPKA0_5_REG(base)                ((base)->LPKA0_5)
#define LTC_K80_LPKA0_6_REG(base)                ((base)->LPKA0_6)
#define LTC_K80_LPKA0_7_REG(base)                ((base)->LPKA0_7)
#define LTC_K80_LPKA0_8_REG(base)                ((base)->LPKA0_8)
#define LTC_K80_LPKA0_9_REG(base)                ((base)->LPKA0_9)
#define LTC_K80_LPKA0_10_REG(base)               ((base)->LPKA0_10)
#define LTC_K80_LPKA0_11_REG(base)               ((base)->LPKA0_11)
#define LTC_K80_LPKA0_12_REG(base)               ((base)->LPKA0_12)
#define LTC_K80_LPKA0_13_REG(base)               ((base)->LPKA0_13)
#define LTC_K80_LPKA0_14_REG(base)               ((base)->LPKA0_14)
#define LTC_K80_LPKA0_15_REG(base)               ((base)->LPKA0_15)
#define LTC_K80_LPKA1_0_REG(base)                ((base)->LPKA1_0)
#define LTC_K80_LPKA1_1_REG(base)                ((base)->LPKA1_1)
#define LTC_K80_LPKA1_2_REG(base)                ((base)->LPKA1_2)
#define LTC_K80_LPKA1_3_REG(base)                ((base)->LPKA1_3)
#define LTC_K80_LPKA1_4_REG(base)                ((base)->LPKA1_4)
#define LTC_K80_LPKA1_5_REG(base)                ((base)->LPKA1_5)
#define LTC_K80_LPKA1_6_REG(base)                ((base)->LPKA1_6)
#define LTC_K80_LPKA1_7_REG(base)                ((base)->LPKA1_7)
#define LTC_K80_LPKA1_8_REG(base)                ((base)->LPKA1_8)
#define LTC_K80_LPKA1_9_REG(base)                ((base)->LPKA1_9)
#define LTC_K80_LPKA1_10_REG(base)               ((base)->LPKA1_10)
#define LTC_K80_LPKA1_11_REG(base)               ((base)->LPKA1_11)
#define LTC_K80_LPKA1_12_REG(base)               ((base)->LPKA1_12)
#define LTC_K80_LPKA1_13_REG(base)               ((base)->LPKA1_13)
#define LTC_K80_LPKA1_14_REG(base)               ((base)->LPKA1_14)
#define LTC_K80_LPKA1_15_REG(base)               ((base)->LPKA1_15)
#define LTC_K80_LPKA2_0_REG(base)                ((base)->LPKA2_0)
#define LTC_K80_LPKA2_1_REG(base)                ((base)->LPKA2_1)
#define LTC_K80_LPKA2_2_REG(base)                ((base)->LPKA2_2)
#define LTC_K80_LPKA2_3_REG(base)                ((base)->LPKA2_3)
#define LTC_K80_LPKA2_4_REG(base)                ((base)->LPKA2_4)
#define LTC_K80_LPKA2_5_REG(base)                ((base)->LPKA2_5)
#define LTC_K80_LPKA2_6_REG(base)                ((base)->LPKA2_6)
#define LTC_K80_LPKA2_7_REG(base)                ((base)->LPKA2_7)
#define LTC_K80_LPKA2_8_REG(base)                ((base)->LPKA2_8)
#define LTC_K80_LPKA2_9_REG(base)                ((base)->LPKA2_9)
#define LTC_K80_LPKA2_10_REG(base)               ((base)->LPKA2_10)
#define LTC_K80_LPKA2_11_REG(base)               ((base)->LPKA2_11)
#define LTC_K80_LPKA2_12_REG(base)               ((base)->LPKA2_12)
#define LTC_K80_LPKA2_13_REG(base)               ((base)->LPKA2_13)
#define LTC_K80_LPKA2_14_REG(base)               ((base)->LPKA2_14)
#define LTC_K80_LPKA2_15_REG(base)               ((base)->LPKA2_15)
#define LTC_K80_LPKA3_0_REG(base)                ((base)->LPKA3_0)
#define LTC_K80_LPKA3_1_REG(base)                ((base)->LPKA3_1)
#define LTC_K80_LPKA3_2_REG(base)                ((base)->LPKA3_2)
#define LTC_K80_LPKA3_3_REG(base)                ((base)->LPKA3_3)
#define LTC_K80_LPKA3_4_REG(base)                ((base)->LPKA3_4)
#define LTC_K80_LPKA3_5_REG(base)                ((base)->LPKA3_5)
#define LTC_K80_LPKA3_6_REG(base)                ((base)->LPKA3_6)
#define LTC_K80_LPKA3_7_REG(base)                ((base)->LPKA3_7)
#define LTC_K80_LPKA3_8_REG(base)                ((base)->LPKA3_8)
#define LTC_K80_LPKA3_9_REG(base)                ((base)->LPKA3_9)
#define LTC_K80_LPKA3_10_REG(base)               ((base)->LPKA3_10)
#define LTC_K80_LPKA3_11_REG(base)               ((base)->LPKA3_11)
#define LTC_K80_LPKA3_12_REG(base)               ((base)->LPKA3_12)
#define LTC_K80_LPKA3_13_REG(base)               ((base)->LPKA3_13)
#define LTC_K80_LPKA3_14_REG(base)               ((base)->LPKA3_14)
#define LTC_K80_LPKA3_15_REG(base)               ((base)->LPKA3_15)
#define LTC_K80_LPKB0_0_REG(base)                ((base)->LPKB0_0)
#define LTC_K80_LPKB0_1_REG(base)                ((base)->LPKB0_1)
#define LTC_K80_LPKB0_2_REG(base)                ((base)->LPKB0_2)
#define LTC_K80_LPKB0_3_REG(base)                ((base)->LPKB0_3)
#define LTC_K80_LPKB0_4_REG(base)                ((base)->LPKB0_4)
#define LTC_K80_LPKB0_5_REG(base)                ((base)->LPKB0_5)
#define LTC_K80_LPKB0_6_REG(base)                ((base)->LPKB0_6)
#define LTC_K80_LPKB0_7_REG(base)                ((base)->LPKB0_7)
#define LTC_K80_LPKB0_8_REG(base)                ((base)->LPKB0_8)
#define LTC_K80_LPKB0_9_REG(base)                ((base)->LPKB0_9)
#define LTC_K80_LPKB0_10_REG(base)               ((base)->LPKB0_10)
#define LTC_K80_LPKB0_11_REG(base)               ((base)->LPKB0_11)
#define LTC_K80_LPKB0_12_REG(base)               ((base)->LPKB0_12)
#define LTC_K80_LPKB0_13_REG(base)               ((base)->LPKB0_13)
#define LTC_K80_LPKB0_14_REG(base)               ((base)->LPKB0_14)
#define LTC_K80_LPKB0_15_REG(base)               ((base)->LPKB0_15)
#define LTC_K80_LPKB1_0_REG(base)                ((base)->LPKB1_0)
#define LTC_K80_LPKB1_1_REG(base)                ((base)->LPKB1_1)
#define LTC_K80_LPKB1_2_REG(base)                ((base)->LPKB1_2)
#define LTC_K80_LPKB1_3_REG(base)                ((base)->LPKB1_3)
#define LTC_K80_LPKB1_4_REG(base)                ((base)->LPKB1_4)
#define LTC_K80_LPKB1_5_REG(base)                ((base)->LPKB1_5)
#define LTC_K80_LPKB1_6_REG(base)                ((base)->LPKB1_6)
#define LTC_K80_LPKB1_7_REG(base)                ((base)->LPKB1_7)
#define LTC_K80_LPKB1_8_REG(base)                ((base)->LPKB1_8)
#define LTC_K80_LPKB1_9_REG(base)                ((base)->LPKB1_9)
#define LTC_K80_LPKB1_10_REG(base)               ((base)->LPKB1_10)
#define LTC_K80_LPKB1_11_REG(base)               ((base)->LPKB1_11)
#define LTC_K80_LPKB1_12_REG(base)               ((base)->LPKB1_12)
#define LTC_K80_LPKB1_13_REG(base)               ((base)->LPKB1_13)
#define LTC_K80_LPKB1_14_REG(base)               ((base)->LPKB1_14)
#define LTC_K80_LPKB1_15_REG(base)               ((base)->LPKB1_15)
#define LTC_K80_LPKB2_0_REG(base)                ((base)->LPKB2_0)
#define LTC_K80_LPKB2_1_REG(base)                ((base)->LPKB2_1)
#define LTC_K80_LPKB2_2_REG(base)                ((base)->LPKB2_2)
#define LTC_K80_LPKB2_3_REG(base)                ((base)->LPKB2_3)
#define LTC_K80_LPKB2_4_REG(base)                ((base)->LPKB2_4)
#define LTC_K80_LPKB2_5_REG(base)                ((base)->LPKB2_5)
#define LTC_K80_LPKB2_6_REG(base)                ((base)->LPKB2_6)
#define LTC_K80_LPKB2_7_REG(base)                ((base)->LPKB2_7)
#define LTC_K80_LPKB2_8_REG(base)                ((base)->LPKB2_8)
#define LTC_K80_LPKB2_9_REG(base)                ((base)->LPKB2_9)
#define LTC_K80_LPKB2_10_REG(base)               ((base)->LPKB2_10)
#define LTC_K80_LPKB2_11_REG(base)               ((base)->LPKB2_11)
#define LTC_K80_LPKB2_12_REG(base)               ((base)->LPKB2_12)
#define LTC_K80_LPKB2_13_REG(base)               ((base)->LPKB2_13)
#define LTC_K80_LPKB2_14_REG(base)               ((base)->LPKB2_14)
#define LTC_K80_LPKB2_15_REG(base)               ((base)->LPKB2_15)
#define LTC_K80_LPKB3_0_REG(base)                ((base)->LPKB3_0)
#define LTC_K80_LPKB3_1_REG(base)                ((base)->LPKB3_1)
#define LTC_K80_LPKB3_2_REG(base)                ((base)->LPKB3_2)
#define LTC_K80_LPKB3_3_REG(base)                ((base)->LPKB3_3)
#define LTC_K80_LPKB3_4_REG(base)                ((base)->LPKB3_4)
#define LTC_K80_LPKB3_5_REG(base)                ((base)->LPKB3_5)
#define LTC_K80_LPKB3_6_REG(base)                ((base)->LPKB3_6)
#define LTC_K80_LPKB3_7_REG(base)                ((base)->LPKB3_7)
#define LTC_K80_LPKB3_8_REG(base)                ((base)->LPKB3_8)
#define LTC_K80_LPKB3_9_REG(base)                ((base)->LPKB3_9)
#define LTC_K80_LPKB3_10_REG(base)               ((base)->LPKB3_10)
#define LTC_K80_LPKB3_11_REG(base)               ((base)->LPKB3_11)
#define LTC_K80_LPKB3_12_REG(base)               ((base)->LPKB3_12)
#define LTC_K80_LPKB3_13_REG(base)               ((base)->LPKB3_13)
#define LTC_K80_LPKB3_14_REG(base)               ((base)->LPKB3_14)
#define LTC_K80_LPKB3_15_REG(base)               ((base)->LPKB3_15)
#define LTC_K80_LPKN0_0_REG(base)                ((base)->LPKN0_0)
#define LTC_K80_LPKN0_1_REG(base)                ((base)->LPKN0_1)
#define LTC_K80_LPKN0_2_REG(base)                ((base)->LPKN0_2)
#define LTC_K80_LPKN0_3_REG(base)                ((base)->LPKN0_3)
#define LTC_K80_LPKN0_4_REG(base)                ((base)->LPKN0_4)
#define LTC_K80_LPKN0_5_REG(base)                ((base)->LPKN0_5)
#define LTC_K80_LPKN0_6_REG(base)                ((base)->LPKN0_6)
#define LTC_K80_LPKN0_7_REG(base)                ((base)->LPKN0_7)
#define LTC_K80_LPKN0_8_REG(base)                ((base)->LPKN0_8)
#define LTC_K80_LPKN0_9_REG(base)                ((base)->LPKN0_9)
#define LTC_K80_LPKN0_10_REG(base)               ((base)->LPKN0_10)
#define LTC_K80_LPKN0_11_REG(base)               ((base)->LPKN0_11)
#define LTC_K80_LPKN0_12_REG(base)               ((base)->LPKN0_12)
#define LTC_K80_LPKN0_13_REG(base)               ((base)->LPKN0_13)
#define LTC_K80_LPKN0_14_REG(base)               ((base)->LPKN0_14)
#define LTC_K80_LPKN0_15_REG(base)               ((base)->LPKN0_15)
#define LTC_K80_LPKN1_0_REG(base)                ((base)->LPKN1_0)
#define LTC_K80_LPKN1_1_REG(base)                ((base)->LPKN1_1)
#define LTC_K80_LPKN1_2_REG(base)                ((base)->LPKN1_2)
#define LTC_K80_LPKN1_3_REG(base)                ((base)->LPKN1_3)
#define LTC_K80_LPKN1_4_REG(base)                ((base)->LPKN1_4)
#define LTC_K80_LPKN1_5_REG(base)                ((base)->LPKN1_5)
#define LTC_K80_LPKN1_6_REG(base)                ((base)->LPKN1_6)
#define LTC_K80_LPKN1_7_REG(base)                ((base)->LPKN1_7)
#define LTC_K80_LPKN1_8_REG(base)                ((base)->LPKN1_8)
#define LTC_K80_LPKN1_9_REG(base)                ((base)->LPKN1_9)
#define LTC_K80_LPKN1_10_REG(base)               ((base)->LPKN1_10)
#define LTC_K80_LPKN1_11_REG(base)               ((base)->LPKN1_11)
#define LTC_K80_LPKN1_12_REG(base)               ((base)->LPKN1_12)
#define LTC_K80_LPKN1_13_REG(base)               ((base)->LPKN1_13)
#define LTC_K80_LPKN1_14_REG(base)               ((base)->LPKN1_14)
#define LTC_K80_LPKN1_15_REG(base)               ((base)->LPKN1_15)
#define LTC_K80_LPKN2_0_REG(base)                ((base)->LPKN2_0)
#define LTC_K80_LPKN2_1_REG(base)                ((base)->LPKN2_1)
#define LTC_K80_LPKN2_2_REG(base)                ((base)->LPKN2_2)
#define LTC_K80_LPKN2_3_REG(base)                ((base)->LPKN2_3)
#define LTC_K80_LPKN2_4_REG(base)                ((base)->LPKN2_4)
#define LTC_K80_LPKN2_5_REG(base)                ((base)->LPKN2_5)
#define LTC_K80_LPKN2_6_REG(base)                ((base)->LPKN2_6)
#define LTC_K80_LPKN2_7_REG(base)                ((base)->LPKN2_7)
#define LTC_K80_LPKN2_8_REG(base)                ((base)->LPKN2_8)
#define LTC_K80_LPKN2_9_REG(base)                ((base)->LPKN2_9)
#define LTC_K80_LPKN2_10_REG(base)               ((base)->LPKN2_10)
#define LTC_K80_LPKN2_11_REG(base)               ((base)->LPKN2_11)
#define LTC_K80_LPKN2_12_REG(base)               ((base)->LPKN2_12)
#define LTC_K80_LPKN2_13_REG(base)               ((base)->LPKN2_13)
#define LTC_K80_LPKN2_14_REG(base)               ((base)->LPKN2_14)
#define LTC_K80_LPKN2_15_REG(base)               ((base)->LPKN2_15)
#define LTC_K80_LPKN3_0_REG(base)                ((base)->LPKN3_0)
#define LTC_K80_LPKN3_1_REG(base)                ((base)->LPKN3_1)
#define LTC_K80_LPKN3_2_REG(base)                ((base)->LPKN3_2)
#define LTC_K80_LPKN3_3_REG(base)                ((base)->LPKN3_3)
#define LTC_K80_LPKN3_4_REG(base)                ((base)->LPKN3_4)
#define LTC_K80_LPKN3_5_REG(base)                ((base)->LPKN3_5)
#define LTC_K80_LPKN3_6_REG(base)                ((base)->LPKN3_6)
#define LTC_K80_LPKN3_7_REG(base)                ((base)->LPKN3_7)
#define LTC_K80_LPKN3_8_REG(base)                ((base)->LPKN3_8)
#define LTC_K80_LPKN3_9_REG(base)                ((base)->LPKN3_9)
#define LTC_K80_LPKN3_10_REG(base)               ((base)->LPKN3_10)
#define LTC_K80_LPKN3_11_REG(base)               ((base)->LPKN3_11)
#define LTC_K80_LPKN3_12_REG(base)               ((base)->LPKN3_12)
#define LTC_K80_LPKN3_13_REG(base)               ((base)->LPKN3_13)
#define LTC_K80_LPKN3_14_REG(base)               ((base)->LPKN3_14)
#define LTC_K80_LPKN3_15_REG(base)               ((base)->LPKN3_15)
#define LTC_K80_LPKE_0_REG(base)                 ((base)->LPKE_0)
#define LTC_K80_LPKE_1_REG(base)                 ((base)->LPKE_1)
#define LTC_K80_LPKE_2_REG(base)                 ((base)->LPKE_2)
#define LTC_K80_LPKE_3_REG(base)                 ((base)->LPKE_3)
#define LTC_K80_LPKE_4_REG(base)                 ((base)->LPKE_4)
#define LTC_K80_LPKE_5_REG(base)                 ((base)->LPKE_5)
#define LTC_K80_LPKE_6_REG(base)                 ((base)->LPKE_6)
#define LTC_K80_LPKE_7_REG(base)                 ((base)->LPKE_7)
#define LTC_K80_LPKE_8_REG(base)                 ((base)->LPKE_8)
#define LTC_K80_LPKE_9_REG(base)                 ((base)->LPKE_9)
#define LTC_K80_LPKE_10_REG(base)                ((base)->LPKE_10)
#define LTC_K80_LPKE_11_REG(base)                ((base)->LPKE_11)
#define LTC_K80_LPKE_12_REG(base)                ((base)->LPKE_12)
#define LTC_K80_LPKE_13_REG(base)                ((base)->LPKE_13)
#define LTC_K80_LPKE_14_REG(base)                ((base)->LPKE_14)
#define LTC_K80_LPKE_15_REG(base)                ((base)->LPKE_15)
#define LTC_K80_LPKE_16_REG(base)                ((base)->LPKE_16)
#define LTC_K80_LPKE_17_REG(base)                ((base)->LPKE_17)
#define LTC_K80_LPKE_18_REG(base)                ((base)->LPKE_18)
#define LTC_K80_LPKE_19_REG(base)                ((base)->LPKE_19)
#define LTC_K80_LPKE_20_REG(base)                ((base)->LPKE_20)
#define LTC_K80_LPKE_21_REG(base)                ((base)->LPKE_21)
#define LTC_K80_LPKE_22_REG(base)                ((base)->LPKE_22)
#define LTC_K80_LPKE_23_REG(base)                ((base)->LPKE_23)
#define LTC_K80_LPKE_24_REG(base)                ((base)->LPKE_24)
#define LTC_K80_LPKE_25_REG(base)                ((base)->LPKE_25)
#define LTC_K80_LPKE_26_REG(base)                ((base)->LPKE_26)
#define LTC_K80_LPKE_27_REG(base)                ((base)->LPKE_27)
#define LTC_K80_LPKE_28_REG(base)                ((base)->LPKE_28)
#define LTC_K80_LPKE_29_REG(base)                ((base)->LPKE_29)
#define LTC_K80_LPKE_30_REG(base)                ((base)->LPKE_30)
#define LTC_K80_LPKE_31_REG(base)                ((base)->LPKE_31)
#define LTC_K80_LPKE_32_REG(base)                ((base)->LPKE_32)
#define LTC_K80_LPKE_33_REG(base)                ((base)->LPKE_33)
#define LTC_K80_LPKE_34_REG(base)                ((base)->LPKE_34)
#define LTC_K80_LPKE_35_REG(base)                ((base)->LPKE_35)
#define LTC_K80_LPKE_36_REG(base)                ((base)->LPKE_36)
#define LTC_K80_LPKE_37_REG(base)                ((base)->LPKE_37)
#define LTC_K80_LPKE_38_REG(base)                ((base)->LPKE_38)
#define LTC_K80_LPKE_39_REG(base)                ((base)->LPKE_39)
#define LTC_K80_LPKE_40_REG(base)                ((base)->LPKE_40)
#define LTC_K80_LPKE_41_REG(base)                ((base)->LPKE_41)
#define LTC_K80_LPKE_42_REG(base)                ((base)->LPKE_42)
#define LTC_K80_LPKE_43_REG(base)                ((base)->LPKE_43)
#define LTC_K80_LPKE_44_REG(base)                ((base)->LPKE_44)
#define LTC_K80_LPKE_45_REG(base)                ((base)->LPKE_45)
#define LTC_K80_LPKE_46_REG(base)                ((base)->LPKE_46)
#define LTC_K80_LPKE_47_REG(base)                ((base)->LPKE_47)
#define LTC_K80_LPKE_48_REG(base)                ((base)->LPKE_48)
#define LTC_K80_LPKE_49_REG(base)                ((base)->LPKE_49)
#define LTC_K80_LPKE_50_REG(base)                ((base)->LPKE_50)
#define LTC_K80_LPKE_51_REG(base)                ((base)->LPKE_51)
#define LTC_K80_LPKE_52_REG(base)                ((base)->LPKE_52)
#define LTC_K80_LPKE_53_REG(base)                ((base)->LPKE_53)
#define LTC_K80_LPKE_54_REG(base)                ((base)->LPKE_54)
#define LTC_K80_LPKE_55_REG(base)                ((base)->LPKE_55)
#define LTC_K80_LPKE_56_REG(base)                ((base)->LPKE_56)
#define LTC_K80_LPKE_57_REG(base)                ((base)->LPKE_57)
#define LTC_K80_LPKE_58_REG(base)                ((base)->LPKE_58)
#define LTC_K80_LPKE_59_REG(base)                ((base)->LPKE_59)
#define LTC_K80_LPKE_60_REG(base)                ((base)->LPKE_60)
#define LTC_K80_LPKE_61_REG(base)                ((base)->LPKE_61)
#define LTC_K80_LPKE_62_REG(base)                ((base)->LPKE_62)
#define LTC_K80_LPKE_63_REG(base)                ((base)->LPKE_63)

/*!
 * @}
 */ /* end of group LTC_K80_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- LTC_K80 Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup LTC_K80_Register_Masks LTC_K80 Register Masks
 * @{
 */

/* LTCMR Bit Fields */
#define LTC_K80_LTCMR_ENC_MASK                   0x1u
#define LTC_K80_LTCMR_ENC_SHIFT                  0
#define LTC_K80_LTCMR_ICV_TEST_MASK              0x2u
#define LTC_K80_LTCMR_ICV_TEST_SHIFT             1
#define LTC_K80_LTCMR_AS_MASK                    0xCu
#define LTC_K80_LTCMR_AS_SHIFT                   2
#define LTC_K80_LTCMR_AS(x)                      (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCMR_AS_SHIFT))&LTC_K80_LTCMR_AS_MASK)
#define LTC_K80_LTCMR_AAI_MASK                   0x1FF0u
#define LTC_K80_LTCMR_AAI_SHIFT                  4
#define LTC_K80_LTCMR_AAI(x)                     (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCMR_AAI_SHIFT))&LTC_K80_LTCMR_AAI_MASK)
#define LTC_K80_LTCMR_ALG_MASK                   0xFF0000u
#define LTC_K80_LTCMR_ALG_SHIFT                  16
#define LTC_K80_LTCMR_ALG(x)                     (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCMR_ALG_SHIFT))&LTC_K80_LTCMR_ALG_MASK)
/* LTCMR_PK Bit Fields */
#define LTC_K80_LTCMR_PK_PKHA_MODE_LS_MASK       0xFFFu
#define LTC_K80_LTCMR_PK_PKHA_MODE_LS_SHIFT      0
#define LTC_K80_LTCMR_PK_PKHA_MODE_LS(x)         (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCMR_PK_PKHA_MODE_LS_SHIFT))&LTC_K80_LTCMR_PK_PKHA_MODE_LS_MASK)
#define LTC_K80_LTCMR_PK_PKHA_MODE_MS_MASK       0xF0000u
#define LTC_K80_LTCMR_PK_PKHA_MODE_MS_SHIFT      16
#define LTC_K80_LTCMR_PK_PKHA_MODE_MS(x)         (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCMR_PK_PKHA_MODE_MS_SHIFT))&LTC_K80_LTCMR_PK_PKHA_MODE_MS_MASK)
#define LTC_K80_LTCMR_PK_ALG_MASK                0xF00000u
#define LTC_K80_LTCMR_PK_ALG_SHIFT               20
#define LTC_K80_LTCMR_PK_ALG(x)                  (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCMR_PK_ALG_SHIFT))&LTC_K80_LTCMR_PK_ALG_MASK)
/* LTCKSR Bit Fields */
#define LTC_K80_LTCKSR_KS_MASK                   0x3Fu
#define LTC_K80_LTCKSR_KS_SHIFT                  0
#define LTC_K80_LTCKSR_KS(x)                     (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCKSR_KS_SHIFT))&LTC_K80_LTCKSR_KS_MASK)
/* LTCDSR Bit Fields */
#define LTC_K80_LTCDSR_DS_MASK                   0xFFFu
#define LTC_K80_LTCDSR_DS_SHIFT                  0
#define LTC_K80_LTCDSR_DS(x)                     (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCDSR_DS_SHIFT))&LTC_K80_LTCDSR_DS_MASK)
/* LTCICVSR Bit Fields */
#define LTC_K80_LTCICVSR_ICVS_MASK               0x1Fu
#define LTC_K80_LTCICVSR_ICVS_SHIFT              0
#define LTC_K80_LTCICVSR_ICVS(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCICVSR_ICVS_SHIFT))&LTC_K80_LTCICVSR_ICVS_MASK)
/* LTCCOM Bit Fields */
#define LTC_K80_LTCCOM_ALL_MASK                  0x1u
#define LTC_K80_LTCCOM_ALL_SHIFT                 0
#define LTC_K80_LTCCOM_AES_MASK                  0x2u
#define LTC_K80_LTCCOM_AES_SHIFT                 1
#define LTC_K80_LTCCOM_DES_MASK                  0x4u
#define LTC_K80_LTCCOM_DES_SHIFT                 2
#define LTC_K80_LTCCOM_PK_MASK                   0x40u
#define LTC_K80_LTCCOM_PK_SHIFT                  6
/* LTCCTL Bit Fields */
#define LTC_K80_LTCCTL_IM_MASK                   0x1u
#define LTC_K80_LTCCTL_IM_SHIFT                  0
#define LTC_K80_LTCCTL_PDE_MASK                  0x10u
#define LTC_K80_LTCCTL_PDE_SHIFT                 4
#define LTC_K80_LTCCTL_IFE_MASK                  0x100u
#define LTC_K80_LTCCTL_IFE_SHIFT                 8
#define LTC_K80_LTCCTL_IFR_MASK                  0x200u
#define LTC_K80_LTCCTL_IFR_SHIFT                 9
#define LTC_K80_LTCCTL_OFE_MASK                  0x1000u
#define LTC_K80_LTCCTL_OFE_SHIFT                 12
#define LTC_K80_LTCCTL_OFR_MASK                  0x2000u
#define LTC_K80_LTCCTL_OFR_SHIFT                 13
#define LTC_K80_LTCCTL_IFS_MASK                  0x10000u
#define LTC_K80_LTCCTL_IFS_SHIFT                 16
#define LTC_K80_LTCCTL_OFS_MASK                  0x20000u
#define LTC_K80_LTCCTL_OFS_SHIFT                 17
#define LTC_K80_LTCCTL_KIS_MASK                  0x100000u
#define LTC_K80_LTCCTL_KIS_SHIFT                 20
#define LTC_K80_LTCCTL_KOS_MASK                  0x200000u
#define LTC_K80_LTCCTL_KOS_SHIFT                 21
#define LTC_K80_LTCCTL_CIS_MASK                  0x400000u
#define LTC_K80_LTCCTL_CIS_SHIFT                 22
#define LTC_K80_LTCCTL_COS_MASK                  0x800000u
#define LTC_K80_LTCCTL_COS_SHIFT                 23
#define LTC_K80_LTCCTL_KAL_MASK                  0x80000000u
#define LTC_K80_LTCCTL_KAL_SHIFT                 31
/* LTCCWR Bit Fields */
#define LTC_K80_LTCCWR_CM_MASK                   0x1u
#define LTC_K80_LTCCWR_CM_SHIFT                  0
#define LTC_K80_LTCCWR_CDS_MASK                  0x4u
#define LTC_K80_LTCCWR_CDS_SHIFT                 2
#define LTC_K80_LTCCWR_CICV_MASK                 0x8u
#define LTC_K80_LTCCWR_CICV_SHIFT                3
#define LTC_K80_LTCCWR_CCR_MASK                  0x20u
#define LTC_K80_LTCCWR_CCR_SHIFT                 5
#define LTC_K80_LTCCWR_CKR_MASK                  0x40u
#define LTC_K80_LTCCWR_CKR_SHIFT                 6
#define LTC_K80_LTCCWR_CPKA_MASK                 0x1000u
#define LTC_K80_LTCCWR_CPKA_SHIFT                12
#define LTC_K80_LTCCWR_CPKB_MASK                 0x2000u
#define LTC_K80_LTCCWR_CPKB_SHIFT                13
#define LTC_K80_LTCCWR_CPKN_MASK                 0x4000u
#define LTC_K80_LTCCWR_CPKN_SHIFT                14
#define LTC_K80_LTCCWR_CPKE_MASK                 0x8000u
#define LTC_K80_LTCCWR_CPKE_SHIFT                15
#define LTC_K80_LTCCWR_COF_MASK                  0x40000000u
#define LTC_K80_LTCCWR_COF_SHIFT                 30
#define LTC_K80_LTCCWR_CIF_MASK                  0x80000000u
#define LTC_K80_LTCCWR_CIF_SHIFT                 31
/* LTCSTA Bit Fields */
#define LTC_K80_LTCSTA_AB_MASK                   0x2u
#define LTC_K80_LTCSTA_AB_SHIFT                  1
#define LTC_K80_LTCSTA_DB_MASK                   0x4u
#define LTC_K80_LTCSTA_DB_SHIFT                  2
#define LTC_K80_LTCSTA_PB_MASK                   0x40u
#define LTC_K80_LTCSTA_PB_SHIFT                  6
#define LTC_K80_LTCSTA_DI_MASK                   0x10000u
#define LTC_K80_LTCSTA_DI_SHIFT                  16
#define LTC_K80_LTCSTA_EI_MASK                   0x100000u
#define LTC_K80_LTCSTA_EI_SHIFT                  20
#define LTC_K80_LTCSTA_PKP_MASK                  0x10000000u
#define LTC_K80_LTCSTA_PKP_SHIFT                 28
#define LTC_K80_LTCSTA_PKO_MASK                  0x20000000u
#define LTC_K80_LTCSTA_PKO_SHIFT                 29
#define LTC_K80_LTCSTA_PKZ_MASK                  0x40000000u
#define LTC_K80_LTCSTA_PKZ_SHIFT                 30
/* LTCESTA Bit Fields */
#define LTC_K80_LTCESTA_ERRID1_MASK              0xFu
#define LTC_K80_LTCESTA_ERRID1_SHIFT             0
#define LTC_K80_LTCESTA_ERRID1(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCESTA_ERRID1_SHIFT))&LTC_K80_LTCESTA_ERRID1_MASK)
#define LTC_K80_LTCESTA_CL1_MASK                 0xF00u
#define LTC_K80_LTCESTA_CL1_SHIFT                8
#define LTC_K80_LTCESTA_CL1(x)                   (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCESTA_CL1_SHIFT))&LTC_K80_LTCESTA_CL1_MASK)
/* LTCAADSZR Bit Fields */
#define LTC_K80_LTCAADSZR_AADSZ_MASK             0xFu
#define LTC_K80_LTCAADSZR_AADSZ_SHIFT            0
#define LTC_K80_LTCAADSZR_AADSZ(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCAADSZR_AADSZ_SHIFT))&LTC_K80_LTCAADSZR_AADSZ_MASK)
#define LTC_K80_LTCAADSZR_AL_MASK                0x80000000u
#define LTC_K80_LTCAADSZR_AL_SHIFT               31
/* LTCIVSZR Bit Fields */
#define LTC_K80_LTCIVSZR_IVSZ_MASK               0xFu
#define LTC_K80_LTCIVSZR_IVSZ_SHIFT              0
#define LTC_K80_LTCIVSZR_IVSZ(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCIVSZR_IVSZ_SHIFT))&LTC_K80_LTCIVSZR_IVSZ_MASK)
#define LTC_K80_LTCIVSZR_IL_MASK                 0x80000000u
#define LTC_K80_LTCIVSZR_IL_SHIFT                31
/* LTCDPAMSR Bit Fields */
#define LTC_K80_LTCDPAMSR_DPAMS_MASK             0xFFFFFFFFu
#define LTC_K80_LTCDPAMSR_DPAMS_SHIFT            0
#define LTC_K80_LTCDPAMSR_DPAMS(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCDPAMSR_DPAMS_SHIFT))&LTC_K80_LTCDPAMSR_DPAMS_MASK)
/* LPKASZR Bit Fields */
#define LTC_K80_LPKASZR_PKASZ_MASK               0x1FFu
#define LTC_K80_LPKASZR_PKASZ_SHIFT              0
#define LTC_K80_LPKASZR_PKASZ(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKASZR_PKASZ_SHIFT))&LTC_K80_LPKASZR_PKASZ_MASK)
/* LPKBSZR Bit Fields */
#define LTC_K80_LPKBSZR_PKBSZ_MASK               0x1FFu
#define LTC_K80_LPKBSZR_PKBSZ_SHIFT              0
#define LTC_K80_LPKBSZR_PKBSZ(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKBSZR_PKBSZ_SHIFT))&LTC_K80_LPKBSZR_PKBSZ_MASK)
/* LPKNSZR Bit Fields */
#define LTC_K80_LPKNSZR_PKNSZ_MASK               0x1FFu
#define LTC_K80_LPKNSZR_PKNSZ_SHIFT              0
#define LTC_K80_LPKNSZR_PKNSZ(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKNSZR_PKNSZ_SHIFT))&LTC_K80_LPKNSZR_PKNSZ_MASK)
/* LPKESZR Bit Fields */
#define LTC_K80_LPKESZR_PKESZ_MASK               0x1FFu
#define LTC_K80_LPKESZR_PKESZ_SHIFT              0
#define LTC_K80_LPKESZR_PKESZ(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKESZR_PKESZ_SHIFT))&LTC_K80_LPKESZR_PKESZ_MASK)
/* LTCCTXR_0 Bit Fields */
#define LTC_K80_LTCCTXR_0_CTX_MASK               0xFFFFFFFFu
#define LTC_K80_LTCCTXR_0_CTX_SHIFT              0
#define LTC_K80_LTCCTXR_0_CTX(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCCTXR_0_CTX_SHIFT))&LTC_K80_LTCCTXR_0_CTX_MASK)
/* LTCCTXR_1 Bit Fields */
#define LTC_K80_LTCCTXR_1_CTX_MASK               0xFFFFFFFFu
#define LTC_K80_LTCCTXR_1_CTX_SHIFT              0
#define LTC_K80_LTCCTXR_1_CTX(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCCTXR_1_CTX_SHIFT))&LTC_K80_LTCCTXR_1_CTX_MASK)
/* LTCCTXR_2 Bit Fields */
#define LTC_K80_LTCCTXR_2_CTX_MASK               0xFFFFFFFFu
#define LTC_K80_LTCCTXR_2_CTX_SHIFT              0
#define LTC_K80_LTCCTXR_2_CTX(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCCTXR_2_CTX_SHIFT))&LTC_K80_LTCCTXR_2_CTX_MASK)
/* LTCCTXR_3 Bit Fields */
#define LTC_K80_LTCCTXR_3_CTX_MASK               0xFFFFFFFFu
#define LTC_K80_LTCCTXR_3_CTX_SHIFT              0
#define LTC_K80_LTCCTXR_3_CTX(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCCTXR_3_CTX_SHIFT))&LTC_K80_LTCCTXR_3_CTX_MASK)
/* LTCCTXR_4 Bit Fields */
#define LTC_K80_LTCCTXR_4_CTX_MASK               0xFFFFFFFFu
#define LTC_K80_LTCCTXR_4_CTX_SHIFT              0
#define LTC_K80_LTCCTXR_4_CTX(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCCTXR_4_CTX_SHIFT))&LTC_K80_LTCCTXR_4_CTX_MASK)
/* LTCCTXR_5 Bit Fields */
#define LTC_K80_LTCCTXR_5_CTX_MASK               0xFFFFFFFFu
#define LTC_K80_LTCCTXR_5_CTX_SHIFT              0
#define LTC_K80_LTCCTXR_5_CTX(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCCTXR_5_CTX_SHIFT))&LTC_K80_LTCCTXR_5_CTX_MASK)
/* LTCCTXR_6 Bit Fields */
#define LTC_K80_LTCCTXR_6_CTX_MASK               0xFFFFFFFFu
#define LTC_K80_LTCCTXR_6_CTX_SHIFT              0
#define LTC_K80_LTCCTXR_6_CTX(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCCTXR_6_CTX_SHIFT))&LTC_K80_LTCCTXR_6_CTX_MASK)
/* LTCCTXR_7 Bit Fields */
#define LTC_K80_LTCCTXR_7_CTX_MASK               0xFFFFFFFFu
#define LTC_K80_LTCCTXR_7_CTX_SHIFT              0
#define LTC_K80_LTCCTXR_7_CTX(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCCTXR_7_CTX_SHIFT))&LTC_K80_LTCCTXR_7_CTX_MASK)
/* LTCCTXR_8 Bit Fields */
#define LTC_K80_LTCCTXR_8_CTX_MASK               0xFFFFFFFFu
#define LTC_K80_LTCCTXR_8_CTX_SHIFT              0
#define LTC_K80_LTCCTXR_8_CTX(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCCTXR_8_CTX_SHIFT))&LTC_K80_LTCCTXR_8_CTX_MASK)
/* LTCCTXR_9 Bit Fields */
#define LTC_K80_LTCCTXR_9_CTX_MASK               0xFFFFFFFFu
#define LTC_K80_LTCCTXR_9_CTX_SHIFT              0
#define LTC_K80_LTCCTXR_9_CTX(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCCTXR_9_CTX_SHIFT))&LTC_K80_LTCCTXR_9_CTX_MASK)
/* LTCCTXR_10 Bit Fields */
#define LTC_K80_LTCCTXR_10_CTX_MASK              0xFFFFFFFFu
#define LTC_K80_LTCCTXR_10_CTX_SHIFT             0
#define LTC_K80_LTCCTXR_10_CTX(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCCTXR_10_CTX_SHIFT))&LTC_K80_LTCCTXR_10_CTX_MASK)
/* LTCCTXR_11 Bit Fields */
#define LTC_K80_LTCCTXR_11_CTX_MASK              0xFFFFFFFFu
#define LTC_K80_LTCCTXR_11_CTX_SHIFT             0
#define LTC_K80_LTCCTXR_11_CTX(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCCTXR_11_CTX_SHIFT))&LTC_K80_LTCCTXR_11_CTX_MASK)
/* LTCCTXR_12 Bit Fields */
#define LTC_K80_LTCCTXR_12_CTX_MASK              0xFFFFFFFFu
#define LTC_K80_LTCCTXR_12_CTX_SHIFT             0
#define LTC_K80_LTCCTXR_12_CTX(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCCTXR_12_CTX_SHIFT))&LTC_K80_LTCCTXR_12_CTX_MASK)
/* LTCCTXR_13 Bit Fields */
#define LTC_K80_LTCCTXR_13_CTX_MASK              0xFFFFFFFFu
#define LTC_K80_LTCCTXR_13_CTX_SHIFT             0
#define LTC_K80_LTCCTXR_13_CTX(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCCTXR_13_CTX_SHIFT))&LTC_K80_LTCCTXR_13_CTX_MASK)
/* LTCCTXR_14 Bit Fields */
#define LTC_K80_LTCCTXR_14_CTX_MASK              0xFFFFFFFFu
#define LTC_K80_LTCCTXR_14_CTX_SHIFT             0
#define LTC_K80_LTCCTXR_14_CTX(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCCTXR_14_CTX_SHIFT))&LTC_K80_LTCCTXR_14_CTX_MASK)
/* LTCCTXR_15 Bit Fields */
#define LTC_K80_LTCCTXR_15_CTX_MASK              0xFFFFFFFFu
#define LTC_K80_LTCCTXR_15_CTX_SHIFT             0
#define LTC_K80_LTCCTXR_15_CTX(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCCTXR_15_CTX_SHIFT))&LTC_K80_LTCCTXR_15_CTX_MASK)
/* LTCKEYR_0 Bit Fields */
#define LTC_K80_LTCKEYR_0_KEYR_MASK              0xFFFFFFFFu
#define LTC_K80_LTCKEYR_0_KEYR_SHIFT             0
#define LTC_K80_LTCKEYR_0_KEYR(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCKEYR_0_KEYR_SHIFT))&LTC_K80_LTCKEYR_0_KEYR_MASK)
/* LTCKEYR_1 Bit Fields */
#define LTC_K80_LTCKEYR_1_KEYR_MASK              0xFFFFFFFFu
#define LTC_K80_LTCKEYR_1_KEYR_SHIFT             0
#define LTC_K80_LTCKEYR_1_KEYR(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCKEYR_1_KEYR_SHIFT))&LTC_K80_LTCKEYR_1_KEYR_MASK)
/* LTCKEYR_2 Bit Fields */
#define LTC_K80_LTCKEYR_2_KEYR_MASK              0xFFFFFFFFu
#define LTC_K80_LTCKEYR_2_KEYR_SHIFT             0
#define LTC_K80_LTCKEYR_2_KEYR(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCKEYR_2_KEYR_SHIFT))&LTC_K80_LTCKEYR_2_KEYR_MASK)
/* LTCKEYR_3 Bit Fields */
#define LTC_K80_LTCKEYR_3_KEYR_MASK              0xFFFFFFFFu
#define LTC_K80_LTCKEYR_3_KEYR_SHIFT             0
#define LTC_K80_LTCKEYR_3_KEYR(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCKEYR_3_KEYR_SHIFT))&LTC_K80_LTCKEYR_3_KEYR_MASK)
/* LTCKEYR_4 Bit Fields */
#define LTC_K80_LTCKEYR_4_KEYR_MASK              0xFFFFFFFFu
#define LTC_K80_LTCKEYR_4_KEYR_SHIFT             0
#define LTC_K80_LTCKEYR_4_KEYR(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCKEYR_4_KEYR_SHIFT))&LTC_K80_LTCKEYR_4_KEYR_MASK)
/* LTCKEYR_5 Bit Fields */
#define LTC_K80_LTCKEYR_5_KEYR_MASK              0xFFFFFFFFu
#define LTC_K80_LTCKEYR_5_KEYR_SHIFT             0
#define LTC_K80_LTCKEYR_5_KEYR(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCKEYR_5_KEYR_SHIFT))&LTC_K80_LTCKEYR_5_KEYR_MASK)
/* LTCKEYR_6 Bit Fields */
#define LTC_K80_LTCKEYR_6_KEYR_MASK              0xFFFFFFFFu
#define LTC_K80_LTCKEYR_6_KEYR_SHIFT             0
#define LTC_K80_LTCKEYR_6_KEYR(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCKEYR_6_KEYR_SHIFT))&LTC_K80_LTCKEYR_6_KEYR_MASK)
/* LTCKEYR_7 Bit Fields */
#define LTC_K80_LTCKEYR_7_KEYR_MASK              0xFFFFFFFFu
#define LTC_K80_LTCKEYR_7_KEYR_SHIFT             0
#define LTC_K80_LTCKEYR_7_KEYR(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCKEYR_7_KEYR_SHIFT))&LTC_K80_LTCKEYR_7_KEYR_MASK)
/* LTCVID1 Bit Fields */
#define LTC_K80_LTCVID1_MIN_REV_MASK             0xFFu
#define LTC_K80_LTCVID1_MIN_REV_SHIFT            0
#define LTC_K80_LTCVID1_MIN_REV(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCVID1_MIN_REV_SHIFT))&LTC_K80_LTCVID1_MIN_REV_MASK)
#define LTC_K80_LTCVID1_MAJ_REV_MASK             0xFF00u
#define LTC_K80_LTCVID1_MAJ_REV_SHIFT            8
#define LTC_K80_LTCVID1_MAJ_REV(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCVID1_MAJ_REV_SHIFT))&LTC_K80_LTCVID1_MAJ_REV_MASK)
#define LTC_K80_LTCVID1_IP_ID_MASK               0xFFFF0000u
#define LTC_K80_LTCVID1_IP_ID_SHIFT              16
#define LTC_K80_LTCVID1_IP_ID(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCVID1_IP_ID_SHIFT))&LTC_K80_LTCVID1_IP_ID_MASK)
/* CHAVID Bit Fields */
#define LTC_K80_CHAVID_AESREV_MASK               0xFu
#define LTC_K80_CHAVID_AESREV_SHIFT              0
#define LTC_K80_CHAVID_AESREV(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_CHAVID_AESREV_SHIFT))&LTC_K80_CHAVID_AESREV_MASK)
#define LTC_K80_CHAVID_AESVID_MASK               0xF0u
#define LTC_K80_CHAVID_AESVID_SHIFT              4
#define LTC_K80_CHAVID_AESVID(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_CHAVID_AESVID_SHIFT))&LTC_K80_CHAVID_AESVID_MASK)
#define LTC_K80_CHAVID_DESREV_MASK               0xF00u
#define LTC_K80_CHAVID_DESREV_SHIFT              8
#define LTC_K80_CHAVID_DESREV(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_CHAVID_DESREV_SHIFT))&LTC_K80_CHAVID_DESREV_MASK)
#define LTC_K80_CHAVID_DESVID_MASK               0xF000u
#define LTC_K80_CHAVID_DESVID_SHIFT              12
#define LTC_K80_CHAVID_DESVID(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_CHAVID_DESVID_SHIFT))&LTC_K80_CHAVID_DESVID_MASK)
#define LTC_K80_CHAVID_PKHAREV_MASK              0xF0000u
#define LTC_K80_CHAVID_PKHAREV_SHIFT             16
#define LTC_K80_CHAVID_PKHAREV(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_CHAVID_PKHAREV_SHIFT))&LTC_K80_CHAVID_PKHAREV_MASK)
#define LTC_K80_CHAVID_PKHAVID_MASK              0xF00000u
#define LTC_K80_CHAVID_PKHAVID_SHIFT             20
#define LTC_K80_CHAVID_PKHAVID(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_CHAVID_PKHAVID_SHIFT))&LTC_K80_CHAVID_PKHAVID_MASK)
/* LTCFIFOSTA Bit Fields */
#define LTC_K80_LTCFIFOSTA_IFL_MASK              0x7Fu
#define LTC_K80_LTCFIFOSTA_IFL_SHIFT             0
#define LTC_K80_LTCFIFOSTA_IFL(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCFIFOSTA_IFL_SHIFT))&LTC_K80_LTCFIFOSTA_IFL_MASK)
#define LTC_K80_LTCFIFOSTA_IFF_MASK              0x8000u
#define LTC_K80_LTCFIFOSTA_IFF_SHIFT             15
#define LTC_K80_LTCFIFOSTA_OFL_MASK              0x7F0000u
#define LTC_K80_LTCFIFOSTA_OFL_SHIFT             16
#define LTC_K80_LTCFIFOSTA_OFL(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCFIFOSTA_OFL_SHIFT))&LTC_K80_LTCFIFOSTA_OFL_MASK)
#define LTC_K80_LTCFIFOSTA_OFF_MASK              0x80000000u
#define LTC_K80_LTCFIFOSTA_OFF_SHIFT             31
/* LTCIFIFO Bit Fields */
#define LTC_K80_LTCIFIFO_IFIFO_MASK              0xFFFFFFFFu
#define LTC_K80_LTCIFIFO_IFIFO_SHIFT             0
#define LTC_K80_LTCIFIFO_IFIFO(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCIFIFO_IFIFO_SHIFT))&LTC_K80_LTCIFIFO_IFIFO_MASK)
/* LTCOFIFO Bit Fields */
#define LTC_K80_LTCOFIFO_OFIFO_MASK              0xFFFFFFFFu
#define LTC_K80_LTCOFIFO_OFIFO_SHIFT             0
#define LTC_K80_LTCOFIFO_OFIFO(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LTCOFIFO_OFIFO_SHIFT))&LTC_K80_LTCOFIFO_OFIFO_MASK)
/* LPKA0_0 Bit Fields */
#define LTC_K80_LPKA0_0_PKHA_A0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA0_0_PKHA_A0_SHIFT            0
#define LTC_K80_LPKA0_0_PKHA_A0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA0_0_PKHA_A0_SHIFT))&LTC_K80_LPKA0_0_PKHA_A0_MASK)
/* LPKA0_1 Bit Fields */
#define LTC_K80_LPKA0_1_PKHA_A0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA0_1_PKHA_A0_SHIFT            0
#define LTC_K80_LPKA0_1_PKHA_A0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA0_1_PKHA_A0_SHIFT))&LTC_K80_LPKA0_1_PKHA_A0_MASK)
/* LPKA0_2 Bit Fields */
#define LTC_K80_LPKA0_2_PKHA_A0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA0_2_PKHA_A0_SHIFT            0
#define LTC_K80_LPKA0_2_PKHA_A0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA0_2_PKHA_A0_SHIFT))&LTC_K80_LPKA0_2_PKHA_A0_MASK)
/* LPKA0_3 Bit Fields */
#define LTC_K80_LPKA0_3_PKHA_A0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA0_3_PKHA_A0_SHIFT            0
#define LTC_K80_LPKA0_3_PKHA_A0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA0_3_PKHA_A0_SHIFT))&LTC_K80_LPKA0_3_PKHA_A0_MASK)
/* LPKA0_4 Bit Fields */
#define LTC_K80_LPKA0_4_PKHA_A0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA0_4_PKHA_A0_SHIFT            0
#define LTC_K80_LPKA0_4_PKHA_A0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA0_4_PKHA_A0_SHIFT))&LTC_K80_LPKA0_4_PKHA_A0_MASK)
/* LPKA0_5 Bit Fields */
#define LTC_K80_LPKA0_5_PKHA_A0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA0_5_PKHA_A0_SHIFT            0
#define LTC_K80_LPKA0_5_PKHA_A0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA0_5_PKHA_A0_SHIFT))&LTC_K80_LPKA0_5_PKHA_A0_MASK)
/* LPKA0_6 Bit Fields */
#define LTC_K80_LPKA0_6_PKHA_A0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA0_6_PKHA_A0_SHIFT            0
#define LTC_K80_LPKA0_6_PKHA_A0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA0_6_PKHA_A0_SHIFT))&LTC_K80_LPKA0_6_PKHA_A0_MASK)
/* LPKA0_7 Bit Fields */
#define LTC_K80_LPKA0_7_PKHA_A0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA0_7_PKHA_A0_SHIFT            0
#define LTC_K80_LPKA0_7_PKHA_A0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA0_7_PKHA_A0_SHIFT))&LTC_K80_LPKA0_7_PKHA_A0_MASK)
/* LPKA0_8 Bit Fields */
#define LTC_K80_LPKA0_8_PKHA_A0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA0_8_PKHA_A0_SHIFT            0
#define LTC_K80_LPKA0_8_PKHA_A0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA0_8_PKHA_A0_SHIFT))&LTC_K80_LPKA0_8_PKHA_A0_MASK)
/* LPKA0_9 Bit Fields */
#define LTC_K80_LPKA0_9_PKHA_A0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA0_9_PKHA_A0_SHIFT            0
#define LTC_K80_LPKA0_9_PKHA_A0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA0_9_PKHA_A0_SHIFT))&LTC_K80_LPKA0_9_PKHA_A0_MASK)
/* LPKA0_10 Bit Fields */
#define LTC_K80_LPKA0_10_PKHA_A0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA0_10_PKHA_A0_SHIFT           0
#define LTC_K80_LPKA0_10_PKHA_A0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA0_10_PKHA_A0_SHIFT))&LTC_K80_LPKA0_10_PKHA_A0_MASK)
/* LPKA0_11 Bit Fields */
#define LTC_K80_LPKA0_11_PKHA_A0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA0_11_PKHA_A0_SHIFT           0
#define LTC_K80_LPKA0_11_PKHA_A0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA0_11_PKHA_A0_SHIFT))&LTC_K80_LPKA0_11_PKHA_A0_MASK)
/* LPKA0_12 Bit Fields */
#define LTC_K80_LPKA0_12_PKHA_A0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA0_12_PKHA_A0_SHIFT           0
#define LTC_K80_LPKA0_12_PKHA_A0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA0_12_PKHA_A0_SHIFT))&LTC_K80_LPKA0_12_PKHA_A0_MASK)
/* LPKA0_13 Bit Fields */
#define LTC_K80_LPKA0_13_PKHA_A0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA0_13_PKHA_A0_SHIFT           0
#define LTC_K80_LPKA0_13_PKHA_A0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA0_13_PKHA_A0_SHIFT))&LTC_K80_LPKA0_13_PKHA_A0_MASK)
/* LPKA0_14 Bit Fields */
#define LTC_K80_LPKA0_14_PKHA_A0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA0_14_PKHA_A0_SHIFT           0
#define LTC_K80_LPKA0_14_PKHA_A0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA0_14_PKHA_A0_SHIFT))&LTC_K80_LPKA0_14_PKHA_A0_MASK)
/* LPKA0_15 Bit Fields */
#define LTC_K80_LPKA0_15_PKHA_A0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA0_15_PKHA_A0_SHIFT           0
#define LTC_K80_LPKA0_15_PKHA_A0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA0_15_PKHA_A0_SHIFT))&LTC_K80_LPKA0_15_PKHA_A0_MASK)
/* LPKA1_0 Bit Fields */
#define LTC_K80_LPKA1_0_PKHA_A1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA1_0_PKHA_A1_SHIFT            0
#define LTC_K80_LPKA1_0_PKHA_A1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA1_0_PKHA_A1_SHIFT))&LTC_K80_LPKA1_0_PKHA_A1_MASK)
/* LPKA1_1 Bit Fields */
#define LTC_K80_LPKA1_1_PKHA_A1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA1_1_PKHA_A1_SHIFT            0
#define LTC_K80_LPKA1_1_PKHA_A1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA1_1_PKHA_A1_SHIFT))&LTC_K80_LPKA1_1_PKHA_A1_MASK)
/* LPKA1_2 Bit Fields */
#define LTC_K80_LPKA1_2_PKHA_A1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA1_2_PKHA_A1_SHIFT            0
#define LTC_K80_LPKA1_2_PKHA_A1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA1_2_PKHA_A1_SHIFT))&LTC_K80_LPKA1_2_PKHA_A1_MASK)
/* LPKA1_3 Bit Fields */
#define LTC_K80_LPKA1_3_PKHA_A1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA1_3_PKHA_A1_SHIFT            0
#define LTC_K80_LPKA1_3_PKHA_A1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA1_3_PKHA_A1_SHIFT))&LTC_K80_LPKA1_3_PKHA_A1_MASK)
/* LPKA1_4 Bit Fields */
#define LTC_K80_LPKA1_4_PKHA_A1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA1_4_PKHA_A1_SHIFT            0
#define LTC_K80_LPKA1_4_PKHA_A1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA1_4_PKHA_A1_SHIFT))&LTC_K80_LPKA1_4_PKHA_A1_MASK)
/* LPKA1_5 Bit Fields */
#define LTC_K80_LPKA1_5_PKHA_A1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA1_5_PKHA_A1_SHIFT            0
#define LTC_K80_LPKA1_5_PKHA_A1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA1_5_PKHA_A1_SHIFT))&LTC_K80_LPKA1_5_PKHA_A1_MASK)
/* LPKA1_6 Bit Fields */
#define LTC_K80_LPKA1_6_PKHA_A1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA1_6_PKHA_A1_SHIFT            0
#define LTC_K80_LPKA1_6_PKHA_A1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA1_6_PKHA_A1_SHIFT))&LTC_K80_LPKA1_6_PKHA_A1_MASK)
/* LPKA1_7 Bit Fields */
#define LTC_K80_LPKA1_7_PKHA_A1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA1_7_PKHA_A1_SHIFT            0
#define LTC_K80_LPKA1_7_PKHA_A1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA1_7_PKHA_A1_SHIFT))&LTC_K80_LPKA1_7_PKHA_A1_MASK)
/* LPKA1_8 Bit Fields */
#define LTC_K80_LPKA1_8_PKHA_A1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA1_8_PKHA_A1_SHIFT            0
#define LTC_K80_LPKA1_8_PKHA_A1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA1_8_PKHA_A1_SHIFT))&LTC_K80_LPKA1_8_PKHA_A1_MASK)
/* LPKA1_9 Bit Fields */
#define LTC_K80_LPKA1_9_PKHA_A1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA1_9_PKHA_A1_SHIFT            0
#define LTC_K80_LPKA1_9_PKHA_A1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA1_9_PKHA_A1_SHIFT))&LTC_K80_LPKA1_9_PKHA_A1_MASK)
/* LPKA1_10 Bit Fields */
#define LTC_K80_LPKA1_10_PKHA_A1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA1_10_PKHA_A1_SHIFT           0
#define LTC_K80_LPKA1_10_PKHA_A1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA1_10_PKHA_A1_SHIFT))&LTC_K80_LPKA1_10_PKHA_A1_MASK)
/* LPKA1_11 Bit Fields */
#define LTC_K80_LPKA1_11_PKHA_A1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA1_11_PKHA_A1_SHIFT           0
#define LTC_K80_LPKA1_11_PKHA_A1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA1_11_PKHA_A1_SHIFT))&LTC_K80_LPKA1_11_PKHA_A1_MASK)
/* LPKA1_12 Bit Fields */
#define LTC_K80_LPKA1_12_PKHA_A1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA1_12_PKHA_A1_SHIFT           0
#define LTC_K80_LPKA1_12_PKHA_A1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA1_12_PKHA_A1_SHIFT))&LTC_K80_LPKA1_12_PKHA_A1_MASK)
/* LPKA1_13 Bit Fields */
#define LTC_K80_LPKA1_13_PKHA_A1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA1_13_PKHA_A1_SHIFT           0
#define LTC_K80_LPKA1_13_PKHA_A1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA1_13_PKHA_A1_SHIFT))&LTC_K80_LPKA1_13_PKHA_A1_MASK)
/* LPKA1_14 Bit Fields */
#define LTC_K80_LPKA1_14_PKHA_A1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA1_14_PKHA_A1_SHIFT           0
#define LTC_K80_LPKA1_14_PKHA_A1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA1_14_PKHA_A1_SHIFT))&LTC_K80_LPKA1_14_PKHA_A1_MASK)
/* LPKA1_15 Bit Fields */
#define LTC_K80_LPKA1_15_PKHA_A1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA1_15_PKHA_A1_SHIFT           0
#define LTC_K80_LPKA1_15_PKHA_A1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA1_15_PKHA_A1_SHIFT))&LTC_K80_LPKA1_15_PKHA_A1_MASK)
/* LPKA2_0 Bit Fields */
#define LTC_K80_LPKA2_0_PKHA_A2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA2_0_PKHA_A2_SHIFT            0
#define LTC_K80_LPKA2_0_PKHA_A2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA2_0_PKHA_A2_SHIFT))&LTC_K80_LPKA2_0_PKHA_A2_MASK)
/* LPKA2_1 Bit Fields */
#define LTC_K80_LPKA2_1_PKHA_A2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA2_1_PKHA_A2_SHIFT            0
#define LTC_K80_LPKA2_1_PKHA_A2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA2_1_PKHA_A2_SHIFT))&LTC_K80_LPKA2_1_PKHA_A2_MASK)
/* LPKA2_2 Bit Fields */
#define LTC_K80_LPKA2_2_PKHA_A2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA2_2_PKHA_A2_SHIFT            0
#define LTC_K80_LPKA2_2_PKHA_A2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA2_2_PKHA_A2_SHIFT))&LTC_K80_LPKA2_2_PKHA_A2_MASK)
/* LPKA2_3 Bit Fields */
#define LTC_K80_LPKA2_3_PKHA_A2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA2_3_PKHA_A2_SHIFT            0
#define LTC_K80_LPKA2_3_PKHA_A2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA2_3_PKHA_A2_SHIFT))&LTC_K80_LPKA2_3_PKHA_A2_MASK)
/* LPKA2_4 Bit Fields */
#define LTC_K80_LPKA2_4_PKHA_A2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA2_4_PKHA_A2_SHIFT            0
#define LTC_K80_LPKA2_4_PKHA_A2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA2_4_PKHA_A2_SHIFT))&LTC_K80_LPKA2_4_PKHA_A2_MASK)
/* LPKA2_5 Bit Fields */
#define LTC_K80_LPKA2_5_PKHA_A2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA2_5_PKHA_A2_SHIFT            0
#define LTC_K80_LPKA2_5_PKHA_A2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA2_5_PKHA_A2_SHIFT))&LTC_K80_LPKA2_5_PKHA_A2_MASK)
/* LPKA2_6 Bit Fields */
#define LTC_K80_LPKA2_6_PKHA_A2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA2_6_PKHA_A2_SHIFT            0
#define LTC_K80_LPKA2_6_PKHA_A2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA2_6_PKHA_A2_SHIFT))&LTC_K80_LPKA2_6_PKHA_A2_MASK)
/* LPKA2_7 Bit Fields */
#define LTC_K80_LPKA2_7_PKHA_A2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA2_7_PKHA_A2_SHIFT            0
#define LTC_K80_LPKA2_7_PKHA_A2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA2_7_PKHA_A2_SHIFT))&LTC_K80_LPKA2_7_PKHA_A2_MASK)
/* LPKA2_8 Bit Fields */
#define LTC_K80_LPKA2_8_PKHA_A2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA2_8_PKHA_A2_SHIFT            0
#define LTC_K80_LPKA2_8_PKHA_A2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA2_8_PKHA_A2_SHIFT))&LTC_K80_LPKA2_8_PKHA_A2_MASK)
/* LPKA2_9 Bit Fields */
#define LTC_K80_LPKA2_9_PKHA_A2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA2_9_PKHA_A2_SHIFT            0
#define LTC_K80_LPKA2_9_PKHA_A2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA2_9_PKHA_A2_SHIFT))&LTC_K80_LPKA2_9_PKHA_A2_MASK)
/* LPKA2_10 Bit Fields */
#define LTC_K80_LPKA2_10_PKHA_A2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA2_10_PKHA_A2_SHIFT           0
#define LTC_K80_LPKA2_10_PKHA_A2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA2_10_PKHA_A2_SHIFT))&LTC_K80_LPKA2_10_PKHA_A2_MASK)
/* LPKA2_11 Bit Fields */
#define LTC_K80_LPKA2_11_PKHA_A2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA2_11_PKHA_A2_SHIFT           0
#define LTC_K80_LPKA2_11_PKHA_A2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA2_11_PKHA_A2_SHIFT))&LTC_K80_LPKA2_11_PKHA_A2_MASK)
/* LPKA2_12 Bit Fields */
#define LTC_K80_LPKA2_12_PKHA_A2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA2_12_PKHA_A2_SHIFT           0
#define LTC_K80_LPKA2_12_PKHA_A2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA2_12_PKHA_A2_SHIFT))&LTC_K80_LPKA2_12_PKHA_A2_MASK)
/* LPKA2_13 Bit Fields */
#define LTC_K80_LPKA2_13_PKHA_A2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA2_13_PKHA_A2_SHIFT           0
#define LTC_K80_LPKA2_13_PKHA_A2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA2_13_PKHA_A2_SHIFT))&LTC_K80_LPKA2_13_PKHA_A2_MASK)
/* LPKA2_14 Bit Fields */
#define LTC_K80_LPKA2_14_PKHA_A2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA2_14_PKHA_A2_SHIFT           0
#define LTC_K80_LPKA2_14_PKHA_A2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA2_14_PKHA_A2_SHIFT))&LTC_K80_LPKA2_14_PKHA_A2_MASK)
/* LPKA2_15 Bit Fields */
#define LTC_K80_LPKA2_15_PKHA_A2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA2_15_PKHA_A2_SHIFT           0
#define LTC_K80_LPKA2_15_PKHA_A2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA2_15_PKHA_A2_SHIFT))&LTC_K80_LPKA2_15_PKHA_A2_MASK)
/* LPKA3_0 Bit Fields */
#define LTC_K80_LPKA3_0_PKHA_A3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA3_0_PKHA_A3_SHIFT            0
#define LTC_K80_LPKA3_0_PKHA_A3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA3_0_PKHA_A3_SHIFT))&LTC_K80_LPKA3_0_PKHA_A3_MASK)
/* LPKA3_1 Bit Fields */
#define LTC_K80_LPKA3_1_PKHA_A3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA3_1_PKHA_A3_SHIFT            0
#define LTC_K80_LPKA3_1_PKHA_A3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA3_1_PKHA_A3_SHIFT))&LTC_K80_LPKA3_1_PKHA_A3_MASK)
/* LPKA3_2 Bit Fields */
#define LTC_K80_LPKA3_2_PKHA_A3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA3_2_PKHA_A3_SHIFT            0
#define LTC_K80_LPKA3_2_PKHA_A3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA3_2_PKHA_A3_SHIFT))&LTC_K80_LPKA3_2_PKHA_A3_MASK)
/* LPKA3_3 Bit Fields */
#define LTC_K80_LPKA3_3_PKHA_A3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA3_3_PKHA_A3_SHIFT            0
#define LTC_K80_LPKA3_3_PKHA_A3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA3_3_PKHA_A3_SHIFT))&LTC_K80_LPKA3_3_PKHA_A3_MASK)
/* LPKA3_4 Bit Fields */
#define LTC_K80_LPKA3_4_PKHA_A3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA3_4_PKHA_A3_SHIFT            0
#define LTC_K80_LPKA3_4_PKHA_A3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA3_4_PKHA_A3_SHIFT))&LTC_K80_LPKA3_4_PKHA_A3_MASK)
/* LPKA3_5 Bit Fields */
#define LTC_K80_LPKA3_5_PKHA_A3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA3_5_PKHA_A3_SHIFT            0
#define LTC_K80_LPKA3_5_PKHA_A3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA3_5_PKHA_A3_SHIFT))&LTC_K80_LPKA3_5_PKHA_A3_MASK)
/* LPKA3_6 Bit Fields */
#define LTC_K80_LPKA3_6_PKHA_A3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA3_6_PKHA_A3_SHIFT            0
#define LTC_K80_LPKA3_6_PKHA_A3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA3_6_PKHA_A3_SHIFT))&LTC_K80_LPKA3_6_PKHA_A3_MASK)
/* LPKA3_7 Bit Fields */
#define LTC_K80_LPKA3_7_PKHA_A3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA3_7_PKHA_A3_SHIFT            0
#define LTC_K80_LPKA3_7_PKHA_A3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA3_7_PKHA_A3_SHIFT))&LTC_K80_LPKA3_7_PKHA_A3_MASK)
/* LPKA3_8 Bit Fields */
#define LTC_K80_LPKA3_8_PKHA_A3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA3_8_PKHA_A3_SHIFT            0
#define LTC_K80_LPKA3_8_PKHA_A3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA3_8_PKHA_A3_SHIFT))&LTC_K80_LPKA3_8_PKHA_A3_MASK)
/* LPKA3_9 Bit Fields */
#define LTC_K80_LPKA3_9_PKHA_A3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKA3_9_PKHA_A3_SHIFT            0
#define LTC_K80_LPKA3_9_PKHA_A3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA3_9_PKHA_A3_SHIFT))&LTC_K80_LPKA3_9_PKHA_A3_MASK)
/* LPKA3_10 Bit Fields */
#define LTC_K80_LPKA3_10_PKHA_A3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA3_10_PKHA_A3_SHIFT           0
#define LTC_K80_LPKA3_10_PKHA_A3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA3_10_PKHA_A3_SHIFT))&LTC_K80_LPKA3_10_PKHA_A3_MASK)
/* LPKA3_11 Bit Fields */
#define LTC_K80_LPKA3_11_PKHA_A3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA3_11_PKHA_A3_SHIFT           0
#define LTC_K80_LPKA3_11_PKHA_A3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA3_11_PKHA_A3_SHIFT))&LTC_K80_LPKA3_11_PKHA_A3_MASK)
/* LPKA3_12 Bit Fields */
#define LTC_K80_LPKA3_12_PKHA_A3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA3_12_PKHA_A3_SHIFT           0
#define LTC_K80_LPKA3_12_PKHA_A3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA3_12_PKHA_A3_SHIFT))&LTC_K80_LPKA3_12_PKHA_A3_MASK)
/* LPKA3_13 Bit Fields */
#define LTC_K80_LPKA3_13_PKHA_A3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA3_13_PKHA_A3_SHIFT           0
#define LTC_K80_LPKA3_13_PKHA_A3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA3_13_PKHA_A3_SHIFT))&LTC_K80_LPKA3_13_PKHA_A3_MASK)
/* LPKA3_14 Bit Fields */
#define LTC_K80_LPKA3_14_PKHA_A3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA3_14_PKHA_A3_SHIFT           0
#define LTC_K80_LPKA3_14_PKHA_A3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA3_14_PKHA_A3_SHIFT))&LTC_K80_LPKA3_14_PKHA_A3_MASK)
/* LPKA3_15 Bit Fields */
#define LTC_K80_LPKA3_15_PKHA_A3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKA3_15_PKHA_A3_SHIFT           0
#define LTC_K80_LPKA3_15_PKHA_A3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKA3_15_PKHA_A3_SHIFT))&LTC_K80_LPKA3_15_PKHA_A3_MASK)
/* LPKB0_0 Bit Fields */
#define LTC_K80_LPKB0_0_PKHA_B0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB0_0_PKHA_B0_SHIFT            0
#define LTC_K80_LPKB0_0_PKHA_B0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB0_0_PKHA_B0_SHIFT))&LTC_K80_LPKB0_0_PKHA_B0_MASK)
/* LPKB0_1 Bit Fields */
#define LTC_K80_LPKB0_1_PKHA_B0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB0_1_PKHA_B0_SHIFT            0
#define LTC_K80_LPKB0_1_PKHA_B0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB0_1_PKHA_B0_SHIFT))&LTC_K80_LPKB0_1_PKHA_B0_MASK)
/* LPKB0_2 Bit Fields */
#define LTC_K80_LPKB0_2_PKHA_B0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB0_2_PKHA_B0_SHIFT            0
#define LTC_K80_LPKB0_2_PKHA_B0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB0_2_PKHA_B0_SHIFT))&LTC_K80_LPKB0_2_PKHA_B0_MASK)
/* LPKB0_3 Bit Fields */
#define LTC_K80_LPKB0_3_PKHA_B0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB0_3_PKHA_B0_SHIFT            0
#define LTC_K80_LPKB0_3_PKHA_B0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB0_3_PKHA_B0_SHIFT))&LTC_K80_LPKB0_3_PKHA_B0_MASK)
/* LPKB0_4 Bit Fields */
#define LTC_K80_LPKB0_4_PKHA_B0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB0_4_PKHA_B0_SHIFT            0
#define LTC_K80_LPKB0_4_PKHA_B0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB0_4_PKHA_B0_SHIFT))&LTC_K80_LPKB0_4_PKHA_B0_MASK)
/* LPKB0_5 Bit Fields */
#define LTC_K80_LPKB0_5_PKHA_B0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB0_5_PKHA_B0_SHIFT            0
#define LTC_K80_LPKB0_5_PKHA_B0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB0_5_PKHA_B0_SHIFT))&LTC_K80_LPKB0_5_PKHA_B0_MASK)
/* LPKB0_6 Bit Fields */
#define LTC_K80_LPKB0_6_PKHA_B0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB0_6_PKHA_B0_SHIFT            0
#define LTC_K80_LPKB0_6_PKHA_B0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB0_6_PKHA_B0_SHIFT))&LTC_K80_LPKB0_6_PKHA_B0_MASK)
/* LPKB0_7 Bit Fields */
#define LTC_K80_LPKB0_7_PKHA_B0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB0_7_PKHA_B0_SHIFT            0
#define LTC_K80_LPKB0_7_PKHA_B0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB0_7_PKHA_B0_SHIFT))&LTC_K80_LPKB0_7_PKHA_B0_MASK)
/* LPKB0_8 Bit Fields */
#define LTC_K80_LPKB0_8_PKHA_B0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB0_8_PKHA_B0_SHIFT            0
#define LTC_K80_LPKB0_8_PKHA_B0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB0_8_PKHA_B0_SHIFT))&LTC_K80_LPKB0_8_PKHA_B0_MASK)
/* LPKB0_9 Bit Fields */
#define LTC_K80_LPKB0_9_PKHA_B0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB0_9_PKHA_B0_SHIFT            0
#define LTC_K80_LPKB0_9_PKHA_B0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB0_9_PKHA_B0_SHIFT))&LTC_K80_LPKB0_9_PKHA_B0_MASK)
/* LPKB0_10 Bit Fields */
#define LTC_K80_LPKB0_10_PKHA_B0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB0_10_PKHA_B0_SHIFT           0
#define LTC_K80_LPKB0_10_PKHA_B0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB0_10_PKHA_B0_SHIFT))&LTC_K80_LPKB0_10_PKHA_B0_MASK)
/* LPKB0_11 Bit Fields */
#define LTC_K80_LPKB0_11_PKHA_B0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB0_11_PKHA_B0_SHIFT           0
#define LTC_K80_LPKB0_11_PKHA_B0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB0_11_PKHA_B0_SHIFT))&LTC_K80_LPKB0_11_PKHA_B0_MASK)
/* LPKB0_12 Bit Fields */
#define LTC_K80_LPKB0_12_PKHA_B0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB0_12_PKHA_B0_SHIFT           0
#define LTC_K80_LPKB0_12_PKHA_B0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB0_12_PKHA_B0_SHIFT))&LTC_K80_LPKB0_12_PKHA_B0_MASK)
/* LPKB0_13 Bit Fields */
#define LTC_K80_LPKB0_13_PKHA_B0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB0_13_PKHA_B0_SHIFT           0
#define LTC_K80_LPKB0_13_PKHA_B0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB0_13_PKHA_B0_SHIFT))&LTC_K80_LPKB0_13_PKHA_B0_MASK)
/* LPKB0_14 Bit Fields */
#define LTC_K80_LPKB0_14_PKHA_B0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB0_14_PKHA_B0_SHIFT           0
#define LTC_K80_LPKB0_14_PKHA_B0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB0_14_PKHA_B0_SHIFT))&LTC_K80_LPKB0_14_PKHA_B0_MASK)
/* LPKB0_15 Bit Fields */
#define LTC_K80_LPKB0_15_PKHA_B0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB0_15_PKHA_B0_SHIFT           0
#define LTC_K80_LPKB0_15_PKHA_B0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB0_15_PKHA_B0_SHIFT))&LTC_K80_LPKB0_15_PKHA_B0_MASK)
/* LPKB1_0 Bit Fields */
#define LTC_K80_LPKB1_0_PKHA_B1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB1_0_PKHA_B1_SHIFT            0
#define LTC_K80_LPKB1_0_PKHA_B1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB1_0_PKHA_B1_SHIFT))&LTC_K80_LPKB1_0_PKHA_B1_MASK)
/* LPKB1_1 Bit Fields */
#define LTC_K80_LPKB1_1_PKHA_B1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB1_1_PKHA_B1_SHIFT            0
#define LTC_K80_LPKB1_1_PKHA_B1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB1_1_PKHA_B1_SHIFT))&LTC_K80_LPKB1_1_PKHA_B1_MASK)
/* LPKB1_2 Bit Fields */
#define LTC_K80_LPKB1_2_PKHA_B1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB1_2_PKHA_B1_SHIFT            0
#define LTC_K80_LPKB1_2_PKHA_B1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB1_2_PKHA_B1_SHIFT))&LTC_K80_LPKB1_2_PKHA_B1_MASK)
/* LPKB1_3 Bit Fields */
#define LTC_K80_LPKB1_3_PKHA_B1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB1_3_PKHA_B1_SHIFT            0
#define LTC_K80_LPKB1_3_PKHA_B1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB1_3_PKHA_B1_SHIFT))&LTC_K80_LPKB1_3_PKHA_B1_MASK)
/* LPKB1_4 Bit Fields */
#define LTC_K80_LPKB1_4_PKHA_B1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB1_4_PKHA_B1_SHIFT            0
#define LTC_K80_LPKB1_4_PKHA_B1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB1_4_PKHA_B1_SHIFT))&LTC_K80_LPKB1_4_PKHA_B1_MASK)
/* LPKB1_5 Bit Fields */
#define LTC_K80_LPKB1_5_PKHA_B1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB1_5_PKHA_B1_SHIFT            0
#define LTC_K80_LPKB1_5_PKHA_B1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB1_5_PKHA_B1_SHIFT))&LTC_K80_LPKB1_5_PKHA_B1_MASK)
/* LPKB1_6 Bit Fields */
#define LTC_K80_LPKB1_6_PKHA_B1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB1_6_PKHA_B1_SHIFT            0
#define LTC_K80_LPKB1_6_PKHA_B1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB1_6_PKHA_B1_SHIFT))&LTC_K80_LPKB1_6_PKHA_B1_MASK)
/* LPKB1_7 Bit Fields */
#define LTC_K80_LPKB1_7_PKHA_B1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB1_7_PKHA_B1_SHIFT            0
#define LTC_K80_LPKB1_7_PKHA_B1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB1_7_PKHA_B1_SHIFT))&LTC_K80_LPKB1_7_PKHA_B1_MASK)
/* LPKB1_8 Bit Fields */
#define LTC_K80_LPKB1_8_PKHA_B1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB1_8_PKHA_B1_SHIFT            0
#define LTC_K80_LPKB1_8_PKHA_B1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB1_8_PKHA_B1_SHIFT))&LTC_K80_LPKB1_8_PKHA_B1_MASK)
/* LPKB1_9 Bit Fields */
#define LTC_K80_LPKB1_9_PKHA_B1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB1_9_PKHA_B1_SHIFT            0
#define LTC_K80_LPKB1_9_PKHA_B1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB1_9_PKHA_B1_SHIFT))&LTC_K80_LPKB1_9_PKHA_B1_MASK)
/* LPKB1_10 Bit Fields */
#define LTC_K80_LPKB1_10_PKHA_B1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB1_10_PKHA_B1_SHIFT           0
#define LTC_K80_LPKB1_10_PKHA_B1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB1_10_PKHA_B1_SHIFT))&LTC_K80_LPKB1_10_PKHA_B1_MASK)
/* LPKB1_11 Bit Fields */
#define LTC_K80_LPKB1_11_PKHA_B1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB1_11_PKHA_B1_SHIFT           0
#define LTC_K80_LPKB1_11_PKHA_B1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB1_11_PKHA_B1_SHIFT))&LTC_K80_LPKB1_11_PKHA_B1_MASK)
/* LPKB1_12 Bit Fields */
#define LTC_K80_LPKB1_12_PKHA_B1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB1_12_PKHA_B1_SHIFT           0
#define LTC_K80_LPKB1_12_PKHA_B1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB1_12_PKHA_B1_SHIFT))&LTC_K80_LPKB1_12_PKHA_B1_MASK)
/* LPKB1_13 Bit Fields */
#define LTC_K80_LPKB1_13_PKHA_B1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB1_13_PKHA_B1_SHIFT           0
#define LTC_K80_LPKB1_13_PKHA_B1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB1_13_PKHA_B1_SHIFT))&LTC_K80_LPKB1_13_PKHA_B1_MASK)
/* LPKB1_14 Bit Fields */
#define LTC_K80_LPKB1_14_PKHA_B1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB1_14_PKHA_B1_SHIFT           0
#define LTC_K80_LPKB1_14_PKHA_B1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB1_14_PKHA_B1_SHIFT))&LTC_K80_LPKB1_14_PKHA_B1_MASK)
/* LPKB1_15 Bit Fields */
#define LTC_K80_LPKB1_15_PKHA_B1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB1_15_PKHA_B1_SHIFT           0
#define LTC_K80_LPKB1_15_PKHA_B1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB1_15_PKHA_B1_SHIFT))&LTC_K80_LPKB1_15_PKHA_B1_MASK)
/* LPKB2_0 Bit Fields */
#define LTC_K80_LPKB2_0_PKHA_B2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB2_0_PKHA_B2_SHIFT            0
#define LTC_K80_LPKB2_0_PKHA_B2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB2_0_PKHA_B2_SHIFT))&LTC_K80_LPKB2_0_PKHA_B2_MASK)
/* LPKB2_1 Bit Fields */
#define LTC_K80_LPKB2_1_PKHA_B2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB2_1_PKHA_B2_SHIFT            0
#define LTC_K80_LPKB2_1_PKHA_B2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB2_1_PKHA_B2_SHIFT))&LTC_K80_LPKB2_1_PKHA_B2_MASK)
/* LPKB2_2 Bit Fields */
#define LTC_K80_LPKB2_2_PKHA_B2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB2_2_PKHA_B2_SHIFT            0
#define LTC_K80_LPKB2_2_PKHA_B2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB2_2_PKHA_B2_SHIFT))&LTC_K80_LPKB2_2_PKHA_B2_MASK)
/* LPKB2_3 Bit Fields */
#define LTC_K80_LPKB2_3_PKHA_B2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB2_3_PKHA_B2_SHIFT            0
#define LTC_K80_LPKB2_3_PKHA_B2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB2_3_PKHA_B2_SHIFT))&LTC_K80_LPKB2_3_PKHA_B2_MASK)
/* LPKB2_4 Bit Fields */
#define LTC_K80_LPKB2_4_PKHA_B2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB2_4_PKHA_B2_SHIFT            0
#define LTC_K80_LPKB2_4_PKHA_B2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB2_4_PKHA_B2_SHIFT))&LTC_K80_LPKB2_4_PKHA_B2_MASK)
/* LPKB2_5 Bit Fields */
#define LTC_K80_LPKB2_5_PKHA_B2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB2_5_PKHA_B2_SHIFT            0
#define LTC_K80_LPKB2_5_PKHA_B2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB2_5_PKHA_B2_SHIFT))&LTC_K80_LPKB2_5_PKHA_B2_MASK)
/* LPKB2_6 Bit Fields */
#define LTC_K80_LPKB2_6_PKHA_B2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB2_6_PKHA_B2_SHIFT            0
#define LTC_K80_LPKB2_6_PKHA_B2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB2_6_PKHA_B2_SHIFT))&LTC_K80_LPKB2_6_PKHA_B2_MASK)
/* LPKB2_7 Bit Fields */
#define LTC_K80_LPKB2_7_PKHA_B2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB2_7_PKHA_B2_SHIFT            0
#define LTC_K80_LPKB2_7_PKHA_B2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB2_7_PKHA_B2_SHIFT))&LTC_K80_LPKB2_7_PKHA_B2_MASK)
/* LPKB2_8 Bit Fields */
#define LTC_K80_LPKB2_8_PKHA_B2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB2_8_PKHA_B2_SHIFT            0
#define LTC_K80_LPKB2_8_PKHA_B2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB2_8_PKHA_B2_SHIFT))&LTC_K80_LPKB2_8_PKHA_B2_MASK)
/* LPKB2_9 Bit Fields */
#define LTC_K80_LPKB2_9_PKHA_B2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB2_9_PKHA_B2_SHIFT            0
#define LTC_K80_LPKB2_9_PKHA_B2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB2_9_PKHA_B2_SHIFT))&LTC_K80_LPKB2_9_PKHA_B2_MASK)
/* LPKB2_10 Bit Fields */
#define LTC_K80_LPKB2_10_PKHA_B2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB2_10_PKHA_B2_SHIFT           0
#define LTC_K80_LPKB2_10_PKHA_B2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB2_10_PKHA_B2_SHIFT))&LTC_K80_LPKB2_10_PKHA_B2_MASK)
/* LPKB2_11 Bit Fields */
#define LTC_K80_LPKB2_11_PKHA_B2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB2_11_PKHA_B2_SHIFT           0
#define LTC_K80_LPKB2_11_PKHA_B2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB2_11_PKHA_B2_SHIFT))&LTC_K80_LPKB2_11_PKHA_B2_MASK)
/* LPKB2_12 Bit Fields */
#define LTC_K80_LPKB2_12_PKHA_B2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB2_12_PKHA_B2_SHIFT           0
#define LTC_K80_LPKB2_12_PKHA_B2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB2_12_PKHA_B2_SHIFT))&LTC_K80_LPKB2_12_PKHA_B2_MASK)
/* LPKB2_13 Bit Fields */
#define LTC_K80_LPKB2_13_PKHA_B2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB2_13_PKHA_B2_SHIFT           0
#define LTC_K80_LPKB2_13_PKHA_B2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB2_13_PKHA_B2_SHIFT))&LTC_K80_LPKB2_13_PKHA_B2_MASK)
/* LPKB2_14 Bit Fields */
#define LTC_K80_LPKB2_14_PKHA_B2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB2_14_PKHA_B2_SHIFT           0
#define LTC_K80_LPKB2_14_PKHA_B2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB2_14_PKHA_B2_SHIFT))&LTC_K80_LPKB2_14_PKHA_B2_MASK)
/* LPKB2_15 Bit Fields */
#define LTC_K80_LPKB2_15_PKHA_B2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB2_15_PKHA_B2_SHIFT           0
#define LTC_K80_LPKB2_15_PKHA_B2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB2_15_PKHA_B2_SHIFT))&LTC_K80_LPKB2_15_PKHA_B2_MASK)
/* LPKB3_0 Bit Fields */
#define LTC_K80_LPKB3_0_PKHA_B3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB3_0_PKHA_B3_SHIFT            0
#define LTC_K80_LPKB3_0_PKHA_B3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB3_0_PKHA_B3_SHIFT))&LTC_K80_LPKB3_0_PKHA_B3_MASK)
/* LPKB3_1 Bit Fields */
#define LTC_K80_LPKB3_1_PKHA_B3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB3_1_PKHA_B3_SHIFT            0
#define LTC_K80_LPKB3_1_PKHA_B3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB3_1_PKHA_B3_SHIFT))&LTC_K80_LPKB3_1_PKHA_B3_MASK)
/* LPKB3_2 Bit Fields */
#define LTC_K80_LPKB3_2_PKHA_B3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB3_2_PKHA_B3_SHIFT            0
#define LTC_K80_LPKB3_2_PKHA_B3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB3_2_PKHA_B3_SHIFT))&LTC_K80_LPKB3_2_PKHA_B3_MASK)
/* LPKB3_3 Bit Fields */
#define LTC_K80_LPKB3_3_PKHA_B3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB3_3_PKHA_B3_SHIFT            0
#define LTC_K80_LPKB3_3_PKHA_B3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB3_3_PKHA_B3_SHIFT))&LTC_K80_LPKB3_3_PKHA_B3_MASK)
/* LPKB3_4 Bit Fields */
#define LTC_K80_LPKB3_4_PKHA_B3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB3_4_PKHA_B3_SHIFT            0
#define LTC_K80_LPKB3_4_PKHA_B3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB3_4_PKHA_B3_SHIFT))&LTC_K80_LPKB3_4_PKHA_B3_MASK)
/* LPKB3_5 Bit Fields */
#define LTC_K80_LPKB3_5_PKHA_B3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB3_5_PKHA_B3_SHIFT            0
#define LTC_K80_LPKB3_5_PKHA_B3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB3_5_PKHA_B3_SHIFT))&LTC_K80_LPKB3_5_PKHA_B3_MASK)
/* LPKB3_6 Bit Fields */
#define LTC_K80_LPKB3_6_PKHA_B3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB3_6_PKHA_B3_SHIFT            0
#define LTC_K80_LPKB3_6_PKHA_B3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB3_6_PKHA_B3_SHIFT))&LTC_K80_LPKB3_6_PKHA_B3_MASK)
/* LPKB3_7 Bit Fields */
#define LTC_K80_LPKB3_7_PKHA_B3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB3_7_PKHA_B3_SHIFT            0
#define LTC_K80_LPKB3_7_PKHA_B3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB3_7_PKHA_B3_SHIFT))&LTC_K80_LPKB3_7_PKHA_B3_MASK)
/* LPKB3_8 Bit Fields */
#define LTC_K80_LPKB3_8_PKHA_B3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB3_8_PKHA_B3_SHIFT            0
#define LTC_K80_LPKB3_8_PKHA_B3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB3_8_PKHA_B3_SHIFT))&LTC_K80_LPKB3_8_PKHA_B3_MASK)
/* LPKB3_9 Bit Fields */
#define LTC_K80_LPKB3_9_PKHA_B3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKB3_9_PKHA_B3_SHIFT            0
#define LTC_K80_LPKB3_9_PKHA_B3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB3_9_PKHA_B3_SHIFT))&LTC_K80_LPKB3_9_PKHA_B3_MASK)
/* LPKB3_10 Bit Fields */
#define LTC_K80_LPKB3_10_PKHA_B3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB3_10_PKHA_B3_SHIFT           0
#define LTC_K80_LPKB3_10_PKHA_B3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB3_10_PKHA_B3_SHIFT))&LTC_K80_LPKB3_10_PKHA_B3_MASK)
/* LPKB3_11 Bit Fields */
#define LTC_K80_LPKB3_11_PKHA_B3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB3_11_PKHA_B3_SHIFT           0
#define LTC_K80_LPKB3_11_PKHA_B3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB3_11_PKHA_B3_SHIFT))&LTC_K80_LPKB3_11_PKHA_B3_MASK)
/* LPKB3_12 Bit Fields */
#define LTC_K80_LPKB3_12_PKHA_B3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB3_12_PKHA_B3_SHIFT           0
#define LTC_K80_LPKB3_12_PKHA_B3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB3_12_PKHA_B3_SHIFT))&LTC_K80_LPKB3_12_PKHA_B3_MASK)
/* LPKB3_13 Bit Fields */
#define LTC_K80_LPKB3_13_PKHA_B3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB3_13_PKHA_B3_SHIFT           0
#define LTC_K80_LPKB3_13_PKHA_B3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB3_13_PKHA_B3_SHIFT))&LTC_K80_LPKB3_13_PKHA_B3_MASK)
/* LPKB3_14 Bit Fields */
#define LTC_K80_LPKB3_14_PKHA_B3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB3_14_PKHA_B3_SHIFT           0
#define LTC_K80_LPKB3_14_PKHA_B3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB3_14_PKHA_B3_SHIFT))&LTC_K80_LPKB3_14_PKHA_B3_MASK)
/* LPKB3_15 Bit Fields */
#define LTC_K80_LPKB3_15_PKHA_B3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKB3_15_PKHA_B3_SHIFT           0
#define LTC_K80_LPKB3_15_PKHA_B3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKB3_15_PKHA_B3_SHIFT))&LTC_K80_LPKB3_15_PKHA_B3_MASK)
/* LPKN0_0 Bit Fields */
#define LTC_K80_LPKN0_0_PKHA_N0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN0_0_PKHA_N0_SHIFT            0
#define LTC_K80_LPKN0_0_PKHA_N0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN0_0_PKHA_N0_SHIFT))&LTC_K80_LPKN0_0_PKHA_N0_MASK)
/* LPKN0_1 Bit Fields */
#define LTC_K80_LPKN0_1_PKHA_N0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN0_1_PKHA_N0_SHIFT            0
#define LTC_K80_LPKN0_1_PKHA_N0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN0_1_PKHA_N0_SHIFT))&LTC_K80_LPKN0_1_PKHA_N0_MASK)
/* LPKN0_2 Bit Fields */
#define LTC_K80_LPKN0_2_PKHA_N0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN0_2_PKHA_N0_SHIFT            0
#define LTC_K80_LPKN0_2_PKHA_N0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN0_2_PKHA_N0_SHIFT))&LTC_K80_LPKN0_2_PKHA_N0_MASK)
/* LPKN0_3 Bit Fields */
#define LTC_K80_LPKN0_3_PKHA_N0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN0_3_PKHA_N0_SHIFT            0
#define LTC_K80_LPKN0_3_PKHA_N0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN0_3_PKHA_N0_SHIFT))&LTC_K80_LPKN0_3_PKHA_N0_MASK)
/* LPKN0_4 Bit Fields */
#define LTC_K80_LPKN0_4_PKHA_N0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN0_4_PKHA_N0_SHIFT            0
#define LTC_K80_LPKN0_4_PKHA_N0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN0_4_PKHA_N0_SHIFT))&LTC_K80_LPKN0_4_PKHA_N0_MASK)
/* LPKN0_5 Bit Fields */
#define LTC_K80_LPKN0_5_PKHA_N0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN0_5_PKHA_N0_SHIFT            0
#define LTC_K80_LPKN0_5_PKHA_N0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN0_5_PKHA_N0_SHIFT))&LTC_K80_LPKN0_5_PKHA_N0_MASK)
/* LPKN0_6 Bit Fields */
#define LTC_K80_LPKN0_6_PKHA_N0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN0_6_PKHA_N0_SHIFT            0
#define LTC_K80_LPKN0_6_PKHA_N0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN0_6_PKHA_N0_SHIFT))&LTC_K80_LPKN0_6_PKHA_N0_MASK)
/* LPKN0_7 Bit Fields */
#define LTC_K80_LPKN0_7_PKHA_N0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN0_7_PKHA_N0_SHIFT            0
#define LTC_K80_LPKN0_7_PKHA_N0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN0_7_PKHA_N0_SHIFT))&LTC_K80_LPKN0_7_PKHA_N0_MASK)
/* LPKN0_8 Bit Fields */
#define LTC_K80_LPKN0_8_PKHA_N0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN0_8_PKHA_N0_SHIFT            0
#define LTC_K80_LPKN0_8_PKHA_N0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN0_8_PKHA_N0_SHIFT))&LTC_K80_LPKN0_8_PKHA_N0_MASK)
/* LPKN0_9 Bit Fields */
#define LTC_K80_LPKN0_9_PKHA_N0_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN0_9_PKHA_N0_SHIFT            0
#define LTC_K80_LPKN0_9_PKHA_N0(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN0_9_PKHA_N0_SHIFT))&LTC_K80_LPKN0_9_PKHA_N0_MASK)
/* LPKN0_10 Bit Fields */
#define LTC_K80_LPKN0_10_PKHA_N0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN0_10_PKHA_N0_SHIFT           0
#define LTC_K80_LPKN0_10_PKHA_N0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN0_10_PKHA_N0_SHIFT))&LTC_K80_LPKN0_10_PKHA_N0_MASK)
/* LPKN0_11 Bit Fields */
#define LTC_K80_LPKN0_11_PKHA_N0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN0_11_PKHA_N0_SHIFT           0
#define LTC_K80_LPKN0_11_PKHA_N0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN0_11_PKHA_N0_SHIFT))&LTC_K80_LPKN0_11_PKHA_N0_MASK)
/* LPKN0_12 Bit Fields */
#define LTC_K80_LPKN0_12_PKHA_N0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN0_12_PKHA_N0_SHIFT           0
#define LTC_K80_LPKN0_12_PKHA_N0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN0_12_PKHA_N0_SHIFT))&LTC_K80_LPKN0_12_PKHA_N0_MASK)
/* LPKN0_13 Bit Fields */
#define LTC_K80_LPKN0_13_PKHA_N0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN0_13_PKHA_N0_SHIFT           0
#define LTC_K80_LPKN0_13_PKHA_N0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN0_13_PKHA_N0_SHIFT))&LTC_K80_LPKN0_13_PKHA_N0_MASK)
/* LPKN0_14 Bit Fields */
#define LTC_K80_LPKN0_14_PKHA_N0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN0_14_PKHA_N0_SHIFT           0
#define LTC_K80_LPKN0_14_PKHA_N0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN0_14_PKHA_N0_SHIFT))&LTC_K80_LPKN0_14_PKHA_N0_MASK)
/* LPKN0_15 Bit Fields */
#define LTC_K80_LPKN0_15_PKHA_N0_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN0_15_PKHA_N0_SHIFT           0
#define LTC_K80_LPKN0_15_PKHA_N0(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN0_15_PKHA_N0_SHIFT))&LTC_K80_LPKN0_15_PKHA_N0_MASK)
/* LPKN1_0 Bit Fields */
#define LTC_K80_LPKN1_0_PKHA_N1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN1_0_PKHA_N1_SHIFT            0
#define LTC_K80_LPKN1_0_PKHA_N1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN1_0_PKHA_N1_SHIFT))&LTC_K80_LPKN1_0_PKHA_N1_MASK)
/* LPKN1_1 Bit Fields */
#define LTC_K80_LPKN1_1_PKHA_N1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN1_1_PKHA_N1_SHIFT            0
#define LTC_K80_LPKN1_1_PKHA_N1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN1_1_PKHA_N1_SHIFT))&LTC_K80_LPKN1_1_PKHA_N1_MASK)
/* LPKN1_2 Bit Fields */
#define LTC_K80_LPKN1_2_PKHA_N1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN1_2_PKHA_N1_SHIFT            0
#define LTC_K80_LPKN1_2_PKHA_N1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN1_2_PKHA_N1_SHIFT))&LTC_K80_LPKN1_2_PKHA_N1_MASK)
/* LPKN1_3 Bit Fields */
#define LTC_K80_LPKN1_3_PKHA_N1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN1_3_PKHA_N1_SHIFT            0
#define LTC_K80_LPKN1_3_PKHA_N1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN1_3_PKHA_N1_SHIFT))&LTC_K80_LPKN1_3_PKHA_N1_MASK)
/* LPKN1_4 Bit Fields */
#define LTC_K80_LPKN1_4_PKHA_N1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN1_4_PKHA_N1_SHIFT            0
#define LTC_K80_LPKN1_4_PKHA_N1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN1_4_PKHA_N1_SHIFT))&LTC_K80_LPKN1_4_PKHA_N1_MASK)
/* LPKN1_5 Bit Fields */
#define LTC_K80_LPKN1_5_PKHA_N1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN1_5_PKHA_N1_SHIFT            0
#define LTC_K80_LPKN1_5_PKHA_N1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN1_5_PKHA_N1_SHIFT))&LTC_K80_LPKN1_5_PKHA_N1_MASK)
/* LPKN1_6 Bit Fields */
#define LTC_K80_LPKN1_6_PKHA_N1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN1_6_PKHA_N1_SHIFT            0
#define LTC_K80_LPKN1_6_PKHA_N1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN1_6_PKHA_N1_SHIFT))&LTC_K80_LPKN1_6_PKHA_N1_MASK)
/* LPKN1_7 Bit Fields */
#define LTC_K80_LPKN1_7_PKHA_N1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN1_7_PKHA_N1_SHIFT            0
#define LTC_K80_LPKN1_7_PKHA_N1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN1_7_PKHA_N1_SHIFT))&LTC_K80_LPKN1_7_PKHA_N1_MASK)
/* LPKN1_8 Bit Fields */
#define LTC_K80_LPKN1_8_PKHA_N1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN1_8_PKHA_N1_SHIFT            0
#define LTC_K80_LPKN1_8_PKHA_N1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN1_8_PKHA_N1_SHIFT))&LTC_K80_LPKN1_8_PKHA_N1_MASK)
/* LPKN1_9 Bit Fields */
#define LTC_K80_LPKN1_9_PKHA_N1_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN1_9_PKHA_N1_SHIFT            0
#define LTC_K80_LPKN1_9_PKHA_N1(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN1_9_PKHA_N1_SHIFT))&LTC_K80_LPKN1_9_PKHA_N1_MASK)
/* LPKN1_10 Bit Fields */
#define LTC_K80_LPKN1_10_PKHA_N1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN1_10_PKHA_N1_SHIFT           0
#define LTC_K80_LPKN1_10_PKHA_N1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN1_10_PKHA_N1_SHIFT))&LTC_K80_LPKN1_10_PKHA_N1_MASK)
/* LPKN1_11 Bit Fields */
#define LTC_K80_LPKN1_11_PKHA_N1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN1_11_PKHA_N1_SHIFT           0
#define LTC_K80_LPKN1_11_PKHA_N1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN1_11_PKHA_N1_SHIFT))&LTC_K80_LPKN1_11_PKHA_N1_MASK)
/* LPKN1_12 Bit Fields */
#define LTC_K80_LPKN1_12_PKHA_N1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN1_12_PKHA_N1_SHIFT           0
#define LTC_K80_LPKN1_12_PKHA_N1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN1_12_PKHA_N1_SHIFT))&LTC_K80_LPKN1_12_PKHA_N1_MASK)
/* LPKN1_13 Bit Fields */
#define LTC_K80_LPKN1_13_PKHA_N1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN1_13_PKHA_N1_SHIFT           0
#define LTC_K80_LPKN1_13_PKHA_N1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN1_13_PKHA_N1_SHIFT))&LTC_K80_LPKN1_13_PKHA_N1_MASK)
/* LPKN1_14 Bit Fields */
#define LTC_K80_LPKN1_14_PKHA_N1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN1_14_PKHA_N1_SHIFT           0
#define LTC_K80_LPKN1_14_PKHA_N1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN1_14_PKHA_N1_SHIFT))&LTC_K80_LPKN1_14_PKHA_N1_MASK)
/* LPKN1_15 Bit Fields */
#define LTC_K80_LPKN1_15_PKHA_N1_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN1_15_PKHA_N1_SHIFT           0
#define LTC_K80_LPKN1_15_PKHA_N1(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN1_15_PKHA_N1_SHIFT))&LTC_K80_LPKN1_15_PKHA_N1_MASK)
/* LPKN2_0 Bit Fields */
#define LTC_K80_LPKN2_0_PKHA_N2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN2_0_PKHA_N2_SHIFT            0
#define LTC_K80_LPKN2_0_PKHA_N2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN2_0_PKHA_N2_SHIFT))&LTC_K80_LPKN2_0_PKHA_N2_MASK)
/* LPKN2_1 Bit Fields */
#define LTC_K80_LPKN2_1_PKHA_N2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN2_1_PKHA_N2_SHIFT            0
#define LTC_K80_LPKN2_1_PKHA_N2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN2_1_PKHA_N2_SHIFT))&LTC_K80_LPKN2_1_PKHA_N2_MASK)
/* LPKN2_2 Bit Fields */
#define LTC_K80_LPKN2_2_PKHA_N2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN2_2_PKHA_N2_SHIFT            0
#define LTC_K80_LPKN2_2_PKHA_N2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN2_2_PKHA_N2_SHIFT))&LTC_K80_LPKN2_2_PKHA_N2_MASK)
/* LPKN2_3 Bit Fields */
#define LTC_K80_LPKN2_3_PKHA_N2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN2_3_PKHA_N2_SHIFT            0
#define LTC_K80_LPKN2_3_PKHA_N2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN2_3_PKHA_N2_SHIFT))&LTC_K80_LPKN2_3_PKHA_N2_MASK)
/* LPKN2_4 Bit Fields */
#define LTC_K80_LPKN2_4_PKHA_N2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN2_4_PKHA_N2_SHIFT            0
#define LTC_K80_LPKN2_4_PKHA_N2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN2_4_PKHA_N2_SHIFT))&LTC_K80_LPKN2_4_PKHA_N2_MASK)
/* LPKN2_5 Bit Fields */
#define LTC_K80_LPKN2_5_PKHA_N2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN2_5_PKHA_N2_SHIFT            0
#define LTC_K80_LPKN2_5_PKHA_N2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN2_5_PKHA_N2_SHIFT))&LTC_K80_LPKN2_5_PKHA_N2_MASK)
/* LPKN2_6 Bit Fields */
#define LTC_K80_LPKN2_6_PKHA_N2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN2_6_PKHA_N2_SHIFT            0
#define LTC_K80_LPKN2_6_PKHA_N2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN2_6_PKHA_N2_SHIFT))&LTC_K80_LPKN2_6_PKHA_N2_MASK)
/* LPKN2_7 Bit Fields */
#define LTC_K80_LPKN2_7_PKHA_N2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN2_7_PKHA_N2_SHIFT            0
#define LTC_K80_LPKN2_7_PKHA_N2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN2_7_PKHA_N2_SHIFT))&LTC_K80_LPKN2_7_PKHA_N2_MASK)
/* LPKN2_8 Bit Fields */
#define LTC_K80_LPKN2_8_PKHA_N2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN2_8_PKHA_N2_SHIFT            0
#define LTC_K80_LPKN2_8_PKHA_N2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN2_8_PKHA_N2_SHIFT))&LTC_K80_LPKN2_8_PKHA_N2_MASK)
/* LPKN2_9 Bit Fields */
#define LTC_K80_LPKN2_9_PKHA_N2_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN2_9_PKHA_N2_SHIFT            0
#define LTC_K80_LPKN2_9_PKHA_N2(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN2_9_PKHA_N2_SHIFT))&LTC_K80_LPKN2_9_PKHA_N2_MASK)
/* LPKN2_10 Bit Fields */
#define LTC_K80_LPKN2_10_PKHA_N2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN2_10_PKHA_N2_SHIFT           0
#define LTC_K80_LPKN2_10_PKHA_N2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN2_10_PKHA_N2_SHIFT))&LTC_K80_LPKN2_10_PKHA_N2_MASK)
/* LPKN2_11 Bit Fields */
#define LTC_K80_LPKN2_11_PKHA_N2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN2_11_PKHA_N2_SHIFT           0
#define LTC_K80_LPKN2_11_PKHA_N2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN2_11_PKHA_N2_SHIFT))&LTC_K80_LPKN2_11_PKHA_N2_MASK)
/* LPKN2_12 Bit Fields */
#define LTC_K80_LPKN2_12_PKHA_N2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN2_12_PKHA_N2_SHIFT           0
#define LTC_K80_LPKN2_12_PKHA_N2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN2_12_PKHA_N2_SHIFT))&LTC_K80_LPKN2_12_PKHA_N2_MASK)
/* LPKN2_13 Bit Fields */
#define LTC_K80_LPKN2_13_PKHA_N2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN2_13_PKHA_N2_SHIFT           0
#define LTC_K80_LPKN2_13_PKHA_N2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN2_13_PKHA_N2_SHIFT))&LTC_K80_LPKN2_13_PKHA_N2_MASK)
/* LPKN2_14 Bit Fields */
#define LTC_K80_LPKN2_14_PKHA_N2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN2_14_PKHA_N2_SHIFT           0
#define LTC_K80_LPKN2_14_PKHA_N2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN2_14_PKHA_N2_SHIFT))&LTC_K80_LPKN2_14_PKHA_N2_MASK)
/* LPKN2_15 Bit Fields */
#define LTC_K80_LPKN2_15_PKHA_N2_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN2_15_PKHA_N2_SHIFT           0
#define LTC_K80_LPKN2_15_PKHA_N2(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN2_15_PKHA_N2_SHIFT))&LTC_K80_LPKN2_15_PKHA_N2_MASK)
/* LPKN3_0 Bit Fields */
#define LTC_K80_LPKN3_0_PKHA_N3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN3_0_PKHA_N3_SHIFT            0
#define LTC_K80_LPKN3_0_PKHA_N3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN3_0_PKHA_N3_SHIFT))&LTC_K80_LPKN3_0_PKHA_N3_MASK)
/* LPKN3_1 Bit Fields */
#define LTC_K80_LPKN3_1_PKHA_N3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN3_1_PKHA_N3_SHIFT            0
#define LTC_K80_LPKN3_1_PKHA_N3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN3_1_PKHA_N3_SHIFT))&LTC_K80_LPKN3_1_PKHA_N3_MASK)
/* LPKN3_2 Bit Fields */
#define LTC_K80_LPKN3_2_PKHA_N3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN3_2_PKHA_N3_SHIFT            0
#define LTC_K80_LPKN3_2_PKHA_N3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN3_2_PKHA_N3_SHIFT))&LTC_K80_LPKN3_2_PKHA_N3_MASK)
/* LPKN3_3 Bit Fields */
#define LTC_K80_LPKN3_3_PKHA_N3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN3_3_PKHA_N3_SHIFT            0
#define LTC_K80_LPKN3_3_PKHA_N3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN3_3_PKHA_N3_SHIFT))&LTC_K80_LPKN3_3_PKHA_N3_MASK)
/* LPKN3_4 Bit Fields */
#define LTC_K80_LPKN3_4_PKHA_N3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN3_4_PKHA_N3_SHIFT            0
#define LTC_K80_LPKN3_4_PKHA_N3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN3_4_PKHA_N3_SHIFT))&LTC_K80_LPKN3_4_PKHA_N3_MASK)
/* LPKN3_5 Bit Fields */
#define LTC_K80_LPKN3_5_PKHA_N3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN3_5_PKHA_N3_SHIFT            0
#define LTC_K80_LPKN3_5_PKHA_N3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN3_5_PKHA_N3_SHIFT))&LTC_K80_LPKN3_5_PKHA_N3_MASK)
/* LPKN3_6 Bit Fields */
#define LTC_K80_LPKN3_6_PKHA_N3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN3_6_PKHA_N3_SHIFT            0
#define LTC_K80_LPKN3_6_PKHA_N3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN3_6_PKHA_N3_SHIFT))&LTC_K80_LPKN3_6_PKHA_N3_MASK)
/* LPKN3_7 Bit Fields */
#define LTC_K80_LPKN3_7_PKHA_N3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN3_7_PKHA_N3_SHIFT            0
#define LTC_K80_LPKN3_7_PKHA_N3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN3_7_PKHA_N3_SHIFT))&LTC_K80_LPKN3_7_PKHA_N3_MASK)
/* LPKN3_8 Bit Fields */
#define LTC_K80_LPKN3_8_PKHA_N3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN3_8_PKHA_N3_SHIFT            0
#define LTC_K80_LPKN3_8_PKHA_N3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN3_8_PKHA_N3_SHIFT))&LTC_K80_LPKN3_8_PKHA_N3_MASK)
/* LPKN3_9 Bit Fields */
#define LTC_K80_LPKN3_9_PKHA_N3_MASK             0xFFFFFFFFu
#define LTC_K80_LPKN3_9_PKHA_N3_SHIFT            0
#define LTC_K80_LPKN3_9_PKHA_N3(x)               (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN3_9_PKHA_N3_SHIFT))&LTC_K80_LPKN3_9_PKHA_N3_MASK)
/* LPKN3_10 Bit Fields */
#define LTC_K80_LPKN3_10_PKHA_N3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN3_10_PKHA_N3_SHIFT           0
#define LTC_K80_LPKN3_10_PKHA_N3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN3_10_PKHA_N3_SHIFT))&LTC_K80_LPKN3_10_PKHA_N3_MASK)
/* LPKN3_11 Bit Fields */
#define LTC_K80_LPKN3_11_PKHA_N3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN3_11_PKHA_N3_SHIFT           0
#define LTC_K80_LPKN3_11_PKHA_N3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN3_11_PKHA_N3_SHIFT))&LTC_K80_LPKN3_11_PKHA_N3_MASK)
/* LPKN3_12 Bit Fields */
#define LTC_K80_LPKN3_12_PKHA_N3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN3_12_PKHA_N3_SHIFT           0
#define LTC_K80_LPKN3_12_PKHA_N3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN3_12_PKHA_N3_SHIFT))&LTC_K80_LPKN3_12_PKHA_N3_MASK)
/* LPKN3_13 Bit Fields */
#define LTC_K80_LPKN3_13_PKHA_N3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN3_13_PKHA_N3_SHIFT           0
#define LTC_K80_LPKN3_13_PKHA_N3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN3_13_PKHA_N3_SHIFT))&LTC_K80_LPKN3_13_PKHA_N3_MASK)
/* LPKN3_14 Bit Fields */
#define LTC_K80_LPKN3_14_PKHA_N3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN3_14_PKHA_N3_SHIFT           0
#define LTC_K80_LPKN3_14_PKHA_N3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN3_14_PKHA_N3_SHIFT))&LTC_K80_LPKN3_14_PKHA_N3_MASK)
/* LPKN3_15 Bit Fields */
#define LTC_K80_LPKN3_15_PKHA_N3_MASK            0xFFFFFFFFu
#define LTC_K80_LPKN3_15_PKHA_N3_SHIFT           0
#define LTC_K80_LPKN3_15_PKHA_N3(x)              (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKN3_15_PKHA_N3_SHIFT))&LTC_K80_LPKN3_15_PKHA_N3_MASK)
/* LPKE_0 Bit Fields */
#define LTC_K80_LPKE_0_PKHA_E_MASK               0xFFFFFFFFu
#define LTC_K80_LPKE_0_PKHA_E_SHIFT              0
#define LTC_K80_LPKE_0_PKHA_E(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_0_PKHA_E_SHIFT))&LTC_K80_LPKE_0_PKHA_E_MASK)
/* LPKE_1 Bit Fields */
#define LTC_K80_LPKE_1_PKHA_E_MASK               0xFFFFFFFFu
#define LTC_K80_LPKE_1_PKHA_E_SHIFT              0
#define LTC_K80_LPKE_1_PKHA_E(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_1_PKHA_E_SHIFT))&LTC_K80_LPKE_1_PKHA_E_MASK)
/* LPKE_2 Bit Fields */
#define LTC_K80_LPKE_2_PKHA_E_MASK               0xFFFFFFFFu
#define LTC_K80_LPKE_2_PKHA_E_SHIFT              0
#define LTC_K80_LPKE_2_PKHA_E(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_2_PKHA_E_SHIFT))&LTC_K80_LPKE_2_PKHA_E_MASK)
/* LPKE_3 Bit Fields */
#define LTC_K80_LPKE_3_PKHA_E_MASK               0xFFFFFFFFu
#define LTC_K80_LPKE_3_PKHA_E_SHIFT              0
#define LTC_K80_LPKE_3_PKHA_E(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_3_PKHA_E_SHIFT))&LTC_K80_LPKE_3_PKHA_E_MASK)
/* LPKE_4 Bit Fields */
#define LTC_K80_LPKE_4_PKHA_E_MASK               0xFFFFFFFFu
#define LTC_K80_LPKE_4_PKHA_E_SHIFT              0
#define LTC_K80_LPKE_4_PKHA_E(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_4_PKHA_E_SHIFT))&LTC_K80_LPKE_4_PKHA_E_MASK)
/* LPKE_5 Bit Fields */
#define LTC_K80_LPKE_5_PKHA_E_MASK               0xFFFFFFFFu
#define LTC_K80_LPKE_5_PKHA_E_SHIFT              0
#define LTC_K80_LPKE_5_PKHA_E(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_5_PKHA_E_SHIFT))&LTC_K80_LPKE_5_PKHA_E_MASK)
/* LPKE_6 Bit Fields */
#define LTC_K80_LPKE_6_PKHA_E_MASK               0xFFFFFFFFu
#define LTC_K80_LPKE_6_PKHA_E_SHIFT              0
#define LTC_K80_LPKE_6_PKHA_E(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_6_PKHA_E_SHIFT))&LTC_K80_LPKE_6_PKHA_E_MASK)
/* LPKE_7 Bit Fields */
#define LTC_K80_LPKE_7_PKHA_E_MASK               0xFFFFFFFFu
#define LTC_K80_LPKE_7_PKHA_E_SHIFT              0
#define LTC_K80_LPKE_7_PKHA_E(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_7_PKHA_E_SHIFT))&LTC_K80_LPKE_7_PKHA_E_MASK)
/* LPKE_8 Bit Fields */
#define LTC_K80_LPKE_8_PKHA_E_MASK               0xFFFFFFFFu
#define LTC_K80_LPKE_8_PKHA_E_SHIFT              0
#define LTC_K80_LPKE_8_PKHA_E(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_8_PKHA_E_SHIFT))&LTC_K80_LPKE_8_PKHA_E_MASK)
/* LPKE_9 Bit Fields */
#define LTC_K80_LPKE_9_PKHA_E_MASK               0xFFFFFFFFu
#define LTC_K80_LPKE_9_PKHA_E_SHIFT              0
#define LTC_K80_LPKE_9_PKHA_E(x)                 (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_9_PKHA_E_SHIFT))&LTC_K80_LPKE_9_PKHA_E_MASK)
/* LPKE_10 Bit Fields */
#define LTC_K80_LPKE_10_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_10_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_10_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_10_PKHA_E_SHIFT))&LTC_K80_LPKE_10_PKHA_E_MASK)
/* LPKE_11 Bit Fields */
#define LTC_K80_LPKE_11_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_11_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_11_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_11_PKHA_E_SHIFT))&LTC_K80_LPKE_11_PKHA_E_MASK)
/* LPKE_12 Bit Fields */
#define LTC_K80_LPKE_12_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_12_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_12_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_12_PKHA_E_SHIFT))&LTC_K80_LPKE_12_PKHA_E_MASK)
/* LPKE_13 Bit Fields */
#define LTC_K80_LPKE_13_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_13_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_13_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_13_PKHA_E_SHIFT))&LTC_K80_LPKE_13_PKHA_E_MASK)
/* LPKE_14 Bit Fields */
#define LTC_K80_LPKE_14_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_14_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_14_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_14_PKHA_E_SHIFT))&LTC_K80_LPKE_14_PKHA_E_MASK)
/* LPKE_15 Bit Fields */
#define LTC_K80_LPKE_15_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_15_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_15_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_15_PKHA_E_SHIFT))&LTC_K80_LPKE_15_PKHA_E_MASK)
/* LPKE_16 Bit Fields */
#define LTC_K80_LPKE_16_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_16_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_16_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_16_PKHA_E_SHIFT))&LTC_K80_LPKE_16_PKHA_E_MASK)
/* LPKE_17 Bit Fields */
#define LTC_K80_LPKE_17_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_17_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_17_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_17_PKHA_E_SHIFT))&LTC_K80_LPKE_17_PKHA_E_MASK)
/* LPKE_18 Bit Fields */
#define LTC_K80_LPKE_18_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_18_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_18_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_18_PKHA_E_SHIFT))&LTC_K80_LPKE_18_PKHA_E_MASK)
/* LPKE_19 Bit Fields */
#define LTC_K80_LPKE_19_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_19_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_19_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_19_PKHA_E_SHIFT))&LTC_K80_LPKE_19_PKHA_E_MASK)
/* LPKE_20 Bit Fields */
#define LTC_K80_LPKE_20_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_20_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_20_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_20_PKHA_E_SHIFT))&LTC_K80_LPKE_20_PKHA_E_MASK)
/* LPKE_21 Bit Fields */
#define LTC_K80_LPKE_21_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_21_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_21_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_21_PKHA_E_SHIFT))&LTC_K80_LPKE_21_PKHA_E_MASK)
/* LPKE_22 Bit Fields */
#define LTC_K80_LPKE_22_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_22_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_22_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_22_PKHA_E_SHIFT))&LTC_K80_LPKE_22_PKHA_E_MASK)
/* LPKE_23 Bit Fields */
#define LTC_K80_LPKE_23_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_23_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_23_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_23_PKHA_E_SHIFT))&LTC_K80_LPKE_23_PKHA_E_MASK)
/* LPKE_24 Bit Fields */
#define LTC_K80_LPKE_24_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_24_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_24_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_24_PKHA_E_SHIFT))&LTC_K80_LPKE_24_PKHA_E_MASK)
/* LPKE_25 Bit Fields */
#define LTC_K80_LPKE_25_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_25_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_25_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_25_PKHA_E_SHIFT))&LTC_K80_LPKE_25_PKHA_E_MASK)
/* LPKE_26 Bit Fields */
#define LTC_K80_LPKE_26_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_26_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_26_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_26_PKHA_E_SHIFT))&LTC_K80_LPKE_26_PKHA_E_MASK)
/* LPKE_27 Bit Fields */
#define LTC_K80_LPKE_27_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_27_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_27_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_27_PKHA_E_SHIFT))&LTC_K80_LPKE_27_PKHA_E_MASK)
/* LPKE_28 Bit Fields */
#define LTC_K80_LPKE_28_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_28_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_28_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_28_PKHA_E_SHIFT))&LTC_K80_LPKE_28_PKHA_E_MASK)
/* LPKE_29 Bit Fields */
#define LTC_K80_LPKE_29_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_29_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_29_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_29_PKHA_E_SHIFT))&LTC_K80_LPKE_29_PKHA_E_MASK)
/* LPKE_30 Bit Fields */
#define LTC_K80_LPKE_30_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_30_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_30_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_30_PKHA_E_SHIFT))&LTC_K80_LPKE_30_PKHA_E_MASK)
/* LPKE_31 Bit Fields */
#define LTC_K80_LPKE_31_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_31_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_31_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_31_PKHA_E_SHIFT))&LTC_K80_LPKE_31_PKHA_E_MASK)
/* LPKE_32 Bit Fields */
#define LTC_K80_LPKE_32_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_32_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_32_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_32_PKHA_E_SHIFT))&LTC_K80_LPKE_32_PKHA_E_MASK)
/* LPKE_33 Bit Fields */
#define LTC_K80_LPKE_33_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_33_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_33_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_33_PKHA_E_SHIFT))&LTC_K80_LPKE_33_PKHA_E_MASK)
/* LPKE_34 Bit Fields */
#define LTC_K80_LPKE_34_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_34_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_34_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_34_PKHA_E_SHIFT))&LTC_K80_LPKE_34_PKHA_E_MASK)
/* LPKE_35 Bit Fields */
#define LTC_K80_LPKE_35_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_35_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_35_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_35_PKHA_E_SHIFT))&LTC_K80_LPKE_35_PKHA_E_MASK)
/* LPKE_36 Bit Fields */
#define LTC_K80_LPKE_36_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_36_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_36_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_36_PKHA_E_SHIFT))&LTC_K80_LPKE_36_PKHA_E_MASK)
/* LPKE_37 Bit Fields */
#define LTC_K80_LPKE_37_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_37_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_37_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_37_PKHA_E_SHIFT))&LTC_K80_LPKE_37_PKHA_E_MASK)
/* LPKE_38 Bit Fields */
#define LTC_K80_LPKE_38_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_38_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_38_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_38_PKHA_E_SHIFT))&LTC_K80_LPKE_38_PKHA_E_MASK)
/* LPKE_39 Bit Fields */
#define LTC_K80_LPKE_39_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_39_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_39_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_39_PKHA_E_SHIFT))&LTC_K80_LPKE_39_PKHA_E_MASK)
/* LPKE_40 Bit Fields */
#define LTC_K80_LPKE_40_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_40_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_40_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_40_PKHA_E_SHIFT))&LTC_K80_LPKE_40_PKHA_E_MASK)
/* LPKE_41 Bit Fields */
#define LTC_K80_LPKE_41_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_41_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_41_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_41_PKHA_E_SHIFT))&LTC_K80_LPKE_41_PKHA_E_MASK)
/* LPKE_42 Bit Fields */
#define LTC_K80_LPKE_42_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_42_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_42_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_42_PKHA_E_SHIFT))&LTC_K80_LPKE_42_PKHA_E_MASK)
/* LPKE_43 Bit Fields */
#define LTC_K80_LPKE_43_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_43_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_43_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_43_PKHA_E_SHIFT))&LTC_K80_LPKE_43_PKHA_E_MASK)
/* LPKE_44 Bit Fields */
#define LTC_K80_LPKE_44_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_44_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_44_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_44_PKHA_E_SHIFT))&LTC_K80_LPKE_44_PKHA_E_MASK)
/* LPKE_45 Bit Fields */
#define LTC_K80_LPKE_45_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_45_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_45_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_45_PKHA_E_SHIFT))&LTC_K80_LPKE_45_PKHA_E_MASK)
/* LPKE_46 Bit Fields */
#define LTC_K80_LPKE_46_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_46_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_46_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_46_PKHA_E_SHIFT))&LTC_K80_LPKE_46_PKHA_E_MASK)
/* LPKE_47 Bit Fields */
#define LTC_K80_LPKE_47_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_47_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_47_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_47_PKHA_E_SHIFT))&LTC_K80_LPKE_47_PKHA_E_MASK)
/* LPKE_48 Bit Fields */
#define LTC_K80_LPKE_48_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_48_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_48_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_48_PKHA_E_SHIFT))&LTC_K80_LPKE_48_PKHA_E_MASK)
/* LPKE_49 Bit Fields */
#define LTC_K80_LPKE_49_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_49_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_49_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_49_PKHA_E_SHIFT))&LTC_K80_LPKE_49_PKHA_E_MASK)
/* LPKE_50 Bit Fields */
#define LTC_K80_LPKE_50_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_50_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_50_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_50_PKHA_E_SHIFT))&LTC_K80_LPKE_50_PKHA_E_MASK)
/* LPKE_51 Bit Fields */
#define LTC_K80_LPKE_51_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_51_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_51_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_51_PKHA_E_SHIFT))&LTC_K80_LPKE_51_PKHA_E_MASK)
/* LPKE_52 Bit Fields */
#define LTC_K80_LPKE_52_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_52_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_52_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_52_PKHA_E_SHIFT))&LTC_K80_LPKE_52_PKHA_E_MASK)
/* LPKE_53 Bit Fields */
#define LTC_K80_LPKE_53_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_53_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_53_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_53_PKHA_E_SHIFT))&LTC_K80_LPKE_53_PKHA_E_MASK)
/* LPKE_54 Bit Fields */
#define LTC_K80_LPKE_54_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_54_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_54_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_54_PKHA_E_SHIFT))&LTC_K80_LPKE_54_PKHA_E_MASK)
/* LPKE_55 Bit Fields */
#define LTC_K80_LPKE_55_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_55_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_55_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_55_PKHA_E_SHIFT))&LTC_K80_LPKE_55_PKHA_E_MASK)
/* LPKE_56 Bit Fields */
#define LTC_K80_LPKE_56_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_56_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_56_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_56_PKHA_E_SHIFT))&LTC_K80_LPKE_56_PKHA_E_MASK)
/* LPKE_57 Bit Fields */
#define LTC_K80_LPKE_57_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_57_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_57_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_57_PKHA_E_SHIFT))&LTC_K80_LPKE_57_PKHA_E_MASK)
/* LPKE_58 Bit Fields */
#define LTC_K80_LPKE_58_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_58_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_58_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_58_PKHA_E_SHIFT))&LTC_K80_LPKE_58_PKHA_E_MASK)
/* LPKE_59 Bit Fields */
#define LTC_K80_LPKE_59_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_59_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_59_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_59_PKHA_E_SHIFT))&LTC_K80_LPKE_59_PKHA_E_MASK)
/* LPKE_60 Bit Fields */
#define LTC_K80_LPKE_60_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_60_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_60_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_60_PKHA_E_SHIFT))&LTC_K80_LPKE_60_PKHA_E_MASK)
/* LPKE_61 Bit Fields */
#define LTC_K80_LPKE_61_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_61_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_61_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_61_PKHA_E_SHIFT))&LTC_K80_LPKE_61_PKHA_E_MASK)
/* LPKE_62 Bit Fields */
#define LTC_K80_LPKE_62_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_62_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_62_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_62_PKHA_E_SHIFT))&LTC_K80_LPKE_62_PKHA_E_MASK)
/* LPKE_63 Bit Fields */
#define LTC_K80_LPKE_63_PKHA_E_MASK              0xFFFFFFFFu
#define LTC_K80_LPKE_63_PKHA_E_SHIFT             0
#define LTC_K80_LPKE_63_PKHA_E(x)                (((uint32_t)(((uint32_t)(x))<<LTC_K80_LPKE_63_PKHA_E_SHIFT))&LTC_K80_LPKE_63_PKHA_E_MASK)

/*!
 * @}
 */ /* end of group LTC_K80_Register_Masks */


/* LTC_K80 - Peripheral instance base addresses */
/** Peripheral LTC_K80 base address */
#define LTC_K80_BASE                                (0x400D1000u)
/** Peripheral LTC_K80 base pointer */
#define LTC_K80                                     ((LTC_K80_Type *)LTC_K80_BASE)
#define LTC_K80_BASE_PTR                            (LTC_K80)
/** Array initializer of LTC_K80 peripheral base addresses */
#define LTC_K80_BASE_ADDRS                           { LTC_K80_BASE }
/** Array initializer of LTC_K80 peripheral base pointers */
#define LTC_K80_BASE_PTRS                            { LTC_K80 }
/** Interrupt vectors for the LTC_K80 peripheral type */
#define LTC_K80_IRQS                                 { LTC_K80_IRQn }

/* ----------------------------------------------------------------------------
   -- LTC_K80 - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup LTC_K80_Register_Accessor_Macros LTC_K80 - Register accessor macros
 * @{
 */


/* LTC_K80 - Register instance definitions */
/* LTC_K80 */
#define LTC_K80_LTCMR                            LTC_K80_LTCMR_REG(LTC_K80)
#define LTC_K80_LTCMR_PK                         LTC_K80_LTCMR_PK_REG(LTC_K80)
#define LTC_K80_LTCKSR                           LTC_K80_LTCKSR_REG(LTC_K80)
#define LTC_K80_LTCDSR                           LTC_K80_LTCDSR_REG(LTC_K80)
#define LTC_K80_LTCICVSR                         LTC_K80_LTCICVSR_REG(LTC_K80)
#define LTC_K80_LTCCOM                           LTC_K80_LTCCOM_REG(LTC_K80)
#define LTC_K80_LTCCTL                           LTC_K80_LTCCTL_REG(LTC_K80)
#define LTC_K80_LTCCWR                           LTC_K80_LTCCWR_REG(LTC_K80)
#define LTC_K80_LTCSTA                           LTC_K80_LTCSTA_REG(LTC_K80)
#define LTC_K80_LTCESTA                          LTC_K80_LTCESTA_REG(LTC_K80)
#define LTC_K80_LTCAADSZR                        LTC_K80_LTCAADSZR_REG(LTC_K80)
#define LTC_K80_LTCIVSZR                         LTC_K80_LTCIVSZR_REG(LTC_K80)
#define LTC_K80_LTCDPAMSR                        LTC_K80_LTCDPAMSR_REG(LTC_K80)
#define LTC_K80_LPKASZR                          LTC_K80_LPKASZR_REG(LTC_K80)
#define LTC_K80_LPKBSZR                          LTC_K80_LPKBSZR_REG(LTC_K80)
#define LTC_K80_LPKNSZR                          LTC_K80_LPKNSZR_REG(LTC_K80)
#define LTC_K80_LPKESZR                          LTC_K80_LPKESZR_REG(LTC_K80)
#define LTC_K80_LTCCTXR_0                        LTC_K80_LTCCTXR_0_REG(LTC_K80)
#define LTC_K80_LTCCTXR_1                        LTC_K80_LTCCTXR_1_REG(LTC_K80)
#define LTC_K80_LTCCTXR_2                        LTC_K80_LTCCTXR_2_REG(LTC_K80)
#define LTC_K80_LTCCTXR_3                        LTC_K80_LTCCTXR_3_REG(LTC_K80)
#define LTC_K80_LTCCTXR_4                        LTC_K80_LTCCTXR_4_REG(LTC_K80)
#define LTC_K80_LTCCTXR_5                        LTC_K80_LTCCTXR_5_REG(LTC_K80)
#define LTC_K80_LTCCTXR_6                        LTC_K80_LTCCTXR_6_REG(LTC_K80)
#define LTC_K80_LTCCTXR_7                        LTC_K80_LTCCTXR_7_REG(LTC_K80)
#define LTC_K80_LTCCTXR_8                        LTC_K80_LTCCTXR_8_REG(LTC_K80)
#define LTC_K80_LTCCTXR_9                        LTC_K80_LTCCTXR_9_REG(LTC_K80)
#define LTC_K80_LTCCTXR_10                       LTC_K80_LTCCTXR_10_REG(LTC_K80)
#define LTC_K80_LTCCTXR_11                       LTC_K80_LTCCTXR_11_REG(LTC_K80)
#define LTC_K80_LTCCTXR_12                       LTC_K80_LTCCTXR_12_REG(LTC_K80)
#define LTC_K80_LTCCTXR_13                       LTC_K80_LTCCTXR_13_REG(LTC_K80)
#define LTC_K80_LTCCTXR_14                       LTC_K80_LTCCTXR_14_REG(LTC_K80)
#define LTC_K80_LTCCTXR_15                       LTC_K80_LTCCTXR_15_REG(LTC_K80)
#define LTC_K80_LTCKEYR_0                        LTC_K80_LTCKEYR_0_REG(LTC_K80)
#define LTC_K80_LTCKEYR_1                        LTC_K80_LTCKEYR_1_REG(LTC_K80)
#define LTC_K80_LTCKEYR_2                        LTC_K80_LTCKEYR_2_REG(LTC_K80)
#define LTC_K80_LTCKEYR_3                        LTC_K80_LTCKEYR_3_REG(LTC_K80)
#define LTC_K80_LTCKEYR_4                        LTC_K80_LTCKEYR_4_REG(LTC_K80)
#define LTC_K80_LTCKEYR_5                        LTC_K80_LTCKEYR_5_REG(LTC_K80)
#define LTC_K80_LTCKEYR_6                        LTC_K80_LTCKEYR_6_REG(LTC_K80)
#define LTC_K80_LTCKEYR_7                        LTC_K80_LTCKEYR_7_REG(LTC_K80)
#define LTC_K80_LTCVID1                          LTC_K80_LTCVID1_REG(LTC_K80)
#define LTC_K80_CHAVID                           LTC_K80_CHAVID_REG(LTC_K80)
#define LTC_K80_LTCFIFOSTA                       LTC_K80_LTCFIFOSTA_REG(LTC_K80)
#define LTC_K80_LTCIFIFO                         LTC_K80_LTCIFIFO_REG(LTC_K80)
#define LTC_K80_LTCOFIFO                         LTC_K80_LTCOFIFO_REG(LTC_K80)
#define LTC_K80_LPKA0_0                          LTC_K80_LPKA0_0_REG(LTC_K80)
#define LTC_K80_LPKA0_1                          LTC_K80_LPKA0_1_REG(LTC_K80)
#define LTC_K80_LPKA0_2                          LTC_K80_LPKA0_2_REG(LTC_K80)
#define LTC_K80_LPKA0_3                          LTC_K80_LPKA0_3_REG(LTC_K80)
#define LTC_K80_LPKA0_4                          LTC_K80_LPKA0_4_REG(LTC_K80)
#define LTC_K80_LPKA0_5                          LTC_K80_LPKA0_5_REG(LTC_K80)
#define LTC_K80_LPKA0_6                          LTC_K80_LPKA0_6_REG(LTC_K80)
#define LTC_K80_LPKA0_7                          LTC_K80_LPKA0_7_REG(LTC_K80)
#define LTC_K80_LPKA0_8                          LTC_K80_LPKA0_8_REG(LTC_K80)
#define LTC_K80_LPKA0_9                          LTC_K80_LPKA0_9_REG(LTC_K80)
#define LTC_K80_LPKA0_10                         LTC_K80_LPKA0_10_REG(LTC_K80)
#define LTC_K80_LPKA0_11                         LTC_K80_LPKA0_11_REG(LTC_K80)
#define LTC_K80_LPKA0_12                         LTC_K80_LPKA0_12_REG(LTC_K80)
#define LTC_K80_LPKA0_13                         LTC_K80_LPKA0_13_REG(LTC_K80)
#define LTC_K80_LPKA0_14                         LTC_K80_LPKA0_14_REG(LTC_K80)
#define LTC_K80_LPKA0_15                         LTC_K80_LPKA0_15_REG(LTC_K80)
#define LTC_K80_LPKA1_0                          LTC_K80_LPKA1_0_REG(LTC_K80)
#define LTC_K80_LPKA1_1                          LTC_K80_LPKA1_1_REG(LTC_K80)
#define LTC_K80_LPKA1_2                          LTC_K80_LPKA1_2_REG(LTC_K80)
#define LTC_K80_LPKA1_3                          LTC_K80_LPKA1_3_REG(LTC_K80)
#define LTC_K80_LPKA1_4                          LTC_K80_LPKA1_4_REG(LTC_K80)
#define LTC_K80_LPKA1_5                          LTC_K80_LPKA1_5_REG(LTC_K80)
#define LTC_K80_LPKA1_6                          LTC_K80_LPKA1_6_REG(LTC_K80)
#define LTC_K80_LPKA1_7                          LTC_K80_LPKA1_7_REG(LTC_K80)
#define LTC_K80_LPKA1_8                          LTC_K80_LPKA1_8_REG(LTC_K80)
#define LTC_K80_LPKA1_9                          LTC_K80_LPKA1_9_REG(LTC_K80)
#define LTC_K80_LPKA1_10                         LTC_K80_LPKA1_10_REG(LTC_K80)
#define LTC_K80_LPKA1_11                         LTC_K80_LPKA1_11_REG(LTC_K80)
#define LTC_K80_LPKA1_12                         LTC_K80_LPKA1_12_REG(LTC_K80)
#define LTC_K80_LPKA1_13                         LTC_K80_LPKA1_13_REG(LTC_K80)
#define LTC_K80_LPKA1_14                         LTC_K80_LPKA1_14_REG(LTC_K80)
#define LTC_K80_LPKA1_15                         LTC_K80_LPKA1_15_REG(LTC_K80)
#define LTC_K80_LPKA2_0                          LTC_K80_LPKA2_0_REG(LTC_K80)
#define LTC_K80_LPKA2_1                          LTC_K80_LPKA2_1_REG(LTC_K80)
#define LTC_K80_LPKA2_2                          LTC_K80_LPKA2_2_REG(LTC_K80)
#define LTC_K80_LPKA2_3                          LTC_K80_LPKA2_3_REG(LTC_K80)
#define LTC_K80_LPKA2_4                          LTC_K80_LPKA2_4_REG(LTC_K80)
#define LTC_K80_LPKA2_5                          LTC_K80_LPKA2_5_REG(LTC_K80)
#define LTC_K80_LPKA2_6                          LTC_K80_LPKA2_6_REG(LTC_K80)
#define LTC_K80_LPKA2_7                          LTC_K80_LPKA2_7_REG(LTC_K80)
#define LTC_K80_LPKA2_8                          LTC_K80_LPKA2_8_REG(LTC_K80)
#define LTC_K80_LPKA2_9                          LTC_K80_LPKA2_9_REG(LTC_K80)
#define LTC_K80_LPKA2_10                         LTC_K80_LPKA2_10_REG(LTC_K80)
#define LTC_K80_LPKA2_11                         LTC_K80_LPKA2_11_REG(LTC_K80)
#define LTC_K80_LPKA2_12                         LTC_K80_LPKA2_12_REG(LTC_K80)
#define LTC_K80_LPKA2_13                         LTC_K80_LPKA2_13_REG(LTC_K80)
#define LTC_K80_LPKA2_14                         LTC_K80_LPKA2_14_REG(LTC_K80)
#define LTC_K80_LPKA2_15                         LTC_K80_LPKA2_15_REG(LTC_K80)
#define LTC_K80_LPKA3_0                          LTC_K80_LPKA3_0_REG(LTC_K80)
#define LTC_K80_LPKA3_1                          LTC_K80_LPKA3_1_REG(LTC_K80)
#define LTC_K80_LPKA3_2                          LTC_K80_LPKA3_2_REG(LTC_K80)
#define LTC_K80_LPKA3_3                          LTC_K80_LPKA3_3_REG(LTC_K80)
#define LTC_K80_LPKA3_4                          LTC_K80_LPKA3_4_REG(LTC_K80)
#define LTC_K80_LPKA3_5                          LTC_K80_LPKA3_5_REG(LTC_K80)
#define LTC_K80_LPKA3_6                          LTC_K80_LPKA3_6_REG(LTC_K80)
#define LTC_K80_LPKA3_7                          LTC_K80_LPKA3_7_REG(LTC_K80)
#define LTC_K80_LPKA3_8                          LTC_K80_LPKA3_8_REG(LTC_K80)
#define LTC_K80_LPKA3_9                          LTC_K80_LPKA3_9_REG(LTC_K80)
#define LTC_K80_LPKA3_10                         LTC_K80_LPKA3_10_REG(LTC_K80)
#define LTC_K80_LPKA3_11                         LTC_K80_LPKA3_11_REG(LTC_K80)
#define LTC_K80_LPKA3_12                         LTC_K80_LPKA3_12_REG(LTC_K80)
#define LTC_K80_LPKA3_13                         LTC_K80_LPKA3_13_REG(LTC_K80)
#define LTC_K80_LPKA3_14                         LTC_K80_LPKA3_14_REG(LTC_K80)
#define LTC_K80_LPKA3_15                         LTC_K80_LPKA3_15_REG(LTC_K80)
#define LTC_K80_LPKB0_0                          LTC_K80_LPKB0_0_REG(LTC_K80)
#define LTC_K80_LPKB0_1                          LTC_K80_LPKB0_1_REG(LTC_K80)
#define LTC_K80_LPKB0_2                          LTC_K80_LPKB0_2_REG(LTC_K80)
#define LTC_K80_LPKB0_3                          LTC_K80_LPKB0_3_REG(LTC_K80)
#define LTC_K80_LPKB0_4                          LTC_K80_LPKB0_4_REG(LTC_K80)
#define LTC_K80_LPKB0_5                          LTC_K80_LPKB0_5_REG(LTC_K80)
#define LTC_K80_LPKB0_6                          LTC_K80_LPKB0_6_REG(LTC_K80)
#define LTC_K80_LPKB0_7                          LTC_K80_LPKB0_7_REG(LTC_K80)
#define LTC_K80_LPKB0_8                          LTC_K80_LPKB0_8_REG(LTC_K80)
#define LTC_K80_LPKB0_9                          LTC_K80_LPKB0_9_REG(LTC_K80)
#define LTC_K80_LPKB0_10                         LTC_K80_LPKB0_10_REG(LTC_K80)
#define LTC_K80_LPKB0_11                         LTC_K80_LPKB0_11_REG(LTC_K80)
#define LTC_K80_LPKB0_12                         LTC_K80_LPKB0_12_REG(LTC_K80)
#define LTC_K80_LPKB0_13                         LTC_K80_LPKB0_13_REG(LTC_K80)
#define LTC_K80_LPKB0_14                         LTC_K80_LPKB0_14_REG(LTC_K80)
#define LTC_K80_LPKB0_15                         LTC_K80_LPKB0_15_REG(LTC_K80)
#define LTC_K80_LPKB1_0                          LTC_K80_LPKB1_0_REG(LTC_K80)
#define LTC_K80_LPKB1_1                          LTC_K80_LPKB1_1_REG(LTC_K80)
#define LTC_K80_LPKB1_2                          LTC_K80_LPKB1_2_REG(LTC_K80)
#define LTC_K80_LPKB1_3                          LTC_K80_LPKB1_3_REG(LTC_K80)
#define LTC_K80_LPKB1_4                          LTC_K80_LPKB1_4_REG(LTC_K80)
#define LTC_K80_LPKB1_5                          LTC_K80_LPKB1_5_REG(LTC_K80)
#define LTC_K80_LPKB1_6                          LTC_K80_LPKB1_6_REG(LTC_K80)
#define LTC_K80_LPKB1_7                          LTC_K80_LPKB1_7_REG(LTC_K80)
#define LTC_K80_LPKB1_8                          LTC_K80_LPKB1_8_REG(LTC_K80)
#define LTC_K80_LPKB1_9                          LTC_K80_LPKB1_9_REG(LTC_K80)
#define LTC_K80_LPKB1_10                         LTC_K80_LPKB1_10_REG(LTC_K80)
#define LTC_K80_LPKB1_11                         LTC_K80_LPKB1_11_REG(LTC_K80)
#define LTC_K80_LPKB1_12                         LTC_K80_LPKB1_12_REG(LTC_K80)
#define LTC_K80_LPKB1_13                         LTC_K80_LPKB1_13_REG(LTC_K80)
#define LTC_K80_LPKB1_14                         LTC_K80_LPKB1_14_REG(LTC_K80)
#define LTC_K80_LPKB1_15                         LTC_K80_LPKB1_15_REG(LTC_K80)
#define LTC_K80_LPKB2_0                          LTC_K80_LPKB2_0_REG(LTC_K80)
#define LTC_K80_LPKB2_1                          LTC_K80_LPKB2_1_REG(LTC_K80)
#define LTC_K80_LPKB2_2                          LTC_K80_LPKB2_2_REG(LTC_K80)
#define LTC_K80_LPKB2_3                          LTC_K80_LPKB2_3_REG(LTC_K80)
#define LTC_K80_LPKB2_4                          LTC_K80_LPKB2_4_REG(LTC_K80)
#define LTC_K80_LPKB2_5                          LTC_K80_LPKB2_5_REG(LTC_K80)
#define LTC_K80_LPKB2_6                          LTC_K80_LPKB2_6_REG(LTC_K80)
#define LTC_K80_LPKB2_7                          LTC_K80_LPKB2_7_REG(LTC_K80)
#define LTC_K80_LPKB2_8                          LTC_K80_LPKB2_8_REG(LTC_K80)
#define LTC_K80_LPKB2_9                          LTC_K80_LPKB2_9_REG(LTC_K80)
#define LTC_K80_LPKB2_10                         LTC_K80_LPKB2_10_REG(LTC_K80)
#define LTC_K80_LPKB2_11                         LTC_K80_LPKB2_11_REG(LTC_K80)
#define LTC_K80_LPKB2_12                         LTC_K80_LPKB2_12_REG(LTC_K80)
#define LTC_K80_LPKB2_13                         LTC_K80_LPKB2_13_REG(LTC_K80)
#define LTC_K80_LPKB2_14                         LTC_K80_LPKB2_14_REG(LTC_K80)
#define LTC_K80_LPKB2_15                         LTC_K80_LPKB2_15_REG(LTC_K80)
#define LTC_K80_LPKB3_0                          LTC_K80_LPKB3_0_REG(LTC_K80)
#define LTC_K80_LPKB3_1                          LTC_K80_LPKB3_1_REG(LTC_K80)
#define LTC_K80_LPKB3_2                          LTC_K80_LPKB3_2_REG(LTC_K80)
#define LTC_K80_LPKB3_3                          LTC_K80_LPKB3_3_REG(LTC_K80)
#define LTC_K80_LPKB3_4                          LTC_K80_LPKB3_4_REG(LTC_K80)
#define LTC_K80_LPKB3_5                          LTC_K80_LPKB3_5_REG(LTC_K80)
#define LTC_K80_LPKB3_6                          LTC_K80_LPKB3_6_REG(LTC_K80)
#define LTC_K80_LPKB3_7                          LTC_K80_LPKB3_7_REG(LTC_K80)
#define LTC_K80_LPKB3_8                          LTC_K80_LPKB3_8_REG(LTC_K80)
#define LTC_K80_LPKB3_9                          LTC_K80_LPKB3_9_REG(LTC_K80)
#define LTC_K80_LPKB3_10                         LTC_K80_LPKB3_10_REG(LTC_K80)
#define LTC_K80_LPKB3_11                         LTC_K80_LPKB3_11_REG(LTC_K80)
#define LTC_K80_LPKB3_12                         LTC_K80_LPKB3_12_REG(LTC_K80)
#define LTC_K80_LPKB3_13                         LTC_K80_LPKB3_13_REG(LTC_K80)
#define LTC_K80_LPKB3_14                         LTC_K80_LPKB3_14_REG(LTC_K80)
#define LTC_K80_LPKB3_15                         LTC_K80_LPKB3_15_REG(LTC_K80)
#define LTC_K80_LPKN0_0                          LTC_K80_LPKN0_0_REG(LTC_K80)
#define LTC_K80_LPKN0_1                          LTC_K80_LPKN0_1_REG(LTC_K80)
#define LTC_K80_LPKN0_2                          LTC_K80_LPKN0_2_REG(LTC_K80)
#define LTC_K80_LPKN0_3                          LTC_K80_LPKN0_3_REG(LTC_K80)
#define LTC_K80_LPKN0_4                          LTC_K80_LPKN0_4_REG(LTC_K80)
#define LTC_K80_LPKN0_5                          LTC_K80_LPKN0_5_REG(LTC_K80)
#define LTC_K80_LPKN0_6                          LTC_K80_LPKN0_6_REG(LTC_K80)
#define LTC_K80_LPKN0_7                          LTC_K80_LPKN0_7_REG(LTC_K80)
#define LTC_K80_LPKN0_8                          LTC_K80_LPKN0_8_REG(LTC_K80)
#define LTC_K80_LPKN0_9                          LTC_K80_LPKN0_9_REG(LTC_K80)
#define LTC_K80_LPKN0_10                         LTC_K80_LPKN0_10_REG(LTC_K80)
#define LTC_K80_LPKN0_11                         LTC_K80_LPKN0_11_REG(LTC_K80)
#define LTC_K80_LPKN0_12                         LTC_K80_LPKN0_12_REG(LTC_K80)
#define LTC_K80_LPKN0_13                         LTC_K80_LPKN0_13_REG(LTC_K80)
#define LTC_K80_LPKN0_14                         LTC_K80_LPKN0_14_REG(LTC_K80)
#define LTC_K80_LPKN0_15                         LTC_K80_LPKN0_15_REG(LTC_K80)
#define LTC_K80_LPKN1_0                          LTC_K80_LPKN1_0_REG(LTC_K80)
#define LTC_K80_LPKN1_1                          LTC_K80_LPKN1_1_REG(LTC_K80)
#define LTC_K80_LPKN1_2                          LTC_K80_LPKN1_2_REG(LTC_K80)
#define LTC_K80_LPKN1_3                          LTC_K80_LPKN1_3_REG(LTC_K80)
#define LTC_K80_LPKN1_4                          LTC_K80_LPKN1_4_REG(LTC_K80)
#define LTC_K80_LPKN1_5                          LTC_K80_LPKN1_5_REG(LTC_K80)
#define LTC_K80_LPKN1_6                          LTC_K80_LPKN1_6_REG(LTC_K80)
#define LTC_K80_LPKN1_7                          LTC_K80_LPKN1_7_REG(LTC_K80)
#define LTC_K80_LPKN1_8                          LTC_K80_LPKN1_8_REG(LTC_K80)
#define LTC_K80_LPKN1_9                          LTC_K80_LPKN1_9_REG(LTC_K80)
#define LTC_K80_LPKN1_10                         LTC_K80_LPKN1_10_REG(LTC_K80)
#define LTC_K80_LPKN1_11                         LTC_K80_LPKN1_11_REG(LTC_K80)
#define LTC_K80_LPKN1_12                         LTC_K80_LPKN1_12_REG(LTC_K80)
#define LTC_K80_LPKN1_13                         LTC_K80_LPKN1_13_REG(LTC_K80)
#define LTC_K80_LPKN1_14                         LTC_K80_LPKN1_14_REG(LTC_K80)
#define LTC_K80_LPKN1_15                         LTC_K80_LPKN1_15_REG(LTC_K80)
#define LTC_K80_LPKN2_0                          LTC_K80_LPKN2_0_REG(LTC_K80)
#define LTC_K80_LPKN2_1                          LTC_K80_LPKN2_1_REG(LTC_K80)
#define LTC_K80_LPKN2_2                          LTC_K80_LPKN2_2_REG(LTC_K80)
#define LTC_K80_LPKN2_3                          LTC_K80_LPKN2_3_REG(LTC_K80)
#define LTC_K80_LPKN2_4                          LTC_K80_LPKN2_4_REG(LTC_K80)
#define LTC_K80_LPKN2_5                          LTC_K80_LPKN2_5_REG(LTC_K80)
#define LTC_K80_LPKN2_6                          LTC_K80_LPKN2_6_REG(LTC_K80)
#define LTC_K80_LPKN2_7                          LTC_K80_LPKN2_7_REG(LTC_K80)
#define LTC_K80_LPKN2_8                          LTC_K80_LPKN2_8_REG(LTC_K80)
#define LTC_K80_LPKN2_9                          LTC_K80_LPKN2_9_REG(LTC_K80)
#define LTC_K80_LPKN2_10                         LTC_K80_LPKN2_10_REG(LTC_K80)
#define LTC_K80_LPKN2_11                         LTC_K80_LPKN2_11_REG(LTC_K80)
#define LTC_K80_LPKN2_12                         LTC_K80_LPKN2_12_REG(LTC_K80)
#define LTC_K80_LPKN2_13                         LTC_K80_LPKN2_13_REG(LTC_K80)
#define LTC_K80_LPKN2_14                         LTC_K80_LPKN2_14_REG(LTC_K80)
#define LTC_K80_LPKN2_15                         LTC_K80_LPKN2_15_REG(LTC_K80)
#define LTC_K80_LPKN3_0                          LTC_K80_LPKN3_0_REG(LTC_K80)
#define LTC_K80_LPKN3_1                          LTC_K80_LPKN3_1_REG(LTC_K80)
#define LTC_K80_LPKN3_2                          LTC_K80_LPKN3_2_REG(LTC_K80)
#define LTC_K80_LPKN3_3                          LTC_K80_LPKN3_3_REG(LTC_K80)
#define LTC_K80_LPKN3_4                          LTC_K80_LPKN3_4_REG(LTC_K80)
#define LTC_K80_LPKN3_5                          LTC_K80_LPKN3_5_REG(LTC_K80)
#define LTC_K80_LPKN3_6                          LTC_K80_LPKN3_6_REG(LTC_K80)
#define LTC_K80_LPKN3_7                          LTC_K80_LPKN3_7_REG(LTC_K80)
#define LTC_K80_LPKN3_8                          LTC_K80_LPKN3_8_REG(LTC_K80)
#define LTC_K80_LPKN3_9                          LTC_K80_LPKN3_9_REG(LTC_K80)
#define LTC_K80_LPKN3_10                         LTC_K80_LPKN3_10_REG(LTC_K80)
#define LTC_K80_LPKN3_11                         LTC_K80_LPKN3_11_REG(LTC_K80)
#define LTC_K80_LPKN3_12                         LTC_K80_LPKN3_12_REG(LTC_K80)
#define LTC_K80_LPKN3_13                         LTC_K80_LPKN3_13_REG(LTC_K80)
#define LTC_K80_LPKN3_14                         LTC_K80_LPKN3_14_REG(LTC_K80)
#define LTC_K80_LPKN3_15                         LTC_K80_LPKN3_15_REG(LTC_K80)
#define LTC_K80_LPKE_0                           LTC_K80_LPKE_0_REG(LTC_K80)
#define LTC_K80_LPKE_1                           LTC_K80_LPKE_1_REG(LTC_K80)
#define LTC_K80_LPKE_2                           LTC_K80_LPKE_2_REG(LTC_K80)
#define LTC_K80_LPKE_3                           LTC_K80_LPKE_3_REG(LTC_K80)
#define LTC_K80_LPKE_4                           LTC_K80_LPKE_4_REG(LTC_K80)
#define LTC_K80_LPKE_5                           LTC_K80_LPKE_5_REG(LTC_K80)
#define LTC_K80_LPKE_6                           LTC_K80_LPKE_6_REG(LTC_K80)
#define LTC_K80_LPKE_7                           LTC_K80_LPKE_7_REG(LTC_K80)
#define LTC_K80_LPKE_8                           LTC_K80_LPKE_8_REG(LTC_K80)
#define LTC_K80_LPKE_9                           LTC_K80_LPKE_9_REG(LTC_K80)
#define LTC_K80_LPKE_10                          LTC_K80_LPKE_10_REG(LTC_K80)
#define LTC_K80_LPKE_11                          LTC_K80_LPKE_11_REG(LTC_K80)
#define LTC_K80_LPKE_12                          LTC_K80_LPKE_12_REG(LTC_K80)
#define LTC_K80_LPKE_13                          LTC_K80_LPKE_13_REG(LTC_K80)
#define LTC_K80_LPKE_14                          LTC_K80_LPKE_14_REG(LTC_K80)
#define LTC_K80_LPKE_15                          LTC_K80_LPKE_15_REG(LTC_K80)
#define LTC_K80_LPKE_16                          LTC_K80_LPKE_16_REG(LTC_K80)
#define LTC_K80_LPKE_17                          LTC_K80_LPKE_17_REG(LTC_K80)
#define LTC_K80_LPKE_18                          LTC_K80_LPKE_18_REG(LTC_K80)
#define LTC_K80_LPKE_19                          LTC_K80_LPKE_19_REG(LTC_K80)
#define LTC_K80_LPKE_20                          LTC_K80_LPKE_20_REG(LTC_K80)
#define LTC_K80_LPKE_21                          LTC_K80_LPKE_21_REG(LTC_K80)
#define LTC_K80_LPKE_22                          LTC_K80_LPKE_22_REG(LTC_K80)
#define LTC_K80_LPKE_23                          LTC_K80_LPKE_23_REG(LTC_K80)
#define LTC_K80_LPKE_24                          LTC_K80_LPKE_24_REG(LTC_K80)
#define LTC_K80_LPKE_25                          LTC_K80_LPKE_25_REG(LTC_K80)
#define LTC_K80_LPKE_26                          LTC_K80_LPKE_26_REG(LTC_K80)
#define LTC_K80_LPKE_27                          LTC_K80_LPKE_27_REG(LTC_K80)
#define LTC_K80_LPKE_28                          LTC_K80_LPKE_28_REG(LTC_K80)
#define LTC_K80_LPKE_29                          LTC_K80_LPKE_29_REG(LTC_K80)
#define LTC_K80_LPKE_30                          LTC_K80_LPKE_30_REG(LTC_K80)
#define LTC_K80_LPKE_31                          LTC_K80_LPKE_31_REG(LTC_K80)
#define LTC_K80_LPKE_32                          LTC_K80_LPKE_32_REG(LTC_K80)
#define LTC_K80_LPKE_33                          LTC_K80_LPKE_33_REG(LTC_K80)
#define LTC_K80_LPKE_34                          LTC_K80_LPKE_34_REG(LTC_K80)
#define LTC_K80_LPKE_35                          LTC_K80_LPKE_35_REG(LTC_K80)
#define LTC_K80_LPKE_36                          LTC_K80_LPKE_36_REG(LTC_K80)
#define LTC_K80_LPKE_37                          LTC_K80_LPKE_37_REG(LTC_K80)
#define LTC_K80_LPKE_38                          LTC_K80_LPKE_38_REG(LTC_K80)
#define LTC_K80_LPKE_39                          LTC_K80_LPKE_39_REG(LTC_K80)
#define LTC_K80_LPKE_40                          LTC_K80_LPKE_40_REG(LTC_K80)
#define LTC_K80_LPKE_41                          LTC_K80_LPKE_41_REG(LTC_K80)
#define LTC_K80_LPKE_42                          LTC_K80_LPKE_42_REG(LTC_K80)
#define LTC_K80_LPKE_43                          LTC_K80_LPKE_43_REG(LTC_K80)
#define LTC_K80_LPKE_44                          LTC_K80_LPKE_44_REG(LTC_K80)
#define LTC_K80_LPKE_45                          LTC_K80_LPKE_45_REG(LTC_K80)
#define LTC_K80_LPKE_46                          LTC_K80_LPKE_46_REG(LTC_K80)
#define LTC_K80_LPKE_47                          LTC_K80_LPKE_47_REG(LTC_K80)
#define LTC_K80_LPKE_48                          LTC_K80_LPKE_48_REG(LTC_K80)
#define LTC_K80_LPKE_49                          LTC_K80_LPKE_49_REG(LTC_K80)
#define LTC_K80_LPKE_50                          LTC_K80_LPKE_50_REG(LTC_K80)
#define LTC_K80_LPKE_51                          LTC_K80_LPKE_51_REG(LTC_K80)
#define LTC_K80_LPKE_52                          LTC_K80_LPKE_52_REG(LTC_K80)
#define LTC_K80_LPKE_53                          LTC_K80_LPKE_53_REG(LTC_K80)
#define LTC_K80_LPKE_54                          LTC_K80_LPKE_54_REG(LTC_K80)
#define LTC_K80_LPKE_55                          LTC_K80_LPKE_55_REG(LTC_K80)
#define LTC_K80_LPKE_56                          LTC_K80_LPKE_56_REG(LTC_K80)
#define LTC_K80_LPKE_57                          LTC_K80_LPKE_57_REG(LTC_K80)
#define LTC_K80_LPKE_58                          LTC_K80_LPKE_58_REG(LTC_K80)
#define LTC_K80_LPKE_59                          LTC_K80_LPKE_59_REG(LTC_K80)
#define LTC_K80_LPKE_60                          LTC_K80_LPKE_60_REG(LTC_K80)
#define LTC_K80_LPKE_61                          LTC_K80_LPKE_61_REG(LTC_K80)
#define LTC_K80_LPKE_62                          LTC_K80_LPKE_62_REG(LTC_K80)
#define LTC_K80_LPKE_63                          LTC_K80_LPKE_63_REG(LTC_K80)

/* LTC_K80 - Register array accessors */

/*!
 * @}
 */ /* end of group LTC_K80_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group LTC_K80_Peripheral_Access_Layer */


/* ----------------------------------------------------------------------------
   -- MCG Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MCG_Peripheral_Access_Layer MCG Peripheral Access Layer
 * @{
 */

/** MCG - Register Layout Typedef */
typedef struct {
  __IO uint8_t C1;                                 /**< MCG Control 1 Register, offset: 0x0 */
  __IO uint8_t C2;                                 /**< MCG Control 2 Register, offset: 0x1 */
  __IO uint8_t C3;                                 /**< MCG Control 3 Register, offset: 0x2 */
  __IO uint8_t C4;                                 /**< MCG Control 4 Register, offset: 0x3 */
  __IO uint8_t C5;                                 /**< MCG Control 5 Register, offset: 0x4 */
  __IO uint8_t C6;                                 /**< MCG Control 6 Register, offset: 0x5 */
  __I  uint8_t S;                                  /**< MCG Status Register, offset: 0x6 */
       uint8_t RESERVED_0;
  __IO uint8_t SC;                                 /**< MCG Status and Control Register, offset: 0x8 */
       uint8_t RESERVED_1;
  __IO uint8_t ATCVH;                              /**< MCG Auto Trim Compare Value High Register, offset: 0xA */
  __IO uint8_t ATCVL;                              /**< MCG Auto Trim Compare Value Low Register, offset: 0xB */
  __IO uint8_t C7;                                 /**< MCG Control 7 Register, offset: 0xC */
  __IO uint8_t C8;                                 /**< MCG Control 8 Register, offset: 0xD */
  __IO uint8_t C9;                                 /**< MCG Control 9 Register, offset: 0xE */
       uint8_t RESERVED_2;
  __IO uint8_t C11;                                /**< MCG Control 11 Register, offset: 0x10 */
  __IO uint8_t C12;                                /**< MCG Control 12 Register, offset: 0x11 */
  __IO uint8_t S2;                                 /**< MCG Status 2 Register, offset: 0x12 */
  __IO uint8_t T3;                                 /**< MCG Test 3 Register, offset: 0x13 */
} MCG_Type, *MCG_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- MCG - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MCG_Register_Accessor_Macros MCG - Register accessor macros
 * @{
 */


/* MCG - Register accessors */
#define MCG_C1_REG(base)                         ((base)->C1)
#define MCG_C2_REG(base)                         ((base)->C2)
#define MCG_C3_REG(base)                         ((base)->C3)
#define MCG_C4_REG(base)                         ((base)->C4)
#define MCG_C5_REG(base)                         ((base)->C5)
#define MCG_C6_REG(base)                         ((base)->C6)
#define MCG_S_REG(base)                          ((base)->S)
#define MCG_SC_REG(base)                         ((base)->SC)
#define MCG_ATCVH_REG(base)                      ((base)->ATCVH)
#define MCG_ATCVL_REG(base)                      ((base)->ATCVL)
#define MCG_C7_REG(base)                         ((base)->C7)
#define MCG_C8_REG(base)                         ((base)->C8)
#define MCG_C9_REG(base)                         ((base)->C9)
#define MCG_C11_REG(base)                        ((base)->C11)
#define MCG_C12_REG(base)                        ((base)->C12)
#define MCG_S2_REG(base)                         ((base)->S2)
#define MCG_T3_REG(base)                         ((base)->T3)

/*!
 * @}
 */ /* end of group MCG_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- MCG Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MCG_Register_Masks MCG Register Masks
 * @{
 */

/* C1 Bit Fields */
#define MCG_C1_IREFSTEN_MASK                     0x1u
#define MCG_C1_IREFSTEN_SHIFT                    0
#define MCG_C1_IRCLKEN_MASK                      0x2u
#define MCG_C1_IRCLKEN_SHIFT                     1
#define MCG_C1_IREFS_MASK                        0x4u
#define MCG_C1_IREFS_SHIFT                       2
#define MCG_C1_FRDIV_MASK                        0x38u
#define MCG_C1_FRDIV_SHIFT                       3
#define MCG_C1_FRDIV(x)                          (((uint8_t)(((uint8_t)(x))<<MCG_C1_FRDIV_SHIFT))&MCG_C1_FRDIV_MASK)
#define MCG_C1_CLKS_MASK                         0xC0u
#define MCG_C1_CLKS_SHIFT                        6
#define MCG_C1_CLKS(x)                           (((uint8_t)(((uint8_t)(x))<<MCG_C1_CLKS_SHIFT))&MCG_C1_CLKS_MASK)
/* C2 Bit Fields */
#define MCG_C2_IRCS_MASK                         0x1u
#define MCG_C2_IRCS_SHIFT                        0
#define MCG_C2_LP_MASK                           0x2u
#define MCG_C2_LP_SHIFT                          1
#define MCG_C2_EREFS_MASK                        0x4u
#define MCG_C2_EREFS_SHIFT                       2
#define MCG_C2_HGO_MASK                          0x8u
#define MCG_C2_HGO_SHIFT                         3
#define MCG_C2_RANGE_MASK                        0x30u
#define MCG_C2_RANGE_SHIFT                       4
#define MCG_C2_RANGE(x)                          (((uint8_t)(((uint8_t)(x))<<MCG_C2_RANGE_SHIFT))&MCG_C2_RANGE_MASK)
#define MCG_C2_FCFTRIM_MASK                      0x40u
#define MCG_C2_FCFTRIM_SHIFT                     6
#define MCG_C2_LOCRE0_MASK                       0x80u
#define MCG_C2_LOCRE0_SHIFT                      7
/* C3 Bit Fields */
#define MCG_C3_SCTRIM_MASK                       0xFFu
#define MCG_C3_SCTRIM_SHIFT                      0
#define MCG_C3_SCTRIM(x)                         (((uint8_t)(((uint8_t)(x))<<MCG_C3_SCTRIM_SHIFT))&MCG_C3_SCTRIM_MASK)
/* C4 Bit Fields */
#define MCG_C4_SCFTRIM_MASK                      0x1u
#define MCG_C4_SCFTRIM_SHIFT                     0
#define MCG_C4_FCTRIM_MASK                       0x1Eu
#define MCG_C4_FCTRIM_SHIFT                      1
#define MCG_C4_FCTRIM(x)                         (((uint8_t)(((uint8_t)(x))<<MCG_C4_FCTRIM_SHIFT))&MCG_C4_FCTRIM_MASK)
#define MCG_C4_DRST_DRS_MASK                     0x60u
#define MCG_C4_DRST_DRS_SHIFT                    5
#define MCG_C4_DRST_DRS(x)                       (((uint8_t)(((uint8_t)(x))<<MCG_C4_DRST_DRS_SHIFT))&MCG_C4_DRST_DRS_MASK)
#define MCG_C4_DMX32_MASK                        0x80u
#define MCG_C4_DMX32_SHIFT                       7
/* C5 Bit Fields */
#define MCG_C5_PRDIV_MASK                        0x7u
#define MCG_C5_PRDIV_SHIFT                       0
#define MCG_C5_PRDIV(x)                          (((uint8_t)(((uint8_t)(x))<<MCG_C5_PRDIV_SHIFT))&MCG_C5_PRDIV_MASK)
#define MCG_C5_PLLSTEN_MASK                      0x20u
#define MCG_C5_PLLSTEN_SHIFT                     5
#define MCG_C5_PLLCLKEN_MASK                     0x40u
#define MCG_C5_PLLCLKEN_SHIFT                    6
/* C6 Bit Fields */
#define MCG_C6_VDIV_MASK                         0x1Fu
#define MCG_C6_VDIV_SHIFT                        0
#define MCG_C6_VDIV(x)                           (((uint8_t)(((uint8_t)(x))<<MCG_C6_VDIV_SHIFT))&MCG_C6_VDIV_MASK)
#define MCG_C6_CME0_MASK                         0x20u
#define MCG_C6_CME0_SHIFT                        5
#define MCG_C6_PLLS_MASK                         0x40u
#define MCG_C6_PLLS_SHIFT                        6
#define MCG_C6_LOLIE0_MASK                       0x80u
#define MCG_C6_LOLIE0_SHIFT                      7
/* S Bit Fields */
#define MCG_S_IRCST_MASK                         0x1u
#define MCG_S_IRCST_SHIFT                        0
#define MCG_S_OSCINIT0_MASK                      0x2u
#define MCG_S_OSCINIT0_SHIFT                     1
#define MCG_S_CLKST_MASK                         0xCu
#define MCG_S_CLKST_SHIFT                        2
#define MCG_S_CLKST(x)                           (((uint8_t)(((uint8_t)(x))<<MCG_S_CLKST_SHIFT))&MCG_S_CLKST_MASK)
#define MCG_S_IREFST_MASK                        0x10u
#define MCG_S_IREFST_SHIFT                       4
#define MCG_S_PLLST_MASK                         0x20u
#define MCG_S_PLLST_SHIFT                        5
#define MCG_S_LOCK0_MASK                         0x40u
#define MCG_S_LOCK0_SHIFT                        6
#define MCG_S_LOLS0_MASK                         0x80u
#define MCG_S_LOLS0_SHIFT                        7
/* SC Bit Fields */
#define MCG_SC_LOCS0_MASK                        0x1u
#define MCG_SC_LOCS0_SHIFT                       0
#define MCG_SC_FCRDIV_MASK                       0xEu
#define MCG_SC_FCRDIV_SHIFT                      1
#define MCG_SC_FCRDIV(x)                         (((uint8_t)(((uint8_t)(x))<<MCG_SC_FCRDIV_SHIFT))&MCG_SC_FCRDIV_MASK)
#define MCG_SC_FLTPRSRV_MASK                     0x10u
#define MCG_SC_FLTPRSRV_SHIFT                    4
#define MCG_SC_ATMF_MASK                         0x20u
#define MCG_SC_ATMF_SHIFT                        5
#define MCG_SC_ATMS_MASK                         0x40u
#define MCG_SC_ATMS_SHIFT                        6
#define MCG_SC_ATME_MASK                         0x80u
#define MCG_SC_ATME_SHIFT                        7
/* ATCVH Bit Fields */
#define MCG_ATCVH_ATCVH_MASK                     0xFFu
#define MCG_ATCVH_ATCVH_SHIFT                    0
#define MCG_ATCVH_ATCVH(x)                       (((uint8_t)(((uint8_t)(x))<<MCG_ATCVH_ATCVH_SHIFT))&MCG_ATCVH_ATCVH_MASK)
/* ATCVL Bit Fields */
#define MCG_ATCVL_ATCVL_MASK                     0xFFu
#define MCG_ATCVL_ATCVL_SHIFT                    0
#define MCG_ATCVL_ATCVL(x)                       (((uint8_t)(((uint8_t)(x))<<MCG_ATCVL_ATCVL_SHIFT))&MCG_ATCVL_ATCVL_MASK)
/* C7 Bit Fields */
#define MCG_C7_OSCSEL_MASK                       0x3u
#define MCG_C7_OSCSEL_SHIFT                      0
#define MCG_C7_OSCSEL(x)                         (((uint8_t)(((uint8_t)(x))<<MCG_C7_OSCSEL_SHIFT))&MCG_C7_OSCSEL_MASK)
/* C8 Bit Fields */
#define MCG_C8_LOCS1_MASK                        0x1u
#define MCG_C8_LOCS1_SHIFT                       0
#define MCG_C8_CME1_MASK                         0x20u
#define MCG_C8_CME1_SHIFT                        5
#define MCG_C8_LOLRE_MASK                        0x40u
#define MCG_C8_LOLRE_SHIFT                       6
#define MCG_C8_LOCRE1_MASK                       0x80u
#define MCG_C8_LOCRE1_SHIFT                      7
/* C9 Bit Fields */
#define MCG_C9_EXT_PLL_LOCS_MASK                 0x1u
#define MCG_C9_EXT_PLL_LOCS_SHIFT                0
#define MCG_C9_PLL_LOCRE_MASK                    0x10u
#define MCG_C9_PLL_LOCRE_SHIFT                   4
#define MCG_C9_PLL_CME_MASK                      0x20u
#define MCG_C9_PLL_CME_SHIFT                     5
/* C11 Bit Fields */
#define MCG_C11_PLLCS_MASK                       0x10u
#define MCG_C11_PLLCS_SHIFT                      4
/* C12 Bit Fields */
/* S2 Bit Fields */
#define MCG_S2_PLLCST_MASK                       0x10u
#define MCG_S2_PLLCST_SHIFT                      4
/* T3 Bit Fields */

/*!
 * @}
 */ /* end of group MCG_Register_Masks */


/* MCG - Peripheral instance base addresses */
/** Peripheral MCG base address */
#define MCG_BASE                                (0x40064000u)
/** Peripheral MCG base pointer */
#define MCG                                     ((MCG_Type *)MCG_BASE)
#define MCG_BASE_PTR                            (MCG)
/** Array initializer of MCG peripheral base addresses */
#define MCG_BASE_ADDRS                           { MCG_BASE }
/** Array initializer of MCG peripheral base pointers */
#define MCG_BASE_PTRS                            { MCG }
/** Interrupt vectors for the MCG peripheral type */
#define MCG_IRQS                                 { MCG_IRQn }

/* ----------------------------------------------------------------------------
   -- MCG - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MCG_Register_Accessor_Macros MCG - Register accessor macros
 * @{
 */


/* MCG - Register instance definitions */
/* MCG */
#define MCG_C1                                   MCG_C1_REG(MCG)
#define MCG_C2                                   MCG_C2_REG(MCG)
#define MCG_C3                                   MCG_C3_REG(MCG)
#define MCG_C4                                   MCG_C4_REG(MCG)
#define MCG_C5                                   MCG_C5_REG(MCG)
#define MCG_C6                                   MCG_C6_REG(MCG)
#define MCG_S                                    MCG_S_REG(MCG)
#define MCG_SC                                   MCG_SC_REG(MCG)
#define MCG_ATCVH                                MCG_ATCVH_REG(MCG)
#define MCG_ATCVL                                MCG_ATCVL_REG(MCG)
#define MCG_C7                                   MCG_C7_REG(MCG)
#define MCG_C8                                   MCG_C8_REG(MCG)
#define MCG_C9                                   MCG_C9_REG(MCG)
#define MCG_C11                                  MCG_C11_REG(MCG)
#define MCG_C12                                  MCG_C12_REG(MCG)
#define MCG_S2                                   MCG_S2_REG(MCG)
#define MCG_T3                                   MCG_T3_REG(MCG)

/* MCG - Register array accessors */

/*!
 * @}
 */ /* end of group MCG_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group MCG_Peripheral_Access_Layer */


/* ----------------------------------------------------------------------------
   -- MCM Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MCM_Peripheral_Access_Layer MCM Peripheral Access Layer
 * @{
 */

/** MCM - Register Layout Typedef */
typedef struct {
       uint32_t RESERVED_0[2];
  __I  uint16_t PLASC;                             /**< Crossbar Switch (AXBS) Slave Configuration, offset: 0x8 */
  __I  uint16_t PLAMC;                             /**< Crossbar Switch (AXBS) Master Configuration, offset: 0xA */
  __IO uint32_t CR;                                /**< Control Register, offset: 0xC */
  __I  uint32_t ISCR;                              /**< Interrupt Status Register, offset: 0x10 */
       uint32_t RESERVED_1[3];
  __I  uint32_t FADR;                              /**< Fault address register, offset: 0x20 */
  __I  uint32_t FATR;                              /**< Fault attributes register, offset: 0x24 */
  __I  uint32_t FDR;                               /**< Fault data register, offset: 0x28 */
       uint32_t RESERVED_2;
  __IO uint32_t PID;                               /**< Process ID register, offset: 0x30 */
       uint32_t RESERVED_3[3];
  __IO uint32_t CPO;                               /**< Compute Operation Control Register, offset: 0x40 */
} MCM_Type, *MCM_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- MCM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MCM_Register_Accessor_Macros MCM - Register accessor macros
 * @{
 */


/* MCM - Register accessors */
#define MCM_PLASC_REG(base)                      ((base)->PLASC)
#define MCM_PLAMC_REG(base)                      ((base)->PLAMC)
#define MCM_CR_REG(base)                         ((base)->CR)
#define MCM_ISCR_REG(base)                       ((base)->ISCR)
#define MCM_FADR_REG(base)                       ((base)->FADR)
#define MCM_FATR_REG(base)                       ((base)->FATR)
#define MCM_FDR_REG(base)                        ((base)->FDR)
#define MCM_PID_REG(base)                        ((base)->PID)
#define MCM_CPO_REG(base)                        ((base)->CPO)

/*!
 * @}
 */ /* end of group MCM_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- MCM Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MCM_Register_Masks MCM Register Masks
 * @{
 */

/* PLASC Bit Fields */
#define MCM_PLASC_ASC_MASK                       0xFFu
#define MCM_PLASC_ASC_SHIFT                      0
#define MCM_PLASC_ASC(x)                         (((uint16_t)(((uint16_t)(x))<<MCM_PLASC_ASC_SHIFT))&MCM_PLASC_ASC_MASK)
/* PLAMC Bit Fields */
#define MCM_PLAMC_AMC_MASK                       0xFFu
#define MCM_PLAMC_AMC_SHIFT                      0
#define MCM_PLAMC_AMC(x)                         (((uint16_t)(((uint16_t)(x))<<MCM_PLAMC_AMC_SHIFT))&MCM_PLAMC_AMC_MASK)
/* CR Bit Fields */
#define MCM_CR_SRAMUAP_MASK                      0x3000000u
#define MCM_CR_SRAMUAP_SHIFT                     24
#define MCM_CR_SRAMUAP(x)                        (((uint32_t)(((uint32_t)(x))<<MCM_CR_SRAMUAP_SHIFT))&MCM_CR_SRAMUAP_MASK)
#define MCM_CR_SRAMUWP_MASK                      0x4000000u
#define MCM_CR_SRAMUWP_SHIFT                     26
#define MCM_CR_SRAMLAP_MASK                      0x30000000u
#define MCM_CR_SRAMLAP_SHIFT                     28
#define MCM_CR_SRAMLAP(x)                        (((uint32_t)(((uint32_t)(x))<<MCM_CR_SRAMLAP_SHIFT))&MCM_CR_SRAMLAP_MASK)
#define MCM_CR_SRAMLWP_MASK                      0x40000000u
#define MCM_CR_SRAMLWP_SHIFT                     30
/* ISCR Bit Fields */
#define MCM_ISCR_FIOC_MASK                       0x100u
#define MCM_ISCR_FIOC_SHIFT                      8
#define MCM_ISCR_FDZC_MASK                       0x200u
#define MCM_ISCR_FDZC_SHIFT                      9
#define MCM_ISCR_FOFC_MASK                       0x400u
#define MCM_ISCR_FOFC_SHIFT                      10
#define MCM_ISCR_FUFC_MASK                       0x800u
#define MCM_ISCR_FUFC_SHIFT                      11
#define MCM_ISCR_FIXC_MASK                       0x1000u
#define MCM_ISCR_FIXC_SHIFT                      12
#define MCM_ISCR_FIDC_MASK                       0x8000u
#define MCM_ISCR_FIDC_SHIFT                      15
#define MCM_ISCR_FIOCE_MASK                      0x1000000u
#define MCM_ISCR_FIOCE_SHIFT                     24
#define MCM_ISCR_FDZCE_MASK                      0x2000000u
#define MCM_ISCR_FDZCE_SHIFT                     25
#define MCM_ISCR_FOFCE_MASK                      0x4000000u
#define MCM_ISCR_FOFCE_SHIFT                     26
#define MCM_ISCR_FUFCE_MASK                      0x8000000u
#define MCM_ISCR_FUFCE_SHIFT                     27
#define MCM_ISCR_FIXCE_MASK                      0x10000000u
#define MCM_ISCR_FIXCE_SHIFT                     28
#define MCM_ISCR_FIDCE_MASK                      0x80000000u
#define MCM_ISCR_FIDCE_SHIFT                     31
/* FADR Bit Fields */
#define MCM_FADR_ADDRESS_MASK                    0xFFFFFFFFu
#define MCM_FADR_ADDRESS_SHIFT                   0
#define MCM_FADR_ADDRESS(x)                      (((uint32_t)(((uint32_t)(x))<<MCM_FADR_ADDRESS_SHIFT))&MCM_FADR_ADDRESS_MASK)
/* FATR Bit Fields */
#define MCM_FATR_BEDA_MASK                       0x1u
#define MCM_FATR_BEDA_SHIFT                      0
#define MCM_FATR_BEMD_MASK                       0x2u
#define MCM_FATR_BEMD_SHIFT                      1
#define MCM_FATR_BESZ_MASK                       0x30u
#define MCM_FATR_BESZ_SHIFT                      4
#define MCM_FATR_BESZ(x)                         (((uint32_t)(((uint32_t)(x))<<MCM_FATR_BESZ_SHIFT))&MCM_FATR_BESZ_MASK)
#define MCM_FATR_BEWT_MASK                       0x80u
#define MCM_FATR_BEWT_SHIFT                      7
#define MCM_FATR_BEMN_MASK                       0xF00u
#define MCM_FATR_BEMN_SHIFT                      8
#define MCM_FATR_BEMN(x)                         (((uint32_t)(((uint32_t)(x))<<MCM_FATR_BEMN_SHIFT))&MCM_FATR_BEMN_MASK)
#define MCM_FATR_BEOVR_MASK                      0x80000000u
#define MCM_FATR_BEOVR_SHIFT                     31
/* FDR Bit Fields */
#define MCM_FDR_DATA_MASK                        0xFFFFFFFFu
#define MCM_FDR_DATA_SHIFT                       0
#define MCM_FDR_DATA(x)                          (((uint32_t)(((uint32_t)(x))<<MCM_FDR_DATA_SHIFT))&MCM_FDR_DATA_MASK)
/* PID Bit Fields */
#define MCM_PID_PID_MASK                         0xFFu
#define MCM_PID_PID_SHIFT                        0
#define MCM_PID_PID(x)                           (((uint32_t)(((uint32_t)(x))<<MCM_PID_PID_SHIFT))&MCM_PID_PID_MASK)
/* CPO Bit Fields */
#define MCM_CPO_CPOREQ_MASK                      0x1u
#define MCM_CPO_CPOREQ_SHIFT                     0
#define MCM_CPO_CPOACK_MASK                      0x2u
#define MCM_CPO_CPOACK_SHIFT                     1
#define MCM_CPO_CPOWOI_MASK                      0x4u
#define MCM_CPO_CPOWOI_SHIFT                     2

/*!
 * @}
 */ /* end of group MCM_Register_Masks */


/* MCM - Peripheral instance base addresses */
/** Peripheral MCM base address */
#define MCM_BASE                                (0xE0080000u)
/** Peripheral MCM base pointer */
#define MCM                                     ((MCM_Type *)MCM_BASE)
#define MCM_BASE_PTR                            (MCM)
/** Array initializer of MCM peripheral base addresses */
#define MCM_BASE_ADDRS                           { MCM_BASE }
/** Array initializer of MCM peripheral base pointers */
#define MCM_BASE_PTRS                            { MCM }
/** Interrupt vectors for the MCM peripheral type */
#define MCM_IRQS                                 { MCM_IRQn }

/* ----------------------------------------------------------------------------
   -- MCM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup MCM_Register_Accessor_Macros MCM - Register accessor macros
 * @{
 */


/* MCM - Register instance definitions */
/* MCM */
#define MCM_PLASC                                MCM_PLASC_REG(MCM)
#define MCM_PLAMC                                MCM_PLAMC_REG(MCM)
#define MCM_CR                                   MCM_CR_REG(MCM)
#define MCM_ISCR                                 MCM_ISCR_REG(MCM)
#define MCM_FADR                                 MCM_FADR_REG(MCM)
#define MCM_FATR                                 MCM_FATR_REG(MCM)
#define MCM_FDR                                  MCM_FDR_REG(MCM)
#define MCM_PID                                  MCM_PID_REG(MCM)
#define MCM_CPO                                  MCM_CPO_REG(MCM)

/* MCM - Register array accessors */

/*!
 * @}
 */ /* end of group MCM_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group MCM_Peripheral_Access_Layer */


/* ----------------------------------------------------------------------------
   -- CAU Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CAU_Peripheral_Access_Layer CAU Peripheral Access Layer
 * @{
 */

/** CAU - Register Layout Typedef */
typedef struct {
  __IO uint32_t CASR;                              /**< Status Register, offset: 0x0 */
  __IO uint32_t CAA;                               /**< Accumulator, offset: 0x1 */
  __IO uint32_t CA[9];                             /**< General Purpose Register, array offset: 0x2, array step: 0x4 */
} CAU_Type, *CAU_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- CAU - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CAU_Register_Accessor_Macros CAU - Register accessor macros
 * @{
 */


/* CAU - Register accessors */
#define CAU_CASR_REG(base)                       ((base)->CASR)
#define CAU_CAA_REG(base)                        ((base)->CAA)
#define CAU_CA_REG(base,index)                   ((base)->CA[index])

/*!
 * @}
 */ /* end of group CAU_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- CAU Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CAU_Register_Masks CAU Register Masks
 * @{
 */

/* CASR Bit Fields */
#define CAU_CASR_IC_MASK                         0x1u
#define CAU_CASR_IC_SHIFT                        0
#define CAU_CASR_DPE_MASK                        0x2u
#define CAU_CASR_DPE_SHIFT                       1
#define CAU_CASR_VER_MASK                        0xF0000000u
#define CAU_CASR_VER_SHIFT                       28
#define CAU_CASR_VER(x)                          (((uint32_t)(((uint32_t)(x))<<CAU_CASR_VER_SHIFT))&CAU_CASR_VER_MASK)
/* CAA Bit Fields */
#define CAU_CAA_ACC_MASK                         0xFFFFFFFFu
#define CAU_CAA_ACC_SHIFT                        0
#define CAU_CAA_ACC(x)                           (((uint32_t)(((uint32_t)(x))<<CAU_CAA_ACC_SHIFT))&CAU_CAA_ACC_MASK)
/* CA Bit Fields */
#define CAU_CA_CAN_MASK                          0xFFFFFFFFu
#define CAU_CA_CAN_SHIFT                         0
#define CAU_CA_CAN(x)                            (((uint32_t)(((uint32_t)(x))<<CAU_CA_CAN_SHIFT))&CAU_CA_CAN_MASK)

/*!
 * @}
 */ /* end of group CAU_Register_Masks */


/* CAU - Peripheral instance base addresses */
/** Peripheral CAU base address */
#define CAU_BASE                                (0xE0081000u)
/** Peripheral CAU base pointer */
#define CAU                                     ((CAU_Type *)CAU_BASE)
#define CAU_BASE_PTR                            (CAU)
/** Array initializer of CAU peripheral base addresses */
#define CAU_BASE_ADDRS                           { CAU_BASE }
/** Array initializer of CAU peripheral base pointers */
#define CAU_BASE_PTRS                            { CAU }
/** Interrupt vectors for the CAU peripheral type */
#define CAU_IRQS                                 { CAU_IRQn }

/* ----------------------------------------------------------------------------
   -- CAU - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup CAU_Register_Accessor_Macros CAU - Register accessor macros
 * @{
 */


/* CAU - Register instance definitions */
/* CAU */
#define CAU_CASR                                 CAU_CASR_REG(CAU)
#define CAU_CAA                                  CAU_CAA_REG(CAU)
#define CAU_CA0                                  CAU_CA_REG(CAU,0)
#define CAU_CA1                                  CAU_CA_REG(CAU,1)
#define CAU_CA2                                  CAU_CA_REG(CAU,2)
#define CAU_CA3                                  CAU_CA_REG(CAU,3)
#define CAU_CA4                                  CAU_CA_REG(CAU,4)
#define CAU_CA5                                  CAU_CA_REG(CAU,5)
#define CAU_CA6                                  CAU_CA_REG(CAU,6)
#define CAU_CA7                                  CAU_CA_REG(CAU,7)
#define CAU_CA8                                  CAU_CA_REG(CAU,8)

/* CAU - Register array accessors */
#define CAU_CA(index)                            CAU_CA_REG(CAU,index)

/*!
 * @}
 */ /* end of group CAU_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group CAU_Peripheral_Access_Layer */


/* ----------------------------------------------------------------------------
   -- OTFAD Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup OTFAD_Peripheral_Access_Layer OTFAD Peripheral Access Layer
 * @{
 */

/** OTFAD - Register Layout Typedef */
typedef struct {
       uint32_t RESERVED_0[768];
  __IO uint32_t CR;                                /**< Control, offset: 0xC00 */
  __IO uint32_t SR;                                /**< Status, offset: 0xC04 */
  __IO uint32_t CRC_;                              /**< Cyclic Redundancy Check, offset: 0xC08 */
       uint32_t RESERVED_1[61];
       struct {
           __IO uint32_t CTX_AES_KEY_W0; /**< AES Key Word0, array offset: 0xD00 */
           __IO uint32_t CTX_AES_KEY_W1; /**< AES Key Word1, array offset: 0xD04 */
           __IO uint32_t CTX_AES_KEY_W2; /**< AES Key Word2, array offset: 0xD08 */
           __IO uint32_t CTX_AES_KEY_W3; /**< AES Key Word3, array offset: 0xD0C */
           __IO uint32_t CTX_CTR_W0; /**< AES Counter Word0, array offset: 0xD10 */
           __IO uint32_t CTX_CTR_W1; /**< AES Counter Word1, array offset: 0xD14 */
           __IO uint32_t CTX_RGD_W0; /**< AES Region Descriptor Word0, array offset: 0xD18 */
           __IO uint32_t CTX_RGD_W1; /**< AES Region Descriptor Word1, array offset: 0xD1C */
                uint32_t RESERVED_2[8];
       } AES[4];
} OTFAD_Type, *OTFAD_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- OTFAD - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup OTFAD_Register_Accessor_Macros OTFAD - Register accessor macros
 * @{
 */


/* OTFAD - Register accessors */
#define OTFAD_CR_REG(base)                       ((base)->CR)
#define OTFAD_SR_REG(base)                       ((base)->SR)
#define OTFAD_CRC_REG(base)                      ((base)->CRC)
#define OTFAD_CTX_AES_KEY_W0_REG(base,index)     ((base)->CTX_AES_KEY_W0[index])
#define OTFAD_CTX_AES_KEY_W1_REG(base,index)     ((base)->CTX_AES_KEY_W1[index])
#define OTFAD_CTX_AES_KEY_W2_REG(base,index)     ((base)->CTX_AES_KEY_W2[index])
#define OTFAD_CTX_AES_KEY_W3_REG(base,index)     ((base)->CTX_AES_KEY_W3[index])
#define OTFAD_CTX_CTR_W0_REG(base,index)         ((base)->CTX_CTR_W0[index])
#define OTFAD_CTX_CTR_W1_REG(base,index)         ((base)->CTX_CTR_W1[index])
#define OTFAD_CTX_RGD_W0_REG(base,index)         ((base)->CTX_RGD_W0[index])
#define OTFAD_CTX_RGD_W1_REG(base,index)         ((base)->CTX_RGD_W1[index])

/*!
 * @}
 */ /* end of group OTFAD_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- OTFAD Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup OTFAD_Register_Masks OTFAD Register Masks
 * @{
 */

/* CR Bit Fields */
#define OTFAD_CR_FSVM_MASK                       0x4u
#define OTFAD_CR_FSVM_SHIFT                      2
#define OTFAD_CR_FLDM_MASK                       0x8u
#define OTFAD_CR_FLDM_SHIFT                      3
#define OTFAD_CR_RRAE_MASK                       0x80u
#define OTFAD_CR_RRAE_SHIFT                      7
#define OTFAD_CR_CCTX_MASK                       0x30000u
#define OTFAD_CR_CCTX_SHIFT                      16
#define OTFAD_CR_CCTX(x)                         (((uint32_t)(((uint32_t)(x))<<OTFAD_CR_CCTX_SHIFT))&OTFAD_CR_CCTX_MASK)
#define OTFAD_CR_CRCE_MASK                       0x100000u
#define OTFAD_CR_CRCE_SHIFT                      20
#define OTFAD_CR_CRCI_MASK                       0x200000u
#define OTFAD_CR_CRCI_SHIFT                      21
#define OTFAD_CR_GE_MASK                         0x80000000u
#define OTFAD_CR_GE_SHIFT                        31
/* SR Bit Fields */
#define OTFAD_SR_MDPCP_MASK                      0x2u
#define OTFAD_SR_MDPCP_SHIFT                     1
#define OTFAD_SR_MODE_MASK                       0xCu
#define OTFAD_SR_MODE_SHIFT                      2
#define OTFAD_SR_MODE(x)                         (((uint32_t)(((uint32_t)(x))<<OTFAD_SR_MODE_SHIFT))&OTFAD_SR_MODE_MASK)
#define OTFAD_SR_NCTX_MASK                       0xF0u
#define OTFAD_SR_NCTX_SHIFT                      4
#define OTFAD_SR_NCTX(x)                         (((uint32_t)(((uint32_t)(x))<<OTFAD_SR_NCTX_SHIFT))&OTFAD_SR_NCTX_MASK)
#define OTFAD_SR_HRL_MASK                        0xF000000u
#define OTFAD_SR_HRL_SHIFT                       24
#define OTFAD_SR_HRL(x)                          (((uint32_t)(((uint32_t)(x))<<OTFAD_SR_HRL_SHIFT))&OTFAD_SR_HRL_MASK)
#define OTFAD_SR_RRAM_MASK                       0x10000000u
#define OTFAD_SR_RRAM_SHIFT                      28
#define OTFAD_SR_GEM_MASK                        0x20000000u
#define OTFAD_SR_GEM_SHIFT                       29
/* CRC Bit Fields */
#define OTFAD_CRC_CRCD_MASK                      0xFFFFFFFFu
#define OTFAD_CRC_CRCD_SHIFT                     0
#define OTFAD_CRC_CRCD(x)                        (((uint32_t)(((uint32_t)(x))<<OTFAD_CRC_CRCD_SHIFT))&OTFAD_CRC_CRCD_MASK)
/* CTX_AES_KEY_W0 Bit Fields */
#define OTFAD_CTX_AES_KEY_W0_W0KEY_MASK          0xFFFFFFFFu
#define OTFAD_CTX_AES_KEY_W0_W0KEY_SHIFT         0
#define OTFAD_CTX_AES_KEY_W0_W0KEY(x)            (((uint32_t)(((uint32_t)(x))<<OTFAD_CTX_AES_KEY_W0_W0KEY_SHIFT))&OTFAD_CTX_AES_KEY_W0_W0KEY_MASK)
/* CTX_AES_KEY_W1 Bit Fields */
#define OTFAD_CTX_AES_KEY_W1_W1KEY_MASK          0xFFFFFFFFu
#define OTFAD_CTX_AES_KEY_W1_W1KEY_SHIFT         0
#define OTFAD_CTX_AES_KEY_W1_W1KEY(x)            (((uint32_t)(((uint32_t)(x))<<OTFAD_CTX_AES_KEY_W1_W1KEY_SHIFT))&OTFAD_CTX_AES_KEY_W1_W1KEY_MASK)
/* CTX_AES_KEY_W2 Bit Fields */
#define OTFAD_CTX_AES_KEY_W2_W2KEY_MASK          0xFFFFFFFFu
#define OTFAD_CTX_AES_KEY_W2_W2KEY_SHIFT         0
#define OTFAD_CTX_AES_KEY_W2_W2KEY(x)            (((uint32_t)(((uint32_t)(x))<<OTFAD_CTX_AES_KEY_W2_W2KEY_SHIFT))&OTFAD_CTX_AES_KEY_W2_W2KEY_MASK)
/* CTX_AES_KEY_W3 Bit Fields */
#define OTFAD_CTX_AES_KEY_W3_W3KEY_MASK          0xFFFFFFFFu
#define OTFAD_CTX_AES_KEY_W3_W3KEY_SHIFT         0
#define OTFAD_CTX_AES_KEY_W3_W3KEY(x)            (((uint32_t)(((uint32_t)(x))<<OTFAD_CTX_AES_KEY_W3_W3KEY_SHIFT))&OTFAD_CTX_AES_KEY_W3_W3KEY_MASK)
/* CTX_CTR_W0 Bit Fields */
#define OTFAD_CTX_CTR_W0_W0CTR_MASK              0xFFFFFFFFu
#define OTFAD_CTX_CTR_W0_W0CTR_SHIFT             0
#define OTFAD_CTX_CTR_W0_W0CTR(x)                (((uint32_t)(((uint32_t)(x))<<OTFAD_CTX_CTR_W0_W0CTR_SHIFT))&OTFAD_CTX_CTR_W0_W0CTR_MASK)
/* CTX_CTR_W1 Bit Fields */
#define OTFAD_CTX_CTR_W1_W1CTR_MASK              0xFFFFFFFFu
#define OTFAD_CTX_CTR_W1_W1CTR_SHIFT             0
#define OTFAD_CTX_CTR_W1_W1CTR(x)                (((uint32_t)(((uint32_t)(x))<<OTFAD_CTX_CTR_W1_W1CTR_SHIFT))&OTFAD_CTX_CTR_W1_W1CTR_MASK)
/* CTX_RGD_W0 Bit Fields */
#define OTFAD_CTX_RGD_W0_SRTADDR_MASK            0xFFFFFC00u
#define OTFAD_CTX_RGD_W0_SRTADDR_SHIFT           10
#define OTFAD_CTX_RGD_W0_SRTADDR(x)              (((uint32_t)(((uint32_t)(x))<<OTFAD_CTX_RGD_W0_SRTADDR_SHIFT))&OTFAD_CTX_RGD_W0_SRTADDR_MASK)
/* CTX_RGD_W1 Bit Fields */
#define OTFAD_CTX_RGD_W1_VLD_MASK                0x1u
#define OTFAD_CTX_RGD_W1_VLD_SHIFT               0
#define OTFAD_CTX_RGD_W1_ADE_MASK                0x2u
#define OTFAD_CTX_RGD_W1_ADE_SHIFT               1
#define OTFAD_CTX_RGD_W1_RO_MASK                 0x4u
#define OTFAD_CTX_RGD_W1_RO_SHIFT                2
#define OTFAD_CTX_RGD_W1_ENDADDR_MASK            0xFFFFFC00u
#define OTFAD_CTX_RGD_W1_ENDADDR_SHIFT           10
#define OTFAD_CTX_RGD_W1_ENDADDR(x)              (((uint32_t)(((uint32_t)(x))<<OTFAD_CTX_RGD_W1_ENDADDR_SHIFT))&OTFAD_CTX_RGD_W1_ENDADDR_MASK)

/*!
 * @}
 */ /* end of group OTFAD_Register_Masks */


/* OTFAD - Peripheral instance base addresses */
/** Peripheral OTFAD base address */
#define OTFAD_BASE                                (0x67FFFC00u)
/** Peripheral OTFAD base pointer */
#define OTFAD                                     ((OTFAD_Type *)OTFAD_BASE)
#define OTFAD_BASE_PTR                            (OTFAD)
/** Array initializer of OTFAD peripheral base addresses */
#define OTFAD_BASE_ADDRS                           { OTFAD_BASE }
/** Array initializer of OTFAD peripheral base pointers */
#define OTFAD_BASE_PTRS                            { OTFAD }
/** Interrupt vectors for the OTFAD peripheral type */
#define OTFAD_IRQS                                 { OTFAD_IRQn }

/* ----------------------------------------------------------------------------
   -- OTFAD - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup OTFAD_Register_Accessor_Macros OTFAD - Register accessor macros
 * @{
 */


/* OTFAD - Register instance definitions */
/* OTFAD */
#define OTFAD_CR                                 OTFAD_CR_REG(OTFAD)
#define OTFAD_SR                                 OTFAD_SR_REG(OTFAD)
#define OTFAD_CRC                                OTFAD_CRC_REG(OTFAD)
#define OTFAD_CTX0_AES_KEY_W0                    OTFAD_CTX_AES_KEY_W0_REG(OTFAD,0)
#define OTFAD_CTX1_AES_KEY_W0                    OTFAD_CTX_AES_KEY_W0_REG(OTFAD,1)
#define OTFAD_CTX2_AES_KEY_W0                    OTFAD_CTX_AES_KEY_W0_REG(OTFAD,2)
#define OTFAD_CTX3_AES_KEY_W0                    OTFAD_CTX_AES_KEY_W0_REG(OTFAD,3)
#define OTFAD_CTX0_AES_KEY_W1                    OTFAD_CTX_AES_KEY_W1_REG(OTFAD,0)
#define OTFAD_CTX1_AES_KEY_W1                    OTFAD_CTX_AES_KEY_W1_REG(OTFAD,1)
#define OTFAD_CTX2_AES_KEY_W1                    OTFAD_CTX_AES_KEY_W1_REG(OTFAD,2)
#define OTFAD_CTX3_AES_KEY_W1                    OTFAD_CTX_AES_KEY_W1_REG(OTFAD,3)
#define OTFAD_CTX0_AES_KEY_W2                    OTFAD_CTX_AES_KEY_W2_REG(OTFAD,0)
#define OTFAD_CTX1_AES_KEY_W2                    OTFAD_CTX_AES_KEY_W2_REG(OTFAD,1)
#define OTFAD_CTX2_AES_KEY_W2                    OTFAD_CTX_AES_KEY_W2_REG(OTFAD,2)
#define OTFAD_CTX3_AES_KEY_W2                    OTFAD_CTX_AES_KEY_W2_REG(OTFAD,3)
#define OTFAD_CTX0_AES_KEY_W3                    OTFAD_CTX_AES_KEY_W3_REG(OTFAD,0)
#define OTFAD_CTX1_AES_KEY_W3                    OTFAD_CTX_AES_KEY_W3_REG(OTFAD,1)
#define OTFAD_CTX2_AES_KEY_W3                    OTFAD_CTX_AES_KEY_W3_REG(OTFAD,2)
#define OTFAD_CTX3_AES_KEY_W3                    OTFAD_CTX_AES_KEY_W3_REG(OTFAD,3)
#define OTFAD_CTX0_CTR_W0                        OTFAD_CTX_CTR_W0_REG(OTFAD,0)
#define OTFAD_CTX1_CTR_W0                        OTFAD_CTX_CTR_W0_REG(OTFAD,1)
#define OTFAD_CTX2_CTR_W0                        OTFAD_CTX_CTR_W0_REG(OTFAD,2)
#define OTFAD_CTX3_CTR_W0                        OTFAD_CTX_CTR_W0_REG(OTFAD,3)
#define OTFAD_CTX0_CTR_W1                        OTFAD_CTX_CTR_W1_REG(OTFAD,0)
#define OTFAD_CTX1_CTR_W1                        OTFAD_CTX_CTR_W1_REG(OTFAD,1)
#define OTFAD_CTX2_CTR_W1                        OTFAD_CTX_CTR_W1_REG(OTFAD,2)
#define OTFAD_CTX3_CTR_W1                        OTFAD_CTX_CTR_W1_REG(OTFAD,3)
#define OTFAD_CTX0_RGD_W0                        OTFAD_CTX_RGD_W0_REG(OTFAD,0)
#define OTFAD_CTX1_RGD_W0                        OTFAD_CTX_RGD_W0_REG(OTFAD,1)
#define OTFAD_CTX2_RGD_W0                        OTFAD_CTX_RGD_W0_REG(OTFAD,2)
#define OTFAD_CTX3_RGD_W0                        OTFAD_CTX_RGD_W0_REG(OTFAD,3)
#define OTFAD_CTX0_RGD_W1                        OTFAD_CTX_RGD_W1_REG(OTFAD,0)
#define OTFAD_CTX1_RGD_W1                        OTFAD_CTX_RGD_W1_REG(OTFAD,1)
#define OTFAD_CTX2_RGD_W1                        OTFAD_CTX_RGD_W1_REG(OTFAD,2)
#define OTFAD_CTX3_RGD_W1                        OTFAD_CTX_RGD_W1_REG(OTFAD,3)

/* OTFAD - Register array accessors */
#define OTFAD_CTX_AES_KEY_W0(index)              OTFAD_CTX_AES_KEY_W0_REG(OTFAD,index)
#define OTFAD_CTX_AES_KEY_W1(index)              OTFAD_CTX_AES_KEY_W1_REG(OTFAD,index)
#define OTFAD_CTX_AES_KEY_W2(index)              OTFAD_CTX_AES_KEY_W2_REG(OTFAD,index)
#define OTFAD_CTX_AES_KEY_W3(index)              OTFAD_CTX_AES_KEY_W3_REG(OTFAD,index)
#define OTFAD_CTX_CTR_W0(index)                  OTFAD_CTX_CTR_W0_REG(OTFAD,index)
#define OTFAD_CTX_CTR_W1(index)                  OTFAD_CTX_CTR_W1_REG(OTFAD,index)
#define OTFAD_CTX_RGD_W0(index)                  OTFAD_CTX_RGD_W0_REG(OTFAD,index)
#define OTFAD_CTX_RGD_W1(index)                  OTFAD_CTX_RGD_W1_REG(OTFAD,index)

/*!
 * @}
 */ /* end of group OTFAD_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group OTFAD_Peripheral_Access_Layer */


/* ----------------------------------------------------------------------------
   -- PORT Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PORT_Peripheral_Access_Layer PORT Peripheral Access Layer
 * @{
 */

/** PORT - Register Layout Typedef */
typedef struct {
  __IO uint32_t PCR[32];                           /**< Pin Control Register n, array offset: 0x0, array step: 0x4 */
  __O  uint32_t GPCLR;                             /**< Global Pin Control Low Register, offset: 0x80 */
  __O  uint32_t GPCHR;                             /**< Global Pin Control High Register, offset: 0x84 */
       uint32_t RESERVED_0[6];
  __IO uint32_t ISFR;                              /**< Interrupt Status Flag Register, offset: 0xA0 */
       uint32_t RESERVED_1[7];
  __IO uint32_t DFER;                              /**< Digital Filter Enable Register, offset: 0xC0 */
  __IO uint32_t DFCR;                              /**< Digital Filter Clock Register, offset: 0xC4 */
  __IO uint32_t DFWR;                              /**< Digital Filter Width Register, offset: 0xC8 */
} PORT_Type, *PORT_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- PORT - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PORT_Register_Accessor_Macros PORT - Register accessor macros
 * @{
 */


/* PORT - Register accessors */
#define PORT_PCR_REG(base,index)                 ((base)->PCR[index])
#define PORT_GPCLR_REG(base)                     ((base)->GPCLR)
#define PORT_GPCHR_REG(base)                     ((base)->GPCHR)
#define PORT_ISFR_REG(base)                      ((base)->ISFR)
#define PORT_DFER_REG(base)                      ((base)->DFER)
#define PORT_DFCR_REG(base)                      ((base)->DFCR)
#define PORT_DFWR_REG(base)                      ((base)->DFWR)

/*!
 * @}
 */ /* end of group PORT_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- PORT Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PORT_Register_Masks PORT Register Masks
 * @{
 */

/* PCR Bit Fields */
#define PORT_PCR_PS_MASK                         0x1u
#define PORT_PCR_PS_SHIFT                        0
#define PORT_PCR_PE_MASK                         0x2u
#define PORT_PCR_PE_SHIFT                        1
#define PORT_PCR_SRE_MASK                        0x4u
#define PORT_PCR_SRE_SHIFT                       2
#define PORT_PCR_PFE_MASK                        0x10u
#define PORT_PCR_PFE_SHIFT                       4
#define PORT_PCR_ODE_MASK                        0x20u
#define PORT_PCR_ODE_SHIFT                       5
#define PORT_PCR_DSE_MASK                        0x40u
#define PORT_PCR_DSE_SHIFT                       6
#define PORT_PCR_MUX_MASK                        0x700u
#define PORT_PCR_MUX_SHIFT                       8
#define PORT_PCR_MUX(x)                          (((uint32_t)(((uint32_t)(x))<<PORT_PCR_MUX_SHIFT))&PORT_PCR_MUX_MASK)
#define PORT_PCR_LK_MASK                         0x8000u
#define PORT_PCR_LK_SHIFT                        15
#define PORT_PCR_IRQC_MASK                       0xF0000u
#define PORT_PCR_IRQC_SHIFT                      16
#define PORT_PCR_IRQC(x)                         (((uint32_t)(((uint32_t)(x))<<PORT_PCR_IRQC_SHIFT))&PORT_PCR_IRQC_MASK)
#define PORT_PCR_ISF_MASK                        0x1000000u
#define PORT_PCR_ISF_SHIFT                       24
/* GPCLR Bit Fields */
#define PORT_GPCLR_GPWD_MASK                     0xFFFFu
#define PORT_GPCLR_GPWD_SHIFT                    0
#define PORT_GPCLR_GPWD(x)                       (((uint32_t)(((uint32_t)(x))<<PORT_GPCLR_GPWD_SHIFT))&PORT_GPCLR_GPWD_MASK)
#define PORT_GPCLR_GPWE_MASK                     0xFFFF0000u
#define PORT_GPCLR_GPWE_SHIFT                    16
#define PORT_GPCLR_GPWE(x)                       (((uint32_t)(((uint32_t)(x))<<PORT_GPCLR_GPWE_SHIFT))&PORT_GPCLR_GPWE_MASK)
/* GPCHR Bit Fields */
#define PORT_GPCHR_GPWD_MASK                     0xFFFFu
#define PORT_GPCHR_GPWD_SHIFT                    0
#define PORT_GPCHR_GPWD(x)                       (((uint32_t)(((uint32_t)(x))<<PORT_GPCHR_GPWD_SHIFT))&PORT_GPCHR_GPWD_MASK)
#define PORT_GPCHR_GPWE_MASK                     0xFFFF0000u
#define PORT_GPCHR_GPWE_SHIFT                    16
#define PORT_GPCHR_GPWE(x)                       (((uint32_t)(((uint32_t)(x))<<PORT_GPCHR_GPWE_SHIFT))&PORT_GPCHR_GPWE_MASK)
/* ISFR Bit Fields */
#define PORT_ISFR_ISF_MASK                       0xFFFFFFFFu
#define PORT_ISFR_ISF_SHIFT                      0
#define PORT_ISFR_ISF(x)                         (((uint32_t)(((uint32_t)(x))<<PORT_ISFR_ISF_SHIFT))&PORT_ISFR_ISF_MASK)
/* DFER Bit Fields */
#define PORT_DFER_DFE_MASK                       0xFFFFFFFFu
#define PORT_DFER_DFE_SHIFT                      0
#define PORT_DFER_DFE(x)                         (((uint32_t)(((uint32_t)(x))<<PORT_DFER_DFE_SHIFT))&PORT_DFER_DFE_MASK)
/* DFCR Bit Fields */
#define PORT_DFCR_CS_MASK                        0x1u
#define PORT_DFCR_CS_SHIFT                       0
/* DFWR Bit Fields */
#define PORT_DFWR_FILT_MASK                      0x1Fu
#define PORT_DFWR_FILT_SHIFT                     0
#define PORT_DFWR_FILT(x)                        (((uint32_t)(((uint32_t)(x))<<PORT_DFWR_FILT_SHIFT))&PORT_DFWR_FILT_MASK)

/*!
 * @}
 */ /* end of group PORT_Register_Masks */


/* PORT - Peripheral instance base addresses */
/** Peripheral PORTA base address */
#define PORTA_BASE                                (0x40049000u)
/** Peripheral PORTA base pointer */
#define PORTA                                     ((PORT_Type *)PORTA_BASE)
#define PORTA_BASE_PTR                            (PORTA)
/** Peripheral PORTB base address */
#define PORTB_BASE                                (0x4004A000u)
/** Peripheral PORTB base pointer */
#define PORTB                                     ((PORT_Type *)PORTB_BASE)
#define PORTB_BASE_PTR                            (PORTB)
/** Peripheral PORTC base address */
#define PORTC_BASE                                (0x4004B000u)
/** Peripheral PORTC base pointer */
#define PORTC                                     ((PORT_Type *)PORTC_BASE)
#define PORTC_BASE_PTR                            (PORTC)
/** Peripheral PORTD base address */
#define PORTD_BASE                                (0x4004C000u)
/** Peripheral PORTD base pointer */
#define PORTD                                     ((PORT_Type *)PORTD_BASE)
#define PORTD_BASE_PTR                            (PORTD)
/** Peripheral PORTE base address */
#define PORTE_BASE                                (0x4004D000u)
/** Peripheral PORTE base pointer */
#define PORTE                                     ((PORT_Type *)PORTE_BASE)
#define PORTE_BASE_PTR                            (PORTE)
/** Array initializer of PORT peripheral base addresses */
#define PORT_BASE_ADDRS                           { PORTA_BASE, PORTB_BASE, PORTC_BASE, PORTD_BASE, PORTE_BASE }
/** Array initializer of PORT peripheral base pointers */
#define PORT_BASE_PTRS                            { PORTA, PORTB, PORTC, PORTD, PORTE }
/** Interrupt vectors for the PORT peripheral type */
#define PORT_IRQS                                 { PORTA_IRQn, PORTB_IRQn, PORTC_IRQn, PORTD_IRQn, PORTE_IRQn }

/* ----------------------------------------------------------------------------
   -- PORT - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup PORT_Register_Accessor_Macros PORT - Register accessor macros
 * @{
 */


/* PORT - Register instance definitions */
/* PORTA */
#define PORTA_PCR0                               PORT_PCR_REG(PORTA,0)
#define PORTA_PCR1                               PORT_PCR_REG(PORTA,1)
#define PORTA_PCR2                               PORT_PCR_REG(PORTA,2)
#define PORTA_PCR3                               PORT_PCR_REG(PORTA,3)
#define PORTA_PCR4                               PORT_PCR_REG(PORTA,4)
#define PORTA_PCR5                               PORT_PCR_REG(PORTA,5)
#define PORTA_PCR6                               PORT_PCR_REG(PORTA,6)
#define PORTA_PCR7                               PORT_PCR_REG(PORTA,7)
#define PORTA_PCR8                               PORT_PCR_REG(PORTA,8)
#define PORTA_PCR9                               PORT_PCR_REG(PORTA,9)
#define PORTA_PCR10                              PORT_PCR_REG(PORTA,10)
#define PORTA_PCR11                              PORT_PCR_REG(PORTA,11)
#define PORTA_PCR12                              PORT_PCR_REG(PORTA,12)
#define PORTA_PCR13                              PORT_PCR_REG(PORTA,13)
#define PORTA_PCR14                              PORT_PCR_REG(PORTA,14)
#define PORTA_PCR15                              PORT_PCR_REG(PORTA,15)
#define PORTA_PCR16                              PORT_PCR_REG(PORTA,16)
#define PORTA_PCR17                              PORT_PCR_REG(PORTA,17)
#define PORTA_PCR18                              PORT_PCR_REG(PORTA,18)
#define PORTA_PCR19                              PORT_PCR_REG(PORTA,19)
#define PORTA_PCR20                              PORT_PCR_REG(PORTA,20)
#define PORTA_PCR21                              PORT_PCR_REG(PORTA,21)
#define PORTA_PCR22                              PORT_PCR_REG(PORTA,22)
#define PORTA_PCR23                              PORT_PCR_REG(PORTA,23)
#define PORTA_PCR24                              PORT_PCR_REG(PORTA,24)
#define PORTA_PCR25                              PORT_PCR_REG(PORTA,25)
#define PORTA_PCR26                              PORT_PCR_REG(PORTA,26)
#define PORTA_PCR27                              PORT_PCR_REG(PORTA,27)
#define PORTA_PCR28                              PORT_PCR_REG(PORTA,28)
#define PORTA_PCR29                              PORT_PCR_REG(PORTA,29)
#define PORTA_PCR30                              PORT_PCR_REG(PORTA,30)
#define PORTA_PCR31                              PORT_PCR_REG(PORTA,31)
#define PORTA_GPCLR                              PORT_GPCLR_REG(PORTA)
#define PORTA_GPCHR                              PORT_GPCHR_REG(PORTA)
#define PORTA_ISFR                               PORT_ISFR_REG(PORTA)
#define PORTA_DFER                               PORT_DFER_REG(PORTA)
#define PORTA_DFCR                               PORT_DFCR_REG(PORTA)
#define PORTA_DFWR                               PORT_DFWR_REG(PORTA)
/* PORTB */
#define PORTB_PCR0                               PORT_PCR_REG(PORTB,0)
#define PORTB_PCR1                               PORT_PCR_REG(PORTB,1)
#define PORTB_PCR2                               PORT_PCR_REG(PORTB,2)
#define PORTB_PCR3                               PORT_PCR_REG(PORTB,3)
#define PORTB_PCR4                               PORT_PCR_REG(PORTB,4)
#define PORTB_PCR5                               PORT_PCR_REG(PORTB,5)
#define PORTB_PCR6                               PORT_PCR_REG(PORTB,6)
#define PORTB_PCR7                               PORT_PCR_REG(PORTB,7)
#define PORTB_PCR8                               PORT_PCR_REG(PORTB,8)
#define PORTB_PCR9                               PORT_PCR_REG(PORTB,9)
#define PORTB_PCR10                              PORT_PCR_REG(PORTB,10)
#define PORTB_PCR11                              PORT_PCR_REG(PORTB,11)
#define PORTB_PCR12                              PORT_PCR_REG(PORTB,12)
#define PORTB_PCR13                              PORT_PCR_REG(PORTB,13)
#define PORTB_PCR14                              PORT_PCR_REG(PORTB,14)
#define PORTB_PCR15                              PORT_PCR_REG(PORTB,15)
#define PORTB_PCR16                              PORT_PCR_REG(PORTB,16)
#define PORTB_PCR17                              PORT_PCR_REG(PORTB,17)
#define PORTB_PCR18                              PORT_PCR_REG(PORTB,18)
#define PORTB_PCR19                              PORT_PCR_REG(PORTB,19)
#define PORTB_PCR20                              PORT_PCR_REG(PORTB,20)
#define PORTB_PCR21                              PORT_PCR_REG(PORTB,21)
#define PORTB_PCR22                              PORT_PCR_REG(PORTB,22)
#define PORTB_PCR23                              PORT_PCR_REG(PORTB,23)
#define PORTB_PCR24                              PORT_PCR_REG(PORTB,24)
#define PORTB_PCR25                              PORT_PCR_REG(PORTB,25)
#define PORTB_PCR26                              PORT_PCR_REG(PORTB,26)
#define PORTB_PCR27                              PORT_PCR_REG(PORTB,27)
#define PORTB_PCR28                              PORT_PCR_REG(PORTB,28)
#define PORTB_PCR29                              PORT_PCR_REG(PORTB,29)
#define PORTB_PCR30                              PORT_PCR_REG(PORTB,30)
#define PORTB_PCR31                              PORT_PCR_REG(PORTB,31)
#define PORTB_GPCLR                              PORT_GPCLR_REG(PORTB)
#define PORTB_GPCHR                              PORT_GPCHR_REG(PORTB)
#define PORTB_ISFR                               PORT_ISFR_REG(PORTB)
#define PORTB_DFER                               PORT_DFER_REG(PORTB)
#define PORTB_DFCR                               PORT_DFCR_REG(PORTB)
#define PORTB_DFWR                               PORT_DFWR_REG(PORTB)
/* PORTC */
#define PORTC_PCR0                               PORT_PCR_REG(PORTC,0)
#define PORTC_PCR1                               PORT_PCR_REG(PORTC,1)
#define PORTC_PCR2                               PORT_PCR_REG(PORTC,2)
#define PORTC_PCR3                               PORT_PCR_REG(PORTC,3)
#define PORTC_PCR4                               PORT_PCR_REG(PORTC,4)
#define PORTC_PCR5                               PORT_PCR_REG(PORTC,5)
#define PORTC_PCR6                               PORT_PCR_REG(PORTC,6)
#define PORTC_PCR7                               PORT_PCR_REG(PORTC,7)
#define PORTC_PCR8                               PORT_PCR_REG(PORTC,8)
#define PORTC_PCR9                               PORT_PCR_REG(PORTC,9)
#define PORTC_PCR10                              PORT_PCR_REG(PORTC,10)
#define PORTC_PCR11                              PORT_PCR_REG(PORTC,11)
#define PORTC_PCR12                              PORT_PCR_REG(PORTC,12)
#define PORTC_PCR13                              PORT_PCR_REG(PORTC,13)
#define PORTC_PCR14                              PORT_PCR_REG(PORTC,14)
#define PORTC_PCR15                              PORT_PCR_REG(PORTC,15)
#define PORTC_PCR16                              PORT_PCR_REG(PORTC,16)
#define PORTC_PCR17                              PORT_PCR_REG(PORTC,17)
#define PORTC_PCR18                              PORT_PCR_REG(PORTC,18)
#define PORTC_PCR19                              PORT_PCR_REG(PORTC,19)
#define PORTC_PCR20                              PORT_PCR_REG(PORTC,20)
#define PORTC_PCR21                              PORT_PCR_REG(PORTC,21)
#define PORTC_PCR22                              PORT_PCR_REG(PORTC,22)
#define PORTC_PCR23                              PORT_PCR_REG(PORTC,23)
#define PORTC_PCR24                              PORT_PCR_REG(PORTC,24)
#define PORTC_PCR25                              PORT_PCR_REG(PORTC,25)
#define PORTC_PCR26                              PORT_PCR_REG(PORTC,26)
#define PORTC_PCR27                              PORT_PCR_REG(PORTC,27)
#define PORTC_PCR28                              PORT_PCR_REG(PORTC,28)
#define PORTC_PCR29                              PORT_PCR_REG(PORTC,29)
#define PORTC_PCR30                              PORT_PCR_REG(PORTC,30)
#define PORTC_PCR31                              PORT_PCR_REG(PORTC,31)
#define PORTC_GPCLR                              PORT_GPCLR_REG(PORTC)
#define PORTC_GPCHR                              PORT_GPCHR_REG(PORTC)
#define PORTC_ISFR                               PORT_ISFR_REG(PORTC)
#define PORTC_DFER                               PORT_DFER_REG(PORTC)
#define PORTC_DFCR                               PORT_DFCR_REG(PORTC)
#define PORTC_DFWR                               PORT_DFWR_REG(PORTC)
/* PORTD */
#define PORTD_PCR0                               PORT_PCR_REG(PORTD,0)
#define PORTD_PCR1                               PORT_PCR_REG(PORTD,1)
#define PORTD_PCR2                               PORT_PCR_REG(PORTD,2)
#define PORTD_PCR3                               PORT_PCR_REG(PORTD,3)
#define PORTD_PCR4                               PORT_PCR_REG(PORTD,4)
#define PORTD_PCR5                               PORT_PCR_REG(PORTD,5)
#define PORTD_PCR6                               PORT_PCR_REG(PORTD,6)
#define PORTD_PCR7                               PORT_PCR_REG(PORTD,7)
#define PORTD_PCR8                               PORT_PCR_REG(PORTD,8)
#define PORTD_PCR9                               PORT_PCR_REG(PORTD,9)
#define PORTD_PCR10                              PORT_PCR_REG(PORTD,10)
#define PORTD_PCR11                              PORT_PCR_REG(PORTD,11)
#define PORTD_PCR12                              PORT_PCR_REG(PORTD,12)
#define PORTD_PCR13                              PORT_PCR_REG(PORTD,13)
#define PORTD_PCR14                              PORT_PCR_REG(PORTD,14)
#define PORTD_PCR15                              PORT_PCR_REG(PORTD,15)
#define PORTD_PCR16                              PORT_PCR_REG(PORTD,16)
#define PORTD_PCR17                              PORT_PCR_REG(PORTD,17)
#define PORTD_PCR18                              PORT_PCR_REG(PORTD,18)
#define PORTD_PCR19                              PORT_PCR_REG(PORTD,19)
#define PORTD_PCR20                              PORT_PCR_REG(PORTD,20)
#define PORTD_PCR21                              PORT_PCR_REG(PORTD,21)
#define PORTD_PCR22                              PORT_PCR_REG(PORTD,22)
#define PORTD_PCR23                              PORT_PCR_REG(PORTD,23)
#define PORTD_PCR24                              PORT_PCR_REG(PORTD,24)
#define PORTD_PCR25                              PORT_PCR_REG(PORTD,25)
#define PORTD_PCR26                              PORT_PCR_REG(PORTD,26)
#define PORTD_PCR27                              PORT_PCR_REG(PORTD,27)
#define PORTD_PCR28                              PORT_PCR_REG(PORTD,28)
#define PORTD_PCR29                              PORT_PCR_REG(PORTD,29)
#define PORTD_PCR30                              PORT_PCR_REG(PORTD,30)
#define PORTD_PCR31                              PORT_PCR_REG(PORTD,31)
#define PORTD_GPCLR                              PORT_GPCLR_REG(PORTD)
#define PORTD_GPCHR                              PORT_GPCHR_REG(PORTD)
#define PORTD_ISFR                               PORT_ISFR_REG(PORTD)
#define PORTD_DFER                               PORT_DFER_REG(PORTD)
#define PORTD_DFCR                               PORT_DFCR_REG(PORTD)
#define PORTD_DFWR                               PORT_DFWR_REG(PORTD)
/* PORTE */
#define PORTE_PCR0                               PORT_PCR_REG(PORTE,0)
#define PORTE_PCR1                               PORT_PCR_REG(PORTE,1)
#define PORTE_PCR2                               PORT_PCR_REG(PORTE,2)
#define PORTE_PCR3                               PORT_PCR_REG(PORTE,3)
#define PORTE_PCR4                               PORT_PCR_REG(PORTE,4)
#define PORTE_PCR5                               PORT_PCR_REG(PORTE,5)
#define PORTE_PCR6                               PORT_PCR_REG(PORTE,6)
#define PORTE_PCR7                               PORT_PCR_REG(PORTE,7)
#define PORTE_PCR8                               PORT_PCR_REG(PORTE,8)
#define PORTE_PCR9                               PORT_PCR_REG(PORTE,9)
#define PORTE_PCR10                              PORT_PCR_REG(PORTE,10)
#define PORTE_PCR11                              PORT_PCR_REG(PORTE,11)
#define PORTE_PCR12                              PORT_PCR_REG(PORTE,12)
#define PORTE_PCR13                              PORT_PCR_REG(PORTE,13)
#define PORTE_PCR14                              PORT_PCR_REG(PORTE,14)
#define PORTE_PCR15                              PORT_PCR_REG(PORTE,15)
#define PORTE_PCR16                              PORT_PCR_REG(PORTE,16)
#define PORTE_PCR17                              PORT_PCR_REG(PORTE,17)
#define PORTE_PCR18                              PORT_PCR_REG(PORTE,18)
#define PORTE_PCR19                              PORT_PCR_REG(PORTE,19)
#define PORTE_PCR20                              PORT_PCR_REG(PORTE,20)
#define PORTE_PCR21                              PORT_PCR_REG(PORTE,21)
#define PORTE_PCR22                              PORT_PCR_REG(PORTE,22)
#define PORTE_PCR23                              PORT_PCR_REG(PORTE,23)
#define PORTE_PCR24                              PORT_PCR_REG(PORTE,24)
#define PORTE_PCR25                              PORT_PCR_REG(PORTE,25)
#define PORTE_PCR26                              PORT_PCR_REG(PORTE,26)
#define PORTE_PCR27                              PORT_PCR_REG(PORTE,27)
#define PORTE_PCR28                              PORT_PCR_REG(PORTE,28)
#define PORTE_PCR29                              PORT_PCR_REG(PORTE,29)
#define PORTE_PCR30                              PORT_PCR_REG(PORTE,30)
#define PORTE_PCR31                              PORT_PCR_REG(PORTE,31)
#define PORTE_GPCLR                              PORT_GPCLR_REG(PORTE)
#define PORTE_GPCHR                              PORT_GPCHR_REG(PORTE)
#define PORTE_ISFR                               PORT_ISFR_REG(PORTE)
#define PORTE_DFER                               PORT_DFER_REG(PORTE)
#define PORTE_DFCR                               PORT_DFCR_REG(PORTE)
#define PORTE_DFWR                               PORT_DFWR_REG(PORTE)

/* PORT - Register array accessors */
#define PORTA_PCR(index)                         PORT_PCR_REG(PORTA,index)
#define PORTB_PCR(index)                         PORT_PCR_REG(PORTB,index)
#define PORTC_PCR(index)                         PORT_PCR_REG(PORTC,index)
#define PORTD_PCR(index)                         PORT_PCR_REG(PORTD,index)
#define PORTE_PCR(index)                         PORT_PCR_REG(PORTE,index)

/*!
 * @}
 */ /* end of group PORT_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group PORT_Peripheral_Access_Layer */


/* ----------------------------------------------------------------------------
   -- QUADSPI Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup QUADSPI_Peripheral_Access_Layer QUADSPI Peripheral Access Layer
 * @{
 */

/** QUADSPI - Register Layout Typedef */
typedef struct {
  __IO uint32_t MCR;                               /**< Module Configuration Register, offset: 0x0 */
       uint32_t RESERVED_0;
  __IO uint32_t IPCR;                              /**< IP Configuration Register, offset: 0x8 */
  __IO uint32_t FLSHCR;                            /**< Flash Configuration Register, offset: 0xC */
  __IO uint32_t BUF0CR;                            /**< Buffer0 Configuration Register, offset: 0x10 */
  __IO uint32_t BUF1CR;                            /**< Buffer1 Configuration Register, offset: 0x14 */
  __IO uint32_t BUF2CR;                            /**< Buffer2 Configuration Register, offset: 0x18 */
  __IO uint32_t BUF3CR;                            /**< Buffer3 Configuration Register, offset: 0x1C */
  __IO uint32_t BFGENCR;                           /**< Buffer Generic Configuration Register, offset: 0x20 */
  __IO uint32_t SOCCR;                             /**< SOC Configuration Register, offset: 0x24 */
       uint32_t RESERVED_1[2];
  __IO uint32_t BUF0IND;                           /**< Buffer0 Top Index Register, offset: 0x30 */
  __IO uint32_t BUF1IND;                           /**< Buffer1 Top Index Register, offset: 0x34 */
  __IO uint32_t BUF2IND;                           /**< Buffer2 Top Index Register, offset: 0x38 */
       uint32_t RESERVED_2[49];
  __IO uint32_t SFAR;                              /**< Serial Flash Address Register, offset: 0x100 */
  __IO uint32_t SFACR;                             /**< Serial Flash Address Configuration Register, offset: 0x104 */
  __IO uint32_t SMPR;                              /**< Sampling Register, offset: 0x108 */
  __I  uint32_t RBSR;                              /**< RX Buffer Status Register, offset: 0x10C */
  __IO uint32_t RBCT;                              /**< RX Buffer Control Register, offset: 0x110 */
       uint32_t RESERVED_3[15];
  __I  uint32_t TBSR;                              /**< TX Buffer Status Register, offset: 0x150 */
  __IO uint32_t TBDR;                              /**< TX Buffer Data Register, offset: 0x154 */
  __IO uint32_t TBCT;                              /**< Tx Buffer Control Register, offset: 0x158 */
  __I  uint32_t SR;                                /**< Status Register, offset: 0x15C */
  __IO uint32_t FR;                                /**< Flag Register, offset: 0x160 */
  __IO uint32_t RSER;                              /**< Interrupt and DMA Request Select and Enable Register, offset: 0x164 */
  __I  uint32_t SPNDST;                            /**< Sequence Suspend Status Register, offset: 0x168 */
  __IO uint32_t SPTRCLR;                           /**< Sequence Pointer Clear Register, offset: 0x16C */
       uint32_t RESERVED_4[4];
  __IO uint32_t SFA1AD;                            /**< Serial Flash A1 Top Address, offset: 0x180 */
  __IO uint32_t SFA2AD;                            /**< Serial Flash A2 Top Address, offset: 0x184 */
  __IO uint32_t SFB1AD;                            /**< Serial Flash B1Top Address, offset: 0x188 */
  __IO uint32_t SFB2AD;                            /**< Serial Flash B2Top Address, offset: 0x18C */
  __IO uint32_t DLPR;                              /**< Data Learn Pattern Register, offset: 0x190 */
       uint32_t RESERVED_5[27];
  __IO uint32_t RBDR[32];                          /**< RX Buffer Data Register, array offset: 0x200, array step: 0x4 */
       uint32_t RESERVED_6[32];
  __IO uint32_t LUTKEY;                            /**< LUT Key Register, offset: 0x300 */
  __IO uint32_t LCKCR;                             /**< LUT Lock Configuration Register, offset: 0x304 */
       uint32_t RESERVED_7[2];
  __IO uint32_t LUT[64];                           /**< Look-up Table register, array offset: 0x310, array step: 0x4 */
} QUADSPI_Type, *QUADSPI_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- QUADSPI - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup QUADSPI_Register_Accessor_Macros QUADSPI - Register accessor macros
 * @{
 */


/* QUADSPI - Register accessors */
#define QUADSPI_MCR_REG(base)                    ((base)->MCR)
#define QUADSPI_IPCR_REG(base)                   ((base)->IPCR)
#define QUADSPI_FLSHCR_REG(base)                 ((base)->FLSHCR)
#define QUADSPI_BUF0CR_REG(base)                 ((base)->BUF0CR)
#define QUADSPI_BUF1CR_REG(base)                 ((base)->BUF1CR)
#define QUADSPI_BUF2CR_REG(base)                 ((base)->BUF2CR)
#define QUADSPI_BUF3CR_REG(base)                 ((base)->BUF3CR)
#define QUADSPI_BFGENCR_REG(base)                ((base)->BFGENCR)
#define QUADSPI_SOCCR_REG(base)                  ((base)->SOCCR)
#define QUADSPI_BUF0IND_REG(base)                ((base)->BUF0IND)
#define QUADSPI_BUF1IND_REG(base)                ((base)->BUF1IND)
#define QUADSPI_BUF2IND_REG(base)                ((base)->BUF2IND)
#define QUADSPI_SFAR_REG(base)                   ((base)->SFAR)
#define QUADSPI_SFACR_REG(base)                  ((base)->SFACR)
#define QUADSPI_SMPR_REG(base)                   ((base)->SMPR)
#define QUADSPI_RBSR_REG(base)                   ((base)->RBSR)
#define QUADSPI_RBCT_REG(base)                   ((base)->RBCT)
#define QUADSPI_TBSR_REG(base)                   ((base)->TBSR)
#define QUADSPI_TBDR_REG(base)                   ((base)->TBDR)
#define QUADSPI_TBCT_REG(base)                   ((base)->TBCT)
#define QUADSPI_SR_REG(base)                     ((base)->SR)
#define QUADSPI_FR_REG(base)                     ((base)->FR)
#define QUADSPI_RSER_REG(base)                   ((base)->RSER)
#define QUADSPI_SPNDST_REG(base)                 ((base)->SPNDST)
#define QUADSPI_SPTRCLR_REG(base)                ((base)->SPTRCLR)
#define QUADSPI_SFA1AD_REG(base)                 ((base)->SFA1AD)
#define QUADSPI_SFA2AD_REG(base)                 ((base)->SFA2AD)
#define QUADSPI_SFB1AD_REG(base)                 ((base)->SFB1AD)
#define QUADSPI_SFB2AD_REG(base)                 ((base)->SFB2AD)
#define QUADSPI_DLPR_REG(base)                   ((base)->DLPR)
#define QUADSPI_RBDR_REG(base,index)             ((base)->RBDR[index])
#define QUADSPI_LUTKEY_REG(base)                 ((base)->LUTKEY)
#define QUADSPI_LCKCR_REG(base)                  ((base)->LCKCR)
#define QUADSPI_LUT_REG(base,index)              ((base)->LUT[index])

/*!
 * @}
 */ /* end of group QUADSPI_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- QUADSPI Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup QUADSPI_Register_Masks QUADSPI Register Masks
 * @{
 */

/* MCR Bit Fields */
#define QUADSPI_MCR_SWRSTSD_MASK                 0x1u
#define QUADSPI_MCR_SWRSTSD_SHIFT                0
#define QUADSPI_MCR_SWRSTHD_MASK                 0x2u
#define QUADSPI_MCR_SWRSTHD_SHIFT                1
#define QUADSPI_MCR_END_CFG_MASK                 0xCu
#define QUADSPI_MCR_END_CFG_SHIFT                2
#define QUADSPI_MCR_END_CFG(x)                   (((uint32_t)(((uint32_t)(x))<<QUADSPI_MCR_END_CFG_SHIFT))&QUADSPI_MCR_END_CFG_MASK)
#define QUADSPI_MCR_DQS_LAT_EN_MASK              0x20u
#define QUADSPI_MCR_DQS_LAT_EN_SHIFT             5
#define QUADSPI_MCR_DQS_EN_MASK                  0x40u
#define QUADSPI_MCR_DQS_EN_SHIFT                 6
#define QUADSPI_MCR_DDR_EN_MASK                  0x80u
#define QUADSPI_MCR_DDR_EN_SHIFT                 7
#define QUADSPI_MCR_CLR_RXF_MASK                 0x400u
#define QUADSPI_MCR_CLR_RXF_SHIFT                10
#define QUADSPI_MCR_CLR_TXF_MASK                 0x800u
#define QUADSPI_MCR_CLR_TXF_SHIFT                11
#define QUADSPI_MCR_MDIS_MASK                    0x4000u
#define QUADSPI_MCR_MDIS_SHIFT                   14
#define QUADSPI_MCR_SCLKCFG_MASK                 0xFF000000u
#define QUADSPI_MCR_SCLKCFG_SHIFT                24
#define QUADSPI_MCR_SCLKCFG(x)                   (((uint32_t)(((uint32_t)(x))<<QUADSPI_MCR_SCLKCFG_SHIFT))&QUADSPI_MCR_SCLKCFG_MASK)
/* IPCR Bit Fields */
#define QUADSPI_IPCR_IDATSZ_MASK                 0xFFFFu
#define QUADSPI_IPCR_IDATSZ_SHIFT                0
#define QUADSPI_IPCR_IDATSZ(x)                   (((uint32_t)(((uint32_t)(x))<<QUADSPI_IPCR_IDATSZ_SHIFT))&QUADSPI_IPCR_IDATSZ_MASK)
#define QUADSPI_IPCR_PAR_EN_MASK                 0x10000u
#define QUADSPI_IPCR_PAR_EN_SHIFT                16
#define QUADSPI_IPCR_SEQID_MASK                  0xF000000u
#define QUADSPI_IPCR_SEQID_SHIFT                 24
#define QUADSPI_IPCR_SEQID(x)                    (((uint32_t)(((uint32_t)(x))<<QUADSPI_IPCR_SEQID_SHIFT))&QUADSPI_IPCR_SEQID_MASK)
/* FLSHCR Bit Fields */
#define QUADSPI_FLSHCR_TCSS_MASK                 0xFu
#define QUADSPI_FLSHCR_TCSS_SHIFT                0
#define QUADSPI_FLSHCR_TCSS(x)                   (((uint32_t)(((uint32_t)(x))<<QUADSPI_FLSHCR_TCSS_SHIFT))&QUADSPI_FLSHCR_TCSS_MASK)
#define QUADSPI_FLSHCR_TCSH_MASK                 0xF00u
#define QUADSPI_FLSHCR_TCSH_SHIFT                8
#define QUADSPI_FLSHCR_TCSH(x)                   (((uint32_t)(((uint32_t)(x))<<QUADSPI_FLSHCR_TCSH_SHIFT))&QUADSPI_FLSHCR_TCSH_MASK)
#define QUADSPI_FLSHCR_TDH_MASK                  0x30000u
#define QUADSPI_FLSHCR_TDH_SHIFT                 16
#define QUADSPI_FLSHCR_TDH(x)                    (((uint32_t)(((uint32_t)(x))<<QUADSPI_FLSHCR_TDH_SHIFT))&QUADSPI_FLSHCR_TDH_MASK)
/* BUF0CR Bit Fields */
#define QUADSPI_BUF0CR_MSTRID_MASK               0xFu
#define QUADSPI_BUF0CR_MSTRID_SHIFT              0
#define QUADSPI_BUF0CR_MSTRID(x)                 (((uint32_t)(((uint32_t)(x))<<QUADSPI_BUF0CR_MSTRID_SHIFT))&QUADSPI_BUF0CR_MSTRID_MASK)
#define QUADSPI_BUF0CR_ADATSZ_MASK               0xFF00u
#define QUADSPI_BUF0CR_ADATSZ_SHIFT              8
#define QUADSPI_BUF0CR_ADATSZ(x)                 (((uint32_t)(((uint32_t)(x))<<QUADSPI_BUF0CR_ADATSZ_SHIFT))&QUADSPI_BUF0CR_ADATSZ_MASK)
#define QUADSPI_BUF0CR_HP_EN_MASK                0x80000000u
#define QUADSPI_BUF0CR_HP_EN_SHIFT               31
/* BUF1CR Bit Fields */
#define QUADSPI_BUF1CR_MSTRID_MASK               0xFu
#define QUADSPI_BUF1CR_MSTRID_SHIFT              0
#define QUADSPI_BUF1CR_MSTRID(x)                 (((uint32_t)(((uint32_t)(x))<<QUADSPI_BUF1CR_MSTRID_SHIFT))&QUADSPI_BUF1CR_MSTRID_MASK)
#define QUADSPI_BUF1CR_ADATSZ_MASK               0xFF00u
#define QUADSPI_BUF1CR_ADATSZ_SHIFT              8
#define QUADSPI_BUF1CR_ADATSZ(x)                 (((uint32_t)(((uint32_t)(x))<<QUADSPI_BUF1CR_ADATSZ_SHIFT))&QUADSPI_BUF1CR_ADATSZ_MASK)
/* BUF2CR Bit Fields */
#define QUADSPI_BUF2CR_MSTRID_MASK               0xFu
#define QUADSPI_BUF2CR_MSTRID_SHIFT              0
#define QUADSPI_BUF2CR_MSTRID(x)                 (((uint32_t)(((uint32_t)(x))<<QUADSPI_BUF2CR_MSTRID_SHIFT))&QUADSPI_BUF2CR_MSTRID_MASK)
#define QUADSPI_BUF2CR_ADATSZ_MASK               0xFF00u
#define QUADSPI_BUF2CR_ADATSZ_SHIFT              8
#define QUADSPI_BUF2CR_ADATSZ(x)                 (((uint32_t)(((uint32_t)(x))<<QUADSPI_BUF2CR_ADATSZ_SHIFT))&QUADSPI_BUF2CR_ADATSZ_MASK)
/* BUF3CR Bit Fields */
#define QUADSPI_BUF3CR_MSTRID_MASK               0xFu
#define QUADSPI_BUF3CR_MSTRID_SHIFT              0
#define QUADSPI_BUF3CR_MSTRID(x)                 (((uint32_t)(((uint32_t)(x))<<QUADSPI_BUF3CR_MSTRID_SHIFT))&QUADSPI_BUF3CR_MSTRID_MASK)
#define QUADSPI_BUF3CR_ADATSZ_MASK               0xFF00u
#define QUADSPI_BUF3CR_ADATSZ_SHIFT              8
#define QUADSPI_BUF3CR_ADATSZ(x)                 (((uint32_t)(((uint32_t)(x))<<QUADSPI_BUF3CR_ADATSZ_SHIFT))&QUADSPI_BUF3CR_ADATSZ_MASK)
#define QUADSPI_BUF3CR_ALLMST_MASK               0x80000000u
#define QUADSPI_BUF3CR_ALLMST_SHIFT              31
/* BFGENCR Bit Fields */
#define QUADSPI_BFGENCR_SEQID_MASK               0xF000u
#define QUADSPI_BFGENCR_SEQID_SHIFT              12
#define QUADSPI_BFGENCR_SEQID(x)                 (((uint32_t)(((uint32_t)(x))<<QUADSPI_BFGENCR_SEQID_SHIFT))&QUADSPI_BFGENCR_SEQID_MASK)
#define QUADSPI_BFGENCR_PAR_EN_MASK              0x10000u
#define QUADSPI_BFGENCR_PAR_EN_SHIFT             16
/* SOCCR Bit Fields */
#define QUADSPI_SOCCR_SOCCFG_MASK                0xFFFFFFFFu
#define QUADSPI_SOCCR_SOCCFG_SHIFT               0
#define QUADSPI_SOCCR_SOCCFG(x)                  (((uint32_t)(((uint32_t)(x))<<QUADSPI_SOCCR_SOCCFG_SHIFT))&QUADSPI_SOCCR_SOCCFG_MASK)
/* BUF0IND Bit Fields */
#define QUADSPI_BUF0IND_TPINDX0_MASK             0xFFFFFFF8u
#define QUADSPI_BUF0IND_TPINDX0_SHIFT            3
#define QUADSPI_BUF0IND_TPINDX0(x)               (((uint32_t)(((uint32_t)(x))<<QUADSPI_BUF0IND_TPINDX0_SHIFT))&QUADSPI_BUF0IND_TPINDX0_MASK)
/* BUF1IND Bit Fields */
#define QUADSPI_BUF1IND_TPINDX1_MASK             0xFFFFFFF8u
#define QUADSPI_BUF1IND_TPINDX1_SHIFT            3
#define QUADSPI_BUF1IND_TPINDX1(x)               (((uint32_t)(((uint32_t)(x))<<QUADSPI_BUF1IND_TPINDX1_SHIFT))&QUADSPI_BUF1IND_TPINDX1_MASK)
/* BUF2IND Bit Fields */
#define QUADSPI_BUF2IND_TPINDX2_MASK             0xFFFFFFF8u
#define QUADSPI_BUF2IND_TPINDX2_SHIFT            3
#define QUADSPI_BUF2IND_TPINDX2(x)               (((uint32_t)(((uint32_t)(x))<<QUADSPI_BUF2IND_TPINDX2_SHIFT))&QUADSPI_BUF2IND_TPINDX2_MASK)
/* SFAR Bit Fields */
#define QUADSPI_SFAR_SFADR_MASK                  0xFFFFFFFFu
#define QUADSPI_SFAR_SFADR_SHIFT                 0
#define QUADSPI_SFAR_SFADR(x)                    (((uint32_t)(((uint32_t)(x))<<QUADSPI_SFAR_SFADR_SHIFT))&QUADSPI_SFAR_SFADR_MASK)
/* SFACR Bit Fields */
#define QUADSPI_SFACR_CAS_MASK                   0xFu
#define QUADSPI_SFACR_CAS_SHIFT                  0
#define QUADSPI_SFACR_CAS(x)                     (((uint32_t)(((uint32_t)(x))<<QUADSPI_SFACR_CAS_SHIFT))&QUADSPI_SFACR_CAS_MASK)
#define QUADSPI_SFACR_WA_MASK                    0x10000u
#define QUADSPI_SFACR_WA_SHIFT                   16
/* SMPR Bit Fields */
#define QUADSPI_SMPR_HSENA_MASK                  0x1u
#define QUADSPI_SMPR_HSENA_SHIFT                 0
#define QUADSPI_SMPR_HSPHS_MASK                  0x2u
#define QUADSPI_SMPR_HSPHS_SHIFT                 1
#define QUADSPI_SMPR_HSDLY_MASK                  0x4u
#define QUADSPI_SMPR_HSDLY_SHIFT                 2
#define QUADSPI_SMPR_FSPHS_MASK                  0x20u
#define QUADSPI_SMPR_FSPHS_SHIFT                 5
#define QUADSPI_SMPR_FSDLY_MASK                  0x40u
#define QUADSPI_SMPR_FSDLY_SHIFT                 6
#define QUADSPI_SMPR_DDRSMP_MASK                 0x70000u
#define QUADSPI_SMPR_DDRSMP_SHIFT                16
#define QUADSPI_SMPR_DDRSMP(x)                   (((uint32_t)(((uint32_t)(x))<<QUADSPI_SMPR_DDRSMP_SHIFT))&QUADSPI_SMPR_DDRSMP_MASK)
/* RBSR Bit Fields */
#define QUADSPI_RBSR_RDBFL_MASK                  0x3F00u
#define QUADSPI_RBSR_RDBFL_SHIFT                 8
#define QUADSPI_RBSR_RDBFL(x)                    (((uint32_t)(((uint32_t)(x))<<QUADSPI_RBSR_RDBFL_SHIFT))&QUADSPI_RBSR_RDBFL_MASK)
#define QUADSPI_RBSR_RDCTR_MASK                  0xFFFF0000u
#define QUADSPI_RBSR_RDCTR_SHIFT                 16
#define QUADSPI_RBSR_RDCTR(x)                    (((uint32_t)(((uint32_t)(x))<<QUADSPI_RBSR_RDCTR_SHIFT))&QUADSPI_RBSR_RDCTR_MASK)
/* RBCT Bit Fields */
#define QUADSPI_RBCT_WMRK_MASK                   0x1Fu
#define QUADSPI_RBCT_WMRK_SHIFT                  0
#define QUADSPI_RBCT_WMRK(x)                     (((uint32_t)(((uint32_t)(x))<<QUADSPI_RBCT_WMRK_SHIFT))&QUADSPI_RBCT_WMRK_MASK)
#define QUADSPI_RBCT_RXBRD_MASK                  0x100u
#define QUADSPI_RBCT_RXBRD_SHIFT                 8
/* TBSR Bit Fields */
#define QUADSPI_TBSR_TRBFL_MASK                  0x3F00u
#define QUADSPI_TBSR_TRBFL_SHIFT                 8
#define QUADSPI_TBSR_TRBFL(x)                    (((uint32_t)(((uint32_t)(x))<<QUADSPI_TBSR_TRBFL_SHIFT))&QUADSPI_TBSR_TRBFL_MASK)
#define QUADSPI_TBSR_TRCTR_MASK                  0xFFFF0000u
#define QUADSPI_TBSR_TRCTR_SHIFT                 16
#define QUADSPI_TBSR_TRCTR(x)                    (((uint32_t)(((uint32_t)(x))<<QUADSPI_TBSR_TRCTR_SHIFT))&QUADSPI_TBSR_TRCTR_MASK)
/* TBDR Bit Fields */
#define QUADSPI_TBDR_TXDATA_MASK                 0xFFFFFFFFu
#define QUADSPI_TBDR_TXDATA_SHIFT                0
#define QUADSPI_TBDR_TXDATA(x)                   (((uint32_t)(((uint32_t)(x))<<QUADSPI_TBDR_TXDATA_SHIFT))&QUADSPI_TBDR_TXDATA_MASK)
/* TBCT Bit Fields */
#define QUADSPI_TBCT_WMRK_MASK                   0x1Fu
#define QUADSPI_TBCT_WMRK_SHIFT                  0
#define QUADSPI_TBCT_WMRK(x)                     (((uint32_t)(((uint32_t)(x))<<QUADSPI_TBCT_WMRK_SHIFT))&QUADSPI_TBCT_WMRK_MASK)
/* SR Bit Fields */
#define QUADSPI_SR_BUSY_MASK                     0x1u
#define QUADSPI_SR_BUSY_SHIFT                    0
#define QUADSPI_SR_IP_ACC_MASK                   0x2u
#define QUADSPI_SR_IP_ACC_SHIFT                  1
#define QUADSPI_SR_AHB_ACC_MASK                  0x4u
#define QUADSPI_SR_AHB_ACC_SHIFT                 2
#define QUADSPI_SR_KEY_FET_MASK                  0x8u
#define QUADSPI_SR_KEY_FET_SHIFT                 3
#define QUADSPI_SR_AHBGNT_MASK                   0x20u
#define QUADSPI_SR_AHBGNT_SHIFT                  5
#define QUADSPI_SR_AHBTRN_MASK                   0x40u
#define QUADSPI_SR_AHBTRN_SHIFT                  6
#define QUADSPI_SR_AHB0NE_MASK                   0x80u
#define QUADSPI_SR_AHB0NE_SHIFT                  7
#define QUADSPI_SR_AHB1NE_MASK                   0x100u
#define QUADSPI_SR_AHB1NE_SHIFT                  8
#define QUADSPI_SR_AHB2NE_MASK                   0x200u
#define QUADSPI_SR_AHB2NE_SHIFT                  9
#define QUADSPI_SR_AHB3NE_MASK                   0x400u
#define QUADSPI_SR_AHB3NE_SHIFT                  10
#define QUADSPI_SR_AHB0FUL_MASK                  0x800u
#define QUADSPI_SR_AHB0FUL_SHIFT                 11
#define QUADSPI_SR_AHB1FUL_MASK                  0x1000u
#define QUADSPI_SR_AHB1FUL_SHIFT                 12
#define QUADSPI_SR_AHB2FUL_MASK                  0x2000u
#define QUADSPI_SR_AHB2FUL_SHIFT                 13
#define QUADSPI_SR_AHB3FUL_MASK                  0x4000u
#define QUADSPI_SR_AHB3FUL_SHIFT                 14
#define QUADSPI_SR_RXWE_MASK                     0x10000u
#define QUADSPI_SR_RXWE_SHIFT                    16
#define QUADSPI_SR_RXFULL_MASK                   0x80000u
#define QUADSPI_SR_RXFULL_SHIFT                  19
#define QUADSPI_SR_RXDMA_MASK                    0x800000u
#define QUADSPI_SR_RXDMA_SHIFT                   23
#define QUADSPI_SR_TXEDA_MASK                    0x1000000u
#define QUADSPI_SR_TXEDA_SHIFT                   24
#define QUADSPI_SR_TXWA_MASK                     0x2000000u
#define QUADSPI_SR_TXWA_SHIFT                    25
#define QUADSPI_SR_TXDMA_MASK                    0x4000000u
#define QUADSPI_SR_TXDMA_SHIFT                   26
#define QUADSPI_SR_TXFULL_MASK                   0x8000000u
#define QUADSPI_SR_TXFULL_SHIFT                  27
#define QUADSPI_SR_DLPSMP_MASK                   0xE0000000u
#define QUADSPI_SR_DLPSMP_SHIFT                  29
#define QUADSPI_SR_DLPSMP(x)                     (((uint32_t)(((uint32_t)(x))<<QUADSPI_SR_DLPSMP_SHIFT))&QUADSPI_SR_DLPSMP_MASK)
/* FR Bit Fields */
#define QUADSPI_FR_TFF_MASK                      0x1u
#define QUADSPI_FR_TFF_SHIFT                     0
#define QUADSPI_FR_IPGEF_MASK                    0x10u
#define QUADSPI_FR_IPGEF_SHIFT                   4
#define QUADSPI_FR_IPIEF_MASK                    0x40u
#define QUADSPI_FR_IPIEF_SHIFT                   6
#define QUADSPI_FR_IPAEF_MASK                    0x80u
#define QUADSPI_FR_IPAEF_SHIFT                   7
#define QUADSPI_FR_IUEF_MASK                     0x800u
#define QUADSPI_FR_IUEF_SHIFT                    11
#define QUADSPI_FR_ABOF_MASK                     0x1000u
#define QUADSPI_FR_ABOF_SHIFT                    12
#define QUADSPI_FR_AIBSEF_MASK                   0x2000u
#define QUADSPI_FR_AIBSEF_SHIFT                  13
#define QUADSPI_FR_AITEF_MASK                    0x4000u
#define QUADSPI_FR_AITEF_SHIFT                   14
#define QUADSPI_FR_ABSEF_MASK                    0x8000u
#define QUADSPI_FR_ABSEF_SHIFT                   15
#define QUADSPI_FR_RBDF_MASK                     0x10000u
#define QUADSPI_FR_RBDF_SHIFT                    16
#define QUADSPI_FR_RBOF_MASK                     0x20000u
#define QUADSPI_FR_RBOF_SHIFT                    17
#define QUADSPI_FR_ILLINE_MASK                   0x800000u
#define QUADSPI_FR_ILLINE_SHIFT                  23
#define QUADSPI_FR_TBUF_MASK                     0x4000000u
#define QUADSPI_FR_TBUF_SHIFT                    26
#define QUADSPI_FR_TBFF_MASK                     0x8000000u
#define QUADSPI_FR_TBFF_SHIFT                    27
#define QUADSPI_FR_KFEF_MASK                     0x20000000u
#define QUADSPI_FR_KFEF_SHIFT                    29
#define QUADSPI_FR_IAKFEF_MASK                   0x40000000u
#define QUADSPI_FR_IAKFEF_SHIFT                  30
#define QUADSPI_FR_DLPFF_MASK                    0x80000000u
#define QUADSPI_FR_DLPFF_SHIFT                   31
/* RSER Bit Fields */
#define QUADSPI_RSER_TFIE_MASK                   0x1u
#define QUADSPI_RSER_TFIE_SHIFT                  0
#define QUADSPI_RSER_IPGEIE_MASK                 0x10u
#define QUADSPI_RSER_IPGEIE_SHIFT                4
#define QUADSPI_RSER_IPIEIE_MASK                 0x40u
#define QUADSPI_RSER_IPIEIE_SHIFT                6
#define QUADSPI_RSER_IPAEIE_MASK                 0x80u
#define QUADSPI_RSER_IPAEIE_SHIFT                7
#define QUADSPI_RSER_IUEIE_MASK                  0x800u
#define QUADSPI_RSER_IUEIE_SHIFT                 11
#define QUADSPI_RSER_ABOIE_MASK                  0x1000u
#define QUADSPI_RSER_ABOIE_SHIFT                 12
#define QUADSPI_RSER_AIBSIE_MASK                 0x2000u
#define QUADSPI_RSER_AIBSIE_SHIFT                13
#define QUADSPI_RSER_AITIE_MASK                  0x4000u
#define QUADSPI_RSER_AITIE_SHIFT                 14
#define QUADSPI_RSER_ABSEIE_MASK                 0x8000u
#define QUADSPI_RSER_ABSEIE_SHIFT                15
#define QUADSPI_RSER_RBDIE_MASK                  0x10000u
#define QUADSPI_RSER_RBDIE_SHIFT                 16
#define QUADSPI_RSER_RBOIE_MASK                  0x20000u
#define QUADSPI_RSER_RBOIE_SHIFT                 17
#define QUADSPI_RSER_RBDDE_MASK                  0x200000u
#define QUADSPI_RSER_RBDDE_SHIFT                 21
#define QUADSPI_RSER_ILLINIE_MASK                0x800000u
#define QUADSPI_RSER_ILLINIE_SHIFT               23
#define QUADSPI_RSER_TBFDE_MASK                  0x2000000u
#define QUADSPI_RSER_TBFDE_SHIFT                 25
#define QUADSPI_RSER_TBUIE_MASK                  0x4000000u
#define QUADSPI_RSER_TBUIE_SHIFT                 26
#define QUADSPI_RSER_TBFIE_MASK                  0x8000000u
#define QUADSPI_RSER_TBFIE_SHIFT                 27
#define QUADSPI_RSER_KFEIE_MASK                  0x20000000u
#define QUADSPI_RSER_KFEIE_SHIFT                 29
#define QUADSPI_RSER_IAKFIE_MASK                 0x40000000u
#define QUADSPI_RSER_IAKFIE_SHIFT                30
#define QUADSPI_RSER_DLPFIE_MASK                 0x80000000u
#define QUADSPI_RSER_DLPFIE_SHIFT                31
/* SPNDST Bit Fields */
#define QUADSPI_SPNDST_SUSPND_MASK               0x1u
#define QUADSPI_SPNDST_SUSPND_SHIFT              0
#define QUADSPI_SPNDST_SPDBUF_MASK               0xC0u
#define QUADSPI_SPNDST_SPDBUF_SHIFT              6
#define QUADSPI_SPNDST_SPDBUF(x)                 (((uint32_t)(((uint32_t)(x))<<QUADSPI_SPNDST_SPDBUF_SHIFT))&QUADSPI_SPNDST_SPDBUF_MASK)
#define QUADSPI_SPNDST_DATLFT_MASK               0xFE00u
#define QUADSPI_SPNDST_DATLFT_SHIFT              9
#define QUADSPI_SPNDST_DATLFT(x)                 (((uint32_t)(((uint32_t)(x))<<QUADSPI_SPNDST_DATLFT_SHIFT))&QUADSPI_SPNDST_DATLFT_MASK)
/* SPTRCLR Bit Fields */
#define QUADSPI_SPTRCLR_BFPTRC_MASK              0x1u
#define QUADSPI_SPTRCLR_BFPTRC_SHIFT             0
#define QUADSPI_SPTRCLR_IPPTRC_MASK              0x100u
#define QUADSPI_SPTRCLR_IPPTRC_SHIFT             8
/* SFA1AD Bit Fields */
#define QUADSPI_SFA1AD_TPADA1_MASK               0xFFFFFC00u
#define QUADSPI_SFA1AD_TPADA1_SHIFT              10
#define QUADSPI_SFA1AD_TPADA1(x)                 (((uint32_t)(((uint32_t)(x))<<QUADSPI_SFA1AD_TPADA1_SHIFT))&QUADSPI_SFA1AD_TPADA1_MASK)
/* SFA2AD Bit Fields */
#define QUADSPI_SFA2AD_TPADA2_MASK               0xFFFFFC00u
#define QUADSPI_SFA2AD_TPADA2_SHIFT              10
#define QUADSPI_SFA2AD_TPADA2(x)                 (((uint32_t)(((uint32_t)(x))<<QUADSPI_SFA2AD_TPADA2_SHIFT))&QUADSPI_SFA2AD_TPADA2_MASK)
/* SFB1AD Bit Fields */
#define QUADSPI_SFB1AD_TPADB1_MASK               0xFFFFFC00u
#define QUADSPI_SFB1AD_TPADB1_SHIFT              10
#define QUADSPI_SFB1AD_TPADB1(x)                 (((uint32_t)(((uint32_t)(x))<<QUADSPI_SFB1AD_TPADB1_SHIFT))&QUADSPI_SFB1AD_TPADB1_MASK)
/* SFB2AD Bit Fields */
#define QUADSPI_SFB2AD_TPADB2_MASK               0xFFFFFC00u
#define QUADSPI_SFB2AD_TPADB2_SHIFT              10
#define QUADSPI_SFB2AD_TPADB2(x)                 (((uint32_t)(((uint32_t)(x))<<QUADSPI_SFB2AD_TPADB2_SHIFT))&QUADSPI_SFB2AD_TPADB2_MASK)
/* DLPR Bit Fields */
#define QUADSPI_DLPR_DLPV_MASK                   0xFFFFFFFFu
#define QUADSPI_DLPR_DLPV_SHIFT                  0
#define QUADSPI_DLPR_DLPV(x)                     (((uint32_t)(((uint32_t)(x))<<QUADSPI_DLPR_DLPV_SHIFT))&QUADSPI_DLPR_DLPV_MASK)
/* RBDR Bit Fields */
#define QUADSPI_RBDR_RXDATA_MASK                 0xFFFFFFFFu
#define QUADSPI_RBDR_RXDATA_SHIFT                0
#define QUADSPI_RBDR_RXDATA(x)                   (((uint32_t)(((uint32_t)(x))<<QUADSPI_RBDR_RXDATA_SHIFT))&QUADSPI_RBDR_RXDATA_MASK)
/* LUTKEY Bit Fields */
#define QUADSPI_LUTKEY_KEY_MASK                  0xFFFFFFFFu
#define QUADSPI_LUTKEY_KEY_SHIFT                 0
#define QUADSPI_LUTKEY_KEY(x)                    (((uint32_t)(((uint32_t)(x))<<QUADSPI_LUTKEY_KEY_SHIFT))&QUADSPI_LUTKEY_KEY_MASK)
/* LCKCR Bit Fields */
#define QUADSPI_LCKCR_LOCK_MASK                  0x1u
#define QUADSPI_LCKCR_LOCK_SHIFT                 0
#define QUADSPI_LCKCR_UNLOCK_MASK                0x2u
#define QUADSPI_LCKCR_UNLOCK_SHIFT               1
/* LUT Bit Fields */
#define QUADSPI_LUT_OPRND0_MASK                  0xFFu
#define QUADSPI_LUT_OPRND0_SHIFT                 0
#define QUADSPI_LUT_OPRND0(x)                    (((uint32_t)(((uint32_t)(x))<<QUADSPI_LUT_OPRND0_SHIFT))&QUADSPI_LUT_OPRND0_MASK)
#define QUADSPI_LUT_PAD0_MASK                    0x300u
#define QUADSPI_LUT_PAD0_SHIFT                   8
#define QUADSPI_LUT_PAD0(x)                      (((uint32_t)(((uint32_t)(x))<<QUADSPI_LUT_PAD0_SHIFT))&QUADSPI_LUT_PAD0_MASK)
#define QUADSPI_LUT_INSTR0_MASK                  0xFC00u
#define QUADSPI_LUT_INSTR0_SHIFT                 10
#define QUADSPI_LUT_INSTR0(x)                    (((uint32_t)(((uint32_t)(x))<<QUADSPI_LUT_INSTR0_SHIFT))&QUADSPI_LUT_INSTR0_MASK)
#define QUADSPI_LUT_OPRND1_MASK                  0xFF0000u
#define QUADSPI_LUT_OPRND1_SHIFT                 16
#define QUADSPI_LUT_OPRND1(x)                    (((uint32_t)(((uint32_t)(x))<<QUADSPI_LUT_OPRND1_SHIFT))&QUADSPI_LUT_OPRND1_MASK)
#define QUADSPI_LUT_PAD1_MASK                    0x3000000u
#define QUADSPI_LUT_PAD1_SHIFT                   24
#define QUADSPI_LUT_PAD1(x)                      (((uint32_t)(((uint32_t)(x))<<QUADSPI_LUT_PAD1_SHIFT))&QUADSPI_LUT_PAD1_MASK)
#define QUADSPI_LUT_INSTR1_MASK                  0xFC000000u
#define QUADSPI_LUT_INSTR1_SHIFT                 26
#define QUADSPI_LUT_INSTR1(x)                    (((uint32_t)(((uint32_t)(x))<<QUADSPI_LUT_INSTR1_SHIFT))&QUADSPI_LUT_INSTR1_MASK)

/*!
 * @}
 */ /* end of group QUADSPI_Register_Masks */


/* QUADSPI - Peripheral instance base addresses */
/** Peripheral QUADSPI0 base address */
#define QUADSPI0_BASE                                (0x400DA000u)
/** Peripheral QUADSPI0 base pointer */
#define QUADSPI0                                     ((QUADSPI_Type *)QUADSPI0_BASE)
#define QUADSPI0_BASE_PTR                            (QUADSPI0)
/** Array initializer of QUADSPI peripheral base addresses */
#define QUADSPI_BASE_ADDRS                           { QUADSPI0_BASE }
/** Array initializer of QUADSPI peripheral base pointers */
#define QUADSPI_BASE_PTRS                            { QUADSPI0 }
/** Interrupt vectors for the QUADSPI peripheral type */
#define QUADSPI_IRQS                                 { QUADSPI0_IRQn }

/* ----------------------------------------------------------------------------
   -- QUADSPI - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup QUADSPI_Register_Accessor_Macros QUADSPI - Register accessor macros
 * @{
 */


/* QUADSPI - Register instance definitions */
/* QUADSPI0 */
#define QUADSPI0_MCR                             QUADSPI_MCR_REG(QUADSPI0)
#define QUADSPI0_IPCR                            QUADSPI_IPCR_REG(QUADSPI0)
#define QUADSPI0_FLSHCR                          QUADSPI_FLSHCR_REG(QUADSPI0)
#define QUADSPI0_BUF0CR                          QUADSPI_BUF0CR_REG(QUADSPI0)
#define QUADSPI0_BUF1CR                          QUADSPI_BUF1CR_REG(QUADSPI0)
#define QUADSPI0_BUF2CR                          QUADSPI_BUF2CR_REG(QUADSPI0)
#define QUADSPI0_BUF3CR                          QUADSPI_BUF3CR_REG(QUADSPI0)
#define QUADSPI0_BFGENCR                         QUADSPI_BFGENCR_REG(QUADSPI0)
#define QUADSPI0_SOCCR                           QUADSPI_SOCCR_REG(QUADSPI0)
#define QUADSPI0_BUF0IND                         QUADSPI_BUF0IND_REG(QUADSPI0)
#define QUADSPI0_BUF1IND                         QUADSPI_BUF1IND_REG(QUADSPI0)
#define QUADSPI0_BUF2IND                         QUADSPI_BUF2IND_REG(QUADSPI0)
#define QUADSPI0_SFAR                            QUADSPI_SFAR_REG(QUADSPI0)
#define QUADSPI0_SFACR                           QUADSPI_SFACR_REG(QUADSPI0)
#define QUADSPI0_SMPR                            QUADSPI_SMPR_REG(QUADSPI0)
#define QUADSPI0_RBSR                            QUADSPI_RBSR_REG(QUADSPI0)
#define QUADSPI0_RBCT                            QUADSPI_RBCT_REG(QUADSPI0)
#define QUADSPI0_TBSR                            QUADSPI_TBSR_REG(QUADSPI0)
#define QUADSPI0_TBDR                            QUADSPI_TBDR_REG(QUADSPI0)
#define QUADSPI0_TBCT                            QUADSPI_TBCT_REG(QUADSPI0)
#define QUADSPI0_SR                              QUADSPI_SR_REG(QUADSPI0)
#define QUADSPI0_FR                              QUADSPI_FR_REG(QUADSPI0)
#define QUADSPI0_RSER                            QUADSPI_RSER_REG(QUADSPI0)
#define QUADSPI0_SPNDST                          QUADSPI_SPNDST_REG(QUADSPI0)
#define QUADSPI0_SPTRCLR                         QUADSPI_SPTRCLR_REG(QUADSPI0)
#define QUADSPI0_SFA1AD                          QUADSPI_SFA1AD_REG(QUADSPI0)
#define QUADSPI0_SFA2AD                          QUADSPI_SFA2AD_REG(QUADSPI0)
#define QUADSPI0_SFB1AD                          QUADSPI_SFB1AD_REG(QUADSPI0)
#define QUADSPI0_SFB2AD                          QUADSPI_SFB2AD_REG(QUADSPI0)
#define QUADSPI0_DLPR                            QUADSPI_DLPR_REG(QUADSPI0)
#define QUADSPI0_RBDR0                           QUADSPI_RBDR_REG(QUADSPI0,0)
#define QUADSPI0_RBDR1                           QUADSPI_RBDR_REG(QUADSPI0,1)
#define QUADSPI0_RBDR2                           QUADSPI_RBDR_REG(QUADSPI0,2)
#define QUADSPI0_RBDR3                           QUADSPI_RBDR_REG(QUADSPI0,3)
#define QUADSPI0_RBDR4                           QUADSPI_RBDR_REG(QUADSPI0,4)
#define QUADSPI0_RBDR5                           QUADSPI_RBDR_REG(QUADSPI0,5)
#define QUADSPI0_RBDR6                           QUADSPI_RBDR_REG(QUADSPI0,6)
#define QUADSPI0_RBDR7                           QUADSPI_RBDR_REG(QUADSPI0,7)
#define QUADSPI0_RBDR8                           QUADSPI_RBDR_REG(QUADSPI0,8)
#define QUADSPI0_RBDR9                           QUADSPI_RBDR_REG(QUADSPI0,9)
#define QUADSPI0_RBDR10                          QUADSPI_RBDR_REG(QUADSPI0,10)
#define QUADSPI0_RBDR11                          QUADSPI_RBDR_REG(QUADSPI0,11)
#define QUADSPI0_RBDR12                          QUADSPI_RBDR_REG(QUADSPI0,12)
#define QUADSPI0_RBDR13                          QUADSPI_RBDR_REG(QUADSPI0,13)
#define QUADSPI0_RBDR14                          QUADSPI_RBDR_REG(QUADSPI0,14)
#define QUADSPI0_RBDR15                          QUADSPI_RBDR_REG(QUADSPI0,15)
#define QUADSPI0_RBDR16                          QUADSPI_RBDR_REG(QUADSPI0,16)
#define QUADSPI0_RBDR17                          QUADSPI_RBDR_REG(QUADSPI0,17)
#define QUADSPI0_RBDR18                          QUADSPI_RBDR_REG(QUADSPI0,18)
#define QUADSPI0_RBDR19                          QUADSPI_RBDR_REG(QUADSPI0,19)
#define QUADSPI0_RBDR20                          QUADSPI_RBDR_REG(QUADSPI0,20)
#define QUADSPI0_RBDR21                          QUADSPI_RBDR_REG(QUADSPI0,21)
#define QUADSPI0_RBDR22                          QUADSPI_RBDR_REG(QUADSPI0,22)
#define QUADSPI0_RBDR23                          QUADSPI_RBDR_REG(QUADSPI0,23)
#define QUADSPI0_RBDR24                          QUADSPI_RBDR_REG(QUADSPI0,24)
#define QUADSPI0_RBDR25                          QUADSPI_RBDR_REG(QUADSPI0,25)
#define QUADSPI0_RBDR26                          QUADSPI_RBDR_REG(QUADSPI0,26)
#define QUADSPI0_RBDR27                          QUADSPI_RBDR_REG(QUADSPI0,27)
#define QUADSPI0_RBDR28                          QUADSPI_RBDR_REG(QUADSPI0,28)
#define QUADSPI0_RBDR29                          QUADSPI_RBDR_REG(QUADSPI0,29)
#define QUADSPI0_RBDR30                          QUADSPI_RBDR_REG(QUADSPI0,30)
#define QUADSPI0_RBDR31                          QUADSPI_RBDR_REG(QUADSPI0,31)
#define QUADSPI0_LUTKEY                          QUADSPI_LUTKEY_REG(QUADSPI0)
#define QUADSPI0_LCKCR                           QUADSPI_LCKCR_REG(QUADSPI0)
#define QUADSPI0_LUT0                            QUADSPI_LUT_REG(QUADSPI0,0)
#define QUADSPI0_LUT1                            QUADSPI_LUT_REG(QUADSPI0,1)
#define QUADSPI0_LUT2                            QUADSPI_LUT_REG(QUADSPI0,2)
#define QUADSPI0_LUT3                            QUADSPI_LUT_REG(QUADSPI0,3)
#define QUADSPI0_LUT4                            QUADSPI_LUT_REG(QUADSPI0,4)
#define QUADSPI0_LUT5                            QUADSPI_LUT_REG(QUADSPI0,5)
#define QUADSPI0_LUT6                            QUADSPI_LUT_REG(QUADSPI0,6)
#define QUADSPI0_LUT7                            QUADSPI_LUT_REG(QUADSPI0,7)
#define QUADSPI0_LUT8                            QUADSPI_LUT_REG(QUADSPI0,8)
#define QUADSPI0_LUT9                            QUADSPI_LUT_REG(QUADSPI0,9)
#define QUADSPI0_LUT10                           QUADSPI_LUT_REG(QUADSPI0,10)
#define QUADSPI0_LUT11                           QUADSPI_LUT_REG(QUADSPI0,11)
#define QUADSPI0_LUT12                           QUADSPI_LUT_REG(QUADSPI0,12)
#define QUADSPI0_LUT13                           QUADSPI_LUT_REG(QUADSPI0,13)
#define QUADSPI0_LUT14                           QUADSPI_LUT_REG(QUADSPI0,14)
#define QUADSPI0_LUT15                           QUADSPI_LUT_REG(QUADSPI0,15)
#define QUADSPI0_LUT16                           QUADSPI_LUT_REG(QUADSPI0,16)
#define QUADSPI0_LUT17                           QUADSPI_LUT_REG(QUADSPI0,17)
#define QUADSPI0_LUT18                           QUADSPI_LUT_REG(QUADSPI0,18)
#define QUADSPI0_LUT19                           QUADSPI_LUT_REG(QUADSPI0,19)
#define QUADSPI0_LUT20                           QUADSPI_LUT_REG(QUADSPI0,20)
#define QUADSPI0_LUT21                           QUADSPI_LUT_REG(QUADSPI0,21)
#define QUADSPI0_LUT22                           QUADSPI_LUT_REG(QUADSPI0,22)
#define QUADSPI0_LUT23                           QUADSPI_LUT_REG(QUADSPI0,23)
#define QUADSPI0_LUT24                           QUADSPI_LUT_REG(QUADSPI0,24)
#define QUADSPI0_LUT25                           QUADSPI_LUT_REG(QUADSPI0,25)
#define QUADSPI0_LUT26                           QUADSPI_LUT_REG(QUADSPI0,26)
#define QUADSPI0_LUT27                           QUADSPI_LUT_REG(QUADSPI0,27)
#define QUADSPI0_LUT28                           QUADSPI_LUT_REG(QUADSPI0,28)
#define QUADSPI0_LUT29                           QUADSPI_LUT_REG(QUADSPI0,29)
#define QUADSPI0_LUT30                           QUADSPI_LUT_REG(QUADSPI0,30)
#define QUADSPI0_LUT31                           QUADSPI_LUT_REG(QUADSPI0,31)
#define QUADSPI0_LUT32                           QUADSPI_LUT_REG(QUADSPI0,32)
#define QUADSPI0_LUT33                           QUADSPI_LUT_REG(QUADSPI0,33)
#define QUADSPI0_LUT34                           QUADSPI_LUT_REG(QUADSPI0,34)
#define QUADSPI0_LUT35                           QUADSPI_LUT_REG(QUADSPI0,35)
#define QUADSPI0_LUT36                           QUADSPI_LUT_REG(QUADSPI0,36)
#define QUADSPI0_LUT37                           QUADSPI_LUT_REG(QUADSPI0,37)
#define QUADSPI0_LUT38                           QUADSPI_LUT_REG(QUADSPI0,38)
#define QUADSPI0_LUT39                           QUADSPI_LUT_REG(QUADSPI0,39)
#define QUADSPI0_LUT40                           QUADSPI_LUT_REG(QUADSPI0,40)
#define QUADSPI0_LUT41                           QUADSPI_LUT_REG(QUADSPI0,41)
#define QUADSPI0_LUT42                           QUADSPI_LUT_REG(QUADSPI0,42)
#define QUADSPI0_LUT43                           QUADSPI_LUT_REG(QUADSPI0,43)
#define QUADSPI0_LUT44                           QUADSPI_LUT_REG(QUADSPI0,44)
#define QUADSPI0_LUT45                           QUADSPI_LUT_REG(QUADSPI0,45)
#define QUADSPI0_LUT46                           QUADSPI_LUT_REG(QUADSPI0,46)
#define QUADSPI0_LUT47                           QUADSPI_LUT_REG(QUADSPI0,47)
#define QUADSPI0_LUT48                           QUADSPI_LUT_REG(QUADSPI0,48)
#define QUADSPI0_LUT49                           QUADSPI_LUT_REG(QUADSPI0,49)
#define QUADSPI0_LUT50                           QUADSPI_LUT_REG(QUADSPI0,50)
#define QUADSPI0_LUT51                           QUADSPI_LUT_REG(QUADSPI0,51)
#define QUADSPI0_LUT52                           QUADSPI_LUT_REG(QUADSPI0,52)
#define QUADSPI0_LUT53                           QUADSPI_LUT_REG(QUADSPI0,53)
#define QUADSPI0_LUT54                           QUADSPI_LUT_REG(QUADSPI0,54)
#define QUADSPI0_LUT55                           QUADSPI_LUT_REG(QUADSPI0,55)
#define QUADSPI0_LUT56                           QUADSPI_LUT_REG(QUADSPI0,56)
#define QUADSPI0_LUT57                           QUADSPI_LUT_REG(QUADSPI0,57)
#define QUADSPI0_LUT58                           QUADSPI_LUT_REG(QUADSPI0,58)
#define QUADSPI0_LUT59                           QUADSPI_LUT_REG(QUADSPI0,59)
#define QUADSPI0_LUT60                           QUADSPI_LUT_REG(QUADSPI0,60)
#define QUADSPI0_LUT61                           QUADSPI_LUT_REG(QUADSPI0,61)
#define QUADSPI0_LUT62                           QUADSPI_LUT_REG(QUADSPI0,62)
#define QUADSPI0_LUT63                           QUADSPI_LUT_REG(QUADSPI0,63)

/* QUADSPI - Register array accessors */
#define QUADSPI0_RBDR(index)                     QUADSPI_RBDR_REG(QUADSPI0,index)
#define QUADSPI0_LUT(index)                      QUADSPI_LUT_REG(QUADSPI0,index)

/*!
 * @}
 */ /* end of group QUADSPI_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group QUADSPI_Peripheral_Access_Layer */


/* ----------------------------------------------------------------------------
   -- RCM Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup RCM_Peripheral_Access_Layer RCM Peripheral Access Layer
 * @{
 */

/** RCM - Register Layout Typedef */
typedef struct {
  __I  uint8_t SRS0;                               /**< System Reset Status Register 0, offset: 0x0 */
  __I  uint8_t SRS1;                               /**< System Reset Status Register 1, offset: 0x1 */
       uint16_t RESERVED_0;
  __IO uint8_t RPFC;                               /**< Reset Pin Filter Control register, offset: 0x4 */
  __IO uint8_t RPFW;                               /**< Reset Pin Filter Width register, offset: 0x5 */
  __IO uint8_t FM;                                 /**< Force Mode Register, offset: 0x6 */
  __IO uint8_t MR;                                 /**< Mode Register, offset: 0x7 */
  __IO uint8_t SSRS0;                              /**< Sticky System Reset Status Register 0, offset: 0x8 */
  __IO uint8_t SSRS1;                              /**< Sticky System Reset Status Register 1, offset: 0x9 */
} RCM_Type, *RCM_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- RCM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup RCM_Register_Accessor_Macros RCM - Register accessor macros
 * @{
 */


/* RCM - Register accessors */
#define RCM_SRS0_REG(base)                       ((base)->SRS0)
#define RCM_SRS1_REG(base)                       ((base)->SRS1)
#define RCM_RPFC_REG(base)                       ((base)->RPFC)
#define RCM_RPFW_REG(base)                       ((base)->RPFW)
#define RCM_FM_REG(base)                         ((base)->FM)
#define RCM_MR_REG(base)                         ((base)->MR)
#define RCM_SSRS0_REG(base)                      ((base)->SSRS0)
#define RCM_SSRS1_REG(base)                      ((base)->SSRS1)

/*!
 * @}
 */ /* end of group RCM_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- RCM Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup RCM_Register_Masks RCM Register Masks
 * @{
 */

/* SRS0 Bit Fields */
#define RCM_SRS0_WAKEUP_MASK                     0x1u
#define RCM_SRS0_WAKEUP_SHIFT                    0
#define RCM_SRS0_LVD_MASK                        0x2u
#define RCM_SRS0_LVD_SHIFT                       1
#define RCM_SRS0_WDOG_MASK                       0x20u
#define RCM_SRS0_WDOG_SHIFT                      5
#define RCM_SRS0_PIN_MASK                        0x40u
#define RCM_SRS0_PIN_SHIFT                       6
#define RCM_SRS0_POR_MASK                        0x80u
#define RCM_SRS0_POR_SHIFT                       7
/* SRS1 Bit Fields */
#define RCM_SRS1_LOCKUP_MASK                     0x2u
#define RCM_SRS1_LOCKUP_SHIFT                    1
#define RCM_SRS1_SW_MASK                         0x4u
#define RCM_SRS1_SW_SHIFT                        2
#define RCM_SRS1_MDM_AP_MASK                     0x8u
#define RCM_SRS1_MDM_AP_SHIFT                    3
#define RCM_SRS1_SACKERR_MASK                    0x20u
#define RCM_SRS1_SACKERR_SHIFT                   5
#define RCM_SRS1_TAMPER_MASK                     0x80u
#define RCM_SRS1_TAMPER_SHIFT                    7
/* RPFC Bit Fields */
#define RCM_RPFC_RSTFLTSRW_MASK                  0x3u
#define RCM_RPFC_RSTFLTSRW_SHIFT                 0
#define RCM_RPFC_RSTFLTSRW(x)                    (((uint8_t)(((uint8_t)(x))<<RCM_RPFC_RSTFLTSRW_SHIFT))&RCM_RPFC_RSTFLTSRW_MASK)
#define RCM_RPFC_RSTFLTSS_MASK                   0x4u
#define RCM_RPFC_RSTFLTSS_SHIFT                  2
/* RPFW Bit Fields */
#define RCM_RPFW_RSTFLTSEL_MASK                  0x1Fu
#define RCM_RPFW_RSTFLTSEL_SHIFT                 0
#define RCM_RPFW_RSTFLTSEL(x)                    (((uint8_t)(((uint8_t)(x))<<RCM_RPFW_RSTFLTSEL_SHIFT))&RCM_RPFW_RSTFLTSEL_MASK)
/* FM Bit Fields */
#define RCM_FM_FORCEROM_MASK                     0x6u
#define RCM_FM_FORCEROM_SHIFT                    1
#define RCM_FM_FORCEROM(x)                       (((uint8_t)(((uint8_t)(x))<<RCM_FM_FORCEROM_SHIFT))&RCM_FM_FORCEROM_MASK)
/* MR Bit Fields */
#define RCM_MR_BOOTROM_MASK                      0x6u
#define RCM_MR_BOOTROM_SHIFT                     1
#define RCM_MR_BOOTROM(x)                        (((uint8_t)(((uint8_t)(x))<<RCM_MR_BOOTROM_SHIFT))&RCM_MR_BOOTROM_MASK)
/* SSRS0 Bit Fields */
#define RCM_SSRS0_SWAKEUP_MASK                   0x1u
#define RCM_SSRS0_SWAKEUP_SHIFT                  0
#define RCM_SSRS0_SLVD_MASK                      0x2u
#define RCM_SSRS0_SLVD_SHIFT                     1
#define RCM_SSRS0_SWDOG_MASK                     0x20u
#define RCM_SSRS0_SWDOG_SHIFT                    5
#define RCM_SSRS0_SPIN_MASK                      0x40u
#define RCM_SSRS0_SPIN_SHIFT                     6
#define RCM_SSRS0_SPOR_MASK                      0x80u
#define RCM_SSRS0_SPOR_SHIFT                     7
/* SSRS1 Bit Fields */
#define RCM_SSRS1_SLOCKUP_MASK                   0x2u
#define RCM_SSRS1_SLOCKUP_SHIFT                  1
#define RCM_SSRS1_SSW_MASK                       0x4u
#define RCM_SSRS1_SSW_SHIFT                      2
#define RCM_SSRS1_SMDM_AP_MASK                   0x8u
#define RCM_SSRS1_SMDM_AP_SHIFT                  3
#define RCM_SSRS1_SSACKERR_MASK                  0x20u
#define RCM_SSRS1_SSACKERR_SHIFT                 5
#define RCM_SSRS1_STAMPER_MASK                   0x80u
#define RCM_SSRS1_STAMPER_SHIFT                  7

/*!
 * @}
 */ /* end of group RCM_Register_Masks */


/* RCM - Peripheral instance base addresses */
/** Peripheral RCM base address */
#define RCM_BASE                                (0x4007F000u)
/** Peripheral RCM base pointer */
#define RCM                                     ((RCM_Type *)RCM_BASE)
#define RCM_BASE_PTR                            (RCM)
/** Array initializer of RCM peripheral base addresses */
#define RCM_BASE_ADDRS                           { RCM_BASE }
/** Array initializer of RCM peripheral base pointers */
#define RCM_BASE_PTRS                            { RCM }
/** Interrupt vectors for the RCM peripheral type */
#define RCM_IRQS                                 { RCM_IRQn }

/* ----------------------------------------------------------------------------
   -- RCM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup RCM_Register_Accessor_Macros RCM - Register accessor macros
 * @{
 */


/* RCM - Register instance definitions */
/* RCM */
#define RCM_SRS0                                 RCM_SRS0_REG(RCM)
#define RCM_SRS1                                 RCM_SRS1_REG(RCM)
#define RCM_RPFC                                 RCM_RPFC_REG(RCM)
#define RCM_RPFW                                 RCM_RPFW_REG(RCM)
#define RCM_FM                                   RCM_FM_REG(RCM)
#define RCM_MR                                   RCM_MR_REG(RCM)
#define RCM_SSRS0                                RCM_SSRS0_REG(RCM)
#define RCM_SSRS1                                RCM_SSRS1_REG(RCM)

/* RCM - Register array accessors */

/*!
 * @}
 */ /* end of group RCM_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group RCM_Peripheral_Access_Layer */


/* ----------------------------------------------------------------------------
   -- SIM Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SIM_Peripheral_Access_Layer SIM Peripheral Access Layer
 * @{
 */

/** SIM - Register Layout Typedef */
typedef struct {
  __IO uint32_t SOPT1;                             /**< System Options Register 1, offset: 0x0 */
  __IO uint32_t SOPT1CFG;                          /**< SOPT1 Configuration Register, offset: 0x4 */
       uint32_t RESERVED_0[1023];
  __IO uint32_t SOPT2;                             /**< System Options Register 2, offset: 0x1004 */
  __IO uint32_t SOPT3;                             /**< System Options Register 3, offset: 0x1008 */
  __IO uint32_t SOPT4;                             /**< System Options Register 4, offset: 0x100C */
  __IO uint32_t SOPT5;                             /**< System Options Register 5, offset: 0x1010 */
       uint32_t RESERVED_2;
  __IO uint32_t SOPT7;                             /**< System Options Register 7, offset: 0x1018 */
  __IO uint32_t SOPT8;                             /**< System Options Register 8, offset: 0x101C */
  __IO uint32_t SOPT9;                             /**< System Options Register 9, offset: 0x1020 */
  __I  uint32_t SDID;                              /**< System Device Identification Register, offset: 0x1024 */
  __IO uint32_t SCGC1;                             /**< System Clock Gating Control Register 1, offset: 0x1028 */
  __IO uint32_t SCGC2;                             /**< System Clock Gating Control Register 2, offset: 0x102C */
  __IO uint32_t SCGC3;                             /**< System Clock Gating Control Register 3, offset: 0x1030 */
  __IO uint32_t SCGC4;                             /**< System Clock Gating Control Register 4, offset: 0x1034 */
  __IO uint32_t SCGC5;                             /**< System Clock Gating Control Register 5, offset: 0x1038 */
  __IO uint32_t SCGC6;                             /**< System Clock Gating Control Register 6, offset: 0x103C */
  __IO uint32_t SCGC7;                             /**< System Clock Gating Control Register 7, offset: 0x1040 */
  __IO uint32_t CLKDIV1;                           /**< System Clock Divider Register 1, offset: 0x1044 */
  __IO uint32_t CLKDIV2;                           /**< System Clock Divider Register 2, offset: 0x1048 */
  __I  uint32_t FCFG1;                             /**< Flash Configuration Register 1, offset: 0x104C */
  __I  uint32_t FCFG2;                             /**< Flash Configuration Register 2, offset: 0x1050 */
  __I  uint32_t UIDH;                              /**< Unique Identification Register High, offset: 0x1054 */
  __I  uint32_t UIDMH;                             /**< Unique Identification Register Mid-High, offset: 0x1058 */
  __I  uint32_t UIDML;                             /**< Unique Identification Register Mid Low, offset: 0x105C */
  __I  uint32_t UIDL;                              /**< Unique Identification Register Low, offset: 0x1060 */
  __IO uint32_t CLKDIV3;                           /**< System Clock Divider Register 3, offset: 0x1064 */
  __IO uint32_t CLKDIV4;                           /**< System Clock Divider Register 4, offset: 0x1068 */
       uint32_t RESERVED_4[9];
  __I  uint32_t SECKEY0;                           /**< Secure Key Register 0, offset: 0x1090 */
  __I  uint32_t SECKEY1;                           /**< Secure Key Register 1, offset: 0x1094 */
  __I  uint32_t SECKEY2;                           /**< Secure Key Register 2, offset: 0x1098 */
  __I  uint32_t SECKEY3;                           /**< Secure Key Register 3, offset: 0x109C */
} SIM_Type, *SIM_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- SIM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SIM_Register_Accessor_Macros SIM - Register accessor macros
 * @{
 */


/* SIM - Register accessors */
#define SIM_SOPT1_REG(base)                      ((base)->SOPT1)
#define SIM_SOPT1CFG_REG(base)                   ((base)->SOPT1CFG)
#define SIM_SOPT2_REG(base)                      ((base)->SOPT2)
#define SIM_SOPT3_REG(base)                      ((base)->SOPT3)
#define SIM_SOPT4_REG(base)                      ((base)->SOPT4)
#define SIM_SOPT5_REG(base)                      ((base)->SOPT5)
#define SIM_SOPT7_REG(base)                      ((base)->SOPT7)
#define SIM_SOPT8_REG(base)                      ((base)->SOPT8)
#define SIM_SOPT9_REG(base)                      ((base)->SOPT9)
#define SIM_SDID_REG(base)                       ((base)->SDID)
#define SIM_SCGC1_REG(base)                      ((base)->SCGC1)
#define SIM_SCGC2_REG(base)                      ((base)->SCGC2)
#define SIM_SCGC3_REG(base)                      ((base)->SCGC3)
#define SIM_SCGC4_REG(base)                      ((base)->SCGC4)
#define SIM_SCGC5_REG(base)                      ((base)->SCGC5)
#define SIM_SCGC6_REG(base)                      ((base)->SCGC6)
#define SIM_SCGC7_REG(base)                      ((base)->SCGC7)
#define SIM_CLKDIV1_REG(base)                    ((base)->CLKDIV1)
#define SIM_CLKDIV2_REG(base)                    ((base)->CLKDIV2)
#define SIM_FCFG1_REG(base)                      ((base)->FCFG1)
#define SIM_FCFG2_REG(base)                      ((base)->FCFG2)
#define SIM_UIDH_REG(base)                       ((base)->UIDH)
#define SIM_UIDMH_REG(base)                      ((base)->UIDMH)
#define SIM_UIDML_REG(base)                      ((base)->UIDML)
#define SIM_UIDL_REG(base)                       ((base)->UIDL)
#define SIM_CLKDIV3_REG(base)                    ((base)->CLKDIV3)
#define SIM_CLKDIV4_REG(base)                    ((base)->CLKDIV4)
#define SIM_SECKEY0_REG(base)                    ((base)->SECKEY0)
#define SIM_SECKEY1_REG(base)                    ((base)->SECKEY1)
#define SIM_SECKEY2_REG(base)                    ((base)->SECKEY2)
#define SIM_SECKEY3_REG(base)                    ((base)->SECKEY3)

/*!
 * @}
 */ /* end of group SIM_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- SIM Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SIM_Register_Masks SIM Register Masks
 * @{
 */

/* SOPT1 Bit Fields */
#define SIM_SOPT1_RAMSIZE_MASK                   0xF000u
#define SIM_SOPT1_RAMSIZE_SHIFT                  12
#define SIM_SOPT1_RAMSIZE(x)                     (((uint32_t)(((uint32_t)(x))<<SIM_SOPT1_RAMSIZE_SHIFT))&SIM_SOPT1_RAMSIZE_MASK)
#define SIM_SOPT1_OSC32KSEL_MASK                 0xC0000u
#define SIM_SOPT1_OSC32KSEL_SHIFT                18
#define SIM_SOPT1_OSC32KSEL(x)                   (((uint32_t)(((uint32_t)(x))<<SIM_SOPT1_OSC32KSEL_SHIFT))&SIM_SOPT1_OSC32KSEL_MASK)
#define SIM_SOPT1_USBVSTBY_MASK                  0x20000000u
#define SIM_SOPT1_USBVSTBY_SHIFT                 29
#define SIM_SOPT1_USBSSTBY_MASK                  0x40000000u
#define SIM_SOPT1_USBSSTBY_SHIFT                 30
#define SIM_SOPT1_USBREGEN_MASK                  0x80000000u
#define SIM_SOPT1_USBREGEN_SHIFT                 31
/* SOPT1CFG Bit Fields */
#define SIM_SOPT1CFG_URWE_MASK                   0x1000000u
#define SIM_SOPT1CFG_URWE_SHIFT                  24
#define SIM_SOPT1CFG_UVSWE_MASK                  0x2000000u
#define SIM_SOPT1CFG_UVSWE_SHIFT                 25
#define SIM_SOPT1CFG_USSWE_MASK                  0x4000000u
#define SIM_SOPT1CFG_USSWE_SHIFT                 26
/* SOPT2 Bit Fields */
#define SIM_SOPT2_RTCCLKOUTSEL_MASK              0x10u
#define SIM_SOPT2_RTCCLKOUTSEL_SHIFT             4
#define SIM_SOPT2_CLKOUTSEL_MASK                 0xE0u
#define SIM_SOPT2_CLKOUTSEL_SHIFT                5
#define SIM_SOPT2_CLKOUTSEL(x)                   (((uint32_t)(((uint32_t)(x))<<SIM_SOPT2_CLKOUTSEL_SHIFT))&SIM_SOPT2_CLKOUTSEL_MASK)
#define SIM_SOPT2_FBSL_MASK                      0x300u
#define SIM_SOPT2_FBSL_SHIFT                     8
#define SIM_SOPT2_FBSL(x)                        (((uint32_t)(((uint32_t)(x))<<SIM_SOPT2_FBSL_SHIFT))&SIM_SOPT2_FBSL_MASK)
#define SIM_SOPT2_TRACECLKSEL_MASK               0x1000u
#define SIM_SOPT2_TRACECLKSEL_SHIFT              12
#define SIM_SOPT2_PLLFLLSEL_MASK                 0x30000u
#define SIM_SOPT2_PLLFLLSEL_SHIFT                16
#define SIM_SOPT2_PLLFLLSEL(x)                   (((uint32_t)(((uint32_t)(x))<<SIM_SOPT2_PLLFLLSEL_SHIFT))&SIM_SOPT2_PLLFLLSEL_MASK)
#define SIM_SOPT2_USBSRC_MASK                    0x40000u
#define SIM_SOPT2_USBSRC_SHIFT                   18
#define SIM_SOPT2_FLEXIOSRC_MASK                 0xC00000u
#define SIM_SOPT2_FLEXIOSRC_SHIFT                22
#define SIM_SOPT2_FLEXIOSRC(x)                   (((uint32_t)(((uint32_t)(x))<<SIM_SOPT2_FLEXIOSRC_SHIFT))&SIM_SOPT2_FLEXIOSRC_MASK)
#define SIM_SOPT2_TPMSRC_MASK                    0x3000000u
#define SIM_SOPT2_TPMSRC_SHIFT                   24
#define SIM_SOPT2_TPMSRC(x)                      (((uint32_t)(((uint32_t)(x))<<SIM_SOPT2_TPMSRC_SHIFT))&SIM_SOPT2_TPMSRC_MASK)
#define SIM_SOPT2_LPUARTSRC_MASK                 0xC000000u
#define SIM_SOPT2_LPUARTSRC_SHIFT                26
#define SIM_SOPT2_LPUARTSRC(x)                   (((uint32_t)(((uint32_t)(x))<<SIM_SOPT2_LPUARTSRC_SHIFT))&SIM_SOPT2_LPUARTSRC_MASK)
#define SIM_SOPT2_SDHCSRC_MASK                   0x30000000u
#define SIM_SOPT2_SDHCSRC_SHIFT                  28
#define SIM_SOPT2_SDHCSRC(x)                     (((uint32_t)(((uint32_t)(x))<<SIM_SOPT2_SDHCSRC_SHIFT))&SIM_SOPT2_SDHCSRC_MASK)
#define SIM_SOPT2_EMVSIMSRC_MASK                 0xC0000000u
#define SIM_SOPT2_EMVSIMSRC_SHIFT                30
#define SIM_SOPT2_EMVSIMSRC(x)                   (((uint32_t)(((uint32_t)(x))<<SIM_SOPT2_EMVSIMSRC_SHIFT))&SIM_SOPT2_EMVSIMSRC_MASK)
#define SIM_SOPT3_BROMSUPV_B_MASK                0x1u
#define SIM_SOPT3_BROMSUPV_B_SHIFT               0
#define SIM_SOPT3_BROMEXEC_B_MASK                0x2u
#define SIM_SOPT3_BROMEXEC_B_SHIFT               1
#define SIM_SOPT3_FTFLLSOPT_MASK                 0x4u
#define SIM_SOPT3_FTFLLSOPT_SHIFT                2
#define SIM_SOPT3_VALDIS_MASK                    0x100u
#define SIM_SOPT3_VALDIS_SHIFT                   8
#define SIM_SOPT3_VALRD_MASK                     0xE00u
#define SIM_SOPT3_VALRD_SHIFT                    9
#define SIM_SOPT3_VALRD(x)                       (((uint32_t)(((uint32_t)(x))<<SIM_SOPT3_VALRD_SHIFT))&SIM_SOPT3_VALRD_MASK)
#define SIM_SOPT3_VALWR_MASK                     0x7000u
#define SIM_SOPT3_VALWR_SHIFT                    12
#define SIM_SOPT3_VALWR(x)                       (((uint32_t)(((uint32_t)(x))<<SIM_SOPT3_VALWR_SHIFT))&SIM_SOPT3_VALWR_MASK)
#define SIM_SOPT3_BROMEN_MASK                    0x8000u
#define SIM_SOPT3_BROMEN_SHIFT                   15
#define SIM_SOPT3_FACEN_MASK                     0x10000u
#define SIM_SOPT3_FACEN_SHIFT                    16
#define SIM_SOPT3_ENCDIS_MASK                    0x20000u
#define SIM_SOPT3_ENCDIS_SHIFT                   17
#define SIM_SOPT3_ESDHCDIS_MASK                  0x100000u
#define SIM_SOPT3_ESDHCDIS_SHIFT                 20
#define SIM_SOPT3_USBDIS_MASK                    0x800000u
#define SIM_SOPT3_USBDIS_SHIFT                   23
#define SIM_SOPT3_DRYICEDIS_MASK                 0x1000000u
#define SIM_SOPT3_DRYICEDIS_SHIFT                24
#define SIM_SOPT3_RFDIS_MASK                     0x4000000u
#define SIM_SOPT3_RFDIS_SHIFT                    26
#define SIM_SOPT3_FPUDIS_MASK                    0x8000000u
#define SIM_SOPT3_FPUDIS_SHIFT                   27
#define SIM_SOPT3_QSPIEN_MASK                    0x20000000u
#define SIM_SOPT3_QSPIEN_SHIFT                   29
#define SIM_SOPT3_QSPI_SIPDIS_MASK               0x40000000u
#define SIM_SOPT3_QSPI_SIPDIS_SHIFT              30
/* SOPT4 Bit Fields */
#define SIM_SOPT4_FTM0FLT0_MASK                  0x1u
#define SIM_SOPT4_FTM0FLT0_SHIFT                 0
#define SIM_SOPT4_FTM0FLT1_MASK                  0x2u
#define SIM_SOPT4_FTM0FLT1_SHIFT                 1
#define SIM_SOPT4_FTM1FLT0_MASK                  0x10u
#define SIM_SOPT4_FTM1FLT0_SHIFT                 4
#define SIM_SOPT4_FTM2FLT0_MASK                  0x100u
#define SIM_SOPT4_FTM2FLT0_SHIFT                 8
#define SIM_SOPT4_FTM3FLT0_MASK                  0x1000u
#define SIM_SOPT4_FTM3FLT0_SHIFT                 12
#define SIM_SOPT4_FTM1CH0SRC_MASK                0xC0000u
#define SIM_SOPT4_FTM1CH0SRC_SHIFT               18
#define SIM_SOPT4_FTM1CH0SRC(x)                  (((uint32_t)(((uint32_t)(x))<<SIM_SOPT4_FTM1CH0SRC_SHIFT))&SIM_SOPT4_FTM1CH0SRC_MASK)
#define SIM_SOPT4_FTM2CH0SRC_MASK                0x300000u
#define SIM_SOPT4_FTM2CH0SRC_SHIFT               20
#define SIM_SOPT4_FTM2CH0SRC(x)                  (((uint32_t)(((uint32_t)(x))<<SIM_SOPT4_FTM2CH0SRC_SHIFT))&SIM_SOPT4_FTM2CH0SRC_MASK)
#define SIM_SOPT4_FTM2CH1SRC_MASK                0x400000u
#define SIM_SOPT4_FTM2CH1SRC_SHIFT               22
#define SIM_SOPT4_FTM0CLKSEL_MASK                0x1000000u
#define SIM_SOPT4_FTM0CLKSEL_SHIFT               24
#define SIM_SOPT4_FTM1CLKSEL_MASK                0x2000000u
#define SIM_SOPT4_FTM1CLKSEL_SHIFT               25
#define SIM_SOPT4_FTM2CLKSEL_MASK                0x4000000u
#define SIM_SOPT4_FTM2CLKSEL_SHIFT               26
#define SIM_SOPT4_FTM3CLKSEL_MASK                0x8000000u
#define SIM_SOPT4_FTM3CLKSEL_SHIFT               27
#define SIM_SOPT4_FTM0TRG0SRC_MASK               0x10000000u
#define SIM_SOPT4_FTM0TRG0SRC_SHIFT              28
#define SIM_SOPT4_FTM0TRG1SRC_MASK               0x20000000u
#define SIM_SOPT4_FTM0TRG1SRC_SHIFT              29
#define SIM_SOPT4_FTM3TRG0SRC_MASK               0x40000000u
#define SIM_SOPT4_FTM3TRG0SRC_SHIFT              30
#define SIM_SOPT4_FTM3TRG1SRC_MASK               0x80000000u
#define SIM_SOPT4_FTM3TRG1SRC_SHIFT              31
/* SOPT5 Bit Fields */
#define SIM_SOPT5_LPUART0TXSRC_MASK              0x30000u
#define SIM_SOPT5_LPUART0TXSRC_SHIFT             16
#define SIM_SOPT5_LPUART0TXSRC(x)                (((uint32_t)(((uint32_t)(x))<<SIM_SOPT5_LPUART0TXSRC_SHIFT))&SIM_SOPT5_LPUART0TXSRC_MASK)
#define SIM_SOPT5_LPUART0RXSRC_MASK              0xC0000u
#define SIM_SOPT5_LPUART0RXSRC_SHIFT             18
#define SIM_SOPT5_LPUART0RXSRC(x)                (((uint32_t)(((uint32_t)(x))<<SIM_SOPT5_LPUART0RXSRC_SHIFT))&SIM_SOPT5_LPUART0RXSRC_MASK)
#define SIM_SOPT5_LPUART1TXSRC_MASK              0x300000u
#define SIM_SOPT5_LPUART1TXSRC_SHIFT             20
#define SIM_SOPT5_LPUART1TXSRC(x)                (((uint32_t)(((uint32_t)(x))<<SIM_SOPT5_LPUART1TXSRC_SHIFT))&SIM_SOPT5_LPUART1TXSRC_MASK)
#define SIM_SOPT5_LPUART1RXSRC_MASK              0xC00000u
#define SIM_SOPT5_LPUART1RXSRC_SHIFT             22
#define SIM_SOPT5_LPUART1RXSRC(x)                (((uint32_t)(((uint32_t)(x))<<SIM_SOPT5_LPUART1RXSRC_SHIFT))&SIM_SOPT5_LPUART1RXSRC_MASK)
/* SOPT7 Bit Fields */
#define SIM_SOPT7_ADC0TRGSEL_MASK                0xFu
#define SIM_SOPT7_ADC0TRGSEL_SHIFT               0
#define SIM_SOPT7_ADC0TRGSEL(x)                  (((uint32_t)(((uint32_t)(x))<<SIM_SOPT7_ADC0TRGSEL_SHIFT))&SIM_SOPT7_ADC0TRGSEL_MASK)
#define SIM_SOPT7_ADC0PRETRGSEL_MASK             0x10u
#define SIM_SOPT7_ADC0PRETRGSEL_SHIFT            4
#define SIM_SOPT7_ADC0ALTTRGEN_MASK              0x80u
#define SIM_SOPT7_ADC0ALTTRGEN_SHIFT             7
/* SOPT8 Bit Fields */
#define SIM_SOPT8_FTM0SYNCBIT_MASK               0x1u
#define SIM_SOPT8_FTM0SYNCBIT_SHIFT              0
#define SIM_SOPT8_FTM1SYNCBIT_MASK               0x2u
#define SIM_SOPT8_FTM1SYNCBIT_SHIFT              1
#define SIM_SOPT8_FTM2SYNCBIT_MASK               0x4u
#define SIM_SOPT8_FTM2SYNCBIT_SHIFT              2
#define SIM_SOPT8_FTM3SYNCBIT_MASK               0x8u
#define SIM_SOPT8_FTM3SYNCBIT_SHIFT              3
#define SIM_SOPT8_FTM0OCH0SRC_MASK               0x10000u
#define SIM_SOPT8_FTM0OCH0SRC_SHIFT              16
#define SIM_SOPT8_FTM0OCH1SRC_MASK               0x20000u
#define SIM_SOPT8_FTM0OCH1SRC_SHIFT              17
#define SIM_SOPT8_FTM0OCH2SRC_MASK               0x40000u
#define SIM_SOPT8_FTM0OCH2SRC_SHIFT              18
#define SIM_SOPT8_FTM0OCH3SRC_MASK               0x80000u
#define SIM_SOPT8_FTM0OCH3SRC_SHIFT              19
#define SIM_SOPT8_FTM0OCH4SRC_MASK               0x100000u
#define SIM_SOPT8_FTM0OCH4SRC_SHIFT              20
#define SIM_SOPT8_FTM0OCH5SRC_MASK               0x200000u
#define SIM_SOPT8_FTM0OCH5SRC_SHIFT              21
#define SIM_SOPT8_FTM0OCH6SRC_MASK               0x400000u
#define SIM_SOPT8_FTM0OCH6SRC_SHIFT              22
#define SIM_SOPT8_FTM0OCH7SRC_MASK               0x800000u
#define SIM_SOPT8_FTM0OCH7SRC_SHIFT              23
#define SIM_SOPT8_FTM3OCH0SRC_MASK               0x1000000u
#define SIM_SOPT8_FTM3OCH0SRC_SHIFT              24
#define SIM_SOPT8_FTM3OCH1SRC_MASK               0x2000000u
#define SIM_SOPT8_FTM3OCH1SRC_SHIFT              25
#define SIM_SOPT8_FTM3OCH2SRC_MASK               0x4000000u
#define SIM_SOPT8_FTM3OCH2SRC_SHIFT              26
#define SIM_SOPT8_FTM3OCH3SRC_MASK               0x8000000u
#define SIM_SOPT8_FTM3OCH3SRC_SHIFT              27
#define SIM_SOPT8_FTM3OCH4SRC_MASK               0x10000000u
#define SIM_SOPT8_FTM3OCH4SRC_SHIFT              28
#define SIM_SOPT8_FTM3OCH5SRC_MASK               0x20000000u
#define SIM_SOPT8_FTM3OCH5SRC_SHIFT              29
#define SIM_SOPT8_FTM3OCH6SRC_MASK               0x40000000u
#define SIM_SOPT8_FTM3OCH6SRC_SHIFT              30
#define SIM_SOPT8_FTM3OCH7SRC_MASK               0x80000000u
#define SIM_SOPT8_FTM3OCH7SRC_SHIFT              31
/* SOPT9 Bit Fields */
#define SIM_SOPT9_TPM1CH0SRC_MASK                0xC0000u
#define SIM_SOPT9_TPM1CH0SRC_SHIFT               18
#define SIM_SOPT9_TPM1CH0SRC(x)                  (((uint32_t)(((uint32_t)(x))<<SIM_SOPT9_TPM1CH0SRC_SHIFT))&SIM_SOPT9_TPM1CH0SRC_MASK)
#define SIM_SOPT9_TPM2CH0SRC_MASK                0x300000u
#define SIM_SOPT9_TPM2CH0SRC_SHIFT               20
#define SIM_SOPT9_TPM2CH0SRC(x)                  (((uint32_t)(((uint32_t)(x))<<SIM_SOPT9_TPM2CH0SRC_SHIFT))&SIM_SOPT9_TPM2CH0SRC_MASK)
#define SIM_SOPT9_TPM1CLKSEL_MASK                0x2000000u
#define SIM_SOPT9_TPM1CLKSEL_SHIFT               25
#define SIM_SOPT9_TPM2CLKSEL_MASK                0x4000000u
#define SIM_SOPT9_TPM2CLKSEL_SHIFT               26
/* SDID Bit Fields */
#define SIM_SDID_PINID_MASK                      0xFu
#define SIM_SDID_PINID_SHIFT                     0
#define SIM_SDID_PINID(x)                        (((uint32_t)(((uint32_t)(x))<<SIM_SDID_PINID_SHIFT))&SIM_SDID_PINID_MASK)
#define SIM_SDID_FAMID_MASK                      0x70u
#define SIM_SDID_FAMID_SHIFT                     4
#define SIM_SDID_FAMID(x)                        (((uint32_t)(((uint32_t)(x))<<SIM_SDID_FAMID_SHIFT))&SIM_SDID_FAMID_MASK)
#define SIM_SDID_DIEID_MASK                      0xF80u
#define SIM_SDID_DIEID_SHIFT                     7
#define SIM_SDID_DIEID(x)                        (((uint32_t)(((uint32_t)(x))<<SIM_SDID_DIEID_SHIFT))&SIM_SDID_DIEID_MASK)
#define SIM_SDID_REVID_MASK                      0xF000u
#define SIM_SDID_REVID_SHIFT                     12
#define SIM_SDID_REVID(x)                        (((uint32_t)(((uint32_t)(x))<<SIM_SDID_REVID_SHIFT))&SIM_SDID_REVID_MASK)
#define SIM_SDID_SERIESID_MASK                   0xF00000u
#define SIM_SDID_SERIESID_SHIFT                  20
#define SIM_SDID_SERIESID(x)                     (((uint32_t)(((uint32_t)(x))<<SIM_SDID_SERIESID_SHIFT))&SIM_SDID_SERIESID_MASK)
#define SIM_SDID_SUBFAMID_MASK                   0xF000000u
#define SIM_SDID_SUBFAMID_SHIFT                  24
#define SIM_SDID_SUBFAMID(x)                     (((uint32_t)(((uint32_t)(x))<<SIM_SDID_SUBFAMID_SHIFT))&SIM_SDID_SUBFAMID_MASK)
#define SIM_SDID_FAMILYID_MASK                   0xF0000000u
#define SIM_SDID_FAMILYID_SHIFT                  28
#define SIM_SDID_FAMILYID(x)                     (((uint32_t)(((uint32_t)(x))<<SIM_SDID_FAMILYID_SHIFT))&SIM_SDID_FAMILYID_MASK)
/* SCGC1 Bit Fields */
#define SIM_SCGC1_I2C2_MASK                      0x40u
#define SIM_SCGC1_I2C2_SHIFT                     6
#define SIM_SCGC1_I2C3_MASK                      0x80u
#define SIM_SCGC1_I2C3_SHIFT                     7
/* SCGC2 Bit Fields */
#define SIM_SCGC2_LPUART0_MASK                   0x10u
#define SIM_SCGC2_LPUART0_SHIFT                  4
#define SIM_SCGC2_LPUART1_MASK                   0x20u
#define SIM_SCGC2_LPUART1_SHIFT                  5
#define SIM_SCGC2_LPUART2_MASK                   0x40u
#define SIM_SCGC2_LPUART2_SHIFT                  6
#define SIM_SCGC2_LPUART3_MASK                   0x80u
#define SIM_SCGC2_LPUART3_SHIFT                  7
#define SIM_SCGC2_TPM1_MASK                      0x200u
#define SIM_SCGC2_TPM1_SHIFT                     9
#define SIM_SCGC2_TPM2_MASK                      0x400u
#define SIM_SCGC2_TPM2_SHIFT                     10
#define SIM_SCGC2_DAC0_MASK                      0x1000u
#define SIM_SCGC2_DAC0_SHIFT                     12
#define SIM_SCGC2_LTC_MASK                       0x20000u
#define SIM_SCGC2_LTC_SHIFT                      17
#define SIM_SCGC2_EMVSIM0_MASK                   0x100000u
#define SIM_SCGC2_EMVSIM0_SHIFT                  20
#define SIM_SCGC2_EMVSIM1_MASK                   0x200000u
#define SIM_SCGC2_EMVSIM1_SHIFT                  21
#define SIM_SCGC2_LPUART4_MASK                   0x400000u
#define SIM_SCGC2_LPUART4_SHIFT                  22
#define SIM_SCGC2_QSPI_MASK                      0x4000000u
#define SIM_SCGC2_QSPI_SHIFT                     26
#define SIM_SCGC2_FLEXIO_MASK                    0x80000000u
#define SIM_SCGC2_FLEXIO_SHIFT                   31
/* SCGC3 Bit Fields */
#define SIM_SCGC3_TRNG_MASK                      0x1u
#define SIM_SCGC3_TRNG_SHIFT                     0
#define SIM_SCGC3_SPI2_MASK                      0x1000u
#define SIM_SCGC3_SPI2_SHIFT                     12
#define SIM_SCGC3_SDHC_MASK                      0x20000u
#define SIM_SCGC3_SDHC_SHIFT                     17
#define SIM_SCGC3_FTM2_MASK                      0x1000000u
#define SIM_SCGC3_FTM2_SHIFT                     24
#define SIM_SCGC3_FTM3_MASK                      0x2000000u
#define SIM_SCGC3_FTM3_SHIFT                     25
/* SCGC4 Bit Fields */
#define SIM_SCGC4_EWM_MASK                       0x2u
#define SIM_SCGC4_EWM_SHIFT                      1
#define SIM_SCGC4_CMT_MASK                       0x4u
#define SIM_SCGC4_CMT_SHIFT                      2
#define SIM_SCGC4_I2C0_MASK                      0x40u
#define SIM_SCGC4_I2C0_SHIFT                     6
#define SIM_SCGC4_I2C1_MASK                      0x80u
#define SIM_SCGC4_I2C1_SHIFT                     7
#define SIM_SCGC4_USBOTG_MASK                    0x40000u
#define SIM_SCGC4_USBOTG_SHIFT                   18
#define SIM_SCGC4_CMP_MASK                       0x80000u
#define SIM_SCGC4_CMP_SHIFT                      19
#define SIM_SCGC4_VREF_MASK                      0x100000u
#define SIM_SCGC4_VREF_SHIFT                     20
/* SCGC5 Bit Fields */
#define SIM_SCGC5_LPTMR_MASK                     0x1u
#define SIM_SCGC5_LPTMR_SHIFT                    0
#define SIM_SCGC5_DRYICE_MASK                    0x4u
#define SIM_SCGC5_DRYICE_SHIFT                   2
#define SIM_SCGC5_SECREG_MASK                    0x8u
#define SIM_SCGC5_SECREG_SHIFT                   3
#define SIM_SCGC5_LPTMR1_MASK                    0x10u
#define SIM_SCGC5_LPTMR1_SHIFT                   4
#define SIM_SCGC5_TSI_MASK                       0x20u
#define SIM_SCGC5_TSI_SHIFT                      5
#define SIM_SCGC5_PORTA_MASK                     0x200u
#define SIM_SCGC5_PORTA_SHIFT                    9
#define SIM_SCGC5_PORTB_MASK                     0x400u
#define SIM_SCGC5_PORTB_SHIFT                    10
#define SIM_SCGC5_PORTC_MASK                     0x800u
#define SIM_SCGC5_PORTC_SHIFT                    11
#define SIM_SCGC5_PORTD_MASK                     0x1000u
#define SIM_SCGC5_PORTD_SHIFT                    12
#define SIM_SCGC5_PORTE_MASK                     0x2000u
#define SIM_SCGC5_PORTE_SHIFT                    13
/* SCGC6 Bit Fields */
#define SIM_SCGC6_FTF_MASK                       0x1u
#define SIM_SCGC6_FTF_SHIFT                      0
#define SIM_SCGC6_DMAMUX_MASK                    0x2u
#define SIM_SCGC6_DMAMUX_SHIFT                   1
#define SIM_SCGC6_SPI0_MASK                      0x1000u
#define SIM_SCGC6_SPI0_SHIFT                     12
#define SIM_SCGC6_SPI1_MASK                      0x2000u
#define SIM_SCGC6_SPI1_SHIFT                     13
#define SIM_SCGC6_I2S_MASK                       0x8000u
#define SIM_SCGC6_I2S_SHIFT                      15
#define SIM_SCGC6_CRC_MASK                       0x40000u
#define SIM_SCGC6_CRC_SHIFT                      18
#define SIM_SCGC6_USBDCD_MASK                    0x200000u
#define SIM_SCGC6_USBDCD_SHIFT                   21
#define SIM_SCGC6_PDB_MASK                       0x400000u
#define SIM_SCGC6_PDB_SHIFT                      22
#define SIM_SCGC6_PIT_MASK                       0x800000u
#define SIM_SCGC6_PIT_SHIFT                      23
#define SIM_SCGC6_FTM0_MASK                      0x1000000u
#define SIM_SCGC6_FTM0_SHIFT                     24
#define SIM_SCGC6_FTM1_MASK                      0x2000000u
#define SIM_SCGC6_FTM1_SHIFT                     25
#define SIM_SCGC6_FTM2_MASK                      0x4000000u
#define SIM_SCGC6_FTM2_SHIFT                     26
#define SIM_SCGC6_ADC0_MASK                      0x8000000u
#define SIM_SCGC6_ADC0_SHIFT                     27
#define SIM_SCGC6_RTC_MASK                       0x20000000u
#define SIM_SCGC6_RTC_SHIFT                      29
#define SIM_SCGC6_DAC0_MASK                      0x80000000u
#define SIM_SCGC6_DAC0_SHIFT                     31
/* SCGC7 Bit Fields */
#define SIM_SCGC7_FLEXBUS_MASK                   0x1u
#define SIM_SCGC7_FLEXBUS_SHIFT                  0
#define SIM_SCGC7_DMA_MASK                       0x2u
#define SIM_SCGC7_DMA_SHIFT                      1
#define SIM_SCGC7_MPU_MASK                       0x4u
#define SIM_SCGC7_MPU_SHIFT                      2
#define SIM_SCGC7_SDRAMC_MASK                    0x8u
#define SIM_SCGC7_SDRAMC_SHIFT                   3
/* CLKDIV1 Bit Fields */
#define SIM_CLKDIV1_OUTDIV4_MASK                 0xF0000u
#define SIM_CLKDIV1_OUTDIV4_SHIFT                16
#define SIM_CLKDIV1_OUTDIV4(x)                   (((uint32_t)(((uint32_t)(x))<<SIM_CLKDIV1_OUTDIV4_SHIFT))&SIM_CLKDIV1_OUTDIV4_MASK)
#define SIM_CLKDIV1_OUTDIV3_MASK                 0xF00000u
#define SIM_CLKDIV1_OUTDIV3_SHIFT                20
#define SIM_CLKDIV1_OUTDIV3(x)                   (((uint32_t)(((uint32_t)(x))<<SIM_CLKDIV1_OUTDIV3_SHIFT))&SIM_CLKDIV1_OUTDIV3_MASK)
#define SIM_CLKDIV1_OUTDIV2_MASK                 0xF000000u
#define SIM_CLKDIV1_OUTDIV2_SHIFT                24
#define SIM_CLKDIV1_OUTDIV2(x)                   (((uint32_t)(((uint32_t)(x))<<SIM_CLKDIV1_OUTDIV2_SHIFT))&SIM_CLKDIV1_OUTDIV2_MASK)
#define SIM_CLKDIV1_OUTDIV1_MASK                 0xF0000000u
#define SIM_CLKDIV1_OUTDIV1_SHIFT                28
#define SIM_CLKDIV1_OUTDIV1(x)                   (((uint32_t)(((uint32_t)(x))<<SIM_CLKDIV1_OUTDIV1_SHIFT))&SIM_CLKDIV1_OUTDIV1_MASK)
/* CLKDIV2 Bit Fields */
#define SIM_CLKDIV2_USBFRAC_MASK                 0x1u
#define SIM_CLKDIV2_USBFRAC_SHIFT                0
#define SIM_CLKDIV2_USBDIV_MASK                  0xEu
#define SIM_CLKDIV2_USBDIV_SHIFT                 1
#define SIM_CLKDIV2_USBDIV(x)                    (((uint32_t)(((uint32_t)(x))<<SIM_CLKDIV2_USBDIV_SHIFT))&SIM_CLKDIV2_USBDIV_MASK)
/* FCFG1 Bit Fields */
#define SIM_FCFG1_FLASHDIS_MASK                  0x1u
#define SIM_FCFG1_FLASHDIS_SHIFT                 0
#define SIM_FCFG1_FLASHDOZE_MASK                 0x2u
#define SIM_FCFG1_FLASHDOZE_SHIFT                1
#define SIM_FCFG1_PFSIZE_MASK                    0xF000000u
#define SIM_FCFG1_PFSIZE_SHIFT                   24
#define SIM_FCFG1_PFSIZE(x)                      (((uint32_t)(((uint32_t)(x))<<SIM_FCFG1_PFSIZE_SHIFT))&SIM_FCFG1_PFSIZE_MASK)
/* FCFG2 Bit Fields */
#define SIM_FCFG2_MAXADDR1_MASK                  0x7F0000u
#define SIM_FCFG2_MAXADDR1_SHIFT                 16
#define SIM_FCFG2_MAXADDR1(x)                    (((uint32_t)(((uint32_t)(x))<<SIM_FCFG2_MAXADDR1_SHIFT))&SIM_FCFG2_MAXADDR1_MASK)
#define SIM_FCFG2_MAXADDR0_MASK                  0x7F000000u
#define SIM_FCFG2_MAXADDR0_SHIFT                 24
#define SIM_FCFG2_MAXADDR0(x)                    (((uint32_t)(((uint32_t)(x))<<SIM_FCFG2_MAXADDR0_SHIFT))&SIM_FCFG2_MAXADDR0_MASK)
/* UIDH Bit Fields */
#define SIM_UIDH_UID_MASK                        0xFFFFFFFFu
#define SIM_UIDH_UID_SHIFT                       0
#define SIM_UIDH_UID(x)                          (((uint32_t)(((uint32_t)(x))<<SIM_UIDH_UID_SHIFT))&SIM_UIDH_UID_MASK)
/* UIDMH Bit Fields */
#define SIM_UIDMH_UID_MASK                       0xFFFFFFFFu
#define SIM_UIDMH_UID_SHIFT                      0
#define SIM_UIDMH_UID(x)                         (((uint32_t)(((uint32_t)(x))<<SIM_UIDMH_UID_SHIFT))&SIM_UIDMH_UID_MASK)
/* UIDML Bit Fields */
#define SIM_UIDML_UID_MASK                       0xFFFFFFFFu
#define SIM_UIDML_UID_SHIFT                      0
#define SIM_UIDML_UID(x)                         (((uint32_t)(((uint32_t)(x))<<SIM_UIDML_UID_SHIFT))&SIM_UIDML_UID_MASK)
/* UIDL Bit Fields */
#define SIM_UIDL_UID_MASK                        0xFFFFFFFFu
#define SIM_UIDL_UID_SHIFT                       0
#define SIM_UIDL_UID(x)                          (((uint32_t)(((uint32_t)(x))<<SIM_UIDL_UID_SHIFT))&SIM_UIDL_UID_MASK)
/* CLKDIV3 Bit Fields */
#define SIM_CLKDIV3_PLLFLLFRAC_MASK              0x1u
#define SIM_CLKDIV3_PLLFLLFRAC_SHIFT             0
#define SIM_CLKDIV3_PLLFLLDIV_MASK               0xEu
#define SIM_CLKDIV3_PLLFLLDIV_SHIFT              1
#define SIM_CLKDIV3_PLLFLLDIV(x)                 (((uint32_t)(((uint32_t)(x))<<SIM_CLKDIV3_PLLFLLDIV_SHIFT))&SIM_CLKDIV3_PLLFLLDIV_MASK)
/* CLKDIV4 Bit Fields */
#define SIM_CLKDIV4_TRACEFRAC_MASK               0x1u
#define SIM_CLKDIV4_TRACEFRAC_SHIFT              0
#define SIM_CLKDIV4_TRACEDIV_MASK                0xEu
#define SIM_CLKDIV4_TRACEDIV_SHIFT               1
#define SIM_CLKDIV4_TRACEDIV(x)                  (((uint32_t)(((uint32_t)(x))<<SIM_CLKDIV4_TRACEDIV_SHIFT))&SIM_CLKDIV4_TRACEDIV_MASK)
/* SECKEY0 Bit Fields */
#define SIM_SECKEY0_SECKEY_MASK                  0xFFFFFFFFu
#define SIM_SECKEY0_SECKEY_SHIFT                 0
#define SIM_SECKEY0_SECKEY(x)                    (((uint32_t)(((uint32_t)(x))<<SIM_SECKEY0_SECKEY_SHIFT))&SIM_SECKEY0_SECKEY_MASK)
/* SECKEY1 Bit Fields */
#define SIM_SECKEY1_SECKEY_MASK                  0xFFFFFFFFu
#define SIM_SECKEY1_SECKEY_SHIFT                 0
#define SIM_SECKEY1_SECKEY(x)                    (((uint32_t)(((uint32_t)(x))<<SIM_SECKEY1_SECKEY_SHIFT))&SIM_SECKEY1_SECKEY_MASK)
/* SECKEY2 Bit Fields */
#define SIM_SECKEY2_SECKEY_MASK                  0xFFFFFFFFu
#define SIM_SECKEY2_SECKEY_SHIFT                 0
#define SIM_SECKEY2_SECKEY(x)                    (((uint32_t)(((uint32_t)(x))<<SIM_SECKEY2_SECKEY_SHIFT))&SIM_SECKEY2_SECKEY_MASK)
/* SECKEY3 Bit Fields */
#define SIM_SECKEY3_SECKEY_MASK                  0xFFFFFFFFu
#define SIM_SECKEY3_SECKEY_SHIFT                 0
#define SIM_SECKEY3_SECKEY(x)                    (((uint32_t)(((uint32_t)(x))<<SIM_SECKEY3_SECKEY_SHIFT))&SIM_SECKEY3_SECKEY_MASK)

/*!
 * @}
 */ /* end of group SIM_Register_Masks */


/* SIM - Peripheral instance base addresses */
/** Peripheral SIM base address */
#define SIM_BASE                                (0x40047000u)
/** Peripheral SIM base pointer */
#define SIM                                     ((SIM_Type *)SIM_BASE)
#define SIM_BASE_PTR                            (SIM)
/** Array initializer of SIM peripheral base addresses */
#define SIM_BASE_ADDRS                           { SIM_BASE }
/** Array initializer of SIM peripheral base pointers */
#define SIM_BASE_PTRS                            { SIM }
/** Interrupt vectors for the SIM peripheral type */
#define SIM_IRQS                                 { SIM_IRQn }

/* ----------------------------------------------------------------------------
   -- SIM - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SIM_Register_Accessor_Macros SIM - Register accessor macros
 * @{
 */


/* SIM - Register instance definitions */
/* SIM */
#define SIM_SOPT1                                SIM_SOPT1_REG(SIM)
#define SIM_SOPT1CFG                             SIM_SOPT1CFG_REG(SIM)
#define SIM_SOPT2                                SIM_SOPT2_REG(SIM)
#define SIM_SOPT3                                SIM_SOPT3_REG(SIM)
#define SIM_SOPT4                                SIM_SOPT4_REG(SIM)
#define SIM_SOPT5                                SIM_SOPT5_REG(SIM)
#define SIM_SOPT7                                SIM_SOPT7_REG(SIM)
#define SIM_SOPT8                                SIM_SOPT8_REG(SIM)
#define SIM_SOPT9                                SIM_SOPT9_REG(SIM)
#define SIM_SDID                                 SIM_SDID_REG(SIM)
#define SIM_SCGC1                                SIM_SCGC1_REG(SIM)
#define SIM_SCGC2                                SIM_SCGC2_REG(SIM)
#define SIM_SCGC3                                SIM_SCGC3_REG(SIM)
#define SIM_SCGC4                                SIM_SCGC4_REG(SIM)
#define SIM_SCGC5                                SIM_SCGC5_REG(SIM)
#define SIM_SCGC6                                SIM_SCGC6_REG(SIM)
#define SIM_SCGC7                                SIM_SCGC7_REG(SIM)
#define SIM_CLKDIV1                              SIM_CLKDIV1_REG(SIM)
#define SIM_CLKDIV2                              SIM_CLKDIV2_REG(SIM)
#define SIM_FCFG1                                SIM_FCFG1_REG(SIM)
#define SIM_FCFG2                                SIM_FCFG2_REG(SIM)
#define SIM_UIDH                                 SIM_UIDH_REG(SIM)
#define SIM_UIDMH                                SIM_UIDMH_REG(SIM)
#define SIM_UIDML                                SIM_UIDML_REG(SIM)
#define SIM_UIDL                                 SIM_UIDL_REG(SIM)
#define SIM_CLKDIV3                              SIM_CLKDIV3_REG(SIM)
#define SIM_CLKDIV4                              SIM_CLKDIV4_REG(SIM)
#define SIM_SECKEY0                              SIM_SECKEY0_REG(SIM)
#define SIM_SECKEY1                              SIM_SECKEY1_REG(SIM)
#define SIM_SECKEY2                              SIM_SECKEY2_REG(SIM)
#define SIM_SECKEY3                              SIM_SECKEY3_REG(SIM)

/* SIM - Register array accessors */

/*!
 * @}
 */ /* end of group SIM_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group SIM_Peripheral_Access_Layer */


/* ----------------------------------------------------------------------------
   -- SPI Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SPI_Peripheral_Access_Layer SPI Peripheral Access Layer
 * @{
 */

/** SPI - Register Layout Typedef */
typedef struct {
  __IO uint32_t MCR;                               /**< Module Configuration Register, offset: 0x0 */
       uint32_t RESERVED_0;
  __IO uint32_t TCR;                               /**< Transfer Count Register, offset: 0x8 */
       union {
           struct {
               __IO uint32_t CTAR[2];              /**< Clock and Transfer Attributes Register (In Master Mode), array offset: 0xC, array step: 0x4 */
                    uint32_t RESERVED_1[6];
           };
           struct {
               __IO uint32_t CTAR0_SLAVE;          /**< Clock and Transfer Attributes Register (In Slave Mode), offset: 0xC */
                    uint32_t RESERVED_2[7];
           };
       };
  __IO uint32_t SR;                                /**< Status Register, offset: 0x2C */
  __IO uint32_t RSER;                              /**< DMA/Interrupt Request Select and Enable Register, offset: 0x30 */
       union {
           __IO uint32_t PUSHR;                    /**< PUSH TX FIFO Register In Master Mode, offset: 0x34 */
           __IO uint32_t PUSHR_SLAVE;              /**< PUSH TX FIFO Register In Slave Mode, offset: 0x34 */
       };
  __I  uint32_t POPR;                              /**< POP RX FIFO Register, offset: 0x38 */
  __I  uint32_t TXFR[4];                           /**< Transmit FIFO Registers, array offset: 0x3C, array step: 0x4 */
       uint32_t RESERVED_3[12];
  __I  uint32_t RXFR[4];                           /**< Receive FIFO Registers, array offset: 0x7C, array step: 0x4 */
} SPI_Type, *SPI_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- SPI - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SPI_Register_Accessor_Macros SPI - Register accessor macros
 * @{
 */


/* SPI - Register accessors */
#define SPI_MCR_REG(base)                        ((base)->MCR)
#define SPI_TCR_REG(base)                        ((base)->TCR)
#define SPI_CTAR_REG(base,index)                 ((base)->CTAR[index])
#define SPI_CTAR0_SLAVE_REG(base)                ((base)->CTAR0_SLAVE)
#define SPI_SR_REG(base)                         ((base)->SR)
#define SPI_RSER_REG(base)                       ((base)->RSER)
#define SPI_PUSHR_REG(base)                      ((base)->PUSHR)
#define SPI_PUSHR_SLAVE_REG(base)                ((base)->PUSHR_SLAVE)
#define SPI_POPR_REG(base)                       ((base)->POPR)
#define SPI_TXFR_REG(base,index)                 ((base)->TXFR[index])
#define SPI_RXFR_REG(base,index)                 ((base)->RXFR[index])

/*!
 * @}
 */ /* end of group SPI_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- SPI Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SPI_Register_Masks SPI Register Masks
 * @{
 */

/* MCR Bit Fields */
#define SPI_MCR_HALT_MASK                        0x1u
#define SPI_MCR_HALT_SHIFT                       0
#define SPI_MCR_SMPL_PT_MASK                     0x300u
#define SPI_MCR_SMPL_PT_SHIFT                    8
#define SPI_MCR_SMPL_PT(x)                       (((uint32_t)(((uint32_t)(x))<<SPI_MCR_SMPL_PT_SHIFT))&SPI_MCR_SMPL_PT_MASK)
#define SPI_MCR_CLR_RXF_MASK                     0x400u
#define SPI_MCR_CLR_RXF_SHIFT                    10
#define SPI_MCR_CLR_TXF_MASK                     0x800u
#define SPI_MCR_CLR_TXF_SHIFT                    11
#define SPI_MCR_DIS_RXF_MASK                     0x1000u
#define SPI_MCR_DIS_RXF_SHIFT                    12
#define SPI_MCR_DIS_TXF_MASK                     0x2000u
#define SPI_MCR_DIS_TXF_SHIFT                    13
#define SPI_MCR_MDIS_MASK                        0x4000u
#define SPI_MCR_MDIS_SHIFT                       14
#define SPI_MCR_DOZE_MASK                        0x8000u
#define SPI_MCR_DOZE_SHIFT                       15
#define SPI_MCR_PCSIS_MASK                       0x3F0000u
#define SPI_MCR_PCSIS_SHIFT                      16
#define SPI_MCR_PCSIS(x)                         (((uint32_t)(((uint32_t)(x))<<SPI_MCR_PCSIS_SHIFT))&SPI_MCR_PCSIS_MASK)
#define SPI_MCR_ROOE_MASK                        0x1000000u
#define SPI_MCR_ROOE_SHIFT                       24
#define SPI_MCR_PCSSE_MASK                       0x2000000u
#define SPI_MCR_PCSSE_SHIFT                      25
#define SPI_MCR_MTFE_MASK                        0x4000000u
#define SPI_MCR_MTFE_SHIFT                       26
#define SPI_MCR_FRZ_MASK                         0x8000000u
#define SPI_MCR_FRZ_SHIFT                        27
#define SPI_MCR_DCONF_MASK                       0x30000000u
#define SPI_MCR_DCONF_SHIFT                      28
#define SPI_MCR_DCONF(x)                         (((uint32_t)(((uint32_t)(x))<<SPI_MCR_DCONF_SHIFT))&SPI_MCR_DCONF_MASK)
#define SPI_MCR_CONT_SCKE_MASK                   0x40000000u
#define SPI_MCR_CONT_SCKE_SHIFT                  30
#define SPI_MCR_MSTR_MASK                        0x80000000u
#define SPI_MCR_MSTR_SHIFT                       31
/* TCR Bit Fields */
#define SPI_TCR_SPI_TCNT_MASK                    0xFFFF0000u
#define SPI_TCR_SPI_TCNT_SHIFT                   16
#define SPI_TCR_SPI_TCNT(x)                      (((uint32_t)(((uint32_t)(x))<<SPI_TCR_SPI_TCNT_SHIFT))&SPI_TCR_SPI_TCNT_MASK)
/* CTAR Bit Fields */
#define SPI_CTAR_BR_MASK                         0xFu
#define SPI_CTAR_BR_SHIFT                        0
#define SPI_CTAR_BR(x)                           (((uint32_t)(((uint32_t)(x))<<SPI_CTAR_BR_SHIFT))&SPI_CTAR_BR_MASK)
#define SPI_CTAR_DT_MASK                         0xF0u
#define SPI_CTAR_DT_SHIFT                        4
#define SPI_CTAR_DT(x)                           (((uint32_t)(((uint32_t)(x))<<SPI_CTAR_DT_SHIFT))&SPI_CTAR_DT_MASK)
#define SPI_CTAR_ASC_MASK                        0xF00u
#define SPI_CTAR_ASC_SHIFT                       8
#define SPI_CTAR_ASC(x)                          (((uint32_t)(((uint32_t)(x))<<SPI_CTAR_ASC_SHIFT))&SPI_CTAR_ASC_MASK)
#define SPI_CTAR_CSSCK_MASK                      0xF000u
#define SPI_CTAR_CSSCK_SHIFT                     12
#define SPI_CTAR_CSSCK(x)                        (((uint32_t)(((uint32_t)(x))<<SPI_CTAR_CSSCK_SHIFT))&SPI_CTAR_CSSCK_MASK)
#define SPI_CTAR_PBR_MASK                        0x30000u
#define SPI_CTAR_PBR_SHIFT                       16
#define SPI_CTAR_PBR(x)                          (((uint32_t)(((uint32_t)(x))<<SPI_CTAR_PBR_SHIFT))&SPI_CTAR_PBR_MASK)
#define SPI_CTAR_PDT_MASK                        0xC0000u
#define SPI_CTAR_PDT_SHIFT                       18
#define SPI_CTAR_PDT(x)                          (((uint32_t)(((uint32_t)(x))<<SPI_CTAR_PDT_SHIFT))&SPI_CTAR_PDT_MASK)
#define SPI_CTAR_PASC_MASK                       0x300000u
#define SPI_CTAR_PASC_SHIFT                      20
#define SPI_CTAR_PASC(x)                         (((uint32_t)(((uint32_t)(x))<<SPI_CTAR_PASC_SHIFT))&SPI_CTAR_PASC_MASK)
#define SPI_CTAR_PCSSCK_MASK                     0xC00000u
#define SPI_CTAR_PCSSCK_SHIFT                    22
#define SPI_CTAR_PCSSCK(x)                       (((uint32_t)(((uint32_t)(x))<<SPI_CTAR_PCSSCK_SHIFT))&SPI_CTAR_PCSSCK_MASK)
#define SPI_CTAR_LSBFE_MASK                      0x1000000u
#define SPI_CTAR_LSBFE_SHIFT                     24
#define SPI_CTAR_CPHA_MASK                       0x2000000u
#define SPI_CTAR_CPHA_SHIFT                      25
#define SPI_CTAR_CPOL_MASK                       0x4000000u
#define SPI_CTAR_CPOL_SHIFT                      26
#define SPI_CTAR_FMSZ_MASK                       0x78000000u
#define SPI_CTAR_FMSZ_SHIFT                      27
#define SPI_CTAR_FMSZ(x)                         (((uint32_t)(((uint32_t)(x))<<SPI_CTAR_FMSZ_SHIFT))&SPI_CTAR_FMSZ_MASK)
#define SPI_CTAR_DBR_MASK                        0x80000000u
#define SPI_CTAR_DBR_SHIFT                       31
/* CTAR0_SLAVE Bit Fields */
#define SPI_CTAR0_SLAVE_CPHA_MASK                0x2000000u
#define SPI_CTAR0_SLAVE_CPHA_SHIFT               25
#define SPI_CTAR0_SLAVE_CPOL_MASK                0x4000000u
#define SPI_CTAR0_SLAVE_CPOL_SHIFT               26
#define SPI_CTAR0_SLAVE_FMSZ_MASK                0xF8000000u
#define SPI_CTAR0_SLAVE_FMSZ_SHIFT               27
#define SPI_CTAR0_SLAVE_FMSZ(x)                  (((uint32_t)(((uint32_t)(x))<<SPI_CTAR0_SLAVE_FMSZ_SHIFT))&SPI_CTAR0_SLAVE_FMSZ_MASK)
/* SR Bit Fields */
#define SPI_SR_POPNXTPTR_MASK                    0xFu
#define SPI_SR_POPNXTPTR_SHIFT                   0
#define SPI_SR_POPNXTPTR(x)                      (((uint32_t)(((uint32_t)(x))<<SPI_SR_POPNXTPTR_SHIFT))&SPI_SR_POPNXTPTR_MASK)
#define SPI_SR_RXCTR_MASK                        0xF0u
#define SPI_SR_RXCTR_SHIFT                       4
#define SPI_SR_RXCTR(x)                          (((uint32_t)(((uint32_t)(x))<<SPI_SR_RXCTR_SHIFT))&SPI_SR_RXCTR_MASK)
#define SPI_SR_TXNXTPTR_MASK                     0xF00u
#define SPI_SR_TXNXTPTR_SHIFT                    8
#define SPI_SR_TXNXTPTR(x)                       (((uint32_t)(((uint32_t)(x))<<SPI_SR_TXNXTPTR_SHIFT))&SPI_SR_TXNXTPTR_MASK)
#define SPI_SR_TXCTR_MASK                        0xF000u
#define SPI_SR_TXCTR_SHIFT                       12
#define SPI_SR_TXCTR(x)                          (((uint32_t)(((uint32_t)(x))<<SPI_SR_TXCTR_SHIFT))&SPI_SR_TXCTR_MASK)
#define SPI_SR_RFDF_MASK                         0x20000u
#define SPI_SR_RFDF_SHIFT                        17
#define SPI_SR_RFOF_MASK                         0x80000u
#define SPI_SR_RFOF_SHIFT                        19
#define SPI_SR_TFFF_MASK                         0x2000000u
#define SPI_SR_TFFF_SHIFT                        25
#define SPI_SR_TFUF_MASK                         0x8000000u
#define SPI_SR_TFUF_SHIFT                        27
#define SPI_SR_EOQF_MASK                         0x10000000u
#define SPI_SR_EOQF_SHIFT                        28
#define SPI_SR_TXRXS_MASK                        0x40000000u
#define SPI_SR_TXRXS_SHIFT                       30
#define SPI_SR_TCF_MASK                          0x80000000u
#define SPI_SR_TCF_SHIFT                         31
/* RSER Bit Fields */
#define SPI_RSER_RFDF_DIRS_MASK                  0x10000u
#define SPI_RSER_RFDF_DIRS_SHIFT                 16
#define SPI_RSER_RFDF_RE_MASK                    0x20000u
#define SPI_RSER_RFDF_RE_SHIFT                   17
#define SPI_RSER_RFOF_RE_MASK                    0x80000u
#define SPI_RSER_RFOF_RE_SHIFT                   19
#define SPI_RSER_TFFF_DIRS_MASK                  0x1000000u
#define SPI_RSER_TFFF_DIRS_SHIFT                 24
#define SPI_RSER_TFFF_RE_MASK                    0x2000000u
#define SPI_RSER_TFFF_RE_SHIFT                   25
#define SPI_RSER_TFUF_RE_MASK                    0x8000000u
#define SPI_RSER_TFUF_RE_SHIFT                   27
#define SPI_RSER_EOQF_RE_MASK                    0x10000000u
#define SPI_RSER_EOQF_RE_SHIFT                   28
#define SPI_RSER_TCF_RE_MASK                     0x80000000u
#define SPI_RSER_TCF_RE_SHIFT                    31
/* PUSHR Bit Fields */
#define SPI_PUSHR_TXDATA_MASK                    0xFFFFu
#define SPI_PUSHR_TXDATA_SHIFT                   0
#define SPI_PUSHR_TXDATA(x)                      (((uint32_t)(((uint32_t)(x))<<SPI_PUSHR_TXDATA_SHIFT))&SPI_PUSHR_TXDATA_MASK)
#define SPI_PUSHR_PCS_MASK                       0x3F0000u
#define SPI_PUSHR_PCS_SHIFT                      16
#define SPI_PUSHR_PCS(x)                         (((uint32_t)(((uint32_t)(x))<<SPI_PUSHR_PCS_SHIFT))&SPI_PUSHR_PCS_MASK)
#define SPI_PUSHR_CTCNT_MASK                     0x4000000u
#define SPI_PUSHR_CTCNT_SHIFT                    26
#define SPI_PUSHR_EOQ_MASK                       0x8000000u
#define SPI_PUSHR_EOQ_SHIFT                      27
#define SPI_PUSHR_CTAS_MASK                      0x70000000u
#define SPI_PUSHR_CTAS_SHIFT                     28
#define SPI_PUSHR_CTAS(x)                        (((uint32_t)(((uint32_t)(x))<<SPI_PUSHR_CTAS_SHIFT))&SPI_PUSHR_CTAS_MASK)
#define SPI_PUSHR_CONT_MASK                      0x80000000u
#define SPI_PUSHR_CONT_SHIFT                     31
/* PUSHR_SLAVE Bit Fields */
#define SPI_PUSHR_SLAVE_TXDATA_MASK              0xFFFFFFFFu
#define SPI_PUSHR_SLAVE_TXDATA_SHIFT             0
#define SPI_PUSHR_SLAVE_TXDATA(x)                (((uint32_t)(((uint32_t)(x))<<SPI_PUSHR_SLAVE_TXDATA_SHIFT))&SPI_PUSHR_SLAVE_TXDATA_MASK)
/* POPR Bit Fields */
#define SPI_POPR_RXDATA_MASK                     0xFFFFFFFFu
#define SPI_POPR_RXDATA_SHIFT                    0
#define SPI_POPR_RXDATA(x)                       (((uint32_t)(((uint32_t)(x))<<SPI_POPR_RXDATA_SHIFT))&SPI_POPR_RXDATA_MASK)
/* TXFR Bit Fields */
#define SPI_TXFR_TXDATA_MASK                     0xFFFFu
#define SPI_TXFR_TXDATA_SHIFT                    0
#define SPI_TXFR_TXDATA(x)                       (((uint32_t)(((uint32_t)(x))<<SPI_TXFR_TXDATA_SHIFT))&SPI_TXFR_TXDATA_MASK)
#define SPI_TXFR_TXCMD_TXDATA_MASK               0xFFFF0000u
#define SPI_TXFR_TXCMD_TXDATA_SHIFT              16
#define SPI_TXFR_TXCMD_TXDATA(x)                 (((uint32_t)(((uint32_t)(x))<<SPI_TXFR_TXCMD_TXDATA_SHIFT))&SPI_TXFR_TXCMD_TXDATA_MASK)
/* RXFR Bit Fields */
#define SPI_RXFR_RXDATA_MASK                     0xFFFFFFFFu
#define SPI_RXFR_RXDATA_SHIFT                    0
#define SPI_RXFR_RXDATA(x)                       (((uint32_t)(((uint32_t)(x))<<SPI_RXFR_RXDATA_SHIFT))&SPI_RXFR_RXDATA_MASK)

/*!
 * @}
 */ /* end of group SPI_Register_Masks */


/* SPI - Peripheral instance base addresses */
/** Peripheral SPI0 base address */
#define SPI0_BASE                                (0x4002C000u)
/** Peripheral SPI0 base pointer */
#define SPI0                                     ((SPI_Type *)SPI0_BASE)
#define SPI0_BASE_PTR                            (SPI0)
/** Peripheral SPI1 base address */
#define SPI1_BASE                                (0x4002D000u)
/** Peripheral SPI1 base pointer */
#define SPI1                                     ((SPI_Type *)SPI1_BASE)
#define SPI1_BASE_PTR                            (SPI1)
/** Peripheral SPI2 base address */
#define SPI2_BASE                                (0x400AC000u)
/** Peripheral SPI2 base pointer */
#define SPI2                                     ((SPI_Type *)SPI2_BASE)
#define SPI2_BASE_PTR                            (SPI2)
/** Array initializer of SPI peripheral base addresses */
#define SPI_BASE_ADDRS                           { SPI0_BASE, SPI1_BASE, SPI2_BASE }
/** Array initializer of SPI peripheral base pointers */
#define SPI_BASE_PTRS                            { SPI0, SPI1, SPI2 }
/** Interrupt vectors for the SPI peripheral type */
#define SPI_IRQS                                 { SPI0_IRQn, SPI1_IRQn, SPI2_IRQn }

/* ----------------------------------------------------------------------------
   -- SPI - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup SPI_Register_Accessor_Macros SPI - Register accessor macros
 * @{
 */


/* SPI - Register instance definitions */
/* SPI0 */
#define SPI0_MCR                                 SPI_MCR_REG(SPI0)
#define SPI0_TCR                                 SPI_TCR_REG(SPI0)
#define SPI0_CTAR0                               SPI_CTAR_REG(SPI0,0)
#define SPI0_CTAR1                               SPI_CTAR_REG(SPI0,1)
#define SPI0_CTAR0_SLAVE                         SPI_CTAR0_SLAVE_REG(SPI0)
#define SPI0_SR                                  SPI_SR_REG(SPI0)
#define SPI0_RSER                                SPI_RSER_REG(SPI0)
#define SPI0_PUSHR                               SPI_PUSHR_REG(SPI0)
#define SPI0_PUSHR_SLAVE                         SPI_PUSHR_SLAVE_REG(SPI0)
#define SPI0_POPR                                SPI_POPR_REG(SPI0)
#define SPI0_TXFR0                               SPI_TXFR_REG(SPI0,0)
#define SPI0_TXFR1                               SPI_TXFR_REG(SPI0,1)
#define SPI0_TXFR2                               SPI_TXFR_REG(SPI0,2)
#define SPI0_TXFR3                               SPI_TXFR_REG(SPI0,3)
#define SPI0_RXFR0                               SPI_RXFR_REG(SPI0,0)
#define SPI0_RXFR1                               SPI_RXFR_REG(SPI0,1)
#define SPI0_RXFR2                               SPI_RXFR_REG(SPI0,2)
#define SPI0_RXFR3                               SPI_RXFR_REG(SPI0,3)
/* SPI1 */
#define SPI1_MCR                                 SPI_MCR_REG(SPI1)
#define SPI1_TCR                                 SPI_TCR_REG(SPI1)
#define SPI1_CTAR0                               SPI_CTAR_REG(SPI1,0)
#define SPI1_CTAR1                               SPI_CTAR_REG(SPI1,1)
#define SPI1_CTAR0_SLAVE                         SPI_CTAR0_SLAVE_REG(SPI1)
#define SPI1_SR                                  SPI_SR_REG(SPI1)
#define SPI1_RSER                                SPI_RSER_REG(SPI1)
#define SPI1_PUSHR                               SPI_PUSHR_REG(SPI1)
#define SPI1_PUSHR_SLAVE                         SPI_PUSHR_SLAVE_REG(SPI1)
#define SPI1_POPR                                SPI_POPR_REG(SPI1)
#define SPI1_TXFR0                               SPI_TXFR_REG(SPI1,0)
#define SPI1_TXFR1                               SPI_TXFR_REG(SPI1,1)
#define SPI1_TXFR2                               SPI_TXFR_REG(SPI1,2)
#define SPI1_TXFR3                               SPI_TXFR_REG(SPI1,3)
#define SPI1_RXFR0                               SPI_RXFR_REG(SPI1,0)
#define SPI1_RXFR1                               SPI_RXFR_REG(SPI1,1)
#define SPI1_RXFR2                               SPI_RXFR_REG(SPI1,2)
#define SPI1_RXFR3                               SPI_RXFR_REG(SPI1,3)
/* SPI2 */
#define SPI2_MCR                                 SPI_MCR_REG(SPI2)
#define SPI2_TCR                                 SPI_TCR_REG(SPI2)
#define SPI2_CTAR0                               SPI_CTAR_REG(SPI2,0)
#define SPI2_CTAR1                               SPI_CTAR_REG(SPI2,1)
#define SPI2_CTAR0_SLAVE                         SPI_CTAR0_SLAVE_REG(SPI2)
#define SPI2_SR                                  SPI_SR_REG(SPI2)
#define SPI2_RSER                                SPI_RSER_REG(SPI2)
#define SPI2_PUSHR                               SPI_PUSHR_REG(SPI2)
#define SPI2_PUSHR_SLAVE                         SPI_PUSHR_SLAVE_REG(SPI2)
#define SPI2_POPR                                SPI_POPR_REG(SPI2)
#define SPI2_TXFR0                               SPI_TXFR_REG(SPI2,0)
#define SPI2_TXFR1                               SPI_TXFR_REG(SPI2,1)
#define SPI2_TXFR2                               SPI_TXFR_REG(SPI2,2)
#define SPI2_TXFR3                               SPI_TXFR_REG(SPI2,3)
#define SPI2_RXFR0                               SPI_RXFR_REG(SPI2,0)
#define SPI2_RXFR1                               SPI_RXFR_REG(SPI2,1)
#define SPI2_RXFR2                               SPI_RXFR_REG(SPI2,2)
#define SPI2_RXFR3                               SPI_RXFR_REG(SPI2,3)

/* SPI - Register array accessors */
#define SPI0_CTAR(index)                         SPI_CTAR_REG(SPI0,index)
#define SPI0_TXFR(index)                         SPI_TXFR_REG(SPI0,index)
#define SPI0_RXFR(index)                         SPI_RXFR_REG(SPI0,index)
#define SPI1_CTAR(index)                         SPI_CTAR_REG(SPI1,index)
#define SPI1_TXFR(index)                         SPI_TXFR_REG(SPI1,index)
#define SPI1_RXFR(index)                         SPI_RXFR_REG(SPI1,index)
#define SPI2_CTAR(index)                         SPI_CTAR_REG(SPI2,index)
#define SPI2_TXFR(index)                         SPI_TXFR_REG(SPI2,index)
#define SPI2_RXFR(index)                         SPI_RXFR_REG(SPI2,index)

/*!
 * @}
 */ /* end of group SPI_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group SPI_Peripheral_Access_Layer */


/* ----------------------------------------------------------------------------
   -- USB Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USB_Peripheral_Access_Layer USB Peripheral Access Layer
 * @{
 */

/** USB - Register Layout Typedef */
typedef struct {
  __I  uint8_t PERID;                              /**< Peripheral ID register, offset: 0x0 */
       uint8_t RESERVED_0[3];
  __I  uint8_t IDCOMP;                             /**< Peripheral ID Complement register, offset: 0x4 */
       uint8_t RESERVED_1[3];
  __I  uint8_t REV;                                /**< Peripheral Revision register, offset: 0x8 */
       uint8_t RESERVED_2[3];
  __I  uint8_t ADDINFO;                            /**< Peripheral Additional Info register, offset: 0xC */
       uint8_t RESERVED_3[3];
  __IO uint8_t OTGISTAT;                           /**< OTG Interrupt Status register, offset: 0x10 */
       uint8_t RESERVED_4[3];
  __IO uint8_t OTGICR;                             /**< OTG Interrupt Control register, offset: 0x14 */
       uint8_t RESERVED_5[3];
  __IO uint8_t OTGSTAT;                            /**< OTG Status register, offset: 0x18 */
       uint8_t RESERVED_6[3];
  __IO uint8_t OTGCTL;                             /**< OTG Control register, offset: 0x1C */
       uint8_t RESERVED_7[99];
  __IO uint8_t ISTAT;                              /**< Interrupt Status register, offset: 0x80 */
       uint8_t RESERVED_8[3];
  __IO uint8_t INTEN;                              /**< Interrupt Enable register, offset: 0x84 */
       uint8_t RESERVED_9[3];
  __IO uint8_t ERRSTAT;                            /**< Error Interrupt Status register, offset: 0x88 */
       uint8_t RESERVED_10[3];
  __IO uint8_t ERREN;                              /**< Error Interrupt Enable register, offset: 0x8C */
       uint8_t RESERVED_11[3];
  __I  uint8_t STAT;                               /**< Status register, offset: 0x90 */
       uint8_t RESERVED_12[3];
  __IO uint8_t CTL;                                /**< Control register, offset: 0x94 */
       uint8_t RESERVED_13[3];
  __IO uint8_t ADDR;                               /**< Address register, offset: 0x98 */
       uint8_t RESERVED_14[3];
  __IO uint8_t BDTPAGE1;                           /**< BDT Page register 1, offset: 0x9C */
       uint8_t RESERVED_15[3];
  __IO uint8_t FRMNUML;                            /**< Frame Number register Low, offset: 0xA0 */
       uint8_t RESERVED_16[3];
  __IO uint8_t FRMNUMH;                            /**< Frame Number register High, offset: 0xA4 */
       uint8_t RESERVED_17[3];
  __IO uint8_t TOKEN;                              /**< Token register, offset: 0xA8 */
       uint8_t RESERVED_18[3];
  __IO uint8_t SOFTHLD;                            /**< SOF Threshold register, offset: 0xAC */
       uint8_t RESERVED_19[3];
  __IO uint8_t BDTPAGE2;                           /**< BDT Page Register 2, offset: 0xB0 */
       uint8_t RESERVED_20[3];
  __IO uint8_t BDTPAGE3;                           /**< BDT Page Register 3, offset: 0xB4 */
       uint8_t RESERVED_21[11];
       struct {
           __IO uint8_t ENDPT; /**< Endpoint Control register, array offset: 0xC0 */
                uint8_t RESERVED_22[3];
       } ENDPOINT[16];
       uint8_t RESERVED_23[3];
  __IO uint8_t USBCTRL;                            /**< USB Control register, offset: 0x100 */
       uint8_t RESERVED_24[3];
  __I  uint8_t OBSERVE;                            /**< USB OTG Observe register, offset: 0x104 */
       uint8_t RESERVED_25[3];
  __IO uint8_t CONTROL;                            /**< USB OTG Control register, offset: 0x108 */
       uint8_t RESERVED_26[3];
  __IO uint8_t USBTRC0;                            /**< USB Transceiver Control register 0, offset: 0x10C */
       uint8_t RESERVED_27[7];
  __IO uint8_t USBFRMADJUST;                       /**< Frame Adjust Register, offset: 0x114 */
       uint8_t RESERVED_28[43];
  __IO uint8_t CLK_RECOVER_CTRL;                   /**< USB Clock recovery control, offset: 0x140 */
       uint8_t RESERVED_29[3];
  __IO uint8_t CLK_RECOVER_IRC_EN;                 /**< IRC48M oscillator enable register, offset: 0x144 */
       uint8_t RESERVED_30[15];
  __IO uint8_t CLK_RECOVER_INT_EN;                 /**< Clock recovery combined interrupt enable, offset: 0x154 */
       uint8_t RESERVED_31[7];
  __IO uint8_t CLK_RECOVER_INT_STATUS;             /**< Clock recovery separated interrupt status, offset: 0x15C */
} USB_Type, *USB_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- USB - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USB_Register_Accessor_Macros USB - Register accessor macros
 * @{
 */


/* USB - Register accessors */
#define USB_PERID_REG(base)                      ((base)->PERID)
#define USB_IDCOMP_REG(base)                     ((base)->IDCOMP)
#define USB_REV_REG(base)                        ((base)->REV)
#define USB_ADDINFO_REG(base)                    ((base)->ADDINFO)
#define USB_OTGISTAT_REG(base)                   ((base)->OTGISTAT)
#define USB_OTGICR_REG(base)                     ((base)->OTGICR)
#define USB_OTGSTAT_REG(base)                    ((base)->OTGSTAT)
#define USB_OTGCTL_REG(base)                     ((base)->OTGCTL)
#define USB_ISTAT_REG(base)                      ((base)->ISTAT)
#define USB_INTEN_REG(base)                      ((base)->INTEN)
#define USB_ERRSTAT_REG(base)                    ((base)->ERRSTAT)
#define USB_ERREN_REG(base)                      ((base)->ERREN)
#define USB_STAT_REG(base)                       ((base)->STAT)
#define USB_CTL_REG(base)                        ((base)->CTL)
#define USB_ADDR_REG(base)                       ((base)->ADDR)
#define USB_BDTPAGE1_REG(base)                   ((base)->BDTPAGE1)
#define USB_FRMNUML_REG(base)                    ((base)->FRMNUML)
#define USB_FRMNUMH_REG(base)                    ((base)->FRMNUMH)
#define USB_TOKEN_REG(base)                      ((base)->TOKEN)
#define USB_SOFTHLD_REG(base)                    ((base)->SOFTHLD)
#define USB_BDTPAGE2_REG(base)                   ((base)->BDTPAGE2)
#define USB_BDTPAGE3_REG(base)                   ((base)->BDTPAGE3)
#define USB_ENDPT_REG(base,index)                ((base)->ENDPT[index])
#define USB_USBCTRL_REG(base)                    ((base)->USBCTRL)
#define USB_OBSERVE_REG(base)                    ((base)->OBSERVE)
#define USB_CONTROL_REG(base)                    ((base)->CONTROL)
#define USB_USBTRC0_REG(base)                    ((base)->USBTRC0)
#define USB_USBFRMADJUST_REG(base)               ((base)->USBFRMADJUST)
#define USB_CLK_RECOVER_CTRL_REG(base)           ((base)->CLK_RECOVER_CTRL)
#define USB_CLK_RECOVER_IRC_EN_REG(base)         ((base)->CLK_RECOVER_IRC_EN)
#define USB_CLK_RECOVER_INT_EN_REG(base)         ((base)->CLK_RECOVER_INT_EN)
#define USB_CLK_RECOVER_INT_STATUS_REG(base)     ((base)->CLK_RECOVER_INT_STATUS)

/*!
 * @}
 */ /* end of group USB_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- USB Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USB_Register_Masks USB Register Masks
 * @{
 */

/* PERID Bit Fields */
#define USB_PERID_ID_MASK                        0x3Fu
#define USB_PERID_ID_SHIFT                       0
#define USB_PERID_ID(x)                          (((uint8_t)(((uint8_t)(x))<<USB_PERID_ID_SHIFT))&USB_PERID_ID_MASK)
/* IDCOMP Bit Fields */
#define USB_IDCOMP_NID_MASK                      0x3Fu
#define USB_IDCOMP_NID_SHIFT                     0
#define USB_IDCOMP_NID(x)                        (((uint8_t)(((uint8_t)(x))<<USB_IDCOMP_NID_SHIFT))&USB_IDCOMP_NID_MASK)
/* REV Bit Fields */
#define USB_REV_REV_MASK                         0xFFu
#define USB_REV_REV_SHIFT                        0
#define USB_REV_REV(x)                           (((uint8_t)(((uint8_t)(x))<<USB_REV_REV_SHIFT))&USB_REV_REV_MASK)
/* ADDINFO Bit Fields */
#define USB_ADDINFO_IEHOST_MASK                  0x1u
#define USB_ADDINFO_IEHOST_SHIFT                 0
/* OTGISTAT Bit Fields */
#define USB_OTGISTAT_AVBUSCHG_MASK               0x1u
#define USB_OTGISTAT_AVBUSCHG_SHIFT              0
#define USB_OTGISTAT_B_SESS_CHG_MASK             0x4u
#define USB_OTGISTAT_B_SESS_CHG_SHIFT            2
#define USB_OTGISTAT_SESSVLDCHG_MASK             0x8u
#define USB_OTGISTAT_SESSVLDCHG_SHIFT            3
#define USB_OTGISTAT_LINE_STATE_CHG_MASK         0x20u
#define USB_OTGISTAT_LINE_STATE_CHG_SHIFT        5
#define USB_OTGISTAT_ONEMSEC_MASK                0x40u
#define USB_OTGISTAT_ONEMSEC_SHIFT               6
#define USB_OTGISTAT_IDCHG_MASK                  0x80u
#define USB_OTGISTAT_IDCHG_SHIFT                 7
/* OTGICR Bit Fields */
#define USB_OTGICR_AVBUSEN_MASK                  0x1u
#define USB_OTGICR_AVBUSEN_SHIFT                 0
#define USB_OTGICR_BSESSEN_MASK                  0x4u
#define USB_OTGICR_BSESSEN_SHIFT                 2
#define USB_OTGICR_SESSVLDEN_MASK                0x8u
#define USB_OTGICR_SESSVLDEN_SHIFT               3
#define USB_OTGICR_LINESTATEEN_MASK              0x20u
#define USB_OTGICR_LINESTATEEN_SHIFT             5
#define USB_OTGICR_ONEMSECEN_MASK                0x40u
#define USB_OTGICR_ONEMSECEN_SHIFT               6
#define USB_OTGICR_IDEN_MASK                     0x80u
#define USB_OTGICR_IDEN_SHIFT                    7
/* OTGSTAT Bit Fields */
#define USB_OTGSTAT_AVBUSVLD_MASK                0x1u
#define USB_OTGSTAT_AVBUSVLD_SHIFT               0
#define USB_OTGSTAT_BSESSEND_MASK                0x4u
#define USB_OTGSTAT_BSESSEND_SHIFT               2
#define USB_OTGSTAT_SESS_VLD_MASK                0x8u
#define USB_OTGSTAT_SESS_VLD_SHIFT               3
#define USB_OTGSTAT_LINESTATESTABLE_MASK         0x20u
#define USB_OTGSTAT_LINESTATESTABLE_SHIFT        5
#define USB_OTGSTAT_ONEMSECEN_MASK               0x40u
#define USB_OTGSTAT_ONEMSECEN_SHIFT              6
#define USB_OTGSTAT_ID_MASK                      0x80u
#define USB_OTGSTAT_ID_SHIFT                     7
/* OTGCTL Bit Fields */
#define USB_OTGCTL_OTGEN_MASK                    0x4u
#define USB_OTGCTL_OTGEN_SHIFT                   2
#define USB_OTGCTL_DMLOW_MASK                    0x10u
#define USB_OTGCTL_DMLOW_SHIFT                   4
#define USB_OTGCTL_DPLOW_MASK                    0x20u
#define USB_OTGCTL_DPLOW_SHIFT                   5
#define USB_OTGCTL_DPHIGH_MASK                   0x80u
#define USB_OTGCTL_DPHIGH_SHIFT                  7
/* ISTAT Bit Fields */
#define USB_ISTAT_USBRST_MASK                    0x1u
#define USB_ISTAT_USBRST_SHIFT                   0
#define USB_ISTAT_ERROR_MASK                     0x2u
#define USB_ISTAT_ERROR_SHIFT                    1
#define USB_ISTAT_SOFTOK_MASK                    0x4u
#define USB_ISTAT_SOFTOK_SHIFT                   2
#define USB_ISTAT_TOKDNE_MASK                    0x8u
#define USB_ISTAT_TOKDNE_SHIFT                   3
#define USB_ISTAT_SLEEP_MASK                     0x10u
#define USB_ISTAT_SLEEP_SHIFT                    4
#define USB_ISTAT_RESUME_MASK                    0x20u
#define USB_ISTAT_RESUME_SHIFT                   5
#define USB_ISTAT_ATTACH_MASK                    0x40u
#define USB_ISTAT_ATTACH_SHIFT                   6
#define USB_ISTAT_STALL_MASK                     0x80u
#define USB_ISTAT_STALL_SHIFT                    7
/* INTEN Bit Fields */
#define USB_INTEN_USBRSTEN_MASK                  0x1u
#define USB_INTEN_USBRSTEN_SHIFT                 0
#define USB_INTEN_ERROREN_MASK                   0x2u
#define USB_INTEN_ERROREN_SHIFT                  1
#define USB_INTEN_SOFTOKEN_MASK                  0x4u
#define USB_INTEN_SOFTOKEN_SHIFT                 2
#define USB_INTEN_TOKDNEEN_MASK                  0x8u
#define USB_INTEN_TOKDNEEN_SHIFT                 3
#define USB_INTEN_SLEEPEN_MASK                   0x10u
#define USB_INTEN_SLEEPEN_SHIFT                  4
#define USB_INTEN_RESUMEEN_MASK                  0x20u
#define USB_INTEN_RESUMEEN_SHIFT                 5
#define USB_INTEN_ATTACHEN_MASK                  0x40u
#define USB_INTEN_ATTACHEN_SHIFT                 6
#define USB_INTEN_STALLEN_MASK                   0x80u
#define USB_INTEN_STALLEN_SHIFT                  7
/* ERRSTAT Bit Fields */
#define USB_ERRSTAT_PIDERR_MASK                  0x1u
#define USB_ERRSTAT_PIDERR_SHIFT                 0
#define USB_ERRSTAT_CRC5EOF_MASK                 0x2u
#define USB_ERRSTAT_CRC5EOF_SHIFT                1
#define USB_ERRSTAT_CRC16_MASK                   0x4u
#define USB_ERRSTAT_CRC16_SHIFT                  2
#define USB_ERRSTAT_DFN8_MASK                    0x8u
#define USB_ERRSTAT_DFN8_SHIFT                   3
#define USB_ERRSTAT_BTOERR_MASK                  0x10u
#define USB_ERRSTAT_BTOERR_SHIFT                 4
#define USB_ERRSTAT_DMAERR_MASK                  0x20u
#define USB_ERRSTAT_DMAERR_SHIFT                 5
#define USB_ERRSTAT_BTSERR_MASK                  0x80u
#define USB_ERRSTAT_BTSERR_SHIFT                 7
/* ERREN Bit Fields */
#define USB_ERREN_PIDERREN_MASK                  0x1u
#define USB_ERREN_PIDERREN_SHIFT                 0
#define USB_ERREN_CRC5EOFEN_MASK                 0x2u
#define USB_ERREN_CRC5EOFEN_SHIFT                1
#define USB_ERREN_CRC16EN_MASK                   0x4u
#define USB_ERREN_CRC16EN_SHIFT                  2
#define USB_ERREN_DFN8EN_MASK                    0x8u
#define USB_ERREN_DFN8EN_SHIFT                   3
#define USB_ERREN_BTOERREN_MASK                  0x10u
#define USB_ERREN_BTOERREN_SHIFT                 4
#define USB_ERREN_DMAERREN_MASK                  0x20u
#define USB_ERREN_DMAERREN_SHIFT                 5
#define USB_ERREN_BTSERREN_MASK                  0x80u
#define USB_ERREN_BTSERREN_SHIFT                 7
/* STAT Bit Fields */
#define USB_STAT_ODD_MASK                        0x4u
#define USB_STAT_ODD_SHIFT                       2
#define USB_STAT_TX_MASK                         0x8u
#define USB_STAT_TX_SHIFT                        3
#define USB_STAT_ENDP_MASK                       0xF0u
#define USB_STAT_ENDP_SHIFT                      4
#define USB_STAT_ENDP(x)                         (((uint8_t)(((uint8_t)(x))<<USB_STAT_ENDP_SHIFT))&USB_STAT_ENDP_MASK)
/* CTL Bit Fields */
#define USB_CTL_USBENSOFEN_MASK                  0x1u
#define USB_CTL_USBENSOFEN_SHIFT                 0
#define USB_CTL_ODDRST_MASK                      0x2u
#define USB_CTL_ODDRST_SHIFT                     1
#define USB_CTL_RESUME_MASK                      0x4u
#define USB_CTL_RESUME_SHIFT                     2
#define USB_CTL_HOSTMODEEN_MASK                  0x8u
#define USB_CTL_HOSTMODEEN_SHIFT                 3
#define USB_CTL_RESET_MASK                       0x10u
#define USB_CTL_RESET_SHIFT                      4
#define USB_CTL_TXSUSPENDTOKENBUSY_MASK          0x20u
#define USB_CTL_TXSUSPENDTOKENBUSY_SHIFT         5
#define USB_CTL_SE0_MASK                         0x40u
#define USB_CTL_SE0_SHIFT                        6
#define USB_CTL_JSTATE_MASK                      0x80u
#define USB_CTL_JSTATE_SHIFT                     7
/* ADDR Bit Fields */
#define USB_ADDR_ADDR_MASK                       0x7Fu
#define USB_ADDR_ADDR_SHIFT                      0
#define USB_ADDR_ADDR(x)                         (((uint8_t)(((uint8_t)(x))<<USB_ADDR_ADDR_SHIFT))&USB_ADDR_ADDR_MASK)
#define USB_ADDR_LSEN_MASK                       0x80u
#define USB_ADDR_LSEN_SHIFT                      7
/* BDTPAGE1 Bit Fields */
#define USB_BDTPAGE1_BDTBA_MASK                  0xFEu
#define USB_BDTPAGE1_BDTBA_SHIFT                 1
#define USB_BDTPAGE1_BDTBA(x)                    (((uint8_t)(((uint8_t)(x))<<USB_BDTPAGE1_BDTBA_SHIFT))&USB_BDTPAGE1_BDTBA_MASK)
/* FRMNUML Bit Fields */
#define USB_FRMNUML_FRM_MASK                     0xFFu
#define USB_FRMNUML_FRM_SHIFT                    0
#define USB_FRMNUML_FRM(x)                       (((uint8_t)(((uint8_t)(x))<<USB_FRMNUML_FRM_SHIFT))&USB_FRMNUML_FRM_MASK)
/* FRMNUMH Bit Fields */
#define USB_FRMNUMH_FRM_MASK                     0x7u
#define USB_FRMNUMH_FRM_SHIFT                    0
#define USB_FRMNUMH_FRM(x)                       (((uint8_t)(((uint8_t)(x))<<USB_FRMNUMH_FRM_SHIFT))&USB_FRMNUMH_FRM_MASK)
/* TOKEN Bit Fields */
#define USB_TOKEN_TOKENENDPT_MASK                0xFu
#define USB_TOKEN_TOKENENDPT_SHIFT               0
#define USB_TOKEN_TOKENENDPT(x)                  (((uint8_t)(((uint8_t)(x))<<USB_TOKEN_TOKENENDPT_SHIFT))&USB_TOKEN_TOKENENDPT_MASK)
#define USB_TOKEN_TOKENPID_MASK                  0xF0u
#define USB_TOKEN_TOKENPID_SHIFT                 4
#define USB_TOKEN_TOKENPID(x)                    (((uint8_t)(((uint8_t)(x))<<USB_TOKEN_TOKENPID_SHIFT))&USB_TOKEN_TOKENPID_MASK)
/* SOFTHLD Bit Fields */
#define USB_SOFTHLD_CNT_MASK                     0xFFu
#define USB_SOFTHLD_CNT_SHIFT                    0
#define USB_SOFTHLD_CNT(x)                       (((uint8_t)(((uint8_t)(x))<<USB_SOFTHLD_CNT_SHIFT))&USB_SOFTHLD_CNT_MASK)
/* BDTPAGE2 Bit Fields */
#define USB_BDTPAGE2_BDTBA_MASK                  0xFFu
#define USB_BDTPAGE2_BDTBA_SHIFT                 0
#define USB_BDTPAGE2_BDTBA(x)                    (((uint8_t)(((uint8_t)(x))<<USB_BDTPAGE2_BDTBA_SHIFT))&USB_BDTPAGE2_BDTBA_MASK)
/* BDTPAGE3 Bit Fields */
#define USB_BDTPAGE3_BDTBA_MASK                  0xFFu
#define USB_BDTPAGE3_BDTBA_SHIFT                 0
#define USB_BDTPAGE3_BDTBA(x)                    (((uint8_t)(((uint8_t)(x))<<USB_BDTPAGE3_BDTBA_SHIFT))&USB_BDTPAGE3_BDTBA_MASK)
/* ENDPT Bit Fields */
#define USB_ENDPT_EPHSHK_MASK                    0x1u
#define USB_ENDPT_EPHSHK_SHIFT                   0
#define USB_ENDPT_EPSTALL_MASK                   0x2u
#define USB_ENDPT_EPSTALL_SHIFT                  1
#define USB_ENDPT_EPTXEN_MASK                    0x4u
#define USB_ENDPT_EPTXEN_SHIFT                   2
#define USB_ENDPT_EPRXEN_MASK                    0x8u
#define USB_ENDPT_EPRXEN_SHIFT                   3
#define USB_ENDPT_EPCTLDIS_MASK                  0x10u
#define USB_ENDPT_EPCTLDIS_SHIFT                 4
#define USB_ENDPT_RETRYDIS_MASK                  0x40u
#define USB_ENDPT_RETRYDIS_SHIFT                 6
#define USB_ENDPT_HOSTWOHUB_MASK                 0x80u
#define USB_ENDPT_HOSTWOHUB_SHIFT                7
/* USBCTRL Bit Fields */
#define USB_USBCTRL_PDE_MASK                     0x40u
#define USB_USBCTRL_PDE_SHIFT                    6
#define USB_USBCTRL_SUSP_MASK                    0x80u
#define USB_USBCTRL_SUSP_SHIFT                   7
/* OBSERVE Bit Fields */
#define USB_OBSERVE_DMPD_MASK                    0x10u
#define USB_OBSERVE_DMPD_SHIFT                   4
#define USB_OBSERVE_DPPD_MASK                    0x40u
#define USB_OBSERVE_DPPD_SHIFT                   6
#define USB_OBSERVE_DPPU_MASK                    0x80u
#define USB_OBSERVE_DPPU_SHIFT                   7
/* CONTROL Bit Fields */
#define USB_CONTROL_DPPULLUPNONOTG_MASK          0x10u
#define USB_CONTROL_DPPULLUPNONOTG_SHIFT         4
/* USBTRC0 Bit Fields */
#define USB_USBTRC0_USB_RESUME_INT_MASK          0x1u
#define USB_USBTRC0_USB_RESUME_INT_SHIFT         0
#define USB_USBTRC0_SYNC_DET_MASK                0x2u
#define USB_USBTRC0_SYNC_DET_SHIFT               1
#define USB_USBTRC0_USB_CLK_RECOVERY_INT_MASK    0x4u
#define USB_USBTRC0_USB_CLK_RECOVERY_INT_SHIFT   2
#define USB_USBTRC0_USBRESMEN_MASK               0x20u
#define USB_USBTRC0_USBRESMEN_SHIFT              5
#define USB_USBTRC0_USBRESET_MASK                0x80u
#define USB_USBTRC0_USBRESET_SHIFT               7
/* USBFRMADJUST Bit Fields */
#define USB_USBFRMADJUST_ADJ_MASK                0xFFu
#define USB_USBFRMADJUST_ADJ_SHIFT               0
#define USB_USBFRMADJUST_ADJ(x)                  (((uint8_t)(((uint8_t)(x))<<USB_USBFRMADJUST_ADJ_SHIFT))&USB_USBFRMADJUST_ADJ_MASK)
/* CLK_RECOVER_CTRL Bit Fields */
#define USB_CLK_RECOVER_CTRL_RESTART_IFRTRIM_EN_MASK 0x20u
#define USB_CLK_RECOVER_CTRL_RESTART_IFRTRIM_EN_SHIFT 5
#define USB_CLK_RECOVER_CTRL_RESET_RESUME_ROUGH_EN_MASK 0x40u
#define USB_CLK_RECOVER_CTRL_RESET_RESUME_ROUGH_EN_SHIFT 6
#define USB_CLK_RECOVER_CTRL_CLOCK_RECOVER_EN_MASK 0x80u
#define USB_CLK_RECOVER_CTRL_CLOCK_RECOVER_EN_SHIFT 7
/* CLK_RECOVER_IRC_EN Bit Fields */
#define USB_CLK_RECOVER_IRC_EN_REG_EN_MASK       0x1u
#define USB_CLK_RECOVER_IRC_EN_REG_EN_SHIFT      0
#define USB_CLK_RECOVER_IRC_EN_IRC_EN_MASK       0x2u
#define USB_CLK_RECOVER_IRC_EN_IRC_EN_SHIFT      1
/* CLK_RECOVER_INT_EN Bit Fields */
#define USB_CLK_RECOVER_INT_EN_OVF_ERROR_EN_MASK 0x10u
#define USB_CLK_RECOVER_INT_EN_OVF_ERROR_EN_SHIFT 4
/* CLK_RECOVER_INT_STATUS Bit Fields */
#define USB_CLK_RECOVER_INT_STATUS_OVF_ERROR_MASK 0x10u
#define USB_CLK_RECOVER_INT_STATUS_OVF_ERROR_SHIFT 4

/*!
 * @}
 */ /* end of group USB_Register_Masks */


/* USB - Peripheral instance base addresses */
/** Peripheral USB0 base address */
#define USB0_BASE                                (0x40072000u)
/** Peripheral USB0 base pointer */
#define USB0                                     ((USB_Type *)USB0_BASE)
#define USB0_BASE_PTR                            (USB0)
/** Array initializer of USB peripheral base addresses */
#define USB_BASE_ADDRS                           { USB0_BASE }
/** Array initializer of USB peripheral base pointers */
#define USB_BASE_PTRS                            { USB0 }
/** Interrupt vectors for the USB peripheral type */
#define USB_IRQS                                 { USB0_IRQn }

/* ----------------------------------------------------------------------------
   -- USB - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup USB_Register_Accessor_Macros USB - Register accessor macros
 * @{
 */


/* USB - Register instance definitions */
/* USB0 */
#define USB0_PERID                               USB_PERID_REG(USB0)
#define USB0_IDCOMP                              USB_IDCOMP_REG(USB0)
#define USB0_REV                                 USB_REV_REG(USB0)
#define USB0_ADDINFO                             USB_ADDINFO_REG(USB0)
#define USB0_OTGISTAT                            USB_OTGISTAT_REG(USB0)
#define USB0_OTGICR                              USB_OTGICR_REG(USB0)
#define USB0_OTGSTAT                             USB_OTGSTAT_REG(USB0)
#define USB0_OTGCTL                              USB_OTGCTL_REG(USB0)
#define USB0_ISTAT                               USB_ISTAT_REG(USB0)
#define USB0_INTEN                               USB_INTEN_REG(USB0)
#define USB0_ERRSTAT                             USB_ERRSTAT_REG(USB0)
#define USB0_ERREN                               USB_ERREN_REG(USB0)
#define USB0_STAT                                USB_STAT_REG(USB0)
#define USB0_CTL                                 USB_CTL_REG(USB0)
#define USB0_ADDR                                USB_ADDR_REG(USB0)
#define USB0_BDTPAGE1                            USB_BDTPAGE1_REG(USB0)
#define USB0_FRMNUML                             USB_FRMNUML_REG(USB0)
#define USB0_FRMNUMH                             USB_FRMNUMH_REG(USB0)
#define USB0_TOKEN                               USB_TOKEN_REG(USB0)
#define USB0_SOFTHLD                             USB_SOFTHLD_REG(USB0)
#define USB0_BDTPAGE2                            USB_BDTPAGE2_REG(USB0)
#define USB0_BDTPAGE3                            USB_BDTPAGE3_REG(USB0)
#define USB0_ENDPT0                              USB_ENDPT_REG(USB0,0)
#define USB0_ENDPT1                              USB_ENDPT_REG(USB0,1)
#define USB0_ENDPT2                              USB_ENDPT_REG(USB0,2)
#define USB0_ENDPT3                              USB_ENDPT_REG(USB0,3)
#define USB0_ENDPT4                              USB_ENDPT_REG(USB0,4)
#define USB0_ENDPT5                              USB_ENDPT_REG(USB0,5)
#define USB0_ENDPT6                              USB_ENDPT_REG(USB0,6)
#define USB0_ENDPT7                              USB_ENDPT_REG(USB0,7)
#define USB0_ENDPT8                              USB_ENDPT_REG(USB0,8)
#define USB0_ENDPT9                              USB_ENDPT_REG(USB0,9)
#define USB0_ENDPT10                             USB_ENDPT_REG(USB0,10)
#define USB0_ENDPT11                             USB_ENDPT_REG(USB0,11)
#define USB0_ENDPT12                             USB_ENDPT_REG(USB0,12)
#define USB0_ENDPT13                             USB_ENDPT_REG(USB0,13)
#define USB0_ENDPT14                             USB_ENDPT_REG(USB0,14)
#define USB0_ENDPT15                             USB_ENDPT_REG(USB0,15)
#define USB0_USBCTRL                             USB_USBCTRL_REG(USB0)
#define USB0_OBSERVE                             USB_OBSERVE_REG(USB0)
#define USB0_CONTROL                             USB_CONTROL_REG(USB0)
#define USB0_USBTRC0                             USB_USBTRC0_REG(USB0)
#define USB0_USBFRMADJUST                        USB_USBFRMADJUST_REG(USB0)
#define USB0_CLK_RECOVER_CTRL                    USB_CLK_RECOVER_CTRL_REG(USB0)
#define USB0_CLK_RECOVER_IRC_EN                  USB_CLK_RECOVER_IRC_EN_REG(USB0)
#define USB0_CLK_RECOVER_INT_EN                  USB_CLK_RECOVER_INT_EN_REG(USB0)
#define USB0_CLK_RECOVER_INT_STATUS              USB_CLK_RECOVER_INT_STATUS_REG(USB0)

/* USB - Register array accessors */
#define USB0_ENDPT(index)                        USB_ENDPT_REG(USB0,index)

/*!
 * @}
 */ /* end of group USB_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group USB_Peripheral_Access_Layer */


/* ----------------------------------------------------------------------------
   -- WDOG Peripheral Access Layer
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup WDOG_Peripheral_Access_Layer WDOG Peripheral Access Layer
 * @{
 */

/** WDOG - Register Layout Typedef */
typedef struct {
  __IO uint16_t STCTRLH;                           /**< Watchdog Status and Control Register High, offset: 0x0 */
  __IO uint16_t STCTRLL;                           /**< Watchdog Status and Control Register Low, offset: 0x2 */
  __IO uint16_t TOVALH;                            /**< Watchdog Time-out Value Register High, offset: 0x4 */
  __IO uint16_t TOVALL;                            /**< Watchdog Time-out Value Register Low, offset: 0x6 */
  __IO uint16_t WINH;                              /**< Watchdog Window Register High, offset: 0x8 */
  __IO uint16_t WINL;                              /**< Watchdog Window Register Low, offset: 0xA */
  __IO uint16_t REFRESH;                           /**< Watchdog Refresh register, offset: 0xC */
  __IO uint16_t UNLOCK;                            /**< Watchdog Unlock register, offset: 0xE */
  __IO uint16_t TMROUTH;                           /**< Watchdog Timer Output Register High, offset: 0x10 */
  __IO uint16_t TMROUTL;                           /**< Watchdog Timer Output Register Low, offset: 0x12 */
  __IO uint16_t RSTCNT;                            /**< Watchdog Reset Count register, offset: 0x14 */
  __IO uint16_t PRESC;                             /**< Watchdog Prescaler register, offset: 0x16 */
} WDOG_Type, *WDOG_MemMapPtr;

/* ----------------------------------------------------------------------------
   -- WDOG - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup WDOG_Register_Accessor_Macros WDOG - Register accessor macros
 * @{
 */


/* WDOG - Register accessors */
#define WDOG_STCTRLH_REG(base)                   ((base)->STCTRLH)
#define WDOG_STCTRLL_REG(base)                   ((base)->STCTRLL)
#define WDOG_TOVALH_REG(base)                    ((base)->TOVALH)
#define WDOG_TOVALL_REG(base)                    ((base)->TOVALL)
#define WDOG_WINH_REG(base)                      ((base)->WINH)
#define WDOG_WINL_REG(base)                      ((base)->WINL)
#define WDOG_REFRESH_REG(base)                   ((base)->REFRESH)
#define WDOG_UNLOCK_REG(base)                    ((base)->UNLOCK)
#define WDOG_TMROUTH_REG(base)                   ((base)->TMROUTH)
#define WDOG_TMROUTL_REG(base)                   ((base)->TMROUTL)
#define WDOG_RSTCNT_REG(base)                    ((base)->RSTCNT)
#define WDOG_PRESC_REG(base)                     ((base)->PRESC)

/*!
 * @}
 */ /* end of group WDOG_Register_Accessor_Macros */


/* ----------------------------------------------------------------------------
   -- WDOG Register Masks
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup WDOG_Register_Masks WDOG Register Masks
 * @{
 */

/* STCTRLH Bit Fields */
#define WDOG_STCTRLH_WDOGEN_MASK                 0x1u
#define WDOG_STCTRLH_WDOGEN_SHIFT                0
#define WDOG_STCTRLH_CLKSRC_MASK                 0x2u
#define WDOG_STCTRLH_CLKSRC_SHIFT                1
#define WDOG_STCTRLH_IRQRSTEN_MASK               0x4u
#define WDOG_STCTRLH_IRQRSTEN_SHIFT              2
#define WDOG_STCTRLH_WINEN_MASK                  0x8u
#define WDOG_STCTRLH_WINEN_SHIFT                 3
#define WDOG_STCTRLH_ALLOWUPDATE_MASK            0x10u
#define WDOG_STCTRLH_ALLOWUPDATE_SHIFT           4
#define WDOG_STCTRLH_DBGEN_MASK                  0x20u
#define WDOG_STCTRLH_DBGEN_SHIFT                 5
#define WDOG_STCTRLH_STOPEN_MASK                 0x40u
#define WDOG_STCTRLH_STOPEN_SHIFT                6
#define WDOG_STCTRLH_WAITEN_MASK                 0x80u
#define WDOG_STCTRLH_WAITEN_SHIFT                7
#define WDOG_STCTRLH_TESTWDOG_MASK               0x400u
#define WDOG_STCTRLH_TESTWDOG_SHIFT              10
#define WDOG_STCTRLH_TESTSEL_MASK                0x800u
#define WDOG_STCTRLH_TESTSEL_SHIFT               11
#define WDOG_STCTRLH_BYTESEL_MASK                0x3000u
#define WDOG_STCTRLH_BYTESEL_SHIFT               12
#define WDOG_STCTRLH_BYTESEL(x)                  (((uint16_t)(((uint16_t)(x))<<WDOG_STCTRLH_BYTESEL_SHIFT))&WDOG_STCTRLH_BYTESEL_MASK)
#define WDOG_STCTRLH_DISTESTWDOG_MASK            0x4000u
#define WDOG_STCTRLH_DISTESTWDOG_SHIFT           14
/* STCTRLL Bit Fields */
#define WDOG_STCTRLL_INTFLG_MASK                 0x8000u
#define WDOG_STCTRLL_INTFLG_SHIFT                15
/* TOVALH Bit Fields */
#define WDOG_TOVALH_TOVALHIGH_MASK               0xFFFFu
#define WDOG_TOVALH_TOVALHIGH_SHIFT              0
#define WDOG_TOVALH_TOVALHIGH(x)                 (((uint16_t)(((uint16_t)(x))<<WDOG_TOVALH_TOVALHIGH_SHIFT))&WDOG_TOVALH_TOVALHIGH_MASK)
/* TOVALL Bit Fields */
#define WDOG_TOVALL_TOVALLOW_MASK                0xFFFFu
#define WDOG_TOVALL_TOVALLOW_SHIFT               0
#define WDOG_TOVALL_TOVALLOW(x)                  (((uint16_t)(((uint16_t)(x))<<WDOG_TOVALL_TOVALLOW_SHIFT))&WDOG_TOVALL_TOVALLOW_MASK)
/* WINH Bit Fields */
#define WDOG_WINH_WINHIGH_MASK                   0xFFFFu
#define WDOG_WINH_WINHIGH_SHIFT                  0
#define WDOG_WINH_WINHIGH(x)                     (((uint16_t)(((uint16_t)(x))<<WDOG_WINH_WINHIGH_SHIFT))&WDOG_WINH_WINHIGH_MASK)
/* WINL Bit Fields */
#define WDOG_WINL_WINLOW_MASK                    0xFFFFu
#define WDOG_WINL_WINLOW_SHIFT                   0
#define WDOG_WINL_WINLOW(x)                      (((uint16_t)(((uint16_t)(x))<<WDOG_WINL_WINLOW_SHIFT))&WDOG_WINL_WINLOW_MASK)
/* REFRESH Bit Fields */
#define WDOG_REFRESH_WDOGREFRESH_MASK            0xFFFFu
#define WDOG_REFRESH_WDOGREFRESH_SHIFT           0
#define WDOG_REFRESH_WDOGREFRESH(x)              (((uint16_t)(((uint16_t)(x))<<WDOG_REFRESH_WDOGREFRESH_SHIFT))&WDOG_REFRESH_WDOGREFRESH_MASK)
/* UNLOCK Bit Fields */
#define WDOG_UNLOCK_WDOGUNLOCK_MASK              0xFFFFu
#define WDOG_UNLOCK_WDOGUNLOCK_SHIFT             0
#define WDOG_UNLOCK_WDOGUNLOCK(x)                (((uint16_t)(((uint16_t)(x))<<WDOG_UNLOCK_WDOGUNLOCK_SHIFT))&WDOG_UNLOCK_WDOGUNLOCK_MASK)
/* TMROUTH Bit Fields */
#define WDOG_TMROUTH_TIMEROUTHIGH_MASK           0xFFFFu
#define WDOG_TMROUTH_TIMEROUTHIGH_SHIFT          0
#define WDOG_TMROUTH_TIMEROUTHIGH(x)             (((uint16_t)(((uint16_t)(x))<<WDOG_TMROUTH_TIMEROUTHIGH_SHIFT))&WDOG_TMROUTH_TIMEROUTHIGH_MASK)
/* TMROUTL Bit Fields */
#define WDOG_TMROUTL_TIMEROUTLOW_MASK            0xFFFFu
#define WDOG_TMROUTL_TIMEROUTLOW_SHIFT           0
#define WDOG_TMROUTL_TIMEROUTLOW(x)              (((uint16_t)(((uint16_t)(x))<<WDOG_TMROUTL_TIMEROUTLOW_SHIFT))&WDOG_TMROUTL_TIMEROUTLOW_MASK)
/* RSTCNT Bit Fields */
#define WDOG_RSTCNT_RSTCNT_MASK                  0xFFFFu
#define WDOG_RSTCNT_RSTCNT_SHIFT                 0
#define WDOG_RSTCNT_RSTCNT(x)                    (((uint16_t)(((uint16_t)(x))<<WDOG_RSTCNT_RSTCNT_SHIFT))&WDOG_RSTCNT_RSTCNT_MASK)
/* PRESC Bit Fields */
#define WDOG_PRESC_PRESCVAL_MASK                 0x700u
#define WDOG_PRESC_PRESCVAL_SHIFT                8
#define WDOG_PRESC_PRESCVAL(x)                   (((uint16_t)(((uint16_t)(x))<<WDOG_PRESC_PRESCVAL_SHIFT))&WDOG_PRESC_PRESCVAL_MASK)

/*!
 * @}
 */ /* end of group WDOG_Register_Masks */


/* WDOG - Peripheral instance base addresses */
/** Peripheral WDOG base address */
#define WDOG_BASE                                (0x40052000u)
/** Peripheral WDOG base pointer */
#define WDOG                                     ((WDOG_Type *)WDOG_BASE)
#define WDOG_BASE_PTR                            (WDOG)
/** Array initializer of WDOG peripheral base addresses */
#define WDOG_BASE_ADDRS                           { WDOG_BASE }
/** Array initializer of WDOG peripheral base pointers */
#define WDOG_BASE_PTRS                            { WDOG }
/** Interrupt vectors for the WDOG peripheral type */
#define WDOG_IRQS                                 { WDOG_IRQn }

/* ----------------------------------------------------------------------------
   -- WDOG - Register accessor macros
   ---------------------------------------------------------------------------- */

/*!
 * @addtogroup WDOG_Register_Accessor_Macros WDOG - Register accessor macros
 * @{
 */


/* WDOG - Register instance definitions */
/* WDOG */
#define WDOG_STCTRLH                             WDOG_STCTRLH_REG(WDOG)
#define WDOG_STCTRLL                             WDOG_STCTRLL_REG(WDOG)
#define WDOG_TOVALH                              WDOG_TOVALH_REG(WDOG)
#define WDOG_TOVALL                              WDOG_TOVALL_REG(WDOG)
#define WDOG_WINH                                WDOG_WINH_REG(WDOG)
#define WDOG_WINL                                WDOG_WINL_REG(WDOG)
#define WDOG_REFRESH                             WDOG_REFRESH_REG(WDOG)
#define WDOG_UNLOCK                              WDOG_UNLOCK_REG(WDOG)
#define WDOG_TMROUTH                             WDOG_TMROUTH_REG(WDOG)
#define WDOG_TMROUTL                             WDOG_TMROUTL_REG(WDOG)
#define WDOG_RSTCNT                              WDOG_RSTCNT_REG(WDOG)
#define WDOG_PRESC                               WDOG_PRESC_REG(WDOG)

/* WDOG - Register array accessors */

/*!
 * @}
 */ /* end of group WDOG_Register_Accessor_Macros */


/*!
 * @}
 */ /* end of group WDOG_Peripheral_Access_Layer */


#endif  /* #if !defined(MK80F256_H_) */

/* MK80F256.h, eof. */
