/*
** ###################################################################
**     Compilers:           ARM Compiler
**                          Freescale C/C++ for Embedded ARM
**                          GNU C Compiler
**                          IAR ANSI C/C++ Compiler for ARM
**
**     Reference manual:    xxx
**     Version:             rev. 1.0, 2014-05-26
**     Build:               b140528
**
**     Abstract:
**         Extension to the CMSIS register access layer header.
**
**     Copyright (c) 2014 Freescale Semiconductor, Inc.
**     All rights reserved.
**
**     Redistribution and use in source and binary forms, with or without modification,
**     are permitted provided that the following conditions are met:
**
**     o Redistributions of source code must retain the above copyright notice, this list
**       of conditions and the following disclaimer.
**
**     o Redistributions in binary form must reproduce the above copyright notice, this
**       list of conditions and the following disclaimer in the documentation and/or
**       other materials provided with the distribution.
**
**     o Neither the name of Freescale Semiconductor, Inc. nor the names of its
**       contributors may be used to endorse or promote products derived from this
**       software without specific prior written permission.
**
**     THIS SOFTWARE IS PROVIDED BY THE COPYRIGHT HOLDERS AND CONTRIBUTORS "AS IS" AND
**     ANY EXPRESS OR IMPLIED WARRANTIES, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
**     WARRANTIES OF MERCHANTABILITY AND FITNESS FOR A PARTICULAR PURPOSE ARE
**     DISCLAIMED. IN NO EVENT SHALL THE COPYRIGHT HOLDER OR CONTRIBUTORS BE LIABLE FOR
**     ANY DIRECT, INDIRECT, INCIDENTAL, SPECIAL, EXEMPLARY, OR CONSEQUENTIAL DAMAGES
**     (INCLUDING, BUT NOT LIMITED TO, PROCUREMENT OF SUBSTITUTE GOODS OR SERVICES;
**     LOSS OF USE, DATA, OR PROFITS; OR BUSINESS INTERRUPTION) HOWEVER CAUSED AND ON
**     ANY THEORY OF LIABILITY, WHETHER IN CONTRACT, STRICT LIABILITY, OR TORT
**     (INCLUDING NEGLIGENCE OR OTHERWISE) ARISING IN ANY WAY OUT OF THE USE OF THIS
**     SOFTWARE, EVEN IF ADVISED OF THE POSSIBILITY OF SUCH DAMAGE.
**
**     http:                 www.freescale.com
**     mail:                 support@freescale.com
**
**     Revisions:
**     - rev. 1.0 (2014-05-26)
**
** ###################################################################
*/

/*
 * WARNING! DO NOT EDIT THIS FILE DIRECTLY!
 *
 * This file was generated automatically and any changes may be lost.
 */
#ifndef __HW_QUADSPI_REGISTERS_H__
#define __HW_QUADSPI_REGISTERS_H__

#include "MK80F256.h"
#include "fsl_bitaccess.h"

/*
 * MK80F256 QUADSPI
 *
 * QuadSPI
 *
 * Registers defined in this header file:
 * - HW_QUADSPI_MCR - Module Configuration Register
 * - HW_QUADSPI_IPCR - IP Configuration Register
 * - HW_QUADSPI_FLSHCR - Flash Configuration Register
 * - HW_QUADSPI_BUF0CR - Buffer0 Configuration Register
 * - HW_QUADSPI_BUF1CR - Buffer1 Configuration Register
 * - HW_QUADSPI_BUF2CR - Buffer2 Configuration Register
 * - HW_QUADSPI_BUF3CR - Buffer3 Configuration Register
 * - HW_QUADSPI_BFGENCR - Buffer Generic Configuration Register
 * - HW_QUADSPI_SOCCR - SOC Configuration Register
 * - HW_QUADSPI_BUF0IND - Buffer0 Top Index Register
 * - HW_QUADSPI_BUF1IND - Buffer1 Top Index Register
 * - HW_QUADSPI_BUF2IND - Buffer2 Top Index Register
 * - HW_QUADSPI_SFAR - Serial Flash Address Register
 * - HW_QUADSPI_SFACR - Serial Flash Address Configuration Register
 * - HW_QUADSPI_SMPR - Sampling Register
 * - HW_QUADSPI_RBSR - RX Buffer Status Register
 * - HW_QUADSPI_RBCT - RX Buffer Control Register
 * - HW_QUADSPI_TBSR - TX Buffer Status Register
 * - HW_QUADSPI_TBDR - TX Buffer Data Register
 * - HW_QUADSPI_TBCT - Tx Buffer Control Register
 * - HW_QUADSPI_SR - Status Register
 * - HW_QUADSPI_FR - Flag Register
 * - HW_QUADSPI_RSER - Interrupt and DMA Request Select and Enable Register
 * - HW_QUADSPI_SPNDST - Sequence Suspend Status Register
 * - HW_QUADSPI_SPTRCLR - Sequence Pointer Clear Register
 * - HW_QUADSPI_SFA1AD - Serial Flash A1 Top Address
 * - HW_QUADSPI_SFA2AD - Serial Flash A2 Top Address
 * - HW_QUADSPI_SFB1AD - Serial Flash B1Top Address
 * - HW_QUADSPI_SFB2AD - Serial Flash B2Top Address
 * - HW_QUADSPI_DLPR - Data Learn Pattern Register
 * - HW_QUADSPI_RBDRn - RX Buffer Data Register
 * - HW_QUADSPI_LUTKEY - LUT Key Register
 * - HW_QUADSPI_LCKCR - LUT Lock Configuration Register
 * - HW_QUADSPI_LUTn - Look-up Table register
 *
 * - hw_quadspi_t - Struct containing all module registers.
 */

#define HW_QUADSPI_INSTANCE_COUNT (1U) /*!< Number of instances of the QUADSPI module. */
#define HW_QUADSPI0 (0U) /*!< Instance number for QUADSPI0. */

/*******************************************************************************
 * HW_QUADSPI_MCR - Module Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_MCR - Module Configuration Register (RW)
 *
 * Reset value: 0x000F4000U
 *
 * The QuadSPI_MCR holds configuration data associated with QuadSPI operation. Write: All other
 * fields: Anytime
 */
typedef union _hw_quadspi_mcr
{
    uint32_t U;
    struct _hw_quadspi_mcr_bitfields
    {
        uint32_t SWRSTSD : 1; /*!< [0] Software reset for Serial Flash domain */
        uint32_t SWRSTHD : 1; /*!< [1] Software reset for AHB domain */
        uint32_t END_CFG : 2; /*!< [3:2] Defines the endianness of the QSPI module.For more details refer to Byte Ordering Endianess */
        uint32_t RESERVED0 : 1; /*!< [4]  */
        uint32_t DQS_LAT_EN : 1; /*!< [5] DQS Latency Enable: This field is valid when latency is included in between read access from FLash in case when QSPI_MCR[DQS_EN] is 1.For more details Refer Data Strobe Signal Functionality */
        uint32_t DQS_EN : 1; /*!< [6] DQS enable: This field is valid for both SDR and DDR mode.For more details Refer Data Strobe Signal Functionality */
        uint32_t DDR_EN : 1; /*!< [7] DDR mode enable: */
        uint32_t RESERVED1 : 2; /*!< [9:8]  */
        uint32_t CLR_RXF : 1; /*!< [10] Clear RX FIFO. */
        uint32_t CLR_TXF : 1; /*!< [11] Clear TX FIFO/Buffer. */
        uint32_t RESERVED2 : 2; /*!< [13:12]  */
        uint32_t MDIS : 1; /*!< [14] Module Disable. */
        uint32_t RESERVED4 : 9; /*!< [23:15] Reserved. */
        uint32_t SCLKCFG : 8; /*!< [31:24] Serial Clock Configuration. */
    } B;
} hw_quadspi_mcr_t;

/*!
 * @name Constants and macros for entire QUADSPI_MCR register
 */
/*@{*/
#define HW_QUADSPI_MCR_ADDR(x)        ((x) + 0x0U)
#define HW_QUADSPI_MCR(x)             (*(__IO hw_quadspi_mcr_t *) HW_QUADSPI_MCR_ADDR(x))
#define HW_QUADSPI_MCR_RD(x)          (HW_QUADSPI_MCR(x).U)
#define HW_QUADSPI_MCR_WR(x, v)       (HW_QUADSPI_MCR(x).U = (v))
#define HW_QUADSPI_MCR_SET(x, v)      (HW_QUADSPI_MCR_WR(x, HW_QUADSPI_MCR_RD(x) |  (v)))
#define HW_QUADSPI_MCR_CLR(x, v)      (HW_QUADSPI_MCR_WR(x, HW_QUADSPI_MCR_RD(x) & ~(v)))
#define HW_QUADSPI_MCR_TOG(x, v)      (HW_QUADSPI_MCR_WR(x, HW_QUADSPI_MCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_MCR bitfields
 */

/*!
 * @name Register QUADSPI_MCR, field SWRSTSD[0] (RW)
 *
 * Software reset for Serial Flash domain
 *
 * Values:
 * - 0 - No action
 * - 1 - Serial Flash domain flops are reset. Does not reset configuration registers. It is advisable to
 *     reset both the serial flash domain and AHB domain at the same time. Resetting only one domain
 *     might lead to side effects.The software resets need the clock to be running to propagate to
 *     the design. The MCR[MDIS] should therefore be set to 0 when the software reset bits are
 *     asserted. Also, before they can be deasserted again (by setting MCR[SWRSTSD] to 0), it is
 *     recommended to set the MCR[MDIS] bit to 1. Once the software resets have been deasserted, the
 *     normal operation can be started by setting the MCR[MDIS] bit to 0.
 */
/*@{*/
#define BP_QUADSPI_MCR_SWRSTSD         (0U)      /*!< Bit position for QUADSPI_MCR_SWRSTSD. */
#define BM_QUADSPI_MCR_SWRSTSD         (0x00000001U)  /*!< Bit mask for QUADSPI_MCR_SWRSTSD. */
#define BS_QUADSPI_MCR_SWRSTSD         (1U)  /*!< Bitfield size in bits for QUADSPI_MCR_SWRSTSD. */

/*! @brief Read current value of the QUADSPI_MCR_SWRSTSD field. */
#define BR_QUADSPI_MCR_SWRSTSD(x)   (HW_QUADSPI_MCR(x).B.SWRSTSD)

/*! @brief Format value for bitfield QUADSPI_MCR_SWRSTSD. */
#define BF_QUADSPI_MCR_SWRSTSD(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_MCR_SWRSTSD) & BM_QUADSPI_MCR_SWRSTSD)

/*! @brief Set the SWRSTSD field to a new value. */
#define BW_QUADSPI_MCR_SWRSTSD(x, v)   (HW_QUADSPI_MCR_WR(x, (HW_QUADSPI_MCR_RD(x) & ~BM_QUADSPI_MCR_SWRSTSD) | BF_QUADSPI_MCR_SWRSTSD(v)))
/*@}*/

/*!
 * @name Register QUADSPI_MCR, field SWRSTHD[1] (RW)
 *
 * Software reset for AHB domain
 *
 * Values:
 * - 0 - No action
 * - 1 - AHB domain flops are reset. Does not reset configuration registers. It is advisable to reset both
 *     the serial flash domain and AHB domain at the same time. Resetting only one domain might lead
 *     to side effects.The software resets need the clock to be running to propagate to the design.
 *     The MCR[MDIS] should therefore be set to 0 when the software reset bits are asserted. Also,
 *     before they can be deasserted again (by setting MCR[SWRSTHD] to 0), it is recommended to set
 *     the MCR[MDIS] bit to 1. Once the software resets have been deasserted, the normal operation
 *     can be started by setting the MCR[MDIS] bit to 0.
 */
/*@{*/
#define BP_QUADSPI_MCR_SWRSTHD         (1U)      /*!< Bit position for QUADSPI_MCR_SWRSTHD. */
#define BM_QUADSPI_MCR_SWRSTHD         (0x00000002U)  /*!< Bit mask for QUADSPI_MCR_SWRSTHD. */
#define BS_QUADSPI_MCR_SWRSTHD         (1U)  /*!< Bitfield size in bits for QUADSPI_MCR_SWRSTHD. */

/*! @brief Read current value of the QUADSPI_MCR_SWRSTHD field. */
#define BR_QUADSPI_MCR_SWRSTHD(x)   (HW_QUADSPI_MCR(x).B.SWRSTHD)

/*! @brief Format value for bitfield QUADSPI_MCR_SWRSTHD. */
#define BF_QUADSPI_MCR_SWRSTHD(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_MCR_SWRSTHD) & BM_QUADSPI_MCR_SWRSTHD)

/*! @brief Set the SWRSTHD field to a new value. */
#define BW_QUADSPI_MCR_SWRSTHD(x, v)   (HW_QUADSPI_MCR_WR(x, (HW_QUADSPI_MCR_RD(x) & ~BM_QUADSPI_MCR_SWRSTHD) | BF_QUADSPI_MCR_SWRSTHD(v)))
/*@}*/

/*!
 * @name Register QUADSPI_MCR, field END_CFG[3:2] (RW)
 *
 * Defines the endianness of the QSPI module.For more details refer to Byte Ordering Endianess
 */
/*@{*/
#define BP_QUADSPI_MCR_END_CFG         (2U)      /*!< Bit position for QUADSPI_MCR_END_CFG. */
#define BM_QUADSPI_MCR_END_CFG         (0x0000000CU)  /*!< Bit mask for QUADSPI_MCR_END_CFG. */
#define BS_QUADSPI_MCR_END_CFG         (2U)  /*!< Bitfield size in bits for QUADSPI_MCR_END_CFG. */

/*! @brief Read current value of the QUADSPI_MCR_END_CFG field. */
#define BR_QUADSPI_MCR_END_CFG(x)   (HW_QUADSPI_MCR(x).B.END_CFG)

/*! @brief Format value for bitfield QUADSPI_MCR_END_CFG. */
#define BF_QUADSPI_MCR_END_CFG(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_MCR_END_CFG) & BM_QUADSPI_MCR_END_CFG)

/*! @brief Set the END_CFG field to a new value. */
#define BW_QUADSPI_MCR_END_CFG(x, v)   (HW_QUADSPI_MCR_WR(x, (HW_QUADSPI_MCR_RD(x) & ~BM_QUADSPI_MCR_END_CFG) | BF_QUADSPI_MCR_END_CFG(v)))
/*@}*/

/*!
 * @name Register QUADSPI_MCR, field DQS_LAT_EN[5] (RW)
 *
 * DQS Latency Enable: This field is valid when latency is included in between read access from
 * FLash in case when QSPI_MCR[DQS_EN] is 1.For more details Refer Data Strobe Signal Functionality
 *
 * Values:
 * - 0 - DQS Latency disabled
 * - 1 - DQS feature with latency included enabled
 */
/*@{*/
#define BP_QUADSPI_MCR_DQS_LAT_EN         (5U)      /*!< Bit position for QUADSPI_MCR_DQS_LAT_EN. */
#define BM_QUADSPI_MCR_DQS_LAT_EN         (0x00000020U)  /*!< Bit mask for QUADSPI_MCR_DQS_LAT_EN. */
#define BS_QUADSPI_MCR_DQS_LAT_EN         (1U)  /*!< Bitfield size in bits for QUADSPI_MCR_DQS_LAT_EN. */

/*! @brief Read current value of the QUADSPI_MCR_DQS_LAT_EN field. */
#define BR_QUADSPI_MCR_DQS_LAT_EN(x)   (HW_QUADSPI_MCR(x).B.DQS_LAT_EN)

/*! @brief Format value for bitfield QUADSPI_MCR_DQS_LAT_EN. */
#define BF_QUADSPI_MCR_DQS_LAT_EN(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_MCR_DQS_LAT_EN) & BM_QUADSPI_MCR_DQS_LAT_EN)

/*! @brief Set the DQS_LAT_EN field to a new value. */
#define BW_QUADSPI_MCR_DQS_LAT_EN(x, v)   (HW_QUADSPI_MCR_WR(x, (HW_QUADSPI_MCR_RD(x) & ~BM_QUADSPI_MCR_DQS_LAT_EN) | BF_QUADSPI_MCR_DQS_LAT_EN(v)))
/*@}*/

/*!
 * @name Register QUADSPI_MCR, field DQS_EN[6] (RW)
 *
 * DQS enable: This field is valid for both SDR and DDR mode.For more details Refer Data Strobe
 * Signal Functionality
 *
 * Values:
 * - 0 - DQS disabled.
 * - 1 - DQS enabled- When enabled, the incoming data is sampled on both the edges of DQS input when
 *     QSPI_MCR[DDR_EN] is set, else, on only one edge when QSPI_MCR[DDR_EN] is 0. The
 *     QSPI_SMPR[DDR_SMP] values are ignored.
 */
/*@{*/
#define BP_QUADSPI_MCR_DQS_EN         (6U)      /*!< Bit position for QUADSPI_MCR_DQS_EN. */
#define BM_QUADSPI_MCR_DQS_EN         (0x00000040U)  /*!< Bit mask for QUADSPI_MCR_DQS_EN. */
#define BS_QUADSPI_MCR_DQS_EN         (1U)  /*!< Bitfield size in bits for QUADSPI_MCR_DQS_EN. */

/*! @brief Read current value of the QUADSPI_MCR_DQS_EN field. */
#define BR_QUADSPI_MCR_DQS_EN(x)   (HW_QUADSPI_MCR(x).B.DQS_EN)

/*! @brief Format value for bitfield QUADSPI_MCR_DQS_EN. */
#define BF_QUADSPI_MCR_DQS_EN(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_MCR_DQS_EN) & BM_QUADSPI_MCR_DQS_EN)

/*! @brief Set the DQS_EN field to a new value. */
#define BW_QUADSPI_MCR_DQS_EN(x, v)   (HW_QUADSPI_MCR_WR(x, (HW_QUADSPI_MCR_RD(x) & ~BM_QUADSPI_MCR_DQS_EN) | BF_QUADSPI_MCR_DQS_EN(v)))
/*@}*/

/*!
 * @name Register QUADSPI_MCR, field DDR_EN[7] (RW)
 *
 * DDR mode enable:
 *
 * Values:
 * - 0 - 2x and 4x clocks are disabled for SDR instructions only
 * - 1 - 2x and 4x clocks are enabled supports both SDR and DDR instruction.
 */
/*@{*/
#define BP_QUADSPI_MCR_DDR_EN         (7U)      /*!< Bit position for QUADSPI_MCR_DDR_EN. */
#define BM_QUADSPI_MCR_DDR_EN         (0x00000080U)  /*!< Bit mask for QUADSPI_MCR_DDR_EN. */
#define BS_QUADSPI_MCR_DDR_EN         (1U)  /*!< Bitfield size in bits for QUADSPI_MCR_DDR_EN. */

/*! @brief Read current value of the QUADSPI_MCR_DDR_EN field. */
#define BR_QUADSPI_MCR_DDR_EN(x)   (HW_QUADSPI_MCR(x).B.DDR_EN)

/*! @brief Format value for bitfield QUADSPI_MCR_DDR_EN. */
#define BF_QUADSPI_MCR_DDR_EN(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_MCR_DDR_EN) & BM_QUADSPI_MCR_DDR_EN)

/*! @brief Set the DDR_EN field to a new value. */
#define BW_QUADSPI_MCR_DDR_EN(x, v)   (HW_QUADSPI_MCR_WR(x, (HW_QUADSPI_MCR_RD(x) & ~BM_QUADSPI_MCR_DDR_EN) | BF_QUADSPI_MCR_DDR_EN(v)))
/*@}*/

/*!
 * @name Register QUADSPI_MCR, field CLR_RXF[10] (RW)
 *
 * Clear RX FIFO. Invalidate the RX Buffer.
 *
 * Values:
 * - 0 - No action.
 * - 1 - Read and write pointers of the RX Buffer are reset to 0. QSPI_RBSR[RDBFL] is reset to 0.
 */
/*@{*/
#define BP_QUADSPI_MCR_CLR_RXF         (10U)      /*!< Bit position for QUADSPI_MCR_CLR_RXF. */
#define BM_QUADSPI_MCR_CLR_RXF         (0x00000400U)  /*!< Bit mask for QUADSPI_MCR_CLR_RXF. */
#define BS_QUADSPI_MCR_CLR_RXF         (1U)  /*!< Bitfield size in bits for QUADSPI_MCR_CLR_RXF. */

/*! @brief Read current value of the QUADSPI_MCR_CLR_RXF field. */
#define BR_QUADSPI_MCR_CLR_RXF(x)   (HW_QUADSPI_MCR(x).B.CLR_RXF)

/*! @brief Format value for bitfield QUADSPI_MCR_CLR_RXF. */
#define BF_QUADSPI_MCR_CLR_RXF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_MCR_CLR_RXF) & BM_QUADSPI_MCR_CLR_RXF)

/*! @brief Set the CLR_RXF field to a new value. */
#define BW_QUADSPI_MCR_CLR_RXF(x, v)   (HW_QUADSPI_MCR_WR(x, (HW_QUADSPI_MCR_RD(x) & ~BM_QUADSPI_MCR_CLR_RXF) | BF_QUADSPI_MCR_CLR_RXF(v)))
/*@}*/

/*!
 * @name Register QUADSPI_MCR, field CLR_TXF[11] (RW)
 *
 * Clear TX FIFO/Buffer. Invalidate the TX Buffer content.
 *
 * Values:
 * - 0 - No action.
 * - 1 - Read and write pointers of the TX Buffer are reset to 0. QSPI_TBSR[TRCTR] is reset to 0.
 */
/*@{*/
#define BP_QUADSPI_MCR_CLR_TXF         (11U)      /*!< Bit position for QUADSPI_MCR_CLR_TXF. */
#define BM_QUADSPI_MCR_CLR_TXF         (0x00000800U)  /*!< Bit mask for QUADSPI_MCR_CLR_TXF. */
#define BS_QUADSPI_MCR_CLR_TXF         (1U)  /*!< Bitfield size in bits for QUADSPI_MCR_CLR_TXF. */

/*! @brief Read current value of the QUADSPI_MCR_CLR_TXF field. */
#define BR_QUADSPI_MCR_CLR_TXF(x)   (HW_QUADSPI_MCR(x).B.CLR_TXF)

/*! @brief Format value for bitfield QUADSPI_MCR_CLR_TXF. */
#define BF_QUADSPI_MCR_CLR_TXF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_MCR_CLR_TXF) & BM_QUADSPI_MCR_CLR_TXF)

/*! @brief Set the CLR_TXF field to a new value. */
#define BW_QUADSPI_MCR_CLR_TXF(x, v)   (HW_QUADSPI_MCR_WR(x, (HW_QUADSPI_MCR_RD(x) & ~BM_QUADSPI_MCR_CLR_TXF) | BF_QUADSPI_MCR_CLR_TXF(v)))
/*@}*/

/*!
 * @name Register QUADSPI_MCR, field MDIS[14] (RW)
 *
 * Module Disable. The MDIS bit allows the clock to the non-memory mapped logic in the QuadSPI to be
 * stopped, putting the QuadSPI in a software controlled power-saving state. Please refer to , for
 * more information.
 *
 * Values:
 * - 0 - Enable QuadSPI clocks.
 * - 1 - Allow external logic to disable QuadSPI clocks.
 */
/*@{*/
#define BP_QUADSPI_MCR_MDIS         (14U)      /*!< Bit position for QUADSPI_MCR_MDIS. */
#define BM_QUADSPI_MCR_MDIS         (0x00004000U)  /*!< Bit mask for QUADSPI_MCR_MDIS. */
#define BS_QUADSPI_MCR_MDIS         (1U)  /*!< Bitfield size in bits for QUADSPI_MCR_MDIS. */

/*! @brief Read current value of the QUADSPI_MCR_MDIS field. */
#define BR_QUADSPI_MCR_MDIS(x)   (HW_QUADSPI_MCR(x).B.MDIS)

/*! @brief Format value for bitfield QUADSPI_MCR_MDIS. */
#define BF_QUADSPI_MCR_MDIS(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_MCR_MDIS) & BM_QUADSPI_MCR_MDIS)

/*! @brief Set the MDIS field to a new value. */
#define BW_QUADSPI_MCR_MDIS(x, v)   (HW_QUADSPI_MCR_WR(x, (HW_QUADSPI_MCR_RD(x) & ~BM_QUADSPI_MCR_MDIS) | BF_QUADSPI_MCR_MDIS(v)))
/*@}*/

/*!
 * @name Register QUADSPI_MCR, field SCLKCFG[31:24] (RW)
 *
 * Serial Clock Configuration. This field configuration is chip specific. For details, refer to
 * chip-specific QuadSPI information. It may be used for dividing clocks.
 *
 * Values:
 * - 0x00 - Divide by 1
 * - 0x01 - Divide by 1.5
 * - 0x02 - Divide by 2
 * - 0x03 - Divide by 2.5
 * - 0x04 - Divide by 3
 * - 0x05 - Divide by 3.5 ....
 * - 0x0E - Divide by 8
 * - 0x0F - Divide by 8.5 All others: Reserved
 */
/*@{*/
#define BP_QUADSPI_MCR_SCLKCFG         (24U)      /*!< Bit position for QUADSPI_MCR_SCLKCFG. */
#define BM_QUADSPI_MCR_SCLKCFG         (0xFF000000U)  /*!< Bit mask for QUADSPI_MCR_SCLKCFG. */
#define BS_QUADSPI_MCR_SCLKCFG         (8U)  /*!< Bitfield size in bits for QUADSPI_MCR_SCLKCFG. */

/*! @brief Read current value of the QUADSPI_MCR_SCLKCFG field. */
#define BR_QUADSPI_MCR_SCLKCFG(x)   (HW_QUADSPI_MCR(x).B.SCLKCFG)

/*! @brief Format value for bitfield QUADSPI_MCR_SCLKCFG. */
#define BF_QUADSPI_MCR_SCLKCFG(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_MCR_SCLKCFG) & BM_QUADSPI_MCR_SCLKCFG)

/*! @brief Set the SCLKCFG field to a new value. */
#define BW_QUADSPI_MCR_SCLKCFG(x, v)   (HW_QUADSPI_MCR_WR(x, (HW_QUADSPI_MCR_RD(x) & ~BM_QUADSPI_MCR_SCLKCFG) | BF_QUADSPI_MCR_SCLKCFG(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_IPCR - IP Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_IPCR - IP Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The IP configuration register provides all the configuration required for an IP initiated
 * command. An IP command can be triggered by writing in the SEQID field of this register. If the
 * SEQID field is written successfully, a new command to the external serial flash is started as per
 * the sequence pointed to by the SEQID field. Refer to , for details about the command triggering
 * and command execution. Write: QSPI_SR[IP_ACC]=0
 */
typedef union _hw_quadspi_ipcr
{
    uint32_t U;
    struct _hw_quadspi_ipcr_bitfields
    {
        uint32_t IDATSZ : 16; /*!< [15:0] IP data transfer size: Defines the data transfer size in bytes of the IP command. */
        uint32_t PAR_EN : 1; /*!< [16] When set, a transaction to two serial flash devices is triggered in parallel mode. */
        uint32_t RESERVED0 : 7; /*!< [23:17]  */
        uint32_t SEQID : 4; /*!< [27:24] Points to a sequence in the Look-up-table. */
        uint32_t RESERVED1 : 4; /*!< [31:28]  */
    } B;
} hw_quadspi_ipcr_t;

/*!
 * @name Constants and macros for entire QUADSPI_IPCR register
 */
/*@{*/
#define HW_QUADSPI_IPCR_ADDR(x)        ((x) + 0x8U)
#define HW_QUADSPI_IPCR(x)             (*(__IO hw_quadspi_ipcr_t *) HW_QUADSPI_IPCR_ADDR(x))
#define HW_QUADSPI_IPCR_RD(x)          (HW_QUADSPI_IPCR(x).U)
#define HW_QUADSPI_IPCR_WR(x, v)       (HW_QUADSPI_IPCR(x).U = (v))
#define HW_QUADSPI_IPCR_SET(x, v)      (HW_QUADSPI_IPCR_WR(x, HW_QUADSPI_IPCR_RD(x) |  (v)))
#define HW_QUADSPI_IPCR_CLR(x, v)      (HW_QUADSPI_IPCR_WR(x, HW_QUADSPI_IPCR_RD(x) & ~(v)))
#define HW_QUADSPI_IPCR_TOG(x, v)      (HW_QUADSPI_IPCR_WR(x, HW_QUADSPI_IPCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_IPCR bitfields
 */

/*!
 * @name Register QUADSPI_IPCR, field IDATSZ[15:0] (RW)
 *
 * IP data transfer size: Defines the data transfer size in bytes of the IP command.
 */
/*@{*/
#define BP_QUADSPI_IPCR_IDATSZ         (0U)      /*!< Bit position for QUADSPI_IPCR_IDATSZ. */
#define BM_QUADSPI_IPCR_IDATSZ         (0x0000FFFFU)  /*!< Bit mask for QUADSPI_IPCR_IDATSZ. */
#define BS_QUADSPI_IPCR_IDATSZ         (16U)  /*!< Bitfield size in bits for QUADSPI_IPCR_IDATSZ. */

/*! @brief Read current value of the QUADSPI_IPCR_IDATSZ field. */
#define BR_QUADSPI_IPCR_IDATSZ(x)   (HW_QUADSPI_IPCR(x).B.IDATSZ)

/*! @brief Format value for bitfield QUADSPI_IPCR_IDATSZ. */
#define BF_QUADSPI_IPCR_IDATSZ(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_IPCR_IDATSZ) & BM_QUADSPI_IPCR_IDATSZ)

/*! @brief Set the IDATSZ field to a new value. */
#define BW_QUADSPI_IPCR_IDATSZ(x, v)   (HW_QUADSPI_IPCR_WR(x, (HW_QUADSPI_IPCR_RD(x) & ~BM_QUADSPI_IPCR_IDATSZ) | BF_QUADSPI_IPCR_IDATSZ(v)))
/*@}*/

/*!
 * @name Register QUADSPI_IPCR, field PAR_EN[16] (RW)
 *
 * When set, a transaction to two serial flash devices is triggered in parallel mode. Refer to
 * Parallel Flash Modefor more details.
 */
/*@{*/
#define BP_QUADSPI_IPCR_PAR_EN         (16U)      /*!< Bit position for QUADSPI_IPCR_PAR_EN. */
#define BM_QUADSPI_IPCR_PAR_EN         (0x00010000U)  /*!< Bit mask for QUADSPI_IPCR_PAR_EN. */
#define BS_QUADSPI_IPCR_PAR_EN         (1U)  /*!< Bitfield size in bits for QUADSPI_IPCR_PAR_EN. */

/*! @brief Read current value of the QUADSPI_IPCR_PAR_EN field. */
#define BR_QUADSPI_IPCR_PAR_EN(x)   (HW_QUADSPI_IPCR(x).B.PAR_EN)

/*! @brief Format value for bitfield QUADSPI_IPCR_PAR_EN. */
#define BF_QUADSPI_IPCR_PAR_EN(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_IPCR_PAR_EN) & BM_QUADSPI_IPCR_PAR_EN)

/*! @brief Set the PAR_EN field to a new value. */
#define BW_QUADSPI_IPCR_PAR_EN(x, v)   (HW_QUADSPI_IPCR_WR(x, (HW_QUADSPI_IPCR_RD(x) & ~BM_QUADSPI_IPCR_PAR_EN) | BF_QUADSPI_IPCR_PAR_EN(v)))
/*@}*/

/*!
 * @name Register QUADSPI_IPCR, field SEQID[27:24] (RW)
 *
 * Points to a sequence in the Look-up-table. The SEQID defines the bits [6:2] of the LUT index. The
 * bits [1:0] are always assumed to be 0. Refer to for more details. A write to this bit -field
 * triggers a transaction on the serial flash interface.
 */
/*@{*/
#define BP_QUADSPI_IPCR_SEQID         (24U)      /*!< Bit position for QUADSPI_IPCR_SEQID. */
#define BM_QUADSPI_IPCR_SEQID         (0x0F000000U)  /*!< Bit mask for QUADSPI_IPCR_SEQID. */
#define BS_QUADSPI_IPCR_SEQID         (4U)  /*!< Bitfield size in bits for QUADSPI_IPCR_SEQID. */

/*! @brief Read current value of the QUADSPI_IPCR_SEQID field. */
#define BR_QUADSPI_IPCR_SEQID(x)   (HW_QUADSPI_IPCR(x).B.SEQID)

/*! @brief Format value for bitfield QUADSPI_IPCR_SEQID. */
#define BF_QUADSPI_IPCR_SEQID(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_IPCR_SEQID) & BM_QUADSPI_IPCR_SEQID)

/*! @brief Set the SEQID field to a new value. */
#define BW_QUADSPI_IPCR_SEQID(x, v)   (HW_QUADSPI_IPCR_WR(x, (HW_QUADSPI_IPCR_RD(x) & ~BM_QUADSPI_IPCR_SEQID) | BF_QUADSPI_IPCR_SEQID(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_FLSHCR - Flash Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_FLSHCR - Flash Configuration Register (RW)
 *
 * Reset value: 0x00000303U
 *
 * The Flash configuration register contains the flash device specific timings that must be met by
 * the QuadSPI controller for the device to function correctly. Write: QSPI_SR[AHB_ACC] = 0
 * QSPI_SR[IP_ACC] = 0
 */
typedef union _hw_quadspi_flshcr
{
    uint32_t U;
    struct _hw_quadspi_flshcr_bitfields
    {
        uint32_t TCSS : 4; /*!< [3:0] Serial flash CS setup time in terms of serial flash clock cycles. */
        uint32_t RESERVED0 : 4; /*!< [7:4] Reserved. */
        uint32_t TCSH : 4; /*!< [11:8] Serial flash CS hold time in terms of serial flash clock cycles. */
        uint32_t RESERVED1 : 4; /*!< [15:12]  */
        uint32_t TDH : 2; /*!< [17:16] Serial flash Data In hold time: This helps in meeting the Data In Hold time requirement of a Flash. */
        uint32_t RESERVED2 : 14; /*!< [31:18]  */
    } B;
} hw_quadspi_flshcr_t;

/*!
 * @name Constants and macros for entire QUADSPI_FLSHCR register
 */
/*@{*/
#define HW_QUADSPI_FLSHCR_ADDR(x)        ((x) + 0xCU)
#define HW_QUADSPI_FLSHCR(x)             (*(__IO hw_quadspi_flshcr_t *) HW_QUADSPI_FLSHCR_ADDR(x))
#define HW_QUADSPI_FLSHCR_RD(x)          (HW_QUADSPI_FLSHCR(x).U)
#define HW_QUADSPI_FLSHCR_WR(x, v)       (HW_QUADSPI_FLSHCR(x).U = (v))
#define HW_QUADSPI_FLSHCR_SET(x, v)      (HW_QUADSPI_FLSHCR_WR(x, HW_QUADSPI_FLSHCR_RD(x) |  (v)))
#define HW_QUADSPI_FLSHCR_CLR(x, v)      (HW_QUADSPI_FLSHCR_WR(x, HW_QUADSPI_FLSHCR_RD(x) & ~(v)))
#define HW_QUADSPI_FLSHCR_TOG(x, v)      (HW_QUADSPI_FLSHCR_WR(x, HW_QUADSPI_FLSHCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_FLSHCR bitfields
 */

/*!
 * @name Register QUADSPI_FLSHCR, field TCSS[3:0] (RW)
 *
 * Serial flash CS setup time in terms of serial flash clock cycles.
 */
/*@{*/
#define BP_QUADSPI_FLSHCR_TCSS         (0U)      /*!< Bit position for QUADSPI_FLSHCR_TCSS. */
#define BM_QUADSPI_FLSHCR_TCSS         (0x0000000FU)  /*!< Bit mask for QUADSPI_FLSHCR_TCSS. */
#define BS_QUADSPI_FLSHCR_TCSS         (4U)  /*!< Bitfield size in bits for QUADSPI_FLSHCR_TCSS. */

/*! @brief Read current value of the QUADSPI_FLSHCR_TCSS field. */
#define BR_QUADSPI_FLSHCR_TCSS(x)   (HW_QUADSPI_FLSHCR(x).B.TCSS)

/*! @brief Format value for bitfield QUADSPI_FLSHCR_TCSS. */
#define BF_QUADSPI_FLSHCR_TCSS(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FLSHCR_TCSS) & BM_QUADSPI_FLSHCR_TCSS)

/*! @brief Set the TCSS field to a new value. */
#define BW_QUADSPI_FLSHCR_TCSS(x, v)   (HW_QUADSPI_FLSHCR_WR(x, (HW_QUADSPI_FLSHCR_RD(x) & ~BM_QUADSPI_FLSHCR_TCSS) | BF_QUADSPI_FLSHCR_TCSS(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FLSHCR, field TCSH[11:8] (RW)
 *
 * Serial flash CS hold time in terms of serial flash clock cycles.
 */
/*@{*/
#define BP_QUADSPI_FLSHCR_TCSH         (8U)      /*!< Bit position for QUADSPI_FLSHCR_TCSH. */
#define BM_QUADSPI_FLSHCR_TCSH         (0x00000F00U)  /*!< Bit mask for QUADSPI_FLSHCR_TCSH. */
#define BS_QUADSPI_FLSHCR_TCSH         (4U)  /*!< Bitfield size in bits for QUADSPI_FLSHCR_TCSH. */

/*! @brief Read current value of the QUADSPI_FLSHCR_TCSH field. */
#define BR_QUADSPI_FLSHCR_TCSH(x)   (HW_QUADSPI_FLSHCR(x).B.TCSH)

/*! @brief Format value for bitfield QUADSPI_FLSHCR_TCSH. */
#define BF_QUADSPI_FLSHCR_TCSH(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FLSHCR_TCSH) & BM_QUADSPI_FLSHCR_TCSH)

/*! @brief Set the TCSH field to a new value. */
#define BW_QUADSPI_FLSHCR_TCSH(x, v)   (HW_QUADSPI_FLSHCR_WR(x, (HW_QUADSPI_FLSHCR_RD(x) & ~BM_QUADSPI_FLSHCR_TCSH) | BF_QUADSPI_FLSHCR_TCSH(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FLSHCR, field TDH[17:16] (RW)
 *
 * Serial flash Data In hold time: This helps in meeting the Data In Hold time requirement of a
 * Flash. This is valid only in DDR mode.Refer to Data input hold requirement of Flash for details.
 *
 * Values:
 * - 00 - Data aligned with the posedge of Internal reference clock of QuadSPI
 * - 01 - Data aligned with 2x serial flash half clock
 * - 10 - Data aligned with 4x serial flash half clock
 */
/*@{*/
#define BP_QUADSPI_FLSHCR_TDH         (16U)      /*!< Bit position for QUADSPI_FLSHCR_TDH. */
#define BM_QUADSPI_FLSHCR_TDH         (0x00030000U)  /*!< Bit mask for QUADSPI_FLSHCR_TDH. */
#define BS_QUADSPI_FLSHCR_TDH         (2U)  /*!< Bitfield size in bits for QUADSPI_FLSHCR_TDH. */

/*! @brief Read current value of the QUADSPI_FLSHCR_TDH field. */
#define BR_QUADSPI_FLSHCR_TDH(x)   (HW_QUADSPI_FLSHCR(x).B.TDH)

/*! @brief Format value for bitfield QUADSPI_FLSHCR_TDH. */
#define BF_QUADSPI_FLSHCR_TDH(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FLSHCR_TDH) & BM_QUADSPI_FLSHCR_TDH)

/*! @brief Set the TDH field to a new value. */
#define BW_QUADSPI_FLSHCR_TDH(x, v)   (HW_QUADSPI_FLSHCR_WR(x, (HW_QUADSPI_FLSHCR_RD(x) & ~BM_QUADSPI_FLSHCR_TDH) | BF_QUADSPI_FLSHCR_TDH(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_BUF0CR - Buffer0 Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_BUF0CR - Buffer0 Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the configuration for any access to buffer0. An access is routed to
 * buffer0 when the master port number of the incoming AHB request matches the MSTRID field of the
 * BUF0CR. Any buffer "miss" leads to a serial flash transaction being triggered as per the sequence
 * pointed to the SEQID field. Buffer0 may also be configured as a high priority buffer by setting
 * the HP_EN field of this register. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf0cr
{
    uint32_t U;
    struct _hw_quadspi_buf0cr_bitfields
    {
        uint32_t MSTRID : 4; /*!< [3:0] Master ID: The ID of the AHB master associated with BUFFER0. */
        uint32_t RESERVED0 : 4; /*!< [7:4] Reserved. */
        uint32_t ADATSZ : 8; /*!< [15:8] AHB data transfer size: Defines the data transfer size in 8 bytes of an AHB triggered access to serial flash. */
        uint32_t RESERVED1 : 15; /*!< [30:16]  */
        uint32_t HP_EN : 1; /*!< [31] High Priority Enable: When set, the master associated with this buffer is assigned a priority higher than the rest of the masters. */
    } B;
} hw_quadspi_buf0cr_t;

/*!
 * @name Constants and macros for entire QUADSPI_BUF0CR register
 */
/*@{*/
#define HW_QUADSPI_BUF0CR_ADDR(x)        ((x) + 0x10U)
#define HW_QUADSPI_BUF0CR(x)             (*(__IO hw_quadspi_buf0cr_t *) HW_QUADSPI_BUF0CR_ADDR(x))
#define HW_QUADSPI_BUF0CR_RD(x)          (HW_QUADSPI_BUF0CR(x).U)
#define HW_QUADSPI_BUF0CR_WR(x, v)       (HW_QUADSPI_BUF0CR(x).U = (v))
#define HW_QUADSPI_BUF0CR_SET(x, v)      (HW_QUADSPI_BUF0CR_WR(x, HW_QUADSPI_BUF0CR_RD(x) |  (v)))
#define HW_QUADSPI_BUF0CR_CLR(x, v)      (HW_QUADSPI_BUF0CR_WR(x, HW_QUADSPI_BUF0CR_RD(x) & ~(v)))
#define HW_QUADSPI_BUF0CR_TOG(x, v)      (HW_QUADSPI_BUF0CR_WR(x, HW_QUADSPI_BUF0CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_BUF0CR bitfields
 */

/*!
 * @name Register QUADSPI_BUF0CR, field MSTRID[3:0] (RW)
 *
 * Master ID: The ID of the AHB master associated with BUFFER0. Any AHB access with this master port
 * number is routed to this buffer. It must be ensured that the master id's associated with all
 * buffers must be different.
 */
/*@{*/
#define BP_QUADSPI_BUF0CR_MSTRID         (0U)      /*!< Bit position for QUADSPI_BUF0CR_MSTRID. */
#define BM_QUADSPI_BUF0CR_MSTRID         (0x0000000FU)  /*!< Bit mask for QUADSPI_BUF0CR_MSTRID. */
#define BS_QUADSPI_BUF0CR_MSTRID         (4U)  /*!< Bitfield size in bits for QUADSPI_BUF0CR_MSTRID. */

/*! @brief Read current value of the QUADSPI_BUF0CR_MSTRID field. */
#define BR_QUADSPI_BUF0CR_MSTRID(x)   (HW_QUADSPI_BUF0CR(x).B.MSTRID)

/*! @brief Format value for bitfield QUADSPI_BUF0CR_MSTRID. */
#define BF_QUADSPI_BUF0CR_MSTRID(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_BUF0CR_MSTRID) & BM_QUADSPI_BUF0CR_MSTRID)

/*! @brief Set the MSTRID field to a new value. */
#define BW_QUADSPI_BUF0CR_MSTRID(x, v)   (HW_QUADSPI_BUF0CR_WR(x, (HW_QUADSPI_BUF0CR_RD(x) & ~BM_QUADSPI_BUF0CR_MSTRID) | BF_QUADSPI_BUF0CR_MSTRID(v)))
/*@}*/

/*!
 * @name Register QUADSPI_BUF0CR, field ADATSZ[15:8] (RW)
 *
 * AHB data transfer size: Defines the data transfer size in 8 bytes of an AHB triggered access to
 * serial flash. For example,a value of 0x2 will set transfer size to 16bytes.When ADATSZ = 0, the
 * data size mentioned the sequence pointed to by the SEQID field overrides this value. SW should
 * ensure that this transfer size is not greater than the size of this buffer.
 */
/*@{*/
#define BP_QUADSPI_BUF0CR_ADATSZ         (8U)      /*!< Bit position for QUADSPI_BUF0CR_ADATSZ. */
#define BM_QUADSPI_BUF0CR_ADATSZ         (0x0000FF00U)  /*!< Bit mask for QUADSPI_BUF0CR_ADATSZ. */
#define BS_QUADSPI_BUF0CR_ADATSZ         (8U)  /*!< Bitfield size in bits for QUADSPI_BUF0CR_ADATSZ. */

/*! @brief Read current value of the QUADSPI_BUF0CR_ADATSZ field. */
#define BR_QUADSPI_BUF0CR_ADATSZ(x)   (HW_QUADSPI_BUF0CR(x).B.ADATSZ)

/*! @brief Format value for bitfield QUADSPI_BUF0CR_ADATSZ. */
#define BF_QUADSPI_BUF0CR_ADATSZ(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_BUF0CR_ADATSZ) & BM_QUADSPI_BUF0CR_ADATSZ)

/*! @brief Set the ADATSZ field to a new value. */
#define BW_QUADSPI_BUF0CR_ADATSZ(x, v)   (HW_QUADSPI_BUF0CR_WR(x, (HW_QUADSPI_BUF0CR_RD(x) & ~BM_QUADSPI_BUF0CR_ADATSZ) | BF_QUADSPI_BUF0CR_ADATSZ(v)))
/*@}*/

/*!
 * @name Register QUADSPI_BUF0CR, field HP_EN[31] (RW)
 *
 * High Priority Enable: When set, the master associated with this buffer is assigned a priority
 * higher than the rest of the masters. An access by a high priority master will suspend any ongoing
 * prefetch by another AHB master and will be serviced on high priority.The high priority feature is
 * disabled if OTFAD is enabled in the system. Refer to Flexible AHB Buffersfor details.
 */
/*@{*/
#define BP_QUADSPI_BUF0CR_HP_EN         (31U)      /*!< Bit position for QUADSPI_BUF0CR_HP_EN. */
#define BM_QUADSPI_BUF0CR_HP_EN         (0x80000000U)  /*!< Bit mask for QUADSPI_BUF0CR_HP_EN. */
#define BS_QUADSPI_BUF0CR_HP_EN         (1U)  /*!< Bitfield size in bits for QUADSPI_BUF0CR_HP_EN. */

/*! @brief Read current value of the QUADSPI_BUF0CR_HP_EN field. */
#define BR_QUADSPI_BUF0CR_HP_EN(x)   (HW_QUADSPI_BUF0CR(x).B.HP_EN)

/*! @brief Format value for bitfield QUADSPI_BUF0CR_HP_EN. */
#define BF_QUADSPI_BUF0CR_HP_EN(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_BUF0CR_HP_EN) & BM_QUADSPI_BUF0CR_HP_EN)

/*! @brief Set the HP_EN field to a new value. */
#define BW_QUADSPI_BUF0CR_HP_EN(x, v)   (HW_QUADSPI_BUF0CR_WR(x, (HW_QUADSPI_BUF0CR_RD(x) & ~BM_QUADSPI_BUF0CR_HP_EN) | BF_QUADSPI_BUF0CR_HP_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_BUF1CR - Buffer1 Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_BUF1CR - Buffer1 Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the configuration for any access to buffer1. An access is routed to
 * buffer1 when the master port number of the incoming AHB request matches the MSTRID field of the
 * BUF1CR. Any buffer "miss" leads to the buffer being flushed and a serial flash transaction being
 * triggered as per the sequence pointed to by the SEQID field. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf1cr
{
    uint32_t U;
    struct _hw_quadspi_buf1cr_bitfields
    {
        uint32_t MSTRID : 4; /*!< [3:0] Master ID: The ID of the AHB master associated with BUFFER1. */
        uint32_t RESERVED0 : 4; /*!< [7:4]  */
        uint32_t ADATSZ : 8; /*!< [15:8] AHB data transfer size: Defines the data transfer size in 8 bytes of an AHB triggered access to serial flash.For example, a value of 0x2 will set transfer size to 16bytes. */
        uint32_t RESERVED1 : 16; /*!< [31:16]  */
    } B;
} hw_quadspi_buf1cr_t;

/*!
 * @name Constants and macros for entire QUADSPI_BUF1CR register
 */
/*@{*/
#define HW_QUADSPI_BUF1CR_ADDR(x)        ((x) + 0x14U)
#define HW_QUADSPI_BUF1CR(x)             (*(__IO hw_quadspi_buf1cr_t *) HW_QUADSPI_BUF1CR_ADDR(x))
#define HW_QUADSPI_BUF1CR_RD(x)          (HW_QUADSPI_BUF1CR(x).U)
#define HW_QUADSPI_BUF1CR_WR(x, v)       (HW_QUADSPI_BUF1CR(x).U = (v))
#define HW_QUADSPI_BUF1CR_SET(x, v)      (HW_QUADSPI_BUF1CR_WR(x, HW_QUADSPI_BUF1CR_RD(x) |  (v)))
#define HW_QUADSPI_BUF1CR_CLR(x, v)      (HW_QUADSPI_BUF1CR_WR(x, HW_QUADSPI_BUF1CR_RD(x) & ~(v)))
#define HW_QUADSPI_BUF1CR_TOG(x, v)      (HW_QUADSPI_BUF1CR_WR(x, HW_QUADSPI_BUF1CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_BUF1CR bitfields
 */

/*!
 * @name Register QUADSPI_BUF1CR, field MSTRID[3:0] (RW)
 *
 * Master ID: The ID of the AHB master associated with BUFFER1. Any AHB access with this master port
 * number is routed to this buffer.It must be ensured that the master id's associated with all
 * buffers must be different.
 */
/*@{*/
#define BP_QUADSPI_BUF1CR_MSTRID         (0U)      /*!< Bit position for QUADSPI_BUF1CR_MSTRID. */
#define BM_QUADSPI_BUF1CR_MSTRID         (0x0000000FU)  /*!< Bit mask for QUADSPI_BUF1CR_MSTRID. */
#define BS_QUADSPI_BUF1CR_MSTRID         (4U)  /*!< Bitfield size in bits for QUADSPI_BUF1CR_MSTRID. */

/*! @brief Read current value of the QUADSPI_BUF1CR_MSTRID field. */
#define BR_QUADSPI_BUF1CR_MSTRID(x)   (HW_QUADSPI_BUF1CR(x).B.MSTRID)

/*! @brief Format value for bitfield QUADSPI_BUF1CR_MSTRID. */
#define BF_QUADSPI_BUF1CR_MSTRID(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_BUF1CR_MSTRID) & BM_QUADSPI_BUF1CR_MSTRID)

/*! @brief Set the MSTRID field to a new value. */
#define BW_QUADSPI_BUF1CR_MSTRID(x, v)   (HW_QUADSPI_BUF1CR_WR(x, (HW_QUADSPI_BUF1CR_RD(x) & ~BM_QUADSPI_BUF1CR_MSTRID) | BF_QUADSPI_BUF1CR_MSTRID(v)))
/*@}*/

/*!
 * @name Register QUADSPI_BUF1CR, field ADATSZ[15:8] (RW)
 *
 * AHB data transfer size: Defines the data transfer size in 8 bytes of an AHB triggered access to
 * serial flash.For example, a value of 0x2 will set transfer size to 16bytes. When ADATSZ = 0, the
 * data size mentioned the sequence pointed to by the SEQID field overrides this value.SW should
 * ensure that this transfer size is not greater than the size of this buffer.
 */
/*@{*/
#define BP_QUADSPI_BUF1CR_ADATSZ         (8U)      /*!< Bit position for QUADSPI_BUF1CR_ADATSZ. */
#define BM_QUADSPI_BUF1CR_ADATSZ         (0x0000FF00U)  /*!< Bit mask for QUADSPI_BUF1CR_ADATSZ. */
#define BS_QUADSPI_BUF1CR_ADATSZ         (8U)  /*!< Bitfield size in bits for QUADSPI_BUF1CR_ADATSZ. */

/*! @brief Read current value of the QUADSPI_BUF1CR_ADATSZ field. */
#define BR_QUADSPI_BUF1CR_ADATSZ(x)   (HW_QUADSPI_BUF1CR(x).B.ADATSZ)

/*! @brief Format value for bitfield QUADSPI_BUF1CR_ADATSZ. */
#define BF_QUADSPI_BUF1CR_ADATSZ(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_BUF1CR_ADATSZ) & BM_QUADSPI_BUF1CR_ADATSZ)

/*! @brief Set the ADATSZ field to a new value. */
#define BW_QUADSPI_BUF1CR_ADATSZ(x, v)   (HW_QUADSPI_BUF1CR_WR(x, (HW_QUADSPI_BUF1CR_RD(x) & ~BM_QUADSPI_BUF1CR_ADATSZ) | BF_QUADSPI_BUF1CR_ADATSZ(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_BUF2CR - Buffer2 Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_BUF2CR - Buffer2 Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the configuration for any access to buffer2. An access is routed to
 * buffer2 when the master port number of the incoming AHB request matches the MSTRID field of the
 * BUF2CR. Any buffer "miss" leads to the buffer being flushed and a serial flash transaction being
 * triggered as per the sequence pointed to by the SEQID field. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf2cr
{
    uint32_t U;
    struct _hw_quadspi_buf2cr_bitfields
    {
        uint32_t MSTRID : 4; /*!< [3:0] Master ID: The ID of the AHB master associated with BUFFER2. */
        uint32_t RESERVED0 : 4; /*!< [7:4] Reserved. */
        uint32_t ADATSZ : 8; /*!< [15:8] AHB data transfer size: Defines the data transfer size in 8 Bytes of an AHB triggered access to serial flash. */
        uint32_t RESERVED1 : 16; /*!< [31:16] Reserved. */
    } B;
} hw_quadspi_buf2cr_t;

/*!
 * @name Constants and macros for entire QUADSPI_BUF2CR register
 */
/*@{*/
#define HW_QUADSPI_BUF2CR_ADDR(x)        ((x) + 0x18U)
#define HW_QUADSPI_BUF2CR(x)             (*(__IO hw_quadspi_buf2cr_t *) HW_QUADSPI_BUF2CR_ADDR(x))
#define HW_QUADSPI_BUF2CR_RD(x)          (HW_QUADSPI_BUF2CR(x).U)
#define HW_QUADSPI_BUF2CR_WR(x, v)       (HW_QUADSPI_BUF2CR(x).U = (v))
#define HW_QUADSPI_BUF2CR_SET(x, v)      (HW_QUADSPI_BUF2CR_WR(x, HW_QUADSPI_BUF2CR_RD(x) |  (v)))
#define HW_QUADSPI_BUF2CR_CLR(x, v)      (HW_QUADSPI_BUF2CR_WR(x, HW_QUADSPI_BUF2CR_RD(x) & ~(v)))
#define HW_QUADSPI_BUF2CR_TOG(x, v)      (HW_QUADSPI_BUF2CR_WR(x, HW_QUADSPI_BUF2CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_BUF2CR bitfields
 */

/*!
 * @name Register QUADSPI_BUF2CR, field MSTRID[3:0] (RW)
 *
 * Master ID: The ID of the AHB master associated with BUFFER2. Any AHB access with this master port
 * number is routed to this buffer.It must be ensured that the master id's associated with all
 * buffers must be different.
 */
/*@{*/
#define BP_QUADSPI_BUF2CR_MSTRID         (0U)      /*!< Bit position for QUADSPI_BUF2CR_MSTRID. */
#define BM_QUADSPI_BUF2CR_MSTRID         (0x0000000FU)  /*!< Bit mask for QUADSPI_BUF2CR_MSTRID. */
#define BS_QUADSPI_BUF2CR_MSTRID         (4U)  /*!< Bitfield size in bits for QUADSPI_BUF2CR_MSTRID. */

/*! @brief Read current value of the QUADSPI_BUF2CR_MSTRID field. */
#define BR_QUADSPI_BUF2CR_MSTRID(x)   (HW_QUADSPI_BUF2CR(x).B.MSTRID)

/*! @brief Format value for bitfield QUADSPI_BUF2CR_MSTRID. */
#define BF_QUADSPI_BUF2CR_MSTRID(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_BUF2CR_MSTRID) & BM_QUADSPI_BUF2CR_MSTRID)

/*! @brief Set the MSTRID field to a new value. */
#define BW_QUADSPI_BUF2CR_MSTRID(x, v)   (HW_QUADSPI_BUF2CR_WR(x, (HW_QUADSPI_BUF2CR_RD(x) & ~BM_QUADSPI_BUF2CR_MSTRID) | BF_QUADSPI_BUF2CR_MSTRID(v)))
/*@}*/

/*!
 * @name Register QUADSPI_BUF2CR, field ADATSZ[15:8] (RW)
 *
 * AHB data transfer size: Defines the data transfer size in 8 Bytes of an AHB triggered access to
 * serial flash. For example, a value of 0x2 will set transfer size to 16bytes.When ADATSZ = 0, the
 * data size mentioned the sequence pointed to by the SEQID field overrides this value.SW should
 * ensure that this transfer size is not greater than the size of this buffer.
 */
/*@{*/
#define BP_QUADSPI_BUF2CR_ADATSZ         (8U)      /*!< Bit position for QUADSPI_BUF2CR_ADATSZ. */
#define BM_QUADSPI_BUF2CR_ADATSZ         (0x0000FF00U)  /*!< Bit mask for QUADSPI_BUF2CR_ADATSZ. */
#define BS_QUADSPI_BUF2CR_ADATSZ         (8U)  /*!< Bitfield size in bits for QUADSPI_BUF2CR_ADATSZ. */

/*! @brief Read current value of the QUADSPI_BUF2CR_ADATSZ field. */
#define BR_QUADSPI_BUF2CR_ADATSZ(x)   (HW_QUADSPI_BUF2CR(x).B.ADATSZ)

/*! @brief Format value for bitfield QUADSPI_BUF2CR_ADATSZ. */
#define BF_QUADSPI_BUF2CR_ADATSZ(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_BUF2CR_ADATSZ) & BM_QUADSPI_BUF2CR_ADATSZ)

/*! @brief Set the ADATSZ field to a new value. */
#define BW_QUADSPI_BUF2CR_ADATSZ(x, v)   (HW_QUADSPI_BUF2CR_WR(x, (HW_QUADSPI_BUF2CR_RD(x) & ~BM_QUADSPI_BUF2CR_ADATSZ) | BF_QUADSPI_BUF2CR_ADATSZ(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_BUF3CR - Buffer3 Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_BUF3CR - Buffer3 Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the configuration for any access to buffer3. An access is routed to
 * buffer3 when the master port number of the incoming AHB request matches the MSTRID field of the
 * BUF3CR. Any buffer "miss" leads to the buffer being flushed a serial flash transaction being
 * triggered as per the sequence pointed to by the SEQID field. In the case that the ALLMST field is
 * not set, any such transaction (where master port number does not match any of the MSTRID fields)
 * will be returned an ERROR response. Write:QSPI_SR[AHB_ACC] = 0.
 */
typedef union _hw_quadspi_buf3cr
{
    uint32_t U;
    struct _hw_quadspi_buf3cr_bitfields
    {
        uint32_t MSTRID : 4; /*!< [3:0] Master ID: The ID of the AHB master associated with BUFFER3. */
        uint32_t RESERVED0 : 4; /*!< [7:4]  */
        uint32_t ADATSZ : 8; /*!< [15:8] AHB data transfer size: Defines the data transfer size in 8 Bytes of an AHB triggered access to serial flash. */
        uint32_t RESERVED1 : 15; /*!< [30:16] Reserved. */
        uint32_t ALLMST : 1; /*!< [31] All master enable: When set, buffer3 acts as an all-master buffer. */
    } B;
} hw_quadspi_buf3cr_t;

/*!
 * @name Constants and macros for entire QUADSPI_BUF3CR register
 */
/*@{*/
#define HW_QUADSPI_BUF3CR_ADDR(x)        ((x) + 0x1CU)
#define HW_QUADSPI_BUF3CR(x)             (*(__IO hw_quadspi_buf3cr_t *) HW_QUADSPI_BUF3CR_ADDR(x))
#define HW_QUADSPI_BUF3CR_RD(x)          (HW_QUADSPI_BUF3CR(x).U)
#define HW_QUADSPI_BUF3CR_WR(x, v)       (HW_QUADSPI_BUF3CR(x).U = (v))
#define HW_QUADSPI_BUF3CR_SET(x, v)      (HW_QUADSPI_BUF3CR_WR(x, HW_QUADSPI_BUF3CR_RD(x) |  (v)))
#define HW_QUADSPI_BUF3CR_CLR(x, v)      (HW_QUADSPI_BUF3CR_WR(x, HW_QUADSPI_BUF3CR_RD(x) & ~(v)))
#define HW_QUADSPI_BUF3CR_TOG(x, v)      (HW_QUADSPI_BUF3CR_WR(x, HW_QUADSPI_BUF3CR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_BUF3CR bitfields
 */

/*!
 * @name Register QUADSPI_BUF3CR, field MSTRID[3:0] (RW)
 *
 * Master ID: The ID of the AHB master associated with BUFFER3. Any AHB access with this master port
 * number is routed to this buffer. It must be ensured that the master id's associated with all
 * buffers must be different.
 */
/*@{*/
#define BP_QUADSPI_BUF3CR_MSTRID         (0U)      /*!< Bit position for QUADSPI_BUF3CR_MSTRID. */
#define BM_QUADSPI_BUF3CR_MSTRID         (0x0000000FU)  /*!< Bit mask for QUADSPI_BUF3CR_MSTRID. */
#define BS_QUADSPI_BUF3CR_MSTRID         (4U)  /*!< Bitfield size in bits for QUADSPI_BUF3CR_MSTRID. */

/*! @brief Read current value of the QUADSPI_BUF3CR_MSTRID field. */
#define BR_QUADSPI_BUF3CR_MSTRID(x)   (HW_QUADSPI_BUF3CR(x).B.MSTRID)

/*! @brief Format value for bitfield QUADSPI_BUF3CR_MSTRID. */
#define BF_QUADSPI_BUF3CR_MSTRID(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_BUF3CR_MSTRID) & BM_QUADSPI_BUF3CR_MSTRID)

/*! @brief Set the MSTRID field to a new value. */
#define BW_QUADSPI_BUF3CR_MSTRID(x, v)   (HW_QUADSPI_BUF3CR_WR(x, (HW_QUADSPI_BUF3CR_RD(x) & ~BM_QUADSPI_BUF3CR_MSTRID) | BF_QUADSPI_BUF3CR_MSTRID(v)))
/*@}*/

/*!
 * @name Register QUADSPI_BUF3CR, field ADATSZ[15:8] (RW)
 *
 * AHB data transfer size: Defines the data transfer size in 8 Bytes of an AHB triggered access to
 * serial flash. When ADATSZ = 0, the data size mentioned the sequence pointed to by the SEQID field
 * overrides this value. SW should ensure that this transfer size is not greater than the size of
 * this buffer.
 */
/*@{*/
#define BP_QUADSPI_BUF3CR_ADATSZ         (8U)      /*!< Bit position for QUADSPI_BUF3CR_ADATSZ. */
#define BM_QUADSPI_BUF3CR_ADATSZ         (0x0000FF00U)  /*!< Bit mask for QUADSPI_BUF3CR_ADATSZ. */
#define BS_QUADSPI_BUF3CR_ADATSZ         (8U)  /*!< Bitfield size in bits for QUADSPI_BUF3CR_ADATSZ. */

/*! @brief Read current value of the QUADSPI_BUF3CR_ADATSZ field. */
#define BR_QUADSPI_BUF3CR_ADATSZ(x)   (HW_QUADSPI_BUF3CR(x).B.ADATSZ)

/*! @brief Format value for bitfield QUADSPI_BUF3CR_ADATSZ. */
#define BF_QUADSPI_BUF3CR_ADATSZ(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_BUF3CR_ADATSZ) & BM_QUADSPI_BUF3CR_ADATSZ)

/*! @brief Set the ADATSZ field to a new value. */
#define BW_QUADSPI_BUF3CR_ADATSZ(x, v)   (HW_QUADSPI_BUF3CR_WR(x, (HW_QUADSPI_BUF3CR_RD(x) & ~BM_QUADSPI_BUF3CR_ADATSZ) | BF_QUADSPI_BUF3CR_ADATSZ(v)))
/*@}*/

/*!
 * @name Register QUADSPI_BUF3CR, field ALLMST[31] (RW)
 *
 * All master enable: When set, buffer3 acts as an all-master buffer. Any AHB access with a master
 * port number not matching with the master ID of buffer0 or buffer1 or buffer2 is routed to
 * buffer3. When set, the MSTRID field of this register is ignored.
 */
/*@{*/
#define BP_QUADSPI_BUF3CR_ALLMST         (31U)      /*!< Bit position for QUADSPI_BUF3CR_ALLMST. */
#define BM_QUADSPI_BUF3CR_ALLMST         (0x80000000U)  /*!< Bit mask for QUADSPI_BUF3CR_ALLMST. */
#define BS_QUADSPI_BUF3CR_ALLMST         (1U)  /*!< Bitfield size in bits for QUADSPI_BUF3CR_ALLMST. */

/*! @brief Read current value of the QUADSPI_BUF3CR_ALLMST field. */
#define BR_QUADSPI_BUF3CR_ALLMST(x)   (HW_QUADSPI_BUF3CR(x).B.ALLMST)

/*! @brief Format value for bitfield QUADSPI_BUF3CR_ALLMST. */
#define BF_QUADSPI_BUF3CR_ALLMST(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_BUF3CR_ALLMST) & BM_QUADSPI_BUF3CR_ALLMST)

/*! @brief Set the ALLMST field to a new value. */
#define BW_QUADSPI_BUF3CR_ALLMST(x, v)   (HW_QUADSPI_BUF3CR_WR(x, (HW_QUADSPI_BUF3CR_RD(x) & ~BM_QUADSPI_BUF3CR_ALLMST) | BF_QUADSPI_BUF3CR_ALLMST(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_BFGENCR - Buffer Generic Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_BFGENCR - Buffer Generic Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register provides the generic configuration to any of the buffer accesses. Any buffer "miss"
 * leads to the buffer being flushed and a serial flash transaction being triggered as per the
 * sequence pointed to by the SEQID field. If the PAR_EN field is set, all the buffer accesses
 * result in parallel accesses to the flashes. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_bfgencr
{
    uint32_t U;
    struct _hw_quadspi_bfgencr_bitfields
    {
        uint32_t RESERVED0 : 12; /*!< [11:0]  */
        uint32_t SEQID : 4; /*!< [15:12] Points to a sequence in the Look-up-table. */
        uint32_t PAR_EN : 1; /*!< [16] When set, a transaction to two serial flash devices is triggered in parallel mode. */
        uint32_t RESERVED1 : 15; /*!< [31:17]  */
    } B;
} hw_quadspi_bfgencr_t;

/*!
 * @name Constants and macros for entire QUADSPI_BFGENCR register
 */
/*@{*/
#define HW_QUADSPI_BFGENCR_ADDR(x)        ((x) + 0x20U)
#define HW_QUADSPI_BFGENCR(x)             (*(__IO hw_quadspi_bfgencr_t *) HW_QUADSPI_BFGENCR_ADDR(x))
#define HW_QUADSPI_BFGENCR_RD(x)          (HW_QUADSPI_BFGENCR(x).U)
#define HW_QUADSPI_BFGENCR_WR(x, v)       (HW_QUADSPI_BFGENCR(x).U = (v))
#define HW_QUADSPI_BFGENCR_SET(x, v)      (HW_QUADSPI_BFGENCR_WR(x, HW_QUADSPI_BFGENCR_RD(x) |  (v)))
#define HW_QUADSPI_BFGENCR_CLR(x, v)      (HW_QUADSPI_BFGENCR_WR(x, HW_QUADSPI_BFGENCR_RD(x) & ~(v)))
#define HW_QUADSPI_BFGENCR_TOG(x, v)      (HW_QUADSPI_BFGENCR_WR(x, HW_QUADSPI_BFGENCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_BFGENCR bitfields
 */

/*!
 * @name Register QUADSPI_BFGENCR, field SEQID[15:12] (RW)
 *
 * Points to a sequence in the Look-up-table. The SEQID defines the bits [6:2] of the LUT index. The
 * bits [1:0] are always assumed to be 0. Refer to . If the sequence pointer differs between the new
 * and previous sequence then the user should reset this. See QSPI_SPTRCLR for more information.
 */
/*@{*/
#define BP_QUADSPI_BFGENCR_SEQID         (12U)      /*!< Bit position for QUADSPI_BFGENCR_SEQID. */
#define BM_QUADSPI_BFGENCR_SEQID         (0x0000F000U)  /*!< Bit mask for QUADSPI_BFGENCR_SEQID. */
#define BS_QUADSPI_BFGENCR_SEQID         (4U)  /*!< Bitfield size in bits for QUADSPI_BFGENCR_SEQID. */

/*! @brief Read current value of the QUADSPI_BFGENCR_SEQID field. */
#define BR_QUADSPI_BFGENCR_SEQID(x)   (HW_QUADSPI_BFGENCR(x).B.SEQID)

/*! @brief Format value for bitfield QUADSPI_BFGENCR_SEQID. */
#define BF_QUADSPI_BFGENCR_SEQID(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_BFGENCR_SEQID) & BM_QUADSPI_BFGENCR_SEQID)

/*! @brief Set the SEQID field to a new value. */
#define BW_QUADSPI_BFGENCR_SEQID(x, v)   (HW_QUADSPI_BFGENCR_WR(x, (HW_QUADSPI_BFGENCR_RD(x) & ~BM_QUADSPI_BFGENCR_SEQID) | BF_QUADSPI_BFGENCR_SEQID(v)))
/*@}*/

/*!
 * @name Register QUADSPI_BFGENCR, field PAR_EN[16] (RW)
 *
 * When set, a transaction to two serial flash devices is triggered in parallel mode. Refer to
 * Parallel Flash Mode for more details.
 */
/*@{*/
#define BP_QUADSPI_BFGENCR_PAR_EN         (16U)      /*!< Bit position for QUADSPI_BFGENCR_PAR_EN. */
#define BM_QUADSPI_BFGENCR_PAR_EN         (0x00010000U)  /*!< Bit mask for QUADSPI_BFGENCR_PAR_EN. */
#define BS_QUADSPI_BFGENCR_PAR_EN         (1U)  /*!< Bitfield size in bits for QUADSPI_BFGENCR_PAR_EN. */

/*! @brief Read current value of the QUADSPI_BFGENCR_PAR_EN field. */
#define BR_QUADSPI_BFGENCR_PAR_EN(x)   (HW_QUADSPI_BFGENCR(x).B.PAR_EN)

/*! @brief Format value for bitfield QUADSPI_BFGENCR_PAR_EN. */
#define BF_QUADSPI_BFGENCR_PAR_EN(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_BFGENCR_PAR_EN) & BM_QUADSPI_BFGENCR_PAR_EN)

/*! @brief Set the PAR_EN field to a new value. */
#define BW_QUADSPI_BFGENCR_PAR_EN(x, v)   (HW_QUADSPI_BFGENCR_WR(x, (HW_QUADSPI_BFGENCR_RD(x) & ~BM_QUADSPI_BFGENCR_PAR_EN) | BF_QUADSPI_BFGENCR_PAR_EN(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_SOCCR - SOC Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_SOCCR - SOC Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register is programmed at chip level for QuadSPI delay chain configuration. For details,
 * refer to chip-specific QuadSPI information. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_soccr
{
    uint32_t U;
    struct _hw_quadspi_soccr_bitfields
    {
        uint32_t SOCCFG : 32; /*!< [31:0] SOC Configuration */
    } B;
} hw_quadspi_soccr_t;

/*!
 * @name Constants and macros for entire QUADSPI_SOCCR register
 */
/*@{*/
#define HW_QUADSPI_SOCCR_ADDR(x)        ((x) + 0x24U)
#define HW_QUADSPI_SOCCR(x)             (*(__IO hw_quadspi_soccr_t *) HW_QUADSPI_SOCCR_ADDR(x))
#define HW_QUADSPI_SOCCR_RD(x)          (HW_QUADSPI_SOCCR(x).U)
#define HW_QUADSPI_SOCCR_WR(x, v)       (HW_QUADSPI_SOCCR(x).U = (v))
#define HW_QUADSPI_SOCCR_SET(x, v)      (HW_QUADSPI_SOCCR_WR(x, HW_QUADSPI_SOCCR_RD(x) |  (v)))
#define HW_QUADSPI_SOCCR_CLR(x, v)      (HW_QUADSPI_SOCCR_WR(x, HW_QUADSPI_SOCCR_RD(x) & ~(v)))
#define HW_QUADSPI_SOCCR_TOG(x, v)      (HW_QUADSPI_SOCCR_WR(x, HW_QUADSPI_SOCCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_SOCCR bitfields
 */

/*!
 * @name Register QUADSPI_SOCCR, field SOCCFG[31:0] (RW)
 *
 * SOC Configuration For details, refer to chip-specific QuadSPI information.
 */
/*@{*/
#define BP_QUADSPI_SOCCR_SOCCFG         (0U)      /*!< Bit position for QUADSPI_SOCCR_SOCCFG. */
#define BM_QUADSPI_SOCCR_SOCCFG         (0xFFFFFFFFU)  /*!< Bit mask for QUADSPI_SOCCR_SOCCFG. */
#define BS_QUADSPI_SOCCR_SOCCFG         (32U)  /*!< Bitfield size in bits for QUADSPI_SOCCR_SOCCFG. */

/*! @brief Read current value of the QUADSPI_SOCCR_SOCCFG field. */
#define BR_QUADSPI_SOCCR_SOCCFG(x)      (HW_QUADSPI_SOCCR(x).U)

/*! @brief Format value for bitfield QUADSPI_SOCCR_SOCCFG. */
#define BF_QUADSPI_SOCCR_SOCCFG(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_SOCCR_SOCCFG) & BM_QUADSPI_SOCCR_SOCCFG)

/*! @brief Set the SOCCFG field to a new value. */
#define BW_QUADSPI_SOCCR_SOCCFG(x, v)   (HW_QUADSPI_SOCCR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_BUF0IND - Buffer0 Top Index Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_BUF0IND - Buffer0 Top Index Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register specifies the top index of buffer0, which defines its size. Note that that the 3
 * LSBs of this register are set to zero - this ensures that the buffer is 64bit aligned, as each
 * buffer entry is 64bits long. The register value should be set to the desired number of bytes. The
 * size of buffer0 is the difference between the BUF0IND and 0. It is the responsibility of the
 * software to ensure that BUF0IND value is not greater than the overall size of the buffer. The
 * hardware does not provide any protection against illegal programming. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf0ind
{
    uint32_t U;
    struct _hw_quadspi_buf0ind_bitfields
    {
        uint32_t RESERVED0 : 3; /*!< [2:0] Reserved. */
        uint32_t TPINDX0 : 29; /*!< [31:3] Top index of buffer 0. */
    } B;
} hw_quadspi_buf0ind_t;

/*!
 * @name Constants and macros for entire QUADSPI_BUF0IND register
 */
/*@{*/
#define HW_QUADSPI_BUF0IND_ADDR(x)        ((x) + 0x30U)
#define HW_QUADSPI_BUF0IND(x)             (*(__IO hw_quadspi_buf0ind_t *) HW_QUADSPI_BUF0IND_ADDR(x))
#define HW_QUADSPI_BUF0IND_RD(x)          (HW_QUADSPI_BUF0IND(x).U)
#define HW_QUADSPI_BUF0IND_WR(x, v)       (HW_QUADSPI_BUF0IND(x).U = (v))
#define HW_QUADSPI_BUF0IND_SET(x, v)      (HW_QUADSPI_BUF0IND_WR(x, HW_QUADSPI_BUF0IND_RD(x) |  (v)))
#define HW_QUADSPI_BUF0IND_CLR(x, v)      (HW_QUADSPI_BUF0IND_WR(x, HW_QUADSPI_BUF0IND_RD(x) & ~(v)))
#define HW_QUADSPI_BUF0IND_TOG(x, v)      (HW_QUADSPI_BUF0IND_WR(x, HW_QUADSPI_BUF0IND_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_BUF0IND bitfields
 */

/*!
 * @name Register QUADSPI_BUF0IND, field TPINDX0[31:3] (RW)
 *
 * Top index of buffer 0.
 */
/*@{*/
#define BP_QUADSPI_BUF0IND_TPINDX0         (3U)      /*!< Bit position for QUADSPI_BUF0IND_TPINDX0. */
#define BM_QUADSPI_BUF0IND_TPINDX0         (0xFFFFFFF8U)  /*!< Bit mask for QUADSPI_BUF0IND_TPINDX0. */
#define BS_QUADSPI_BUF0IND_TPINDX0         (29U)  /*!< Bitfield size in bits for QUADSPI_BUF0IND_TPINDX0. */

/*! @brief Read current value of the QUADSPI_BUF0IND_TPINDX0 field. */
#define BR_QUADSPI_BUF0IND_TPINDX0(x)   (HW_QUADSPI_BUF0IND(x).B.TPINDX0)

/*! @brief Format value for bitfield QUADSPI_BUF0IND_TPINDX0. */
#define BF_QUADSPI_BUF0IND_TPINDX0(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_BUF0IND_TPINDX0) & BM_QUADSPI_BUF0IND_TPINDX0)

/*! @brief Set the TPINDX0 field to a new value. */
#define BW_QUADSPI_BUF0IND_TPINDX0(x, v)   (HW_QUADSPI_BUF0IND_WR(x, (HW_QUADSPI_BUF0IND_RD(x) & ~BM_QUADSPI_BUF0IND_TPINDX0) | BF_QUADSPI_BUF0IND_TPINDX0(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_BUF1IND - Buffer1 Top Index Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_BUF1IND - Buffer1 Top Index Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register specifies the top index of buffer1, which defines its size. Note that the 3 LSBs of
 * this register are set to zero - this ensures that the buffer is 64bit aligned as each buffer
 * entry is 64bits long. The size of buffer1 is the difference between the BUF1IND and BUF0IND. The
 * register value should be entered in bytes. e.g. If BUF0IND = 0x100 then setting BUF1IND = 0x130
 * will set buffer1 size to 0x30bytes.. It is the responsibility of the software to ensure that
 * BUF1IND value is not greater than the overall size of the buffer. The hardware does not provide
 * any protection against illegal programming. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf1ind
{
    uint32_t U;
    struct _hw_quadspi_buf1ind_bitfields
    {
        uint32_t RESERVED0 : 3; /*!< [2:0]  */
        uint32_t TPINDX1 : 29; /*!< [31:3] Top index of buffer 1. */
    } B;
} hw_quadspi_buf1ind_t;

/*!
 * @name Constants and macros for entire QUADSPI_BUF1IND register
 */
/*@{*/
#define HW_QUADSPI_BUF1IND_ADDR(x)        ((x) + 0x34U)
#define HW_QUADSPI_BUF1IND(x)             (*(__IO hw_quadspi_buf1ind_t *) HW_QUADSPI_BUF1IND_ADDR(x))
#define HW_QUADSPI_BUF1IND_RD(x)          (HW_QUADSPI_BUF1IND(x).U)
#define HW_QUADSPI_BUF1IND_WR(x, v)       (HW_QUADSPI_BUF1IND(x).U = (v))
#define HW_QUADSPI_BUF1IND_SET(x, v)      (HW_QUADSPI_BUF1IND_WR(x, HW_QUADSPI_BUF1IND_RD(x) |  (v)))
#define HW_QUADSPI_BUF1IND_CLR(x, v)      (HW_QUADSPI_BUF1IND_WR(x, HW_QUADSPI_BUF1IND_RD(x) & ~(v)))
#define HW_QUADSPI_BUF1IND_TOG(x, v)      (HW_QUADSPI_BUF1IND_WR(x, HW_QUADSPI_BUF1IND_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_BUF1IND bitfields
 */

/*!
 * @name Register QUADSPI_BUF1IND, field TPINDX1[31:3] (RW)
 *
 * Top index of buffer 1.
 */
/*@{*/
#define BP_QUADSPI_BUF1IND_TPINDX1         (3U)      /*!< Bit position for QUADSPI_BUF1IND_TPINDX1. */
#define BM_QUADSPI_BUF1IND_TPINDX1         (0xFFFFFFF8U)  /*!< Bit mask for QUADSPI_BUF1IND_TPINDX1. */
#define BS_QUADSPI_BUF1IND_TPINDX1         (29U)  /*!< Bitfield size in bits for QUADSPI_BUF1IND_TPINDX1. */

/*! @brief Read current value of the QUADSPI_BUF1IND_TPINDX1 field. */
#define BR_QUADSPI_BUF1IND_TPINDX1(x)   (HW_QUADSPI_BUF1IND(x).B.TPINDX1)

/*! @brief Format value for bitfield QUADSPI_BUF1IND_TPINDX1. */
#define BF_QUADSPI_BUF1IND_TPINDX1(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_BUF1IND_TPINDX1) & BM_QUADSPI_BUF1IND_TPINDX1)

/*! @brief Set the TPINDX1 field to a new value. */
#define BW_QUADSPI_BUF1IND_TPINDX1(x, v)   (HW_QUADSPI_BUF1IND_WR(x, (HW_QUADSPI_BUF1IND_RD(x) & ~BM_QUADSPI_BUF1IND_TPINDX1) | BF_QUADSPI_BUF1IND_TPINDX1(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_BUF2IND - Buffer2 Top Index Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_BUF2IND - Buffer2 Top Index Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register specifies the top index of buffer2, which defines its size. Note that that the 3
 * LSBs of this register are set to zero - this ensures that the buffer is 64bit aligned as each
 * buffer entry is 64bits long. The size of buffer2 is the difference between the BUF2IND and
 * BUF1IND. The register value should be entered in bytes. e.g. If BUF1IND = 0x130 then setting
 * BUF2IND = 0x180 will set buffer2 size to 0x50 bytes. It is the responsibility of the software to
 * ensure that BUF2IND value is not greater than the overall size of the buffer. The hardware does
 * not provide any protection against illegal programming. Write: QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_buf2ind
{
    uint32_t U;
    struct _hw_quadspi_buf2ind_bitfields
    {
        uint32_t RESERVED0 : 3; /*!< [2:0]  */
        uint32_t TPINDX2 : 29; /*!< [31:3] Top index of buffer 2. */
    } B;
} hw_quadspi_buf2ind_t;

/*!
 * @name Constants and macros for entire QUADSPI_BUF2IND register
 */
/*@{*/
#define HW_QUADSPI_BUF2IND_ADDR(x)        ((x) + 0x38U)
#define HW_QUADSPI_BUF2IND(x)             (*(__IO hw_quadspi_buf2ind_t *) HW_QUADSPI_BUF2IND_ADDR(x))
#define HW_QUADSPI_BUF2IND_RD(x)          (HW_QUADSPI_BUF2IND(x).U)
#define HW_QUADSPI_BUF2IND_WR(x, v)       (HW_QUADSPI_BUF2IND(x).U = (v))
#define HW_QUADSPI_BUF2IND_SET(x, v)      (HW_QUADSPI_BUF2IND_WR(x, HW_QUADSPI_BUF2IND_RD(x) |  (v)))
#define HW_QUADSPI_BUF2IND_CLR(x, v)      (HW_QUADSPI_BUF2IND_WR(x, HW_QUADSPI_BUF2IND_RD(x) & ~(v)))
#define HW_QUADSPI_BUF2IND_TOG(x, v)      (HW_QUADSPI_BUF2IND_WR(x, HW_QUADSPI_BUF2IND_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_BUF2IND bitfields
 */

/*!
 * @name Register QUADSPI_BUF2IND, field TPINDX2[31:3] (RW)
 *
 * Top index of buffer 2.
 */
/*@{*/
#define BP_QUADSPI_BUF2IND_TPINDX2         (3U)      /*!< Bit position for QUADSPI_BUF2IND_TPINDX2. */
#define BM_QUADSPI_BUF2IND_TPINDX2         (0xFFFFFFF8U)  /*!< Bit mask for QUADSPI_BUF2IND_TPINDX2. */
#define BS_QUADSPI_BUF2IND_TPINDX2         (29U)  /*!< Bitfield size in bits for QUADSPI_BUF2IND_TPINDX2. */

/*! @brief Read current value of the QUADSPI_BUF2IND_TPINDX2 field. */
#define BR_QUADSPI_BUF2IND_TPINDX2(x)   (HW_QUADSPI_BUF2IND(x).B.TPINDX2)

/*! @brief Format value for bitfield QUADSPI_BUF2IND_TPINDX2. */
#define BF_QUADSPI_BUF2IND_TPINDX2(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_BUF2IND_TPINDX2) & BM_QUADSPI_BUF2IND_TPINDX2)

/*! @brief Set the TPINDX2 field to a new value. */
#define BW_QUADSPI_BUF2IND_TPINDX2(x, v)   (HW_QUADSPI_BUF2IND_WR(x, (HW_QUADSPI_BUF2IND_RD(x) & ~BM_QUADSPI_BUF2IND_TPINDX2) | BF_QUADSPI_BUF2IND_TPINDX2(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_SFAR - Serial Flash Address Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_SFAR - Serial Flash Address Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The module automatically translates this address on the memory map to the address on the flash
 * itself. When operating in 24bit mode, only bits 23-0 are sent to the flash, in 32bit mode, bits
 * 27-0 are used with bits 31-28 driven to 0 when QSPI_SFACR[CAS] is set to 0. Say, if
 * QSPI_SFACR[CAS] is 3 then bits 26-3 are sent to flash as it page address in case flash is
 * operating in 24bit mode. Total number of address bits request by flash as it page and column
 * address must not be more than 32 bit. Refer to for the mapping between the access mode and the
 * QSPI_SFAR content and to Normal Modefor details about the command triggering and command
 * execution. The software should ensure that the serial flash address provided in the QSPI_SFAR
 * register lies in the valid flash address range as defined in . Write: QSPI_SR[IP_ACC] = 0
 */
typedef union _hw_quadspi_sfar
{
    uint32_t U;
    struct _hw_quadspi_sfar_bitfields
    {
        uint32_t SFADR : 32; /*!< [31:0] Serial Flash Address. */
    } B;
} hw_quadspi_sfar_t;

/*!
 * @name Constants and macros for entire QUADSPI_SFAR register
 */
/*@{*/
#define HW_QUADSPI_SFAR_ADDR(x)        ((x) + 0x100U)
#define HW_QUADSPI_SFAR(x)             (*(__IO hw_quadspi_sfar_t *) HW_QUADSPI_SFAR_ADDR(x))
#define HW_QUADSPI_SFAR_RD(x)          (HW_QUADSPI_SFAR(x).U)
#define HW_QUADSPI_SFAR_WR(x, v)       (HW_QUADSPI_SFAR(x).U = (v))
#define HW_QUADSPI_SFAR_SET(x, v)      (HW_QUADSPI_SFAR_WR(x, HW_QUADSPI_SFAR_RD(x) |  (v)))
#define HW_QUADSPI_SFAR_CLR(x, v)      (HW_QUADSPI_SFAR_WR(x, HW_QUADSPI_SFAR_RD(x) & ~(v)))
#define HW_QUADSPI_SFAR_TOG(x, v)      (HW_QUADSPI_SFAR_WR(x, HW_QUADSPI_SFAR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_SFAR bitfields
 */

/*!
 * @name Register QUADSPI_SFAR, field SFADR[31:0] (RW)
 *
 * Serial Flash Address. The register content is used as byte address for all following IP Commands.
 */
/*@{*/
#define BP_QUADSPI_SFAR_SFADR         (0U)      /*!< Bit position for QUADSPI_SFAR_SFADR. */
#define BM_QUADSPI_SFAR_SFADR         (0xFFFFFFFFU)  /*!< Bit mask for QUADSPI_SFAR_SFADR. */
#define BS_QUADSPI_SFAR_SFADR         (32U)  /*!< Bitfield size in bits for QUADSPI_SFAR_SFADR. */

/*! @brief Read current value of the QUADSPI_SFAR_SFADR field. */
#define BR_QUADSPI_SFAR_SFADR(x)      (HW_QUADSPI_SFAR(x).U)

/*! @brief Format value for bitfield QUADSPI_SFAR_SFADR. */
#define BF_QUADSPI_SFAR_SFADR(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_SFAR_SFADR) & BM_QUADSPI_SFAR_SFADR)

/*! @brief Set the SFADR field to a new value. */
#define BW_QUADSPI_SFAR_SFADR(x, v)   (HW_QUADSPI_SFAR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_SFACR - Serial Flash Address Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_SFACR - Serial Flash Address Configuration Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This serial flash address configuration register contains the serial flash specific address
 * requirements that must be configured according to the flash connected, for the controller to
 * function properly.The module automatically translates the address QSPI_SFAR on the memory map or
 * the incoming address on the AHB bus to the column address on the flash itself. Say, a flash needs
 * 3 bits as its column address than only the lower 3 bits of QSPI_SFAR/AHB address are send to
 * Flash as its column address. The software should ensure that the serial flash address provided in
 * the QSPI_SFAR register or the incoming AHB address lies in the valid flash address range. Write:
 * QSPI_SR[IP_ACC] = 0 QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_sfacr
{
    uint32_t U;
    struct _hw_quadspi_sfacr_bitfields
    {
        uint32_t CAS : 4; /*!< [3:0] Column Address Space */
        uint32_t RESERVED0 : 12; /*!< [15:4]  */
        uint32_t WA : 1; /*!< [16] Word Addressable */
        uint32_t RESERVED1 : 15; /*!< [31:17]  */
    } B;
} hw_quadspi_sfacr_t;

/*!
 * @name Constants and macros for entire QUADSPI_SFACR register
 */
/*@{*/
#define HW_QUADSPI_SFACR_ADDR(x)        ((x) + 0x104U)
#define HW_QUADSPI_SFACR(x)             (*(__IO hw_quadspi_sfacr_t *) HW_QUADSPI_SFACR_ADDR(x))
#define HW_QUADSPI_SFACR_RD(x)          (HW_QUADSPI_SFACR(x).U)
#define HW_QUADSPI_SFACR_WR(x, v)       (HW_QUADSPI_SFACR(x).U = (v))
#define HW_QUADSPI_SFACR_SET(x, v)      (HW_QUADSPI_SFACR_WR(x, HW_QUADSPI_SFACR_RD(x) |  (v)))
#define HW_QUADSPI_SFACR_CLR(x, v)      (HW_QUADSPI_SFACR_WR(x, HW_QUADSPI_SFACR_RD(x) & ~(v)))
#define HW_QUADSPI_SFACR_TOG(x, v)      (HW_QUADSPI_SFACR_WR(x, HW_QUADSPI_SFACR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_SFACR bitfields
 */

/*!
 * @name Register QUADSPI_SFACR, field CAS[3:0] (RW)
 *
 * It defines the width of the column address. If the coulmn address is say [2:0] of QSPI_SFAR/AHB
 * address, then CAS must be 3. In there there is no column address seperation in any Serial flash
 * this bit must be programmed to 0.
 *
 * Values:
 * -  - 
 */
/*@{*/
#define BP_QUADSPI_SFACR_CAS         (0U)      /*!< Bit position for QUADSPI_SFACR_CAS. */
#define BM_QUADSPI_SFACR_CAS         (0x0000000FU)  /*!< Bit mask for QUADSPI_SFACR_CAS. */
#define BS_QUADSPI_SFACR_CAS         (4U)  /*!< Bitfield size in bits for QUADSPI_SFACR_CAS. */

/*! @brief Read current value of the QUADSPI_SFACR_CAS field. */
#define BR_QUADSPI_SFACR_CAS(x)   (HW_QUADSPI_SFACR(x).B.CAS)

/*! @brief Format value for bitfield QUADSPI_SFACR_CAS. */
#define BF_QUADSPI_SFACR_CAS(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_SFACR_CAS) & BM_QUADSPI_SFACR_CAS)

/*! @brief Set the CAS field to a new value. */
#define BW_QUADSPI_SFACR_CAS(x, v)   (HW_QUADSPI_SFACR_WR(x, (HW_QUADSPI_SFACR_RD(x) & ~BM_QUADSPI_SFACR_CAS) | BF_QUADSPI_SFACR_CAS(v)))
/*@}*/

/*!
 * @name Register QUADSPI_SFACR, field WA[16] (RW)
 *
 * It defines whether the serial flash is a byte addressable flash or a word addressable flash.
 * According to this bit configuration the address is re-mapped to the flash interface. Refer to for
 * details
 *
 * Values:
 * - 0 - Byte addressable serial flash mode.
 * - 1 - Word (2 byte) addressable serial flash mode.
 */
/*@{*/
#define BP_QUADSPI_SFACR_WA         (16U)      /*!< Bit position for QUADSPI_SFACR_WA. */
#define BM_QUADSPI_SFACR_WA         (0x00010000U)  /*!< Bit mask for QUADSPI_SFACR_WA. */
#define BS_QUADSPI_SFACR_WA         (1U)  /*!< Bitfield size in bits for QUADSPI_SFACR_WA. */

/*! @brief Read current value of the QUADSPI_SFACR_WA field. */
#define BR_QUADSPI_SFACR_WA(x)   (HW_QUADSPI_SFACR(x).B.WA)

/*! @brief Format value for bitfield QUADSPI_SFACR_WA. */
#define BF_QUADSPI_SFACR_WA(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_SFACR_WA) & BM_QUADSPI_SFACR_WA)

/*! @brief Set the WA field to a new value. */
#define BW_QUADSPI_SFACR_WA(x, v)   (HW_QUADSPI_SFACR_WR(x, (HW_QUADSPI_SFACR_RD(x) & ~BM_QUADSPI_SFACR_WA) | BF_QUADSPI_SFACR_WA(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_SMPR - Sampling Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_SMPR - Sampling Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The Sampling Register allows configuration of how the incoming data from the external serial
 * flash devices are sampled in the QuadSPI module. Write:Disabled Mode
 */
typedef union _hw_quadspi_smpr
{
    uint32_t U;
    struct _hw_quadspi_smpr_bitfields
    {
        uint32_t HSENA : 1; /*!< [0] Half Speed serial flash clock Enable: This bit enables the divide by 2 of the clock to the external serial flash device for all commands,both SDR and DDR. Refer to for details. */
        uint32_t HSPHS : 1; /*!< [1] Half Speed Phase selection for SDR instructions. */
        uint32_t HSDLY : 1; /*!< [2] Half Speed Delay selection for SDR instructions. */
        uint32_t RESERVED0 : 2; /*!< [4:3]  */
        uint32_t FSPHS : 1; /*!< [5] Full Speed Phase selection for SDR instructions. */
        uint32_t FSDLY : 1; /*!< [6] Full Speed Delay selection for SDR instructions. Select the delay with respect to the reference edge for the sample point valid for full speed commands: */
        uint32_t RESERVED1 : 9; /*!< [15:7]  */
        uint32_t DDRSMP : 3; /*!< [18:16] DDR Sampling point. */
        uint32_t RESERVED2 : 13; /*!< [31:19]  */
    } B;
} hw_quadspi_smpr_t;

/*!
 * @name Constants and macros for entire QUADSPI_SMPR register
 */
/*@{*/
#define HW_QUADSPI_SMPR_ADDR(x)        ((x) + 0x108U)
#define HW_QUADSPI_SMPR(x)             (*(__IO hw_quadspi_smpr_t *) HW_QUADSPI_SMPR_ADDR(x))
#define HW_QUADSPI_SMPR_RD(x)          (HW_QUADSPI_SMPR(x).U)
#define HW_QUADSPI_SMPR_WR(x, v)       (HW_QUADSPI_SMPR(x).U = (v))
#define HW_QUADSPI_SMPR_SET(x, v)      (HW_QUADSPI_SMPR_WR(x, HW_QUADSPI_SMPR_RD(x) |  (v)))
#define HW_QUADSPI_SMPR_CLR(x, v)      (HW_QUADSPI_SMPR_WR(x, HW_QUADSPI_SMPR_RD(x) & ~(v)))
#define HW_QUADSPI_SMPR_TOG(x, v)      (HW_QUADSPI_SMPR_WR(x, HW_QUADSPI_SMPR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_SMPR bitfields
 */

/*!
 * @name Register QUADSPI_SMPR, field HSENA[0] (RW)
 *
 * Values:
 * - 0 - Disable divide by 2 of serial flash clock for half speed commands
 * - 1 - Enable divide by 2 of serial flash clock for half speed commands
 */
/*@{*/
#define BP_QUADSPI_SMPR_HSENA         (0U)      /*!< Bit position for QUADSPI_SMPR_HSENA. */
#define BM_QUADSPI_SMPR_HSENA         (0x00000001U)  /*!< Bit mask for QUADSPI_SMPR_HSENA. */
#define BS_QUADSPI_SMPR_HSENA         (1U)  /*!< Bitfield size in bits for QUADSPI_SMPR_HSENA. */

/*! @brief Read current value of the QUADSPI_SMPR_HSENA field. */
#define BR_QUADSPI_SMPR_HSENA(x)   (HW_QUADSPI_SMPR(x).B.HSENA)

/*! @brief Format value for bitfield QUADSPI_SMPR_HSENA. */
#define BF_QUADSPI_SMPR_HSENA(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_SMPR_HSENA) & BM_QUADSPI_SMPR_HSENA)

/*! @brief Set the HSENA field to a new value. */
#define BW_QUADSPI_SMPR_HSENA(x, v)   (HW_QUADSPI_SMPR_WR(x, (HW_QUADSPI_SMPR_RD(x) & ~BM_QUADSPI_SMPR_HSENA) | BF_QUADSPI_SMPR_HSENA(v)))
/*@}*/

/*!
 * @name Register QUADSPI_SMPR, field HSPHS[1] (RW)
 *
 * Only relevant when HSENA bit is set. Select the delay with respect to the reference edge for the
 * sample point valid for half speed commands:
 *
 * Values:
 * - 0 - Select sampling at non-inverted clock
 * - 1 - Select sampling at inverted clock
 */
/*@{*/
#define BP_QUADSPI_SMPR_HSPHS         (1U)      /*!< Bit position for QUADSPI_SMPR_HSPHS. */
#define BM_QUADSPI_SMPR_HSPHS         (0x00000002U)  /*!< Bit mask for QUADSPI_SMPR_HSPHS. */
#define BS_QUADSPI_SMPR_HSPHS         (1U)  /*!< Bitfield size in bits for QUADSPI_SMPR_HSPHS. */

/*! @brief Read current value of the QUADSPI_SMPR_HSPHS field. */
#define BR_QUADSPI_SMPR_HSPHS(x)   (HW_QUADSPI_SMPR(x).B.HSPHS)

/*! @brief Format value for bitfield QUADSPI_SMPR_HSPHS. */
#define BF_QUADSPI_SMPR_HSPHS(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_SMPR_HSPHS) & BM_QUADSPI_SMPR_HSPHS)

/*! @brief Set the HSPHS field to a new value. */
#define BW_QUADSPI_SMPR_HSPHS(x, v)   (HW_QUADSPI_SMPR_WR(x, (HW_QUADSPI_SMPR_RD(x) & ~BM_QUADSPI_SMPR_HSPHS) | BF_QUADSPI_SMPR_HSPHS(v)))
/*@}*/

/*!
 * @name Register QUADSPI_SMPR, field HSDLY[2] (RW)
 *
 * Only relevant when HSENA bit is set. Select the delay with respect to the reference edge for the
 * sample point valid for half speed commands:
 *
 * Values:
 * - 0 - One clock cycle delay
 * - 1 - Two clock cycle delay
 */
/*@{*/
#define BP_QUADSPI_SMPR_HSDLY         (2U)      /*!< Bit position for QUADSPI_SMPR_HSDLY. */
#define BM_QUADSPI_SMPR_HSDLY         (0x00000004U)  /*!< Bit mask for QUADSPI_SMPR_HSDLY. */
#define BS_QUADSPI_SMPR_HSDLY         (1U)  /*!< Bitfield size in bits for QUADSPI_SMPR_HSDLY. */

/*! @brief Read current value of the QUADSPI_SMPR_HSDLY field. */
#define BR_QUADSPI_SMPR_HSDLY(x)   (HW_QUADSPI_SMPR(x).B.HSDLY)

/*! @brief Format value for bitfield QUADSPI_SMPR_HSDLY. */
#define BF_QUADSPI_SMPR_HSDLY(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_SMPR_HSDLY) & BM_QUADSPI_SMPR_HSDLY)

/*! @brief Set the HSDLY field to a new value. */
#define BW_QUADSPI_SMPR_HSDLY(x, v)   (HW_QUADSPI_SMPR_WR(x, (HW_QUADSPI_SMPR_RD(x) & ~BM_QUADSPI_SMPR_HSDLY) | BF_QUADSPI_SMPR_HSDLY(v)))
/*@}*/

/*!
 * @name Register QUADSPI_SMPR, field FSPHS[5] (RW)
 *
 * Select the edge of the sampling clock valid for full speed commands:
 *
 * Values:
 * - 0 - Select sampling at non-inverted clock
 * - 1 - Select sampling at inverted clock. This bit is ignored when using DDR instructions.
 */
/*@{*/
#define BP_QUADSPI_SMPR_FSPHS         (5U)      /*!< Bit position for QUADSPI_SMPR_FSPHS. */
#define BM_QUADSPI_SMPR_FSPHS         (0x00000020U)  /*!< Bit mask for QUADSPI_SMPR_FSPHS. */
#define BS_QUADSPI_SMPR_FSPHS         (1U)  /*!< Bitfield size in bits for QUADSPI_SMPR_FSPHS. */

/*! @brief Read current value of the QUADSPI_SMPR_FSPHS field. */
#define BR_QUADSPI_SMPR_FSPHS(x)   (HW_QUADSPI_SMPR(x).B.FSPHS)

/*! @brief Format value for bitfield QUADSPI_SMPR_FSPHS. */
#define BF_QUADSPI_SMPR_FSPHS(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_SMPR_FSPHS) & BM_QUADSPI_SMPR_FSPHS)

/*! @brief Set the FSPHS field to a new value. */
#define BW_QUADSPI_SMPR_FSPHS(x, v)   (HW_QUADSPI_SMPR_WR(x, (HW_QUADSPI_SMPR_RD(x) & ~BM_QUADSPI_SMPR_FSPHS) | BF_QUADSPI_SMPR_FSPHS(v)))
/*@}*/

/*!
 * @name Register QUADSPI_SMPR, field FSDLY[6] (RW)
 *
 * Values:
 * - 0 - One clock cycle delay
 * - 1 - Two clock cycles delay.This bit is ignored when using DDR instructions
 */
/*@{*/
#define BP_QUADSPI_SMPR_FSDLY         (6U)      /*!< Bit position for QUADSPI_SMPR_FSDLY. */
#define BM_QUADSPI_SMPR_FSDLY         (0x00000040U)  /*!< Bit mask for QUADSPI_SMPR_FSDLY. */
#define BS_QUADSPI_SMPR_FSDLY         (1U)  /*!< Bitfield size in bits for QUADSPI_SMPR_FSDLY. */

/*! @brief Read current value of the QUADSPI_SMPR_FSDLY field. */
#define BR_QUADSPI_SMPR_FSDLY(x)   (HW_QUADSPI_SMPR(x).B.FSDLY)

/*! @brief Format value for bitfield QUADSPI_SMPR_FSDLY. */
#define BF_QUADSPI_SMPR_FSDLY(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_SMPR_FSDLY) & BM_QUADSPI_SMPR_FSDLY)

/*! @brief Set the FSDLY field to a new value. */
#define BW_QUADSPI_SMPR_FSDLY(x, v)   (HW_QUADSPI_SMPR_WR(x, (HW_QUADSPI_SMPR_RD(x) & ~BM_QUADSPI_SMPR_FSDLY) | BF_QUADSPI_SMPR_FSDLY(v)))
/*@}*/

/*!
 * @name Register QUADSPI_SMPR, field DDRSMP[18:16] (RW)
 *
 * DDR Sampling point. Select the sampling point for incoming data when serial flash is executing a
 * DDR instruction. Refer to , for details on the sampling points.
 */
/*@{*/
#define BP_QUADSPI_SMPR_DDRSMP         (16U)      /*!< Bit position for QUADSPI_SMPR_DDRSMP. */
#define BM_QUADSPI_SMPR_DDRSMP         (0x00070000U)  /*!< Bit mask for QUADSPI_SMPR_DDRSMP. */
#define BS_QUADSPI_SMPR_DDRSMP         (3U)  /*!< Bitfield size in bits for QUADSPI_SMPR_DDRSMP. */

/*! @brief Read current value of the QUADSPI_SMPR_DDRSMP field. */
#define BR_QUADSPI_SMPR_DDRSMP(x)   (HW_QUADSPI_SMPR(x).B.DDRSMP)

/*! @brief Format value for bitfield QUADSPI_SMPR_DDRSMP. */
#define BF_QUADSPI_SMPR_DDRSMP(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_SMPR_DDRSMP) & BM_QUADSPI_SMPR_DDRSMP)

/*! @brief Set the DDRSMP field to a new value. */
#define BW_QUADSPI_SMPR_DDRSMP(x, v)   (HW_QUADSPI_SMPR_WR(x, (HW_QUADSPI_SMPR_RD(x) & ~BM_QUADSPI_SMPR_DDRSMP) | BF_QUADSPI_SMPR_DDRSMP(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_RBSR - RX Buffer Status Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_RBSR - RX Buffer Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register contains information related to the receive data buffer.
 */
typedef union _hw_quadspi_rbsr
{
    uint32_t U;
    struct _hw_quadspi_rbsr_bitfields
    {
        uint32_t RESERVED0 : 8; /*!< [7:0]  */
        uint32_t RDBFL : 6; /*!< [13:8] RX Buffer Fill Level, indicates how many entries of 4 bytes are still available in the RX Buffer.For example a value of 0x2 would indicate 8bytes are available. */
        uint32_t RESERVED1 : 2; /*!< [15:14]  */
        uint32_t RDCTR : 16; /*!< [31:16] Read Counter, indicates how many entries of 4 bytes have been removed from the RX Buffer.For example a value of 0x2 would indicate 8bytes have been removed */
    } B;
} hw_quadspi_rbsr_t;

/*!
 * @name Constants and macros for entire QUADSPI_RBSR register
 */
/*@{*/
#define HW_QUADSPI_RBSR_ADDR(x)        ((x) + 0x10CU)
#define HW_QUADSPI_RBSR(x)             (*(__I  hw_quadspi_rbsr_t *) HW_QUADSPI_RBSR_ADDR(x))
#define HW_QUADSPI_RBSR_RD(x)          (HW_QUADSPI_RBSR(x).U)
/*@}*/

/*
 * Constants & macros for individual QUADSPI_RBSR bitfields
 */

/*!
 * @name Register QUADSPI_RBSR, field RDBFL[13:8] (RO)
 *
 * RX Buffer Fill Level, indicates how many entries of 4 bytes are still available in the RX
 * Buffer.For example a value of 0x2 would indicate 8bytes are available.
 */
/*@{*/
#define BP_QUADSPI_RBSR_RDBFL         (8U)      /*!< Bit position for QUADSPI_RBSR_RDBFL. */
#define BM_QUADSPI_RBSR_RDBFL         (0x00003F00U)  /*!< Bit mask for QUADSPI_RBSR_RDBFL. */
#define BS_QUADSPI_RBSR_RDBFL         (6U)  /*!< Bitfield size in bits for QUADSPI_RBSR_RDBFL. */

/*! @brief Read current value of the QUADSPI_RBSR_RDBFL field. */
#define BR_QUADSPI_RBSR_RDBFL(x)   (HW_QUADSPI_RBSR(x).B.RDBFL)
/*@}*/

/*!
 * @name Register QUADSPI_RBSR, field RDCTR[31:16] (RO)
 *
 * Read Counter, indicates how many entries of 4 bytes have been removed from the RX Buffer.For
 * example a value of 0x2 would indicate 8bytes have been removed It is incremented by the number
 * (QSPI_RBCT[WMRK] + 1) on RX Buffer POP event. The RX Buffer can be popped using DMA or pop flag
 * QSPI_FR[RBDF]. The QSPI_RSER[RBDDE] defines which pop has to be done. For further details please
 * refer to and "Data Transfer from the QuadSPI Module Internal Buffers section in section.
 */
/*@{*/
#define BP_QUADSPI_RBSR_RDCTR         (16U)      /*!< Bit position for QUADSPI_RBSR_RDCTR. */
#define BM_QUADSPI_RBSR_RDCTR         (0xFFFF0000U)  /*!< Bit mask for QUADSPI_RBSR_RDCTR. */
#define BS_QUADSPI_RBSR_RDCTR         (16U)  /*!< Bitfield size in bits for QUADSPI_RBSR_RDCTR. */

/*! @brief Read current value of the QUADSPI_RBSR_RDCTR field. */
#define BR_QUADSPI_RBSR_RDCTR(x)   (HW_QUADSPI_RBSR(x).B.RDCTR)
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_RBCT - RX Buffer Control Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_RBCT - RX Buffer Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains control data related to the receive data buffer. Write: QSPI_SR[IP_ACC] =
 * 0
 */
typedef union _hw_quadspi_rbct
{
    uint32_t U;
    struct _hw_quadspi_rbct_bitfields
    {
        uint32_t WMRK : 5; /*!< [4:0] RX Buffer Watermark: This field determines when the readout action of the RX Buffer is triggered. */
        uint32_t RESERVED0 : 3; /*!< [7:5]  */
        uint32_t RXBRD : 1; /*!< [8] RX Buffer Readout: This bit specifies the access scheme for the RX Buffer readout. */
        uint32_t RESERVED1 : 23; /*!< [31:9]  */
    } B;
} hw_quadspi_rbct_t;

/*!
 * @name Constants and macros for entire QUADSPI_RBCT register
 */
/*@{*/
#define HW_QUADSPI_RBCT_ADDR(x)        ((x) + 0x110U)
#define HW_QUADSPI_RBCT(x)             (*(__IO hw_quadspi_rbct_t *) HW_QUADSPI_RBCT_ADDR(x))
#define HW_QUADSPI_RBCT_RD(x)          (HW_QUADSPI_RBCT(x).U)
#define HW_QUADSPI_RBCT_WR(x, v)       (HW_QUADSPI_RBCT(x).U = (v))
#define HW_QUADSPI_RBCT_SET(x, v)      (HW_QUADSPI_RBCT_WR(x, HW_QUADSPI_RBCT_RD(x) |  (v)))
#define HW_QUADSPI_RBCT_CLR(x, v)      (HW_QUADSPI_RBCT_WR(x, HW_QUADSPI_RBCT_RD(x) & ~(v)))
#define HW_QUADSPI_RBCT_TOG(x, v)      (HW_QUADSPI_RBCT_WR(x, HW_QUADSPI_RBCT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_RBCT bitfields
 */

/*!
 * @name Register QUADSPI_RBCT, field WMRK[4:0] (RW)
 *
 * RX Buffer Watermark: This field determines when the readout action of the RX Buffer is triggered.
 * When the number of valid entries in the RX Buffer is equal to or greater than the number given by
 * (WMRK+1) the QSPI_SR[RXWE] flag is asserted.The value should be entered as the number of 4byte
 * entries minus 1. For example a value of 0x0 would set the watermark to 4bytes, 1 to 8bytes, 2 to
 * 12bytes etc. For details, refer to .
 */
/*@{*/
#define BP_QUADSPI_RBCT_WMRK         (0U)      /*!< Bit position for QUADSPI_RBCT_WMRK. */
#define BM_QUADSPI_RBCT_WMRK         (0x0000001FU)  /*!< Bit mask for QUADSPI_RBCT_WMRK. */
#define BS_QUADSPI_RBCT_WMRK         (5U)  /*!< Bitfield size in bits for QUADSPI_RBCT_WMRK. */

/*! @brief Read current value of the QUADSPI_RBCT_WMRK field. */
#define BR_QUADSPI_RBCT_WMRK(x)   (HW_QUADSPI_RBCT(x).B.WMRK)

/*! @brief Format value for bitfield QUADSPI_RBCT_WMRK. */
#define BF_QUADSPI_RBCT_WMRK(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RBCT_WMRK) & BM_QUADSPI_RBCT_WMRK)

/*! @brief Set the WMRK field to a new value. */
#define BW_QUADSPI_RBCT_WMRK(x, v)   (HW_QUADSPI_RBCT_WR(x, (HW_QUADSPI_RBCT_RD(x) & ~BM_QUADSPI_RBCT_WMRK) | BF_QUADSPI_RBCT_WMRK(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RBCT, field RXBRD[8] (RW)
 *
 * RX Buffer Readout: This bit specifies the access scheme for the RX Buffer readout.
 *
 * Values:
 * - 0 - RX Buffer content is read using the AHB Bus registers QSPI_ARDB0 to QSPI_ARDB31. For details, refer
 *     to .
 * - 1 - RX Buffer content is read using the IP Bus registers QSPI_RBDR0 to QSPI_RBDR31.
 */
/*@{*/
#define BP_QUADSPI_RBCT_RXBRD         (8U)      /*!< Bit position for QUADSPI_RBCT_RXBRD. */
#define BM_QUADSPI_RBCT_RXBRD         (0x00000100U)  /*!< Bit mask for QUADSPI_RBCT_RXBRD. */
#define BS_QUADSPI_RBCT_RXBRD         (1U)  /*!< Bitfield size in bits for QUADSPI_RBCT_RXBRD. */

/*! @brief Read current value of the QUADSPI_RBCT_RXBRD field. */
#define BR_QUADSPI_RBCT_RXBRD(x)   (HW_QUADSPI_RBCT(x).B.RXBRD)

/*! @brief Format value for bitfield QUADSPI_RBCT_RXBRD. */
#define BF_QUADSPI_RBCT_RXBRD(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RBCT_RXBRD) & BM_QUADSPI_RBCT_RXBRD)

/*! @brief Set the RXBRD field to a new value. */
#define BW_QUADSPI_RBCT_RXBRD(x, v)   (HW_QUADSPI_RBCT_WR(x, (HW_QUADSPI_RBCT_RD(x) & ~BM_QUADSPI_RBCT_RXBRD) | BF_QUADSPI_RBCT_RXBRD(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_TBSR - TX Buffer Status Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_TBSR - TX Buffer Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * This register contains information related to the transmit data buffer.
 */
typedef union _hw_quadspi_tbsr
{
    uint32_t U;
    struct _hw_quadspi_tbsr_bitfields
    {
        uint32_t RESERVED0 : 8; /*!< [7:0]  */
        uint32_t TRBFL : 6; /*!< [13:8] TX Buffer Fill Level. */
        uint32_t RESERVED1 : 2; /*!< [15:14]  */
        uint32_t TRCTR : 16; /*!< [31:16] Transmit Counter. */
    } B;
} hw_quadspi_tbsr_t;

/*!
 * @name Constants and macros for entire QUADSPI_TBSR register
 */
/*@{*/
#define HW_QUADSPI_TBSR_ADDR(x)        ((x) + 0x150U)
#define HW_QUADSPI_TBSR(x)             (*(__I  hw_quadspi_tbsr_t *) HW_QUADSPI_TBSR_ADDR(x))
#define HW_QUADSPI_TBSR_RD(x)          (HW_QUADSPI_TBSR(x).U)
/*@}*/

/*
 * Constants & macros for individual QUADSPI_TBSR bitfields
 */

/*!
 * @name Register QUADSPI_TBSR, field TRBFL[13:8] (RO)
 *
 * TX Buffer Fill Level. The TRBFL field contains the number of entries of 4 bytes each available in
 * the TX Buffer for the QuadSPI module to transmit to the serial flash device.
 */
/*@{*/
#define BP_QUADSPI_TBSR_TRBFL         (8U)      /*!< Bit position for QUADSPI_TBSR_TRBFL. */
#define BM_QUADSPI_TBSR_TRBFL         (0x00003F00U)  /*!< Bit mask for QUADSPI_TBSR_TRBFL. */
#define BS_QUADSPI_TBSR_TRBFL         (6U)  /*!< Bitfield size in bits for QUADSPI_TBSR_TRBFL. */

/*! @brief Read current value of the QUADSPI_TBSR_TRBFL field. */
#define BR_QUADSPI_TBSR_TRBFL(x)   (HW_QUADSPI_TBSR(x).B.TRBFL)
/*@}*/

/*!
 * @name Register QUADSPI_TBSR, field TRCTR[31:16] (RO)
 *
 * Transmit Counter. This field indicates how many entries of 4 bytes have been written into the TX
 * Buffer by host accesses. It is reset to 0 when a 1 is written into the QSPI_MCR[CLR_TXF] bit. It
 * is incremented on each write access to the QSPI_TBDR register when another word has been pushed
 * onto the TX Buffer. When it is not cleared the TRCTR field wraps around to 0. Refer to for
 * details.
 */
/*@{*/
#define BP_QUADSPI_TBSR_TRCTR         (16U)      /*!< Bit position for QUADSPI_TBSR_TRCTR. */
#define BM_QUADSPI_TBSR_TRCTR         (0xFFFF0000U)  /*!< Bit mask for QUADSPI_TBSR_TRCTR. */
#define BS_QUADSPI_TBSR_TRCTR         (16U)  /*!< Bitfield size in bits for QUADSPI_TBSR_TRCTR. */

/*! @brief Read current value of the QUADSPI_TBSR_TRCTR field. */
#define BR_QUADSPI_TBSR_TRCTR(x)   (HW_QUADSPI_TBSR(x).B.TRCTR)
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_TBDR - TX Buffer Data Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_TBDR - TX Buffer Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QSPI_TBDR register provides access to the circular TX Buffer of depth 128 bytes. This buffer
 * provides the data written into it as write data for the page programming commands to the serial
 * flash device. Refer to for the byte ordering scheme. A write transaction on the flash with data
 * size of less than 32 bits will lead to the removal of four data entry from the TX buffer. The
 * valid bits will be used and the rest of the bits will be discarded. Write: QSPI_SR[TXFULL] = 0
 * 32-bit write access required
 */
typedef union _hw_quadspi_tbdr
{
    uint32_t U;
    struct _hw_quadspi_tbdr_bitfields
    {
        uint32_t TXDATA : 32; /*!< [31:0] TX Data */
    } B;
} hw_quadspi_tbdr_t;

/*!
 * @name Constants and macros for entire QUADSPI_TBDR register
 */
/*@{*/
#define HW_QUADSPI_TBDR_ADDR(x)        ((x) + 0x154U)
#define HW_QUADSPI_TBDR(x)             (*(__IO hw_quadspi_tbdr_t *) HW_QUADSPI_TBDR_ADDR(x))
#define HW_QUADSPI_TBDR_RD(x)          (HW_QUADSPI_TBDR(x).U)
#define HW_QUADSPI_TBDR_WR(x, v)       (HW_QUADSPI_TBDR(x).U = (v))
#define HW_QUADSPI_TBDR_SET(x, v)      (HW_QUADSPI_TBDR_WR(x, HW_QUADSPI_TBDR_RD(x) |  (v)))
#define HW_QUADSPI_TBDR_CLR(x, v)      (HW_QUADSPI_TBDR_WR(x, HW_QUADSPI_TBDR_RD(x) & ~(v)))
#define HW_QUADSPI_TBDR_TOG(x, v)      (HW_QUADSPI_TBDR_WR(x, HW_QUADSPI_TBDR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_TBDR bitfields
 */

/*!
 * @name Register QUADSPI_TBDR, field TXDATA[31:0] (RW)
 *
 * TX Data On write access the data is written into the next available entry of the TX Buffer and
 * the QPSI_TBSR[TRBFL] field is updated accordingly. On a read access, the last data written to the
 * register is returned.
 */
/*@{*/
#define BP_QUADSPI_TBDR_TXDATA         (0U)      /*!< Bit position for QUADSPI_TBDR_TXDATA. */
#define BM_QUADSPI_TBDR_TXDATA         (0xFFFFFFFFU)  /*!< Bit mask for QUADSPI_TBDR_TXDATA. */
#define BS_QUADSPI_TBDR_TXDATA         (32U)  /*!< Bitfield size in bits for QUADSPI_TBDR_TXDATA. */

/*! @brief Read current value of the QUADSPI_TBDR_TXDATA field. */
#define BR_QUADSPI_TBDR_TXDATA(x)      (HW_QUADSPI_TBDR(x).U)

/*! @brief Format value for bitfield QUADSPI_TBDR_TXDATA. */
#define BF_QUADSPI_TBDR_TXDATA(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_TBDR_TXDATA) & BM_QUADSPI_TBDR_TXDATA)

/*! @brief Set the TXDATA field to a new value. */
#define BW_QUADSPI_TBDR_TXDATA(x, v)   (HW_QUADSPI_TBDR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_TBCT - Tx Buffer Control Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_TBCT - Tx Buffer Control Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * This register contains control information for transmit data buffer-
 */
typedef union _hw_quadspi_tbct
{
    uint32_t U;
    struct _hw_quadspi_tbct_bitfields
    {
        uint32_t WMRK : 5; /*!< [4:0] For details, refer to . */
        uint32_t RESERVED0 : 27; /*!< [31:5]  */
    } B;
} hw_quadspi_tbct_t;

/*!
 * @name Constants and macros for entire QUADSPI_TBCT register
 */
/*@{*/
#define HW_QUADSPI_TBCT_ADDR(x)        ((x) + 0x158U)
#define HW_QUADSPI_TBCT(x)             (*(__IO hw_quadspi_tbct_t *) HW_QUADSPI_TBCT_ADDR(x))
#define HW_QUADSPI_TBCT_RD(x)          (HW_QUADSPI_TBCT(x).U)
#define HW_QUADSPI_TBCT_WR(x, v)       (HW_QUADSPI_TBCT(x).U = (v))
#define HW_QUADSPI_TBCT_SET(x, v)      (HW_QUADSPI_TBCT_WR(x, HW_QUADSPI_TBCT_RD(x) |  (v)))
#define HW_QUADSPI_TBCT_CLR(x, v)      (HW_QUADSPI_TBCT_WR(x, HW_QUADSPI_TBCT_RD(x) & ~(v)))
#define HW_QUADSPI_TBCT_TOG(x, v)      (HW_QUADSPI_TBCT_WR(x, HW_QUADSPI_TBCT_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_TBCT bitfields
 */

/*!
 * @name Register QUADSPI_TBCT, field WMRK[4:0] (RW)
 *
 * Determines the watermark for the TX Buffer. When the number of available space in TX Buffer is
 * greater than the number given by (WMRK+1), QSPI_SR[TXWA] is asserted. The values should be
 * entered as the number of 4Bytes entries minus 1. For example, a value of 0x0 would set the
 * watermark to 4 bytes, 1 to 8 bytes, 2 to 12 Bytes, and so on.For details, refer to .
 */
/*@{*/
#define BP_QUADSPI_TBCT_WMRK         (0U)      /*!< Bit position for QUADSPI_TBCT_WMRK. */
#define BM_QUADSPI_TBCT_WMRK         (0x0000001FU)  /*!< Bit mask for QUADSPI_TBCT_WMRK. */
#define BS_QUADSPI_TBCT_WMRK         (5U)  /*!< Bitfield size in bits for QUADSPI_TBCT_WMRK. */

/*! @brief Read current value of the QUADSPI_TBCT_WMRK field. */
#define BR_QUADSPI_TBCT_WMRK(x)   (HW_QUADSPI_TBCT(x).B.WMRK)

/*! @brief Format value for bitfield QUADSPI_TBCT_WMRK. */
#define BF_QUADSPI_TBCT_WMRK(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_TBCT_WMRK) & BM_QUADSPI_TBCT_WMRK)

/*! @brief Set the WMRK field to a new value. */
#define BW_QUADSPI_TBCT_WMRK(x, v)   (HW_QUADSPI_TBCT_WR(x, (HW_QUADSPI_TBCT_RD(x) & ~BM_QUADSPI_TBCT_WMRK) | BF_QUADSPI_TBCT_WMRK(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_SR - Status Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_SR - Status Register (RO)
 *
 * Reset value: 0x02003800U
 *
 * The QSPI_SR register provides all available status information about SFM command execution and
 * arbitration, the RX Buffer and TX Buffer and the AHB Buffer.
 */
typedef union _hw_quadspi_sr
{
    uint32_t U;
    struct _hw_quadspi_sr_bitfields
    {
        uint32_t BUSY : 1; /*!< [0] Module Busy: Asserted when module is currently busy handling a transaction to an external flash device. */
        uint32_t IP_ACC : 1; /*!< [1] IP Access: Asserted when transaction currently executed was initiated by IP bus. */
        uint32_t AHB_ACC : 1; /*!< [2] AHB Access: Asserted when the transaction currently executed was initiated by AHB bus. */
        uint32_t KEY_FET : 1; /*!< [3] Key Fetch: Asserted when OTFAD enabled and AES key fetch ongoing. */
        uint32_t RESERVED0 : 1; /*!< [4]  */
        uint32_t AHBGNT : 1; /*!< [5] AHB Command priority Granted: Asserted when another module has been granted priority of AHB Commands against IP Commands. */
        uint32_t AHBTRN : 1; /*!< [6] AHB Access Transaction pending: Asserted when there is a pending request on the AHB interface. */
        uint32_t AHB0NE : 1; /*!< [7] AHB 0 Buffer Not Empty: Asserted when AHB 0 buffer contains data. */
        uint32_t AHB1NE : 1; /*!< [8] AHB 1 Buffer Not Empty: Asserted when AHB 1 buffer contains data. */
        uint32_t AHB2NE : 1; /*!< [9] AHB 2 Buffer Not Empty: Asserted when AHB 2 buffer contains data. */
        uint32_t AHB3NE : 1; /*!< [10] AHB 3 Buffer Not Empty: Asserted when AHB 3 buffer contains data. */
        uint32_t AHB0FUL : 1; /*!< [11] AHB 0 Buffer Full: Asserted when AHB 0 buffer is full. */
        uint32_t AHB1FUL : 1; /*!< [12] AHB 1 Buffer Full: Asserted when AHB 1 buffer is full. */
        uint32_t AHB2FUL : 1; /*!< [13] AHB 2 Buffer Full: Asserted when AHB 2 buffer is full. */
        uint32_t AHB3FUL : 1; /*!< [14] AHB 3 Buffer Full: Asserted when AHB 3 buffer is full. */
        uint32_t RESERVED1 : 1; /*!< [15]  */
        uint32_t RXWE : 1; /*!< [16] RX Buffer Watermark Exceeded: Asserted when the number of valid entries in the RX Buffer exceeds the number given in the QSPI_RBCT[WMRK] field. */
        uint32_t RESERVED2 : 2; /*!< [18:17]  */
        uint32_t RXFULL : 1; /*!< [19] RX Buffer Full: Asserted when the RX Buffer is full, i.e. */
        uint32_t RESERVED3 : 3; /*!< [22:20]  */
        uint32_t RXDMA : 1; /*!< [23] RX Buffer DMA: Asserted when RX Buffer read out via DMA is active i.e DMA is requested or running. */
        uint32_t TXEDA : 1; /*!< [24] Tx Buffer Enough Data Available */
        uint32_t TXWA : 1; /*!< [25] TX Buffer watermark Available */
        uint32_t TXDMA : 1; /*!< [26] TXDMA */
        uint32_t TXFULL : 1; /*!< [27] TX Buffer Full: Asserted when no more data can be stored. */
        uint32_t RESERVED4 : 1; /*!< [28]  */
        uint32_t DLPSMP : 3; /*!< [31:29] Data learning pattern sampling point: The sampling point found by the controller with the data learning pattern. */
    } B;
} hw_quadspi_sr_t;

/*!
 * @name Constants and macros for entire QUADSPI_SR register
 */
/*@{*/
#define HW_QUADSPI_SR_ADDR(x)        ((x) + 0x15CU)
#define HW_QUADSPI_SR(x)             (*(__I  hw_quadspi_sr_t *) HW_QUADSPI_SR_ADDR(x))
#define HW_QUADSPI_SR_RD(x)          (HW_QUADSPI_SR(x).U)
/*@}*/

/*
 * Constants & macros for individual QUADSPI_SR bitfields
 */

/*!
 * @name Register QUADSPI_SR, field BUSY[0] (RO)
 *
 * Module Busy: Asserted when module is currently busy handling a transaction to an external flash
 * device.
 */
/*@{*/
#define BP_QUADSPI_SR_BUSY         (0U)      /*!< Bit position for QUADSPI_SR_BUSY. */
#define BM_QUADSPI_SR_BUSY         (0x00000001U)  /*!< Bit mask for QUADSPI_SR_BUSY. */
#define BS_QUADSPI_SR_BUSY         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_BUSY. */

/*! @brief Read current value of the QUADSPI_SR_BUSY field. */
#define BR_QUADSPI_SR_BUSY(x)   (HW_QUADSPI_SR(x).B.BUSY)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field IP_ACC[1] (RO)
 *
 * IP Access: Asserted when transaction currently executed was initiated by IP bus.
 */
/*@{*/
#define BP_QUADSPI_SR_IP_ACC         (1U)      /*!< Bit position for QUADSPI_SR_IP_ACC. */
#define BM_QUADSPI_SR_IP_ACC         (0x00000002U)  /*!< Bit mask for QUADSPI_SR_IP_ACC. */
#define BS_QUADSPI_SR_IP_ACC         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_IP_ACC. */

/*! @brief Read current value of the QUADSPI_SR_IP_ACC field. */
#define BR_QUADSPI_SR_IP_ACC(x)   (HW_QUADSPI_SR(x).B.IP_ACC)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field AHB_ACC[2] (RO)
 *
 * AHB Access: Asserted when the transaction currently executed was initiated by AHB bus.
 */
/*@{*/
#define BP_QUADSPI_SR_AHB_ACC         (2U)      /*!< Bit position for QUADSPI_SR_AHB_ACC. */
#define BM_QUADSPI_SR_AHB_ACC         (0x00000004U)  /*!< Bit mask for QUADSPI_SR_AHB_ACC. */
#define BS_QUADSPI_SR_AHB_ACC         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_AHB_ACC. */

/*! @brief Read current value of the QUADSPI_SR_AHB_ACC field. */
#define BR_QUADSPI_SR_AHB_ACC(x)   (HW_QUADSPI_SR(x).B.AHB_ACC)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field KEY_FET[3] (RO)
 *
 * Key Fetch: Asserted when OTFAD enabled and AES key fetch ongoing.
 */
/*@{*/
#define BP_QUADSPI_SR_KEY_FET         (3U)      /*!< Bit position for QUADSPI_SR_KEY_FET. */
#define BM_QUADSPI_SR_KEY_FET         (0x00000008U)  /*!< Bit mask for QUADSPI_SR_KEY_FET. */
#define BS_QUADSPI_SR_KEY_FET         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_KEY_FET. */

/*! @brief Read current value of the QUADSPI_SR_KEY_FET field. */
#define BR_QUADSPI_SR_KEY_FET(x)   (HW_QUADSPI_SR(x).B.KEY_FET)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field AHBGNT[5] (RO)
 *
 * AHB Command priority Granted: Asserted when another module has been granted priority of AHB
 * Commands against IP Commands. For details refer to Command Arbitration.
 */
/*@{*/
#define BP_QUADSPI_SR_AHBGNT         (5U)      /*!< Bit position for QUADSPI_SR_AHBGNT. */
#define BM_QUADSPI_SR_AHBGNT         (0x00000020U)  /*!< Bit mask for QUADSPI_SR_AHBGNT. */
#define BS_QUADSPI_SR_AHBGNT         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_AHBGNT. */

/*! @brief Read current value of the QUADSPI_SR_AHBGNT field. */
#define BR_QUADSPI_SR_AHBGNT(x)   (HW_QUADSPI_SR(x).B.AHBGNT)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field AHBTRN[6] (RO)
 *
 * AHB Access Transaction pending: Asserted when there is a pending request on the AHB interface.
 * Refer to the AMBA specification for details.
 */
/*@{*/
#define BP_QUADSPI_SR_AHBTRN         (6U)      /*!< Bit position for QUADSPI_SR_AHBTRN. */
#define BM_QUADSPI_SR_AHBTRN         (0x00000040U)  /*!< Bit mask for QUADSPI_SR_AHBTRN. */
#define BS_QUADSPI_SR_AHBTRN         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_AHBTRN. */

/*! @brief Read current value of the QUADSPI_SR_AHBTRN field. */
#define BR_QUADSPI_SR_AHBTRN(x)   (HW_QUADSPI_SR(x).B.AHBTRN)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field AHB0NE[7] (RO)
 *
 * AHB 0 Buffer Not Empty: Asserted when AHB 0 buffer contains data.
 */
/*@{*/
#define BP_QUADSPI_SR_AHB0NE         (7U)      /*!< Bit position for QUADSPI_SR_AHB0NE. */
#define BM_QUADSPI_SR_AHB0NE         (0x00000080U)  /*!< Bit mask for QUADSPI_SR_AHB0NE. */
#define BS_QUADSPI_SR_AHB0NE         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_AHB0NE. */

/*! @brief Read current value of the QUADSPI_SR_AHB0NE field. */
#define BR_QUADSPI_SR_AHB0NE(x)   (HW_QUADSPI_SR(x).B.AHB0NE)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field AHB1NE[8] (RO)
 *
 * AHB 1 Buffer Not Empty: Asserted when AHB 1 buffer contains data.
 */
/*@{*/
#define BP_QUADSPI_SR_AHB1NE         (8U)      /*!< Bit position for QUADSPI_SR_AHB1NE. */
#define BM_QUADSPI_SR_AHB1NE         (0x00000100U)  /*!< Bit mask for QUADSPI_SR_AHB1NE. */
#define BS_QUADSPI_SR_AHB1NE         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_AHB1NE. */

/*! @brief Read current value of the QUADSPI_SR_AHB1NE field. */
#define BR_QUADSPI_SR_AHB1NE(x)   (HW_QUADSPI_SR(x).B.AHB1NE)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field AHB2NE[9] (RO)
 *
 * AHB 2 Buffer Not Empty: Asserted when AHB 2 buffer contains data.
 */
/*@{*/
#define BP_QUADSPI_SR_AHB2NE         (9U)      /*!< Bit position for QUADSPI_SR_AHB2NE. */
#define BM_QUADSPI_SR_AHB2NE         (0x00000200U)  /*!< Bit mask for QUADSPI_SR_AHB2NE. */
#define BS_QUADSPI_SR_AHB2NE         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_AHB2NE. */

/*! @brief Read current value of the QUADSPI_SR_AHB2NE field. */
#define BR_QUADSPI_SR_AHB2NE(x)   (HW_QUADSPI_SR(x).B.AHB2NE)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field AHB3NE[10] (RO)
 *
 * AHB 3 Buffer Not Empty: Asserted when AHB 3 buffer contains data.
 */
/*@{*/
#define BP_QUADSPI_SR_AHB3NE         (10U)      /*!< Bit position for QUADSPI_SR_AHB3NE. */
#define BM_QUADSPI_SR_AHB3NE         (0x00000400U)  /*!< Bit mask for QUADSPI_SR_AHB3NE. */
#define BS_QUADSPI_SR_AHB3NE         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_AHB3NE. */

/*! @brief Read current value of the QUADSPI_SR_AHB3NE field. */
#define BR_QUADSPI_SR_AHB3NE(x)   (HW_QUADSPI_SR(x).B.AHB3NE)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field AHB0FUL[11] (RO)
 *
 * AHB 0 Buffer Full: Asserted when AHB 0 buffer is full.
 */
/*@{*/
#define BP_QUADSPI_SR_AHB0FUL         (11U)      /*!< Bit position for QUADSPI_SR_AHB0FUL. */
#define BM_QUADSPI_SR_AHB0FUL         (0x00000800U)  /*!< Bit mask for QUADSPI_SR_AHB0FUL. */
#define BS_QUADSPI_SR_AHB0FUL         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_AHB0FUL. */

/*! @brief Read current value of the QUADSPI_SR_AHB0FUL field. */
#define BR_QUADSPI_SR_AHB0FUL(x)   (HW_QUADSPI_SR(x).B.AHB0FUL)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field AHB1FUL[12] (RO)
 *
 * AHB 1 Buffer Full: Asserted when AHB 1 buffer is full.
 */
/*@{*/
#define BP_QUADSPI_SR_AHB1FUL         (12U)      /*!< Bit position for QUADSPI_SR_AHB1FUL. */
#define BM_QUADSPI_SR_AHB1FUL         (0x00001000U)  /*!< Bit mask for QUADSPI_SR_AHB1FUL. */
#define BS_QUADSPI_SR_AHB1FUL         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_AHB1FUL. */

/*! @brief Read current value of the QUADSPI_SR_AHB1FUL field. */
#define BR_QUADSPI_SR_AHB1FUL(x)   (HW_QUADSPI_SR(x).B.AHB1FUL)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field AHB2FUL[13] (RO)
 *
 * AHB 2 Buffer Full: Asserted when AHB 2 buffer is full.
 */
/*@{*/
#define BP_QUADSPI_SR_AHB2FUL         (13U)      /*!< Bit position for QUADSPI_SR_AHB2FUL. */
#define BM_QUADSPI_SR_AHB2FUL         (0x00002000U)  /*!< Bit mask for QUADSPI_SR_AHB2FUL. */
#define BS_QUADSPI_SR_AHB2FUL         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_AHB2FUL. */

/*! @brief Read current value of the QUADSPI_SR_AHB2FUL field. */
#define BR_QUADSPI_SR_AHB2FUL(x)   (HW_QUADSPI_SR(x).B.AHB2FUL)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field AHB3FUL[14] (RO)
 *
 * AHB 3 Buffer Full: Asserted when AHB 3 buffer is full.
 */
/*@{*/
#define BP_QUADSPI_SR_AHB3FUL         (14U)      /*!< Bit position for QUADSPI_SR_AHB3FUL. */
#define BM_QUADSPI_SR_AHB3FUL         (0x00004000U)  /*!< Bit mask for QUADSPI_SR_AHB3FUL. */
#define BS_QUADSPI_SR_AHB3FUL         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_AHB3FUL. */

/*! @brief Read current value of the QUADSPI_SR_AHB3FUL field. */
#define BR_QUADSPI_SR_AHB3FUL(x)   (HW_QUADSPI_SR(x).B.AHB3FUL)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field RXWE[16] (RO)
 *
 * RX Buffer Watermark Exceeded: Asserted when the number of valid entries in the RX Buffer exceeds
 * the number given in the QSPI_RBCT[WMRK] field.
 */
/*@{*/
#define BP_QUADSPI_SR_RXWE         (16U)      /*!< Bit position for QUADSPI_SR_RXWE. */
#define BM_QUADSPI_SR_RXWE         (0x00010000U)  /*!< Bit mask for QUADSPI_SR_RXWE. */
#define BS_QUADSPI_SR_RXWE         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_RXWE. */

/*! @brief Read current value of the QUADSPI_SR_RXWE field. */
#define BR_QUADSPI_SR_RXWE(x)   (HW_QUADSPI_SR(x).B.RXWE)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field RXFULL[19] (RO)
 *
 * RX Buffer Full: Asserted when the RX Buffer is full, i.e. that QSPI_RBSR[RDBFL] field is equal to
 * 32.
 */
/*@{*/
#define BP_QUADSPI_SR_RXFULL         (19U)      /*!< Bit position for QUADSPI_SR_RXFULL. */
#define BM_QUADSPI_SR_RXFULL         (0x00080000U)  /*!< Bit mask for QUADSPI_SR_RXFULL. */
#define BS_QUADSPI_SR_RXFULL         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_RXFULL. */

/*! @brief Read current value of the QUADSPI_SR_RXFULL field. */
#define BR_QUADSPI_SR_RXFULL(x)   (HW_QUADSPI_SR(x).B.RXFULL)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field RXDMA[23] (RO)
 *
 * RX Buffer DMA: Asserted when RX Buffer read out via DMA is active i.e DMA is requested or
 * running.
 */
/*@{*/
#define BP_QUADSPI_SR_RXDMA         (23U)      /*!< Bit position for QUADSPI_SR_RXDMA. */
#define BM_QUADSPI_SR_RXDMA         (0x00800000U)  /*!< Bit mask for QUADSPI_SR_RXDMA. */
#define BS_QUADSPI_SR_RXDMA         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_RXDMA. */

/*! @brief Read current value of the QUADSPI_SR_RXDMA field. */
#define BR_QUADSPI_SR_RXDMA(x)   (HW_QUADSPI_SR(x).B.RXDMA)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field TXEDA[24] (RO)
 *
 * Asserted when TX Buffer contains enough data for any pop operation to take place. There must be
 * atleast 128bit data available in TX FIFO for any pop operation otherwise QSPI_FR[TBUF] will be
 * set.
 */
/*@{*/
#define BP_QUADSPI_SR_TXEDA         (24U)      /*!< Bit position for QUADSPI_SR_TXEDA. */
#define BM_QUADSPI_SR_TXEDA         (0x01000000U)  /*!< Bit mask for QUADSPI_SR_TXEDA. */
#define BS_QUADSPI_SR_TXEDA         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_TXEDA. */

/*! @brief Read current value of the QUADSPI_SR_TXEDA field. */
#define BR_QUADSPI_SR_TXEDA(x)   (HW_QUADSPI_SR(x).B.TXEDA)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field TXWA[25] (RO)
 *
 * Asserted when the number of available spaces in TX buffer is greater than or equal to the value
 * give by QSPI_TBCT[WMRK].
 */
/*@{*/
#define BP_QUADSPI_SR_TXWA         (25U)      /*!< Bit position for QUADSPI_SR_TXWA. */
#define BM_QUADSPI_SR_TXWA         (0x02000000U)  /*!< Bit mask for QUADSPI_SR_TXWA. */
#define BS_QUADSPI_SR_TXWA         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_TXWA. */

/*! @brief Read current value of the QUADSPI_SR_TXWA field. */
#define BR_QUADSPI_SR_TXWA(x)   (HW_QUADSPI_SR(x).B.TXWA)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field TXDMA[26] (RO)
 *
 * Asserted when TXFIFO fill via DMA is active i.e. DMA is requested or running
 */
/*@{*/
#define BP_QUADSPI_SR_TXDMA         (26U)      /*!< Bit position for QUADSPI_SR_TXDMA. */
#define BM_QUADSPI_SR_TXDMA         (0x04000000U)  /*!< Bit mask for QUADSPI_SR_TXDMA. */
#define BS_QUADSPI_SR_TXDMA         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_TXDMA. */

/*! @brief Read current value of the QUADSPI_SR_TXDMA field. */
#define BR_QUADSPI_SR_TXDMA(x)   (HW_QUADSPI_SR(x).B.TXDMA)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field TXFULL[27] (RO)
 *
 * TX Buffer Full: Asserted when no more data can be stored.
 */
/*@{*/
#define BP_QUADSPI_SR_TXFULL         (27U)      /*!< Bit position for QUADSPI_SR_TXFULL. */
#define BM_QUADSPI_SR_TXFULL         (0x08000000U)  /*!< Bit mask for QUADSPI_SR_TXFULL. */
#define BS_QUADSPI_SR_TXFULL         (1U)  /*!< Bitfield size in bits for QUADSPI_SR_TXFULL. */

/*! @brief Read current value of the QUADSPI_SR_TXFULL field. */
#define BR_QUADSPI_SR_TXFULL(x)   (HW_QUADSPI_SR(x).B.TXFULL)
/*@}*/

/*!
 * @name Register QUADSPI_SR, field DLPSMP[31:29] (RO)
 *
 * Data learning pattern sampling point: The sampling point found by the controller with the data
 * learning pattern. This is used for DDR only.If the learning fails, this field will return garbage
 * and DLPFF bit will be set.In case of Data learning with DQS this field will return the reset
 * value as sampling point match is not found in case of DQS.For details, refer to .
 */
/*@{*/
#define BP_QUADSPI_SR_DLPSMP         (29U)      /*!< Bit position for QUADSPI_SR_DLPSMP. */
#define BM_QUADSPI_SR_DLPSMP         (0xE0000000U)  /*!< Bit mask for QUADSPI_SR_DLPSMP. */
#define BS_QUADSPI_SR_DLPSMP         (3U)  /*!< Bitfield size in bits for QUADSPI_SR_DLPSMP. */

/*! @brief Read current value of the QUADSPI_SR_DLPSMP field. */
#define BR_QUADSPI_SR_DLPSMP(x)   (HW_QUADSPI_SR(x).B.DLPSMP)
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_FR - Flag Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_FR - Flag Register (W1C)
 *
 * Reset value: 0x08000000U
 *
 * The QSPI_FR register provides all available flags about SFM command execution and arbitration
 * which may serve as source for the generation of interrupt service requests. Note that the error
 * flags in this register do not relate directly to the execution of the transaction in the serial
 * flash device itself but only to the behavior and conditions visible in the QuadSPI module.
 * Write:Enabled Mode
 */
typedef union _hw_quadspi_fr
{
    uint32_t U;
    struct _hw_quadspi_fr_bitfields
    {
        uint32_t TFF : 1; /*!< [0] IP Command Transaction Finished Flag: Set when the QuadSPI module has finished a running IP Command. */
        uint32_t RESERVED0 : 3; /*!< [3:1]  */
        uint32_t IPGEF : 1; /*!< [4] IP Command Trigger during AHB Grant Error Flag: Set when the following condition occurs: */
        uint32_t RESERVED1 : 1; /*!< [5]  */
        uint32_t IPIEF : 1; /*!< [6] IP Command Trigger could not be executed Error Flag. */
        uint32_t IPAEF : 1; /*!< [7] IP Command Trigger during AHB Access Error Flag. */
        uint32_t RESERVED2 : 3; /*!< [10:8]  */
        uint32_t IUEF : 1; /*!< [11] IP Command Usage Error Flag: Set when in parallel flash mode the execution of an IP Command is started with more than one pad enabled and the sequence pointed to by the sequence ID contains a WRITE or a WRITE_DDR command. */
        uint32_t ABOF : 1; /*!< [12] AHB Buffer Overflow Flag: Set when the size of the AHB access exceeds the size of the AHB buffer. */
        uint32_t AIBSEF : 1; /*!< [13] AHB Illegal Burst Size Error Flag: Set whenever the total burst size(size x beat) of an AHB transaction is greater than the prefetch data size. */
        uint32_t AITEF : 1; /*!< [14] AHB Illegal transaction error flag.Set whenever there is no response generated from QSPI to AHB bus in case of illegal transaction and the watchdog timer expires.The timer value is taken as parameter. */
        uint32_t ABSEF : 1; /*!< [15] AHB Sequence Error Flag: Set when the execution of an AHB Command is started with an WRITE or WRITE_DDR Command in the sequence pointed to by the QSPI_BUFxCR QSPI_BUFxCR implies anyone of QSPI_BUF0CR/QSPI_BUF1CR/QSPI_BUF2CR/QSPI_BUF3CR register */
        uint32_t RBDF : 1; /*!< [16] RX Buffer Drain Flag: Will be set if the QuadSPI_SR[RXWE] status bit is asserted. */
        uint32_t RBOF : 1; /*!< [17] RX Buffer Overflow Flag: Set when not all the data read from the serial flash device could be pushed into the RX Buffer. */
        uint32_t RESERVED3 : 5; /*!< [22:18]  */
        uint32_t ILLINE : 1; /*!< [23] Illegal Instruction Error Flag: Set when an illegal instruction is encountered by the controller in any of the sequences. */
        uint32_t RESERVED4 : 2; /*!< [25:24]  */
        uint32_t TBUF : 1; /*!< [26] TX Buffer Underrun Flag: Set when the module tried to pull data although TX Buffer was emptyor the buffer contains less than 128bits of data. */
        uint32_t TBFF : 1; /*!< [27] TX Buffer Fill Flag: Before writing to the TX buffer, this bit should be cleared. */
        uint32_t RESERVED5 : 1; /*!< [28]  */
        uint32_t KFEF : 1; /*!< [29] Key Fetch Error Flag */
        uint32_t IAKFEF : 1; /*!< [30] Illegal Access during Key Fetch Error Flag: Set when the ahb access occurs when OTFAD fey blobs are being read from the flash via the QuadSPI and QSPI_SR[KEY_FET] is set. */
        uint32_t DLPFF : 1; /*!< [31] Data Learning Pattern Failure Flag: Set when DATA_LEARN instruction was encountered in a sequence but no sampling point was found for the data learning patternin case only 8 bit data learning is requested for non DQS mode. */
    } B;
} hw_quadspi_fr_t;

/*!
 * @name Constants and macros for entire QUADSPI_FR register
 */
/*@{*/
#define HW_QUADSPI_FR_ADDR(x)        ((x) + 0x160U)
#define HW_QUADSPI_FR(x)             (*(__IO hw_quadspi_fr_t *) HW_QUADSPI_FR_ADDR(x))
#define HW_QUADSPI_FR_RD(x)          (HW_QUADSPI_FR(x).U)
#define HW_QUADSPI_FR_WR(x, v)       (HW_QUADSPI_FR(x).U = (v))
#define HW_QUADSPI_FR_SET(x, v)      (HW_QUADSPI_FR_WR(x, HW_QUADSPI_FR_RD(x) |  (v)))
#define HW_QUADSPI_FR_CLR(x, v)      (HW_QUADSPI_FR_WR(x, HW_QUADSPI_FR_RD(x) & ~(v)))
#define HW_QUADSPI_FR_TOG(x, v)      (HW_QUADSPI_FR_WR(x, HW_QUADSPI_FR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_FR bitfields
 */

/*!
 * @name Register QUADSPI_FR, field TFF[0] (W1C)
 *
 * IP Command Transaction Finished Flag: Set when the QuadSPI module has finished a running IP
 * Command. If an error occurred the related error flags are valid, at the latest, in the same clock
 * cycle when the TFF flag is asserted.
 */
/*@{*/
#define BP_QUADSPI_FR_TFF         (0U)      /*!< Bit position for QUADSPI_FR_TFF. */
#define BM_QUADSPI_FR_TFF         (0x00000001U)  /*!< Bit mask for QUADSPI_FR_TFF. */
#define BS_QUADSPI_FR_TFF         (1U)  /*!< Bitfield size in bits for QUADSPI_FR_TFF. */

/*! @brief Read current value of the QUADSPI_FR_TFF field. */
#define BR_QUADSPI_FR_TFF(x)   (HW_QUADSPI_FR(x).B.TFF)

/*! @brief Format value for bitfield QUADSPI_FR_TFF. */
#define BF_QUADSPI_FR_TFF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FR_TFF) & BM_QUADSPI_FR_TFF)

/*! @brief Set the TFF field to a new value. */
#define BW_QUADSPI_FR_TFF(x, v)   (HW_QUADSPI_FR_WR(x, (HW_QUADSPI_FR_RD(x) & ~BM_QUADSPI_FR_TFF) | BF_QUADSPI_FR_TFF(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FR, field IPGEF[4] (W1C)
 *
 * IP Command Trigger during AHB Grant Error Flag: Set when the following condition occurs: A write
 * access occurs to the QSPI_IPCR[SEQID] field and the QSPI_SR[AHBGNT] bit is set. Any command
 * leading to the assertion of the IPGEF flag is ignored.
 */
/*@{*/
#define BP_QUADSPI_FR_IPGEF         (4U)      /*!< Bit position for QUADSPI_FR_IPGEF. */
#define BM_QUADSPI_FR_IPGEF         (0x00000010U)  /*!< Bit mask for QUADSPI_FR_IPGEF. */
#define BS_QUADSPI_FR_IPGEF         (1U)  /*!< Bitfield size in bits for QUADSPI_FR_IPGEF. */

/*! @brief Read current value of the QUADSPI_FR_IPGEF field. */
#define BR_QUADSPI_FR_IPGEF(x)   (HW_QUADSPI_FR(x).B.IPGEF)

/*! @brief Format value for bitfield QUADSPI_FR_IPGEF. */
#define BF_QUADSPI_FR_IPGEF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FR_IPGEF) & BM_QUADSPI_FR_IPGEF)

/*! @brief Set the IPGEF field to a new value. */
#define BW_QUADSPI_FR_IPGEF(x, v)   (HW_QUADSPI_FR_WR(x, (HW_QUADSPI_FR_RD(x) & ~BM_QUADSPI_FR_IPGEF) | BF_QUADSPI_FR_IPGEF(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FR, field IPIEF[6] (W1C)
 *
 * IP Command Trigger could not be executed Error Flag. Set when the QSPI_SR[IP_ACC] bit is set
 * (i.e. an IP triggered command is currently executing) and any of the following conditions occurs:
 * Write access to the QSPI_IPCR register. Any command leading to the assertion of the IPIEF flag is
 * ignored Write access to the QSPI_SFAR register. Write access to the QSPI_RBCT register.
 */
/*@{*/
#define BP_QUADSPI_FR_IPIEF         (6U)      /*!< Bit position for QUADSPI_FR_IPIEF. */
#define BM_QUADSPI_FR_IPIEF         (0x00000040U)  /*!< Bit mask for QUADSPI_FR_IPIEF. */
#define BS_QUADSPI_FR_IPIEF         (1U)  /*!< Bitfield size in bits for QUADSPI_FR_IPIEF. */

/*! @brief Read current value of the QUADSPI_FR_IPIEF field. */
#define BR_QUADSPI_FR_IPIEF(x)   (HW_QUADSPI_FR(x).B.IPIEF)

/*! @brief Format value for bitfield QUADSPI_FR_IPIEF. */
#define BF_QUADSPI_FR_IPIEF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FR_IPIEF) & BM_QUADSPI_FR_IPIEF)

/*! @brief Set the IPIEF field to a new value. */
#define BW_QUADSPI_FR_IPIEF(x, v)   (HW_QUADSPI_FR_WR(x, (HW_QUADSPI_FR_RD(x) & ~BM_QUADSPI_FR_IPIEF) | BF_QUADSPI_FR_IPIEF(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FR, field IPAEF[7] (W1C)
 *
 * IP Command Trigger during AHB Access Error Flag. Set when the following condition occurs: A write
 * access occurs to the QSPI_IPCR[SEQID] field and the QSPI_SR[AHB_ACC] bit is set. Any command
 * leading to the assertion of the IPAEF flag is ignored.
 */
/*@{*/
#define BP_QUADSPI_FR_IPAEF         (7U)      /*!< Bit position for QUADSPI_FR_IPAEF. */
#define BM_QUADSPI_FR_IPAEF         (0x00000080U)  /*!< Bit mask for QUADSPI_FR_IPAEF. */
#define BS_QUADSPI_FR_IPAEF         (1U)  /*!< Bitfield size in bits for QUADSPI_FR_IPAEF. */

/*! @brief Read current value of the QUADSPI_FR_IPAEF field. */
#define BR_QUADSPI_FR_IPAEF(x)   (HW_QUADSPI_FR(x).B.IPAEF)

/*! @brief Format value for bitfield QUADSPI_FR_IPAEF. */
#define BF_QUADSPI_FR_IPAEF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FR_IPAEF) & BM_QUADSPI_FR_IPAEF)

/*! @brief Set the IPAEF field to a new value. */
#define BW_QUADSPI_FR_IPAEF(x, v)   (HW_QUADSPI_FR_WR(x, (HW_QUADSPI_FR_RD(x) & ~BM_QUADSPI_FR_IPAEF) | BF_QUADSPI_FR_IPAEF(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FR, field IUEF[11] (W1C)
 *
 * IP Command Usage Error Flag: Set when in parallel flash mode the execution of an IP Command is
 * started with more than one pad enabled and the sequence pointed to by the sequence ID contains a
 * WRITE or a WRITE_DDR command. Refer to table for the related commands. Communication with the
 * serial flash device is terminated before the execution of WRITE/WRITE_DDR command by the QuadSPI
 * module.
 */
/*@{*/
#define BP_QUADSPI_FR_IUEF         (11U)      /*!< Bit position for QUADSPI_FR_IUEF. */
#define BM_QUADSPI_FR_IUEF         (0x00000800U)  /*!< Bit mask for QUADSPI_FR_IUEF. */
#define BS_QUADSPI_FR_IUEF         (1U)  /*!< Bitfield size in bits for QUADSPI_FR_IUEF. */

/*! @brief Read current value of the QUADSPI_FR_IUEF field. */
#define BR_QUADSPI_FR_IUEF(x)   (HW_QUADSPI_FR(x).B.IUEF)

/*! @brief Format value for bitfield QUADSPI_FR_IUEF. */
#define BF_QUADSPI_FR_IUEF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FR_IUEF) & BM_QUADSPI_FR_IUEF)

/*! @brief Set the IUEF field to a new value. */
#define BW_QUADSPI_FR_IUEF(x, v)   (HW_QUADSPI_FR_WR(x, (HW_QUADSPI_FR_RD(x) & ~BM_QUADSPI_FR_IUEF) | BF_QUADSPI_FR_IUEF(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FR, field ABOF[12] (W1C)
 *
 * AHB Buffer Overflow Flag: Set when the size of the AHB access exceeds the size of the AHB buffer.
 * This condition can occur only if the QSPI_BUFxCR[ADATSZ] field is programmed incorrectly. The AHB
 * Command leading to this condition is continued until the number of entries according to the
 * QSPI_BUFxCR[ADATSZ] field has been read from the serial flash device. The content of the AHB
 * Buffer is not changed.
 */
/*@{*/
#define BP_QUADSPI_FR_ABOF         (12U)      /*!< Bit position for QUADSPI_FR_ABOF. */
#define BM_QUADSPI_FR_ABOF         (0x00001000U)  /*!< Bit mask for QUADSPI_FR_ABOF. */
#define BS_QUADSPI_FR_ABOF         (1U)  /*!< Bitfield size in bits for QUADSPI_FR_ABOF. */

/*! @brief Read current value of the QUADSPI_FR_ABOF field. */
#define BR_QUADSPI_FR_ABOF(x)   (HW_QUADSPI_FR(x).B.ABOF)

/*! @brief Format value for bitfield QUADSPI_FR_ABOF. */
#define BF_QUADSPI_FR_ABOF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FR_ABOF) & BM_QUADSPI_FR_ABOF)

/*! @brief Set the ABOF field to a new value. */
#define BW_QUADSPI_FR_ABOF(x, v)   (HW_QUADSPI_FR_WR(x, (HW_QUADSPI_FR_RD(x) & ~BM_QUADSPI_FR_ABOF) | BF_QUADSPI_FR_ABOF(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FR, field AIBSEF[13] (W1C)
 *
 * AHB Illegal Burst Size Error Flag: Set whenever the total burst size(size x beat) of an AHB
 * transaction is greater than the prefetch data size. The prefecth data size is defined by
 * QSPI_BUFxCR[ADATSZ] or data size mentioned in the sequence pointed to by the SEQID field in case
 * ADATSZ =0. Refer to for more details on hburst feature.
 */
/*@{*/
#define BP_QUADSPI_FR_AIBSEF         (13U)      /*!< Bit position for QUADSPI_FR_AIBSEF. */
#define BM_QUADSPI_FR_AIBSEF         (0x00002000U)  /*!< Bit mask for QUADSPI_FR_AIBSEF. */
#define BS_QUADSPI_FR_AIBSEF         (1U)  /*!< Bitfield size in bits for QUADSPI_FR_AIBSEF. */

/*! @brief Read current value of the QUADSPI_FR_AIBSEF field. */
#define BR_QUADSPI_FR_AIBSEF(x)   (HW_QUADSPI_FR(x).B.AIBSEF)

/*! @brief Format value for bitfield QUADSPI_FR_AIBSEF. */
#define BF_QUADSPI_FR_AIBSEF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FR_AIBSEF) & BM_QUADSPI_FR_AIBSEF)

/*! @brief Set the AIBSEF field to a new value. */
#define BW_QUADSPI_FR_AIBSEF(x, v)   (HW_QUADSPI_FR_WR(x, (HW_QUADSPI_FR_RD(x) & ~BM_QUADSPI_FR_AIBSEF) | BF_QUADSPI_FR_AIBSEF(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FR, field AITEF[14] (W1C)
 *
 * AHB Illegal transaction error flag.Set whenever there is no response generated from QSPI to AHB
 * bus in case of illegal transaction and the watchdog timer expires.The timer value is taken as
 * parameter.
 */
/*@{*/
#define BP_QUADSPI_FR_AITEF         (14U)      /*!< Bit position for QUADSPI_FR_AITEF. */
#define BM_QUADSPI_FR_AITEF         (0x00004000U)  /*!< Bit mask for QUADSPI_FR_AITEF. */
#define BS_QUADSPI_FR_AITEF         (1U)  /*!< Bitfield size in bits for QUADSPI_FR_AITEF. */

/*! @brief Read current value of the QUADSPI_FR_AITEF field. */
#define BR_QUADSPI_FR_AITEF(x)   (HW_QUADSPI_FR(x).B.AITEF)

/*! @brief Format value for bitfield QUADSPI_FR_AITEF. */
#define BF_QUADSPI_FR_AITEF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FR_AITEF) & BM_QUADSPI_FR_AITEF)

/*! @brief Set the AITEF field to a new value. */
#define BW_QUADSPI_FR_AITEF(x, v)   (HW_QUADSPI_FR_WR(x, (HW_QUADSPI_FR_RD(x) & ~BM_QUADSPI_FR_AITEF) | BF_QUADSPI_FR_AITEF(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FR, field ABSEF[15] (W1C)
 *
 * AHB Sequence Error Flag: Set when the execution of an AHB Command is started with an WRITE or
 * WRITE_DDR Command in the sequence pointed to by the QSPI_BUFxCR QSPI_BUFxCR implies anyone of
 * QSPI_BUF0CR/QSPI_BUF1CR/QSPI_BUF2CR/QSPI_BUF3CR register Communication with the serial flash
 * device is terminated before the execution of WRITE/WRITE_DDR command by the QuadSPI module. The
 * AHB bus request which triggered this command is answered with an ERROR response.
 */
/*@{*/
#define BP_QUADSPI_FR_ABSEF         (15U)      /*!< Bit position for QUADSPI_FR_ABSEF. */
#define BM_QUADSPI_FR_ABSEF         (0x00008000U)  /*!< Bit mask for QUADSPI_FR_ABSEF. */
#define BS_QUADSPI_FR_ABSEF         (1U)  /*!< Bitfield size in bits for QUADSPI_FR_ABSEF. */

/*! @brief Read current value of the QUADSPI_FR_ABSEF field. */
#define BR_QUADSPI_FR_ABSEF(x)   (HW_QUADSPI_FR(x).B.ABSEF)

/*! @brief Format value for bitfield QUADSPI_FR_ABSEF. */
#define BF_QUADSPI_FR_ABSEF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FR_ABSEF) & BM_QUADSPI_FR_ABSEF)

/*! @brief Set the ABSEF field to a new value. */
#define BW_QUADSPI_FR_ABSEF(x, v)   (HW_QUADSPI_FR_WR(x, (HW_QUADSPI_FR_RD(x) & ~BM_QUADSPI_FR_ABSEF) | BF_QUADSPI_FR_ABSEF(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FR, field RBDF[16] (W1C)
 *
 * RX Buffer Drain Flag: Will be set if the QuadSPI_SR[RXWE] status bit is asserted. Writing 1 into
 * this bit triggers one of the following actions: If the RX Buffer has up to QuadSPI_RBCT[WMRK]
 * valid entries then the flag is cleared. If the RX Buffer has more than QuadSPI_RBCT[WMRK] valid
 * entries and the QuadSPI_RSER[RBDDE] bit is not set (flag driven mode) a RX Buffer POP event is
 * triggered. The flag remains set if the RX Buffer contains more than QuadSPI_RBCT[WMRK] valid
 * entries after the RX Buffer POP event is finished. The flag is cleared if the RX Buffer contains
 * less than or equal to QuadSPI_RBCT[WMRK] valid entries after the RX Buffer POP event is finished.
 * Refer to "Receive Buffer Drain Interrupt or DMA Request" section in Normal Mode Interrupt and DMA
 * Requests, for details.
 */
/*@{*/
#define BP_QUADSPI_FR_RBDF         (16U)      /*!< Bit position for QUADSPI_FR_RBDF. */
#define BM_QUADSPI_FR_RBDF         (0x00010000U)  /*!< Bit mask for QUADSPI_FR_RBDF. */
#define BS_QUADSPI_FR_RBDF         (1U)  /*!< Bitfield size in bits for QUADSPI_FR_RBDF. */

/*! @brief Read current value of the QUADSPI_FR_RBDF field. */
#define BR_QUADSPI_FR_RBDF(x)   (HW_QUADSPI_FR(x).B.RBDF)

/*! @brief Format value for bitfield QUADSPI_FR_RBDF. */
#define BF_QUADSPI_FR_RBDF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FR_RBDF) & BM_QUADSPI_FR_RBDF)

/*! @brief Set the RBDF field to a new value. */
#define BW_QUADSPI_FR_RBDF(x, v)   (HW_QUADSPI_FR_WR(x, (HW_QUADSPI_FR_RD(x) & ~BM_QUADSPI_FR_RBDF) | BF_QUADSPI_FR_RBDF(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FR, field RBOF[17] (W1C)
 *
 * RX Buffer Overflow Flag: Set when not all the data read from the serial flash device could be
 * pushed into the RX Buffer. The IP Command leading to this condition is continued until the number
 * of bytes according to the QSPI_IPCR[IDATSZ] field has been read from the serial flash device. The
 * content of the RX Buffer is not changed.
 */
/*@{*/
#define BP_QUADSPI_FR_RBOF         (17U)      /*!< Bit position for QUADSPI_FR_RBOF. */
#define BM_QUADSPI_FR_RBOF         (0x00020000U)  /*!< Bit mask for QUADSPI_FR_RBOF. */
#define BS_QUADSPI_FR_RBOF         (1U)  /*!< Bitfield size in bits for QUADSPI_FR_RBOF. */

/*! @brief Read current value of the QUADSPI_FR_RBOF field. */
#define BR_QUADSPI_FR_RBOF(x)   (HW_QUADSPI_FR(x).B.RBOF)

/*! @brief Format value for bitfield QUADSPI_FR_RBOF. */
#define BF_QUADSPI_FR_RBOF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FR_RBOF) & BM_QUADSPI_FR_RBOF)

/*! @brief Set the RBOF field to a new value. */
#define BW_QUADSPI_FR_RBOF(x, v)   (HW_QUADSPI_FR_WR(x, (HW_QUADSPI_FR_RD(x) & ~BM_QUADSPI_FR_RBOF) | BF_QUADSPI_FR_RBOF(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FR, field ILLINE[23] (W1C)
 *
 * Illegal Instruction Error Flag: Set when an illegal instruction is encountered by the controller
 * in any of the sequences. Refer to for a list of legal instructions.
 */
/*@{*/
#define BP_QUADSPI_FR_ILLINE         (23U)      /*!< Bit position for QUADSPI_FR_ILLINE. */
#define BM_QUADSPI_FR_ILLINE         (0x00800000U)  /*!< Bit mask for QUADSPI_FR_ILLINE. */
#define BS_QUADSPI_FR_ILLINE         (1U)  /*!< Bitfield size in bits for QUADSPI_FR_ILLINE. */

/*! @brief Read current value of the QUADSPI_FR_ILLINE field. */
#define BR_QUADSPI_FR_ILLINE(x)   (HW_QUADSPI_FR(x).B.ILLINE)

/*! @brief Format value for bitfield QUADSPI_FR_ILLINE. */
#define BF_QUADSPI_FR_ILLINE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FR_ILLINE) & BM_QUADSPI_FR_ILLINE)

/*! @brief Set the ILLINE field to a new value. */
#define BW_QUADSPI_FR_ILLINE(x, v)   (HW_QUADSPI_FR_WR(x, (HW_QUADSPI_FR_RD(x) & ~BM_QUADSPI_FR_ILLINE) | BF_QUADSPI_FR_ILLINE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FR, field TBUF[26] (W1C)
 *
 * TX Buffer Underrun Flag: Set when the module tried to pull data although TX Buffer was emptyor
 * the buffer contains less than 128bits of data. The application must ensure that the buffer never
 * goes empty during a transaction expect for the last data fetch. The IP Command leading to the TX
 * Buffer underrun is continued (data sent to the serial flash device is all F in case of valid tx
 * underrun. The application must clear the TX Buffer in response to this event by writing a 1 into
 * the QSPI_MCR[CLR_TXF] bit.
 */
/*@{*/
#define BP_QUADSPI_FR_TBUF         (26U)      /*!< Bit position for QUADSPI_FR_TBUF. */
#define BM_QUADSPI_FR_TBUF         (0x04000000U)  /*!< Bit mask for QUADSPI_FR_TBUF. */
#define BS_QUADSPI_FR_TBUF         (1U)  /*!< Bitfield size in bits for QUADSPI_FR_TBUF. */

/*! @brief Read current value of the QUADSPI_FR_TBUF field. */
#define BR_QUADSPI_FR_TBUF(x)   (HW_QUADSPI_FR(x).B.TBUF)

/*! @brief Format value for bitfield QUADSPI_FR_TBUF. */
#define BF_QUADSPI_FR_TBUF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FR_TBUF) & BM_QUADSPI_FR_TBUF)

/*! @brief Set the TBUF field to a new value. */
#define BW_QUADSPI_FR_TBUF(x, v)   (HW_QUADSPI_FR_WR(x, (HW_QUADSPI_FR_RD(x) & ~BM_QUADSPI_FR_TBUF) | BF_QUADSPI_FR_TBUF(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FR, field TBFF[27] (W1C)
 *
 * TX Buffer Fill Flag: Before writing to the TX buffer, this bit should be cleared. Then this bit
 * has to be read back. If the bit is set, the TX Buffer can take more data. If the bit remains
 * cleared, the TX buffer is full. Refer to Tx Buffer Operation for details.
 */
/*@{*/
#define BP_QUADSPI_FR_TBFF         (27U)      /*!< Bit position for QUADSPI_FR_TBFF. */
#define BM_QUADSPI_FR_TBFF         (0x08000000U)  /*!< Bit mask for QUADSPI_FR_TBFF. */
#define BS_QUADSPI_FR_TBFF         (1U)  /*!< Bitfield size in bits for QUADSPI_FR_TBFF. */

/*! @brief Read current value of the QUADSPI_FR_TBFF field. */
#define BR_QUADSPI_FR_TBFF(x)   (HW_QUADSPI_FR(x).B.TBFF)

/*! @brief Format value for bitfield QUADSPI_FR_TBFF. */
#define BF_QUADSPI_FR_TBFF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FR_TBFF) & BM_QUADSPI_FR_TBFF)

/*! @brief Set the TBFF field to a new value. */
#define BW_QUADSPI_FR_TBFF(x, v)   (HW_QUADSPI_FR_WR(x, (HW_QUADSPI_FR_RD(x) & ~BM_QUADSPI_FR_TBFF) | BF_QUADSPI_FR_TBFF(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FR, field KFEF[29] (W1C)
 *
 * Set when there is an error in key blob fetch.
 */
/*@{*/
#define BP_QUADSPI_FR_KFEF         (29U)      /*!< Bit position for QUADSPI_FR_KFEF. */
#define BM_QUADSPI_FR_KFEF         (0x20000000U)  /*!< Bit mask for QUADSPI_FR_KFEF. */
#define BS_QUADSPI_FR_KFEF         (1U)  /*!< Bitfield size in bits for QUADSPI_FR_KFEF. */

/*! @brief Read current value of the QUADSPI_FR_KFEF field. */
#define BR_QUADSPI_FR_KFEF(x)   (HW_QUADSPI_FR(x).B.KFEF)

/*! @brief Format value for bitfield QUADSPI_FR_KFEF. */
#define BF_QUADSPI_FR_KFEF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FR_KFEF) & BM_QUADSPI_FR_KFEF)

/*! @brief Set the KFEF field to a new value. */
#define BW_QUADSPI_FR_KFEF(x, v)   (HW_QUADSPI_FR_WR(x, (HW_QUADSPI_FR_RD(x) & ~BM_QUADSPI_FR_KFEF) | BF_QUADSPI_FR_KFEF(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FR, field IAKFEF[30] (W1C)
 *
 * Illegal Access during Key Fetch Error Flag: Set when the ahb access occurs when OTFAD fey blobs
 * are being read from the flash via the QuadSPI and QSPI_SR[KEY_FET] is set.
 */
/*@{*/
#define BP_QUADSPI_FR_IAKFEF         (30U)      /*!< Bit position for QUADSPI_FR_IAKFEF. */
#define BM_QUADSPI_FR_IAKFEF         (0x40000000U)  /*!< Bit mask for QUADSPI_FR_IAKFEF. */
#define BS_QUADSPI_FR_IAKFEF         (1U)  /*!< Bitfield size in bits for QUADSPI_FR_IAKFEF. */

/*! @brief Read current value of the QUADSPI_FR_IAKFEF field. */
#define BR_QUADSPI_FR_IAKFEF(x)   (HW_QUADSPI_FR(x).B.IAKFEF)

/*! @brief Format value for bitfield QUADSPI_FR_IAKFEF. */
#define BF_QUADSPI_FR_IAKFEF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FR_IAKFEF) & BM_QUADSPI_FR_IAKFEF)

/*! @brief Set the IAKFEF field to a new value. */
#define BW_QUADSPI_FR_IAKFEF(x, v)   (HW_QUADSPI_FR_WR(x, (HW_QUADSPI_FR_RD(x) & ~BM_QUADSPI_FR_IAKFEF) | BF_QUADSPI_FR_IAKFEF(v)))
/*@}*/

/*!
 * @name Register QUADSPI_FR, field DLPFF[31] (W1C)
 *
 * Data Learning Pattern Failure Flag: Set when DATA_LEARN instruction was encountered in a sequence
 * but no sampling point was found for the data learning patternin case only 8 bit data learning is
 * requested for non DQS mode. The controller automatically starts sampling using the value in
 * QSPI_SMPR[DDRSMP]. If more than 8 bits data learning are requested with QSPI_MCR[DQS_EN] set to
 * 0, and the sampling point found after first 8 bit match doesn't remain same for the whole
 * instruction duration, this flag is set. In case of Data learn with DQS this flag is set whenever
 * the incoming data from flash on DQS edges doesn't match the pattern in QSPI_DLPR. For details,
 * refer to .
 */
/*@{*/
#define BP_QUADSPI_FR_DLPFF         (31U)      /*!< Bit position for QUADSPI_FR_DLPFF. */
#define BM_QUADSPI_FR_DLPFF         (0x80000000U)  /*!< Bit mask for QUADSPI_FR_DLPFF. */
#define BS_QUADSPI_FR_DLPFF         (1U)  /*!< Bitfield size in bits for QUADSPI_FR_DLPFF. */

/*! @brief Read current value of the QUADSPI_FR_DLPFF field. */
#define BR_QUADSPI_FR_DLPFF(x)   (HW_QUADSPI_FR(x).B.DLPFF)

/*! @brief Format value for bitfield QUADSPI_FR_DLPFF. */
#define BF_QUADSPI_FR_DLPFF(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_FR_DLPFF) & BM_QUADSPI_FR_DLPFF)

/*! @brief Set the DLPFF field to a new value. */
#define BW_QUADSPI_FR_DLPFF(x, v)   (HW_QUADSPI_FR_WR(x, (HW_QUADSPI_FR_RD(x) & ~BM_QUADSPI_FR_DLPFF) | BF_QUADSPI_FR_DLPFF(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_RSER - Interrupt and DMA Request Select and Enable Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_RSER - Interrupt and DMA Request Select and Enable Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QuadSPI_RSER register provides enables and selectors for the interrupts in the QuadSPI
 * module. Each flag of the QuadSPI_FR register enabled as source for an interrupt prevents the
 * QuadSPI module from entering Stop Mode or Module Disable Mode when this flag is
 * set.>Write:Anytime
 */
typedef union _hw_quadspi_rser
{
    uint32_t U;
    struct _hw_quadspi_rser_bitfields
    {
        uint32_t TFIE : 1; /*!< [0] Transaction Finished Interrupt Enable */
        uint32_t RESERVED0 : 3; /*!< [3:1] Reserved. */
        uint32_t IPGEIE : 1; /*!< [4] IP Command Trigger during AHB Grant Error Interrupt Enable */
        uint32_t RESERVED1 : 1; /*!< [5]  */
        uint32_t IPIEIE : 1; /*!< [6] IP Command Trigger during IP Access Error Interrupt Enable */
        uint32_t IPAEIE : 1; /*!< [7] IP Command Trigger during AHB Access Error Interrupt Enable */
        uint32_t RESERVED2 : 3; /*!< [10:8]  */
        uint32_t IUEIE : 1; /*!< [11] IP Command Usage Error Interrupt Enable */
        uint32_t ABOIE : 1; /*!< [12] AHB Buffer Overflow Interrupt Enable */
        uint32_t AIBSIE : 1; /*!< [13] AHB Illegal Burst Size Interrupt Enable */
        uint32_t AITIE : 1; /*!< [14] AHB Illegal transaction interrupt enable. */
        uint32_t ABSEIE : 1; /*!< [15] AHB Sequence Error Interrupt Enable: Triggered by ABSEF flags of QSPI_FR */
        uint32_t RBDIE : 1; /*!< [16] RX Buffer Drain Interrupt Enable: Enables generation of IRQ requests for RX Buffer Drain. */
        uint32_t RBOIE : 1; /*!< [17] RX Buffer Overflow Interrupt Enable */
        uint32_t RESERVED3 : 3; /*!< [20:18]  */
        uint32_t RBDDE : 1; /*!< [21] RX Buffer Drain DMA Enable: Enables generation of DMA requests for RX Buffer Drain. */
        uint32_t RESERVED4 : 1; /*!< [22]  */
        uint32_t ILLINIE : 1; /*!< [23] Illegal Instruction Error Interrupt Enable. */
        uint32_t RESERVED5 : 1; /*!< [24]  */
        uint32_t TBFDE : 1; /*!< [25] TX Buffer Fill DMA Enable */
        uint32_t TBUIE : 1; /*!< [26] TX Buffer Underrun Interrupt Enable */
        uint32_t TBFIE : 1; /*!< [27] TX Buffer Fill Interrupt Enable */
        uint32_t RESERVED6 : 1; /*!< [28]  */
        uint32_t KFEIE : 1; /*!< [29] Key Fetch Error Interrupt Enable */
        uint32_t IAKFIE : 1; /*!< [30] Illegal Access during Key Fetch Interrupt Enable */
        uint32_t DLPFIE : 1; /*!< [31] Data Learning Pattern Failure Interrupt enable . */
    } B;
} hw_quadspi_rser_t;

/*!
 * @name Constants and macros for entire QUADSPI_RSER register
 */
/*@{*/
#define HW_QUADSPI_RSER_ADDR(x)        ((x) + 0x164U)
#define HW_QUADSPI_RSER(x)             (*(__IO hw_quadspi_rser_t *) HW_QUADSPI_RSER_ADDR(x))
#define HW_QUADSPI_RSER_RD(x)          (HW_QUADSPI_RSER(x).U)
#define HW_QUADSPI_RSER_WR(x, v)       (HW_QUADSPI_RSER(x).U = (v))
#define HW_QUADSPI_RSER_SET(x, v)      (HW_QUADSPI_RSER_WR(x, HW_QUADSPI_RSER_RD(x) |  (v)))
#define HW_QUADSPI_RSER_CLR(x, v)      (HW_QUADSPI_RSER_WR(x, HW_QUADSPI_RSER_RD(x) & ~(v)))
#define HW_QUADSPI_RSER_TOG(x, v)      (HW_QUADSPI_RSER_WR(x, HW_QUADSPI_RSER_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_RSER bitfields
 */

/*!
 * @name Register QUADSPI_RSER, field TFIE[0] (RW)
 *
 * Transaction Finished Interrupt Enable
 *
 * Values:
 * - 0 - No TFF interrupt will be generated
 * - 1 - TFF interrupt will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_TFIE         (0U)      /*!< Bit position for QUADSPI_RSER_TFIE. */
#define BM_QUADSPI_RSER_TFIE         (0x00000001U)  /*!< Bit mask for QUADSPI_RSER_TFIE. */
#define BS_QUADSPI_RSER_TFIE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_TFIE. */

/*! @brief Read current value of the QUADSPI_RSER_TFIE field. */
#define BR_QUADSPI_RSER_TFIE(x)   (HW_QUADSPI_RSER(x).B.TFIE)

/*! @brief Format value for bitfield QUADSPI_RSER_TFIE. */
#define BF_QUADSPI_RSER_TFIE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_TFIE) & BM_QUADSPI_RSER_TFIE)

/*! @brief Set the TFIE field to a new value. */
#define BW_QUADSPI_RSER_TFIE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_TFIE) | BF_QUADSPI_RSER_TFIE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field IPGEIE[4] (RW)
 *
 * IP Command Trigger during AHB Grant Error Interrupt Enable
 *
 * Values:
 * - 0 - No IPGEF interrupt will be generated
 * - 1 - IPGEF interrupt will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_IPGEIE         (4U)      /*!< Bit position for QUADSPI_RSER_IPGEIE. */
#define BM_QUADSPI_RSER_IPGEIE         (0x00000010U)  /*!< Bit mask for QUADSPI_RSER_IPGEIE. */
#define BS_QUADSPI_RSER_IPGEIE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_IPGEIE. */

/*! @brief Read current value of the QUADSPI_RSER_IPGEIE field. */
#define BR_QUADSPI_RSER_IPGEIE(x)   (HW_QUADSPI_RSER(x).B.IPGEIE)

/*! @brief Format value for bitfield QUADSPI_RSER_IPGEIE. */
#define BF_QUADSPI_RSER_IPGEIE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_IPGEIE) & BM_QUADSPI_RSER_IPGEIE)

/*! @brief Set the IPGEIE field to a new value. */
#define BW_QUADSPI_RSER_IPGEIE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_IPGEIE) | BF_QUADSPI_RSER_IPGEIE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field IPIEIE[6] (RW)
 *
 * IP Command Trigger during IP Access Error Interrupt Enable
 *
 * Values:
 * - 0 - No IPIEF interrupt will be generated
 * - 1 - IPIEF interrupt will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_IPIEIE         (6U)      /*!< Bit position for QUADSPI_RSER_IPIEIE. */
#define BM_QUADSPI_RSER_IPIEIE         (0x00000040U)  /*!< Bit mask for QUADSPI_RSER_IPIEIE. */
#define BS_QUADSPI_RSER_IPIEIE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_IPIEIE. */

/*! @brief Read current value of the QUADSPI_RSER_IPIEIE field. */
#define BR_QUADSPI_RSER_IPIEIE(x)   (HW_QUADSPI_RSER(x).B.IPIEIE)

/*! @brief Format value for bitfield QUADSPI_RSER_IPIEIE. */
#define BF_QUADSPI_RSER_IPIEIE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_IPIEIE) & BM_QUADSPI_RSER_IPIEIE)

/*! @brief Set the IPIEIE field to a new value. */
#define BW_QUADSPI_RSER_IPIEIE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_IPIEIE) | BF_QUADSPI_RSER_IPIEIE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field IPAEIE[7] (RW)
 *
 * IP Command Trigger during AHB Access Error Interrupt Enable
 *
 * Values:
 * - 0 - No IPAEF interrupt will be generated
 * - 1 - IPAEF interrupt will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_IPAEIE         (7U)      /*!< Bit position for QUADSPI_RSER_IPAEIE. */
#define BM_QUADSPI_RSER_IPAEIE         (0x00000080U)  /*!< Bit mask for QUADSPI_RSER_IPAEIE. */
#define BS_QUADSPI_RSER_IPAEIE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_IPAEIE. */

/*! @brief Read current value of the QUADSPI_RSER_IPAEIE field. */
#define BR_QUADSPI_RSER_IPAEIE(x)   (HW_QUADSPI_RSER(x).B.IPAEIE)

/*! @brief Format value for bitfield QUADSPI_RSER_IPAEIE. */
#define BF_QUADSPI_RSER_IPAEIE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_IPAEIE) & BM_QUADSPI_RSER_IPAEIE)

/*! @brief Set the IPAEIE field to a new value. */
#define BW_QUADSPI_RSER_IPAEIE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_IPAEIE) | BF_QUADSPI_RSER_IPAEIE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field IUEIE[11] (RW)
 *
 * IP Command Usage Error Interrupt Enable
 *
 * Values:
 * - 0 - No IUEF interrupt will be generated
 * - 1 - IUEF interrupt will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_IUEIE         (11U)      /*!< Bit position for QUADSPI_RSER_IUEIE. */
#define BM_QUADSPI_RSER_IUEIE         (0x00000800U)  /*!< Bit mask for QUADSPI_RSER_IUEIE. */
#define BS_QUADSPI_RSER_IUEIE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_IUEIE. */

/*! @brief Read current value of the QUADSPI_RSER_IUEIE field. */
#define BR_QUADSPI_RSER_IUEIE(x)   (HW_QUADSPI_RSER(x).B.IUEIE)

/*! @brief Format value for bitfield QUADSPI_RSER_IUEIE. */
#define BF_QUADSPI_RSER_IUEIE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_IUEIE) & BM_QUADSPI_RSER_IUEIE)

/*! @brief Set the IUEIE field to a new value. */
#define BW_QUADSPI_RSER_IUEIE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_IUEIE) | BF_QUADSPI_RSER_IUEIE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field ABOIE[12] (RW)
 *
 * AHB Buffer Overflow Interrupt Enable
 *
 * Values:
 * - 0 - No ABOF interrupt will be generated
 * - 1 - ABOF interrupt will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_ABOIE         (12U)      /*!< Bit position for QUADSPI_RSER_ABOIE. */
#define BM_QUADSPI_RSER_ABOIE         (0x00001000U)  /*!< Bit mask for QUADSPI_RSER_ABOIE. */
#define BS_QUADSPI_RSER_ABOIE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_ABOIE. */

/*! @brief Read current value of the QUADSPI_RSER_ABOIE field. */
#define BR_QUADSPI_RSER_ABOIE(x)   (HW_QUADSPI_RSER(x).B.ABOIE)

/*! @brief Format value for bitfield QUADSPI_RSER_ABOIE. */
#define BF_QUADSPI_RSER_ABOIE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_ABOIE) & BM_QUADSPI_RSER_ABOIE)

/*! @brief Set the ABOIE field to a new value. */
#define BW_QUADSPI_RSER_ABOIE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_ABOIE) | BF_QUADSPI_RSER_ABOIE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field AIBSIE[13] (RW)
 *
 * AHB Illegal Burst Size Interrupt Enable
 *
 * Values:
 * - 0 - No AIBSEF interrupt will be generated
 * - 1 - AIBSEF interrupt will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_AIBSIE         (13U)      /*!< Bit position for QUADSPI_RSER_AIBSIE. */
#define BM_QUADSPI_RSER_AIBSIE         (0x00002000U)  /*!< Bit mask for QUADSPI_RSER_AIBSIE. */
#define BS_QUADSPI_RSER_AIBSIE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_AIBSIE. */

/*! @brief Read current value of the QUADSPI_RSER_AIBSIE field. */
#define BR_QUADSPI_RSER_AIBSIE(x)   (HW_QUADSPI_RSER(x).B.AIBSIE)

/*! @brief Format value for bitfield QUADSPI_RSER_AIBSIE. */
#define BF_QUADSPI_RSER_AIBSIE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_AIBSIE) & BM_QUADSPI_RSER_AIBSIE)

/*! @brief Set the AIBSIE field to a new value. */
#define BW_QUADSPI_RSER_AIBSIE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_AIBSIE) | BF_QUADSPI_RSER_AIBSIE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field AITIE[14] (RW)
 *
 * AHB Illegal transaction interrupt enable.
 *
 * Values:
 * - 0 - No AITEF interrupt will be generated
 * - 1 - AITEF interrupt will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_AITIE         (14U)      /*!< Bit position for QUADSPI_RSER_AITIE. */
#define BM_QUADSPI_RSER_AITIE         (0x00004000U)  /*!< Bit mask for QUADSPI_RSER_AITIE. */
#define BS_QUADSPI_RSER_AITIE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_AITIE. */

/*! @brief Read current value of the QUADSPI_RSER_AITIE field. */
#define BR_QUADSPI_RSER_AITIE(x)   (HW_QUADSPI_RSER(x).B.AITIE)

/*! @brief Format value for bitfield QUADSPI_RSER_AITIE. */
#define BF_QUADSPI_RSER_AITIE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_AITIE) & BM_QUADSPI_RSER_AITIE)

/*! @brief Set the AITIE field to a new value. */
#define BW_QUADSPI_RSER_AITIE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_AITIE) | BF_QUADSPI_RSER_AITIE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field ABSEIE[15] (RW)
 *
 * AHB Sequence Error Interrupt Enable: Triggered by ABSEF flags of QSPI_FR
 *
 * Values:
 * - 0 - No ABSEF interrupt will be generated
 * - 1 - ABSEF interrupt will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_ABSEIE         (15U)      /*!< Bit position for QUADSPI_RSER_ABSEIE. */
#define BM_QUADSPI_RSER_ABSEIE         (0x00008000U)  /*!< Bit mask for QUADSPI_RSER_ABSEIE. */
#define BS_QUADSPI_RSER_ABSEIE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_ABSEIE. */

/*! @brief Read current value of the QUADSPI_RSER_ABSEIE field. */
#define BR_QUADSPI_RSER_ABSEIE(x)   (HW_QUADSPI_RSER(x).B.ABSEIE)

/*! @brief Format value for bitfield QUADSPI_RSER_ABSEIE. */
#define BF_QUADSPI_RSER_ABSEIE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_ABSEIE) & BM_QUADSPI_RSER_ABSEIE)

/*! @brief Set the ABSEIE field to a new value. */
#define BW_QUADSPI_RSER_ABSEIE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_ABSEIE) | BF_QUADSPI_RSER_ABSEIE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field RBDIE[16] (RW)
 *
 * RX Buffer Drain Interrupt Enable: Enables generation of IRQ requests for RX Buffer Drain. When
 * this bit is set the interrupt is asserted as long as the QuadSPI_SR[RBDF] flag is set.
 *
 * Values:
 * - 0 - No RBDF interrupt will be generated
 * - 1 - RBDF Interrupt will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_RBDIE         (16U)      /*!< Bit position for QUADSPI_RSER_RBDIE. */
#define BM_QUADSPI_RSER_RBDIE         (0x00010000U)  /*!< Bit mask for QUADSPI_RSER_RBDIE. */
#define BS_QUADSPI_RSER_RBDIE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_RBDIE. */

/*! @brief Read current value of the QUADSPI_RSER_RBDIE field. */
#define BR_QUADSPI_RSER_RBDIE(x)   (HW_QUADSPI_RSER(x).B.RBDIE)

/*! @brief Format value for bitfield QUADSPI_RSER_RBDIE. */
#define BF_QUADSPI_RSER_RBDIE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_RBDIE) & BM_QUADSPI_RSER_RBDIE)

/*! @brief Set the RBDIE field to a new value. */
#define BW_QUADSPI_RSER_RBDIE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_RBDIE) | BF_QUADSPI_RSER_RBDIE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field RBOIE[17] (RW)
 *
 * RX Buffer Overflow Interrupt Enable
 *
 * Values:
 * - 0 - No RBOF interrupt will be generated
 * - 1 - RBOF interrupt will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_RBOIE         (17U)      /*!< Bit position for QUADSPI_RSER_RBOIE. */
#define BM_QUADSPI_RSER_RBOIE         (0x00020000U)  /*!< Bit mask for QUADSPI_RSER_RBOIE. */
#define BS_QUADSPI_RSER_RBOIE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_RBOIE. */

/*! @brief Read current value of the QUADSPI_RSER_RBOIE field. */
#define BR_QUADSPI_RSER_RBOIE(x)   (HW_QUADSPI_RSER(x).B.RBOIE)

/*! @brief Format value for bitfield QUADSPI_RSER_RBOIE. */
#define BF_QUADSPI_RSER_RBOIE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_RBOIE) & BM_QUADSPI_RSER_RBOIE)

/*! @brief Set the RBOIE field to a new value. */
#define BW_QUADSPI_RSER_RBOIE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_RBOIE) | BF_QUADSPI_RSER_RBOIE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field RBDDE[21] (RW)
 *
 * RX Buffer Drain DMA Enable: Enables generation of DMA requests for RX Buffer Drain. When this bit
 * is set DMA requests are generated as long as the QSPI_SR[RXWE] status bit is set.
 *
 * Values:
 * - 0 - No DMA request will be generated
 * - 1 - DMA request will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_RBDDE         (21U)      /*!< Bit position for QUADSPI_RSER_RBDDE. */
#define BM_QUADSPI_RSER_RBDDE         (0x00200000U)  /*!< Bit mask for QUADSPI_RSER_RBDDE. */
#define BS_QUADSPI_RSER_RBDDE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_RBDDE. */

/*! @brief Read current value of the QUADSPI_RSER_RBDDE field. */
#define BR_QUADSPI_RSER_RBDDE(x)   (HW_QUADSPI_RSER(x).B.RBDDE)

/*! @brief Format value for bitfield QUADSPI_RSER_RBDDE. */
#define BF_QUADSPI_RSER_RBDDE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_RBDDE) & BM_QUADSPI_RSER_RBDDE)

/*! @brief Set the RBDDE field to a new value. */
#define BW_QUADSPI_RSER_RBDDE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_RBDDE) | BF_QUADSPI_RSER_RBDDE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field ILLINIE[23] (RW)
 *
 * Illegal Instruction Error Interrupt Enable. Triggered by ILLINE flag in QSPI_FR
 *
 * Values:
 * - 0 - No ILLINE interrupt will be generated
 * - 1 - ILLINE interrupt will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_ILLINIE         (23U)      /*!< Bit position for QUADSPI_RSER_ILLINIE. */
#define BM_QUADSPI_RSER_ILLINIE         (0x00800000U)  /*!< Bit mask for QUADSPI_RSER_ILLINIE. */
#define BS_QUADSPI_RSER_ILLINIE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_ILLINIE. */

/*! @brief Read current value of the QUADSPI_RSER_ILLINIE field. */
#define BR_QUADSPI_RSER_ILLINIE(x)   (HW_QUADSPI_RSER(x).B.ILLINIE)

/*! @brief Format value for bitfield QUADSPI_RSER_ILLINIE. */
#define BF_QUADSPI_RSER_ILLINIE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_ILLINIE) & BM_QUADSPI_RSER_ILLINIE)

/*! @brief Set the ILLINIE field to a new value. */
#define BW_QUADSPI_RSER_ILLINIE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_ILLINIE) | BF_QUADSPI_RSER_ILLINIE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field TBFDE[25] (RW)
 *
 * Enables generation of DMA requests for TX Buffer fill. When this is set DMA requests are
 * generated as long as the QSPI_SR[TXWA] status bit is set.
 *
 * Values:
 * - 0 - No DMA request will be generated
 * - 1 - DMA request will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_TBFDE         (25U)      /*!< Bit position for QUADSPI_RSER_TBFDE. */
#define BM_QUADSPI_RSER_TBFDE         (0x02000000U)  /*!< Bit mask for QUADSPI_RSER_TBFDE. */
#define BS_QUADSPI_RSER_TBFDE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_TBFDE. */

/*! @brief Read current value of the QUADSPI_RSER_TBFDE field. */
#define BR_QUADSPI_RSER_TBFDE(x)   (HW_QUADSPI_RSER(x).B.TBFDE)

/*! @brief Format value for bitfield QUADSPI_RSER_TBFDE. */
#define BF_QUADSPI_RSER_TBFDE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_TBFDE) & BM_QUADSPI_RSER_TBFDE)

/*! @brief Set the TBFDE field to a new value. */
#define BW_QUADSPI_RSER_TBFDE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_TBFDE) | BF_QUADSPI_RSER_TBFDE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field TBUIE[26] (RW)
 *
 * TX Buffer Underrun Interrupt Enable
 *
 * Values:
 * - 0 - No TBUF interrupt will be generated
 * - 1 - TBUF interrupt will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_TBUIE         (26U)      /*!< Bit position for QUADSPI_RSER_TBUIE. */
#define BM_QUADSPI_RSER_TBUIE         (0x04000000U)  /*!< Bit mask for QUADSPI_RSER_TBUIE. */
#define BS_QUADSPI_RSER_TBUIE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_TBUIE. */

/*! @brief Read current value of the QUADSPI_RSER_TBUIE field. */
#define BR_QUADSPI_RSER_TBUIE(x)   (HW_QUADSPI_RSER(x).B.TBUIE)

/*! @brief Format value for bitfield QUADSPI_RSER_TBUIE. */
#define BF_QUADSPI_RSER_TBUIE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_TBUIE) & BM_QUADSPI_RSER_TBUIE)

/*! @brief Set the TBUIE field to a new value. */
#define BW_QUADSPI_RSER_TBUIE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_TBUIE) | BF_QUADSPI_RSER_TBUIE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field TBFIE[27] (RW)
 *
 * TX Buffer Fill Interrupt Enable
 *
 * Values:
 * - 0 - No TBFF interrupt will be generated
 * - 1 - TBFF interrupt will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_TBFIE         (27U)      /*!< Bit position for QUADSPI_RSER_TBFIE. */
#define BM_QUADSPI_RSER_TBFIE         (0x08000000U)  /*!< Bit mask for QUADSPI_RSER_TBFIE. */
#define BS_QUADSPI_RSER_TBFIE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_TBFIE. */

/*! @brief Read current value of the QUADSPI_RSER_TBFIE field. */
#define BR_QUADSPI_RSER_TBFIE(x)   (HW_QUADSPI_RSER(x).B.TBFIE)

/*! @brief Format value for bitfield QUADSPI_RSER_TBFIE. */
#define BF_QUADSPI_RSER_TBFIE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_TBFIE) & BM_QUADSPI_RSER_TBFIE)

/*! @brief Set the TBFIE field to a new value. */
#define BW_QUADSPI_RSER_TBFIE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_TBFIE) | BF_QUADSPI_RSER_TBFIE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field KFEIE[29] (RW)
 *
 * Key Fetch Error Interrupt Enable
 *
 * Values:
 * - 0 - No KFEF interrupt will be generated
 * - 1 - KFEF interrupt will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_KFEIE         (29U)      /*!< Bit position for QUADSPI_RSER_KFEIE. */
#define BM_QUADSPI_RSER_KFEIE         (0x20000000U)  /*!< Bit mask for QUADSPI_RSER_KFEIE. */
#define BS_QUADSPI_RSER_KFEIE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_KFEIE. */

/*! @brief Read current value of the QUADSPI_RSER_KFEIE field. */
#define BR_QUADSPI_RSER_KFEIE(x)   (HW_QUADSPI_RSER(x).B.KFEIE)

/*! @brief Format value for bitfield QUADSPI_RSER_KFEIE. */
#define BF_QUADSPI_RSER_KFEIE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_KFEIE) & BM_QUADSPI_RSER_KFEIE)

/*! @brief Set the KFEIE field to a new value. */
#define BW_QUADSPI_RSER_KFEIE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_KFEIE) | BF_QUADSPI_RSER_KFEIE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field IAKFIE[30] (RW)
 *
 * Illegal Access during Key Fetch Interrupt Enable
 *
 * Values:
 * - 0 - No IAKFEF interrupt will be generated
 * - 1 - IAKFEF interrupt will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_IAKFIE         (30U)      /*!< Bit position for QUADSPI_RSER_IAKFIE. */
#define BM_QUADSPI_RSER_IAKFIE         (0x40000000U)  /*!< Bit mask for QUADSPI_RSER_IAKFIE. */
#define BS_QUADSPI_RSER_IAKFIE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_IAKFIE. */

/*! @brief Read current value of the QUADSPI_RSER_IAKFIE field. */
#define BR_QUADSPI_RSER_IAKFIE(x)   (HW_QUADSPI_RSER(x).B.IAKFIE)

/*! @brief Format value for bitfield QUADSPI_RSER_IAKFIE. */
#define BF_QUADSPI_RSER_IAKFIE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_IAKFIE) & BM_QUADSPI_RSER_IAKFIE)

/*! @brief Set the IAKFIE field to a new value. */
#define BW_QUADSPI_RSER_IAKFIE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_IAKFIE) | BF_QUADSPI_RSER_IAKFIE(v)))
/*@}*/

/*!
 * @name Register QUADSPI_RSER, field DLPFIE[31] (RW)
 *
 * Data Learning Pattern Failure Interrupt enable . Triggered by DLPFF flag in QSPI_FR register
 *
 * Values:
 * - 0 - No DLPFF interrupt will be generated
 * - 1 - DLPFF interrupt will be generated
 */
/*@{*/
#define BP_QUADSPI_RSER_DLPFIE         (31U)      /*!< Bit position for QUADSPI_RSER_DLPFIE. */
#define BM_QUADSPI_RSER_DLPFIE         (0x80000000U)  /*!< Bit mask for QUADSPI_RSER_DLPFIE. */
#define BS_QUADSPI_RSER_DLPFIE         (1U)  /*!< Bitfield size in bits for QUADSPI_RSER_DLPFIE. */

/*! @brief Read current value of the QUADSPI_RSER_DLPFIE field. */
#define BR_QUADSPI_RSER_DLPFIE(x)   (HW_QUADSPI_RSER(x).B.DLPFIE)

/*! @brief Format value for bitfield QUADSPI_RSER_DLPFIE. */
#define BF_QUADSPI_RSER_DLPFIE(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RSER_DLPFIE) & BM_QUADSPI_RSER_DLPFIE)

/*! @brief Set the DLPFIE field to a new value. */
#define BW_QUADSPI_RSER_DLPFIE(x, v)   (HW_QUADSPI_RSER_WR(x, (HW_QUADSPI_RSER_RD(x) & ~BM_QUADSPI_RSER_DLPFIE) | BF_QUADSPI_RSER_DLPFIE(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_SPNDST - Sequence Suspend Status Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_SPNDST - Sequence Suspend Status Register (RO)
 *
 * Reset value: 0x00000000U
 *
 * The sequence suspend status register provides information specific to any suspended sequence. An
 * AHB sequence may be suspended when a high priority AHB master makes an access before the AHB
 * sequence completes the data transfer requested.
 */
typedef union _hw_quadspi_spndst
{
    uint32_t U;
    struct _hw_quadspi_spndst_bitfields
    {
        uint32_t SUSPND : 1; /*!< [0] When set, it signifies that a sequence is in suspended state */
        uint32_t RESERVED0 : 5; /*!< [5:1]  */
        uint32_t SPDBUF : 2; /*!< [7:6] Suspended Buffer: Provides the suspended buffer number. */
        uint32_t RESERVED1 : 1; /*!< [8]  */
        uint32_t DATLFT : 7; /*!< [15:9] Data left: Provides information about the amount of data left to be read in the suspended sequence. */
        uint32_t RESERVED2 : 16; /*!< [31:16]  */
    } B;
} hw_quadspi_spndst_t;

/*!
 * @name Constants and macros for entire QUADSPI_SPNDST register
 */
/*@{*/
#define HW_QUADSPI_SPNDST_ADDR(x)        ((x) + 0x168U)
#define HW_QUADSPI_SPNDST(x)             (*(__I  hw_quadspi_spndst_t *) HW_QUADSPI_SPNDST_ADDR(x))
#define HW_QUADSPI_SPNDST_RD(x)          (HW_QUADSPI_SPNDST(x).U)
/*@}*/

/*
 * Constants & macros for individual QUADSPI_SPNDST bitfields
 */

/*!
 * @name Register QUADSPI_SPNDST, field SUSPND[0] (RO)
 *
 * When set, it signifies that a sequence is in suspended state
 */
/*@{*/
#define BP_QUADSPI_SPNDST_SUSPND         (0U)      /*!< Bit position for QUADSPI_SPNDST_SUSPND. */
#define BM_QUADSPI_SPNDST_SUSPND         (0x00000001U)  /*!< Bit mask for QUADSPI_SPNDST_SUSPND. */
#define BS_QUADSPI_SPNDST_SUSPND         (1U)  /*!< Bitfield size in bits for QUADSPI_SPNDST_SUSPND. */

/*! @brief Read current value of the QUADSPI_SPNDST_SUSPND field. */
#define BR_QUADSPI_SPNDST_SUSPND(x)   (HW_QUADSPI_SPNDST(x).B.SUSPND)
/*@}*/

/*!
 * @name Register QUADSPI_SPNDST, field SPDBUF[7:6] (RO)
 *
 * Suspended Buffer: Provides the suspended buffer number. Valid only when SUSPND is set to 1'b1
 */
/*@{*/
#define BP_QUADSPI_SPNDST_SPDBUF         (6U)      /*!< Bit position for QUADSPI_SPNDST_SPDBUF. */
#define BM_QUADSPI_SPNDST_SPDBUF         (0x000000C0U)  /*!< Bit mask for QUADSPI_SPNDST_SPDBUF. */
#define BS_QUADSPI_SPNDST_SPDBUF         (2U)  /*!< Bitfield size in bits for QUADSPI_SPNDST_SPDBUF. */

/*! @brief Read current value of the QUADSPI_SPNDST_SPDBUF field. */
#define BR_QUADSPI_SPNDST_SPDBUF(x)   (HW_QUADSPI_SPNDST(x).B.SPDBUF)
/*@}*/

/*!
 * @name Register QUADSPI_SPNDST, field DATLFT[15:9] (RO)
 *
 * Data left: Provides information about the amount of data left to be read in the suspended
 * sequence. Valid only when SUSPND is set to 1'b1. Value in terms of 64 bits or 8 bytes
 */
/*@{*/
#define BP_QUADSPI_SPNDST_DATLFT         (9U)      /*!< Bit position for QUADSPI_SPNDST_DATLFT. */
#define BM_QUADSPI_SPNDST_DATLFT         (0x0000FE00U)  /*!< Bit mask for QUADSPI_SPNDST_DATLFT. */
#define BS_QUADSPI_SPNDST_DATLFT         (7U)  /*!< Bitfield size in bits for QUADSPI_SPNDST_DATLFT. */

/*! @brief Read current value of the QUADSPI_SPNDST_DATLFT field. */
#define BR_QUADSPI_SPNDST_DATLFT(x)   (HW_QUADSPI_SPNDST(x).B.DATLFT)
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_SPTRCLR - Sequence Pointer Clear Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_SPTRCLR - Sequence Pointer Clear Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The sequence pointer clear register provides bits to reset the IP and Buffer sequence pointers.
 * The sequence pointer contains the index of which instruction within the LUT entry is to be
 * executed next. For example, if the LUT entry ends on a JMP_ON_CS value of 2, the index will be
 * stored as 2. The software should reset the sequence pointers whenever the sequence ID is changed
 * by updating the SEQID field in QSPI_IPCR or QSPI_BFGENCR.
 */
typedef union _hw_quadspi_sptrclr
{
    uint32_t U;
    struct _hw_quadspi_sptrclr_bitfields
    {
        uint32_t BFPTRC : 1; /*!< [0] Buffer Pointer Clear: */
        uint32_t RESERVED0 : 7; /*!< [7:1] Reserved. */
        uint32_t IPPTRC : 1; /*!< [8] IP Pointer Clear: */
        uint32_t RESERVED1 : 23; /*!< [31:9]  */
    } B;
} hw_quadspi_sptrclr_t;

/*!
 * @name Constants and macros for entire QUADSPI_SPTRCLR register
 */
/*@{*/
#define HW_QUADSPI_SPTRCLR_ADDR(x)        ((x) + 0x16CU)
#define HW_QUADSPI_SPTRCLR(x)             (*(__IO hw_quadspi_sptrclr_t *) HW_QUADSPI_SPTRCLR_ADDR(x))
#define HW_QUADSPI_SPTRCLR_RD(x)          (HW_QUADSPI_SPTRCLR(x).U)
#define HW_QUADSPI_SPTRCLR_WR(x, v)       (HW_QUADSPI_SPTRCLR(x).U = (v))
#define HW_QUADSPI_SPTRCLR_SET(x, v)      (HW_QUADSPI_SPTRCLR_WR(x, HW_QUADSPI_SPTRCLR_RD(x) |  (v)))
#define HW_QUADSPI_SPTRCLR_CLR(x, v)      (HW_QUADSPI_SPTRCLR_WR(x, HW_QUADSPI_SPTRCLR_RD(x) & ~(v)))
#define HW_QUADSPI_SPTRCLR_TOG(x, v)      (HW_QUADSPI_SPTRCLR_WR(x, HW_QUADSPI_SPTRCLR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_SPTRCLR bitfields
 */

/*!
 * @name Register QUADSPI_SPTRCLR, field BFPTRC[0] (RW)
 *
 * Buffer Pointer Clear: 1: Clears the sequence pointer for AHB accesses as defined in
 * QuadSPI_BFGENCR.
 */
/*@{*/
#define BP_QUADSPI_SPTRCLR_BFPTRC         (0U)      /*!< Bit position for QUADSPI_SPTRCLR_BFPTRC. */
#define BM_QUADSPI_SPTRCLR_BFPTRC         (0x00000001U)  /*!< Bit mask for QUADSPI_SPTRCLR_BFPTRC. */
#define BS_QUADSPI_SPTRCLR_BFPTRC         (1U)  /*!< Bitfield size in bits for QUADSPI_SPTRCLR_BFPTRC. */

/*! @brief Read current value of the QUADSPI_SPTRCLR_BFPTRC field. */
#define BR_QUADSPI_SPTRCLR_BFPTRC(x)   (HW_QUADSPI_SPTRCLR(x).B.BFPTRC)

/*! @brief Format value for bitfield QUADSPI_SPTRCLR_BFPTRC. */
#define BF_QUADSPI_SPTRCLR_BFPTRC(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_SPTRCLR_BFPTRC) & BM_QUADSPI_SPTRCLR_BFPTRC)

/*! @brief Set the BFPTRC field to a new value. */
#define BW_QUADSPI_SPTRCLR_BFPTRC(x, v)   (HW_QUADSPI_SPTRCLR_WR(x, (HW_QUADSPI_SPTRCLR_RD(x) & ~BM_QUADSPI_SPTRCLR_BFPTRC) | BF_QUADSPI_SPTRCLR_BFPTRC(v)))
/*@}*/

/*!
 * @name Register QUADSPI_SPTRCLR, field IPPTRC[8] (RW)
 *
 * IP Pointer Clear: 1: Clears the sequence pointer for IP accesses as defined in QuadSPI_IPCR
 */
/*@{*/
#define BP_QUADSPI_SPTRCLR_IPPTRC         (8U)      /*!< Bit position for QUADSPI_SPTRCLR_IPPTRC. */
#define BM_QUADSPI_SPTRCLR_IPPTRC         (0x00000100U)  /*!< Bit mask for QUADSPI_SPTRCLR_IPPTRC. */
#define BS_QUADSPI_SPTRCLR_IPPTRC         (1U)  /*!< Bitfield size in bits for QUADSPI_SPTRCLR_IPPTRC. */

/*! @brief Read current value of the QUADSPI_SPTRCLR_IPPTRC field. */
#define BR_QUADSPI_SPTRCLR_IPPTRC(x)   (HW_QUADSPI_SPTRCLR(x).B.IPPTRC)

/*! @brief Format value for bitfield QUADSPI_SPTRCLR_IPPTRC. */
#define BF_QUADSPI_SPTRCLR_IPPTRC(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_SPTRCLR_IPPTRC) & BM_QUADSPI_SPTRCLR_IPPTRC)

/*! @brief Set the IPPTRC field to a new value. */
#define BW_QUADSPI_SPTRCLR_IPPTRC(x, v)   (HW_QUADSPI_SPTRCLR_WR(x, (HW_QUADSPI_SPTRCLR_RD(x) & ~BM_QUADSPI_SPTRCLR_IPPTRC) | BF_QUADSPI_SPTRCLR_IPPTRC(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_SFA1AD - Serial Flash A1 Top Address
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_SFA1AD - Serial Flash A1 Top Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QSPI_SFA1AD register provides the address mapping for the serial flash A1.The difference
 * between QSPI_SFA1AD[TPADA1] and QSPI_AMBA_BASE defines the size of the memory map for serial
 * flash A1. Write: QSPI_SR[IP_ACC] = 0 QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_sfa1ad
{
    uint32_t U;
    struct _hw_quadspi_sfa1ad_bitfields
    {
        uint32_t RESERVED0 : 10; /*!< [9:0]  */
        uint32_t TPADA1 : 22; /*!< [31:10] Top address for Serial Flash A1. */
    } B;
} hw_quadspi_sfa1ad_t;

/*!
 * @name Constants and macros for entire QUADSPI_SFA1AD register
 */
/*@{*/
#define HW_QUADSPI_SFA1AD_ADDR(x)        ((x) + 0x180U)
#define HW_QUADSPI_SFA1AD(x)             (*(__IO hw_quadspi_sfa1ad_t *) HW_QUADSPI_SFA1AD_ADDR(x))
#define HW_QUADSPI_SFA1AD_RD(x)          (HW_QUADSPI_SFA1AD(x).U)
#define HW_QUADSPI_SFA1AD_WR(x, v)       (HW_QUADSPI_SFA1AD(x).U = (v))
#define HW_QUADSPI_SFA1AD_SET(x, v)      (HW_QUADSPI_SFA1AD_WR(x, HW_QUADSPI_SFA1AD_RD(x) |  (v)))
#define HW_QUADSPI_SFA1AD_CLR(x, v)      (HW_QUADSPI_SFA1AD_WR(x, HW_QUADSPI_SFA1AD_RD(x) & ~(v)))
#define HW_QUADSPI_SFA1AD_TOG(x, v)      (HW_QUADSPI_SFA1AD_WR(x, HW_QUADSPI_SFA1AD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_SFA1AD bitfields
 */

/*!
 * @name Register QUADSPI_SFA1AD, field TPADA1[31:10] (RW)
 *
 * Top address for Serial Flash A1. In effect, TPADxx is the first location of the next memory.
 */
/*@{*/
#define BP_QUADSPI_SFA1AD_TPADA1         (10U)      /*!< Bit position for QUADSPI_SFA1AD_TPADA1. */
#define BM_QUADSPI_SFA1AD_TPADA1         (0xFFFFFC00U)  /*!< Bit mask for QUADSPI_SFA1AD_TPADA1. */
#define BS_QUADSPI_SFA1AD_TPADA1         (22U)  /*!< Bitfield size in bits for QUADSPI_SFA1AD_TPADA1. */

/*! @brief Read current value of the QUADSPI_SFA1AD_TPADA1 field. */
#define BR_QUADSPI_SFA1AD_TPADA1(x)   (HW_QUADSPI_SFA1AD(x).B.TPADA1)

/*! @brief Format value for bitfield QUADSPI_SFA1AD_TPADA1. */
#define BF_QUADSPI_SFA1AD_TPADA1(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_SFA1AD_TPADA1) & BM_QUADSPI_SFA1AD_TPADA1)

/*! @brief Set the TPADA1 field to a new value. */
#define BW_QUADSPI_SFA1AD_TPADA1(x, v)   (HW_QUADSPI_SFA1AD_WR(x, (HW_QUADSPI_SFA1AD_RD(x) & ~BM_QUADSPI_SFA1AD_TPADA1) | BF_QUADSPI_SFA1AD_TPADA1(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_SFA2AD - Serial Flash A2 Top Address
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_SFA2AD - Serial Flash A2 Top Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QSPI_SFA2AD register provides the address mapping for the serial flash A2.The difference
 * between QSPI_SFA2AD[TPADA2] and QSPI_SFA1AD[TPADA1] defines the size of the memory map for serial
 * flash A2. Write: QSPI_SR[IP_ACC] = 0 QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_sfa2ad
{
    uint32_t U;
    struct _hw_quadspi_sfa2ad_bitfields
    {
        uint32_t RESERVED0 : 10; /*!< [9:0]  */
        uint32_t TPADA2 : 22; /*!< [31:10] Top address for Serial Flash A2. */
    } B;
} hw_quadspi_sfa2ad_t;

/*!
 * @name Constants and macros for entire QUADSPI_SFA2AD register
 */
/*@{*/
#define HW_QUADSPI_SFA2AD_ADDR(x)        ((x) + 0x184U)
#define HW_QUADSPI_SFA2AD(x)             (*(__IO hw_quadspi_sfa2ad_t *) HW_QUADSPI_SFA2AD_ADDR(x))
#define HW_QUADSPI_SFA2AD_RD(x)          (HW_QUADSPI_SFA2AD(x).U)
#define HW_QUADSPI_SFA2AD_WR(x, v)       (HW_QUADSPI_SFA2AD(x).U = (v))
#define HW_QUADSPI_SFA2AD_SET(x, v)      (HW_QUADSPI_SFA2AD_WR(x, HW_QUADSPI_SFA2AD_RD(x) |  (v)))
#define HW_QUADSPI_SFA2AD_CLR(x, v)      (HW_QUADSPI_SFA2AD_WR(x, HW_QUADSPI_SFA2AD_RD(x) & ~(v)))
#define HW_QUADSPI_SFA2AD_TOG(x, v)      (HW_QUADSPI_SFA2AD_WR(x, HW_QUADSPI_SFA2AD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_SFA2AD bitfields
 */

/*!
 * @name Register QUADSPI_SFA2AD, field TPADA2[31:10] (RW)
 *
 * Top address for Serial Flash A2. In effect, TPxxAD is the first location of the next memory.
 */
/*@{*/
#define BP_QUADSPI_SFA2AD_TPADA2         (10U)      /*!< Bit position for QUADSPI_SFA2AD_TPADA2. */
#define BM_QUADSPI_SFA2AD_TPADA2         (0xFFFFFC00U)  /*!< Bit mask for QUADSPI_SFA2AD_TPADA2. */
#define BS_QUADSPI_SFA2AD_TPADA2         (22U)  /*!< Bitfield size in bits for QUADSPI_SFA2AD_TPADA2. */

/*! @brief Read current value of the QUADSPI_SFA2AD_TPADA2 field. */
#define BR_QUADSPI_SFA2AD_TPADA2(x)   (HW_QUADSPI_SFA2AD(x).B.TPADA2)

/*! @brief Format value for bitfield QUADSPI_SFA2AD_TPADA2. */
#define BF_QUADSPI_SFA2AD_TPADA2(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_SFA2AD_TPADA2) & BM_QUADSPI_SFA2AD_TPADA2)

/*! @brief Set the TPADA2 field to a new value. */
#define BW_QUADSPI_SFA2AD_TPADA2(x, v)   (HW_QUADSPI_SFA2AD_WR(x, (HW_QUADSPI_SFA2AD_RD(x) & ~BM_QUADSPI_SFA2AD_TPADA2) | BF_QUADSPI_SFA2AD_TPADA2(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_SFB1AD - Serial Flash B1Top Address
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_SFB1AD - Serial Flash B1Top Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QSPI_SFB1AD register provides the address mapping for the serial flash B1.The difference
 * between QSPI_SFB1AD[TPADB1] and QSPI_SFA2AD[TPADA2] defines the size of the memory map for serial
 * flash B1. Write: QSPI_SR[IP_ACC] = 0 QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_sfb1ad
{
    uint32_t U;
    struct _hw_quadspi_sfb1ad_bitfields
    {
        uint32_t RESERVED0 : 10; /*!< [9:0]  */
        uint32_t TPADB1 : 22; /*!< [31:10] Top address for Serial Flash B1.In effect, TPxxAD is the first location of the next memory. */
    } B;
} hw_quadspi_sfb1ad_t;

/*!
 * @name Constants and macros for entire QUADSPI_SFB1AD register
 */
/*@{*/
#define HW_QUADSPI_SFB1AD_ADDR(x)        ((x) + 0x188U)
#define HW_QUADSPI_SFB1AD(x)             (*(__IO hw_quadspi_sfb1ad_t *) HW_QUADSPI_SFB1AD_ADDR(x))
#define HW_QUADSPI_SFB1AD_RD(x)          (HW_QUADSPI_SFB1AD(x).U)
#define HW_QUADSPI_SFB1AD_WR(x, v)       (HW_QUADSPI_SFB1AD(x).U = (v))
#define HW_QUADSPI_SFB1AD_SET(x, v)      (HW_QUADSPI_SFB1AD_WR(x, HW_QUADSPI_SFB1AD_RD(x) |  (v)))
#define HW_QUADSPI_SFB1AD_CLR(x, v)      (HW_QUADSPI_SFB1AD_WR(x, HW_QUADSPI_SFB1AD_RD(x) & ~(v)))
#define HW_QUADSPI_SFB1AD_TOG(x, v)      (HW_QUADSPI_SFB1AD_WR(x, HW_QUADSPI_SFB1AD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_SFB1AD bitfields
 */

/*!
 * @name Register QUADSPI_SFB1AD, field TPADB1[31:10] (RW)
 *
 * Top address for Serial Flash B1.In effect, TPxxAD is the first location of the next memory.
 */
/*@{*/
#define BP_QUADSPI_SFB1AD_TPADB1         (10U)      /*!< Bit position for QUADSPI_SFB1AD_TPADB1. */
#define BM_QUADSPI_SFB1AD_TPADB1         (0xFFFFFC00U)  /*!< Bit mask for QUADSPI_SFB1AD_TPADB1. */
#define BS_QUADSPI_SFB1AD_TPADB1         (22U)  /*!< Bitfield size in bits for QUADSPI_SFB1AD_TPADB1. */

/*! @brief Read current value of the QUADSPI_SFB1AD_TPADB1 field. */
#define BR_QUADSPI_SFB1AD_TPADB1(x)   (HW_QUADSPI_SFB1AD(x).B.TPADB1)

/*! @brief Format value for bitfield QUADSPI_SFB1AD_TPADB1. */
#define BF_QUADSPI_SFB1AD_TPADB1(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_SFB1AD_TPADB1) & BM_QUADSPI_SFB1AD_TPADB1)

/*! @brief Set the TPADB1 field to a new value. */
#define BW_QUADSPI_SFB1AD_TPADB1(x, v)   (HW_QUADSPI_SFB1AD_WR(x, (HW_QUADSPI_SFB1AD_RD(x) & ~BM_QUADSPI_SFB1AD_TPADB1) | BF_QUADSPI_SFB1AD_TPADB1(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_SFB2AD - Serial Flash B2Top Address
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_SFB2AD - Serial Flash B2Top Address (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QSPI_SFB2AD register provides the address mapping for the serial flash B2.The difference
 * between QSPI_SFB2AD[TPADB2] and QSPI_SFB1AD[TPADB1] defines the size of the memory map for serial
 * flash B2. Write: QSPI_SR[IP_ACC] = 0 QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_sfb2ad
{
    uint32_t U;
    struct _hw_quadspi_sfb2ad_bitfields
    {
        uint32_t RESERVED0 : 10; /*!< [9:0]  */
        uint32_t TPADB2 : 22; /*!< [31:10] Top address for Serial Flash B2. */
    } B;
} hw_quadspi_sfb2ad_t;

/*!
 * @name Constants and macros for entire QUADSPI_SFB2AD register
 */
/*@{*/
#define HW_QUADSPI_SFB2AD_ADDR(x)        ((x) + 0x18CU)
#define HW_QUADSPI_SFB2AD(x)             (*(__IO hw_quadspi_sfb2ad_t *) HW_QUADSPI_SFB2AD_ADDR(x))
#define HW_QUADSPI_SFB2AD_RD(x)          (HW_QUADSPI_SFB2AD(x).U)
#define HW_QUADSPI_SFB2AD_WR(x, v)       (HW_QUADSPI_SFB2AD(x).U = (v))
#define HW_QUADSPI_SFB2AD_SET(x, v)      (HW_QUADSPI_SFB2AD_WR(x, HW_QUADSPI_SFB2AD_RD(x) |  (v)))
#define HW_QUADSPI_SFB2AD_CLR(x, v)      (HW_QUADSPI_SFB2AD_WR(x, HW_QUADSPI_SFB2AD_RD(x) & ~(v)))
#define HW_QUADSPI_SFB2AD_TOG(x, v)      (HW_QUADSPI_SFB2AD_WR(x, HW_QUADSPI_SFB2AD_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_SFB2AD bitfields
 */

/*!
 * @name Register QUADSPI_SFB2AD, field TPADB2[31:10] (RW)
 *
 * Top address for Serial Flash B2. In effect, TPxxAD is the first location of the next memory.
 */
/*@{*/
#define BP_QUADSPI_SFB2AD_TPADB2         (10U)      /*!< Bit position for QUADSPI_SFB2AD_TPADB2. */
#define BM_QUADSPI_SFB2AD_TPADB2         (0xFFFFFC00U)  /*!< Bit mask for QUADSPI_SFB2AD_TPADB2. */
#define BS_QUADSPI_SFB2AD_TPADB2         (22U)  /*!< Bitfield size in bits for QUADSPI_SFB2AD_TPADB2. */

/*! @brief Read current value of the QUADSPI_SFB2AD_TPADB2 field. */
#define BR_QUADSPI_SFB2AD_TPADB2(x)   (HW_QUADSPI_SFB2AD(x).B.TPADB2)

/*! @brief Format value for bitfield QUADSPI_SFB2AD_TPADB2. */
#define BF_QUADSPI_SFB2AD_TPADB2(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_SFB2AD_TPADB2) & BM_QUADSPI_SFB2AD_TPADB2)

/*! @brief Set the TPADB2 field to a new value. */
#define BW_QUADSPI_SFB2AD_TPADB2(x, v)   (HW_QUADSPI_SFB2AD_WR(x, (HW_QUADSPI_SFB2AD_RD(x) & ~BM_QUADSPI_SFB2AD_TPADB2) | BF_QUADSPI_SFB2AD_TPADB2(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_DLPR - Data Learn Pattern Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_DLPR - Data Learn Pattern Register (RW)
 *
 * Reset value: 0xAA553443U
 *
 * The QSPI_DLPR register contains the information of the data to be used for Data Learning. Write:
 * QSPI_SR[IP_ACC] = 0 QSPI_SR[AHB_ACC] = 0
 */
typedef union _hw_quadspi_dlpr
{
    uint32_t U;
    struct _hw_quadspi_dlpr_bitfields
    {
        uint32_t DLPV : 32; /*!< [31:0] Data Learning Pattern Value: This value is used for data learning in DDR and DQS mode. */
    } B;
} hw_quadspi_dlpr_t;

/*!
 * @name Constants and macros for entire QUADSPI_DLPR register
 */
/*@{*/
#define HW_QUADSPI_DLPR_ADDR(x)        ((x) + 0x190U)
#define HW_QUADSPI_DLPR(x)             (*(__IO hw_quadspi_dlpr_t *) HW_QUADSPI_DLPR_ADDR(x))
#define HW_QUADSPI_DLPR_RD(x)          (HW_QUADSPI_DLPR(x).U)
#define HW_QUADSPI_DLPR_WR(x, v)       (HW_QUADSPI_DLPR(x).U = (v))
#define HW_QUADSPI_DLPR_SET(x, v)      (HW_QUADSPI_DLPR_WR(x, HW_QUADSPI_DLPR_RD(x) |  (v)))
#define HW_QUADSPI_DLPR_CLR(x, v)      (HW_QUADSPI_DLPR_WR(x, HW_QUADSPI_DLPR_RD(x) & ~(v)))
#define HW_QUADSPI_DLPR_TOG(x, v)      (HW_QUADSPI_DLPR_WR(x, HW_QUADSPI_DLPR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_DLPR bitfields
 */

/*!
 * @name Register QUADSPI_DLPR, field DLPV[31:0] (RW)
 *
 * Data Learning Pattern Value: This value is used for data learning in DDR and DQS mode. If
 * programmer wants to do data learn for more than 32 bit than the same value in the register is
 * repeated. Say if 64 bit data learning is requested by any flash and the value of DLPR is
 * aa55_3443 then the 64 bit value will be aa55_3443_aa55_3443. If 8 bit data learning was enabled
 * by programming in seq_operand fields of DATA_LEARN instruction to 1 , the bits [7:0] are used as
 * data_learning pattern. For details, refer to .
 */
/*@{*/
#define BP_QUADSPI_DLPR_DLPV         (0U)      /*!< Bit position for QUADSPI_DLPR_DLPV. */
#define BM_QUADSPI_DLPR_DLPV         (0xFFFFFFFFU)  /*!< Bit mask for QUADSPI_DLPR_DLPV. */
#define BS_QUADSPI_DLPR_DLPV         (32U)  /*!< Bitfield size in bits for QUADSPI_DLPR_DLPV. */

/*! @brief Read current value of the QUADSPI_DLPR_DLPV field. */
#define BR_QUADSPI_DLPR_DLPV(x)      (HW_QUADSPI_DLPR(x).U)

/*! @brief Format value for bitfield QUADSPI_DLPR_DLPV. */
#define BF_QUADSPI_DLPR_DLPV(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_DLPR_DLPV) & BM_QUADSPI_DLPR_DLPV)

/*! @brief Set the DLPV field to a new value. */
#define BW_QUADSPI_DLPR_DLPV(x, v)   (HW_QUADSPI_DLPR_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_RBDRn - RX Buffer Data Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_RBDRn - RX Buffer Data Register (RW)
 *
 * Reset value: 0x00000000U
 *
 * The QuadSPI_RBDR registers provide access to the individual entries in the RX Buffer. Refer to
 * for the byte ordering scheme. QuadSPI_RBDR0 corresponds to the actual position of the read
 * pointer within the RX Buffer. The number of valid entries available depends from the number of RX
 * Buffer entries implemented and from the number of valid buffer entries available in the RX
 * Buffer. Example 1, RX Buffer filled completely with 32 words: In this case the address range for
 * valid read access extends from QuadSPI_RBDR0 to QuadSPI_RBDR31. Example 2, RX Buffer filled with
 * 5 valid words: RX Buffer fill level QuadSPI_RBSR[RDBFL] is 5. In this case an access to
 * QuadSPI_RBDR4 provides the last valid entry. Any access beyond the range of valid RX Buffer
 * entries provides undefined results.
 */
typedef union _hw_quadspi_rbdrn
{
    uint32_t U;
    struct _hw_quadspi_rbdrn_bitfields
    {
        uint32_t RXDATA : 32; /*!< [31:0] RX Data. */
    } B;
} hw_quadspi_rbdrn_t;

/*!
 * @name Constants and macros for entire QUADSPI_RBDRn register
 */
/*@{*/
/*! @brief Number of instances of the QUADSPI_RBDRn register. */
#define HW_QUADSPI_RBDRn_COUNT     (32U)

#define HW_QUADSPI_RBDRn_ADDR(x, n)     ((x) + 0x200U + (0x4U * (n)))
#define HW_QUADSPI_RBDRn(x, n)          (*(__IO hw_quadspi_rbdrn_t *) HW_QUADSPI_RBDRn_ADDR(x, n))
#define HW_QUADSPI_RBDRn_RD(x, n)       (HW_QUADSPI_RBDRn(x, n).U)
#define HW_QUADSPI_RBDRn_WR(x, n, v)    (HW_QUADSPI_RBDRn(x, n).U = (v))
#define HW_QUADSPI_RBDRn_SET(x, n, v)   (HW_QUADSPI_RBDRn_WR(x, n, HW_QUADSPI_RBDRn_RD(x, n) |  (v)))
#define HW_QUADSPI_RBDRn_CLR(x, n, v)   (HW_QUADSPI_RBDRn_WR(x, n, HW_QUADSPI_RBDRn_RD(x, n) & ~(v)))
#define HW_QUADSPI_RBDRn_TOG(x, n, v)   (HW_QUADSPI_RBDRn_WR(x, n, HW_QUADSPI_RBDRn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_RBDRn bitfields
 */

/*!
 * @name Register QUADSPI_RBDRn, field RXDATA[31:0] (RW)
 *
 * RX Data. The RXDATA field contains the data associated with the related RX Buffer entry. Data
 * format and byte ordering is given in .
 */
/*@{*/
#define BP_QUADSPI_RBDRn_RXDATA         (0U)      /*!< Bit position for QUADSPI_RBDRn_RXDATA. */
#define BM_QUADSPI_RBDRn_RXDATA         (0xFFFFFFFFU)  /*!< Bit mask for QUADSPI_RBDRn_RXDATA. */
#define BS_QUADSPI_RBDRn_RXDATA         (32U)  /*!< Bitfield size in bits for QUADSPI_RBDRn_RXDATA. */

/*! @brief Read current value of the QUADSPI_RBDRn_RXDATA field. */
#define BR_QUADSPI_RBDRn_RXDATA(x, n)      (HW_QUADSPI_RBDRn(x, n).U)

/*! @brief Format value for bitfield QUADSPI_RBDRn_RXDATA. */
#define BF_QUADSPI_RBDRn_RXDATA(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_RBDRn_RXDATA) & BM_QUADSPI_RBDRn_RXDATA)

/*! @brief Set the RXDATA field to a new value. */
#define BW_QUADSPI_RBDRn_RXDATA(x, n, v)   (HW_QUADSPI_RBDRn_WR(x, n, v))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_LUTKEY - LUT Key Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_LUTKEY - LUT Key Register (RW)
 *
 * Reset value: 0x5AF05AF0U
 *
 * The LUT Key register contains the key to lock and unlock the Look-up-table. Refer to for details.
 * Write:Anytime
 */
typedef union _hw_quadspi_lutkey
{
    uint32_t U;
    struct _hw_quadspi_lutkey_bitfields
    {
        uint32_t KEY : 32; /*!< [31:0] The key to lock or unlock the LUT. */
    } B;
} hw_quadspi_lutkey_t;

/*!
 * @name Constants and macros for entire QUADSPI_LUTKEY register
 */
/*@{*/
#define HW_QUADSPI_LUTKEY_ADDR(x)        ((x) + 0x300U)
#define HW_QUADSPI_LUTKEY(x)             (*(__IO hw_quadspi_lutkey_t *) HW_QUADSPI_LUTKEY_ADDR(x))
#define HW_QUADSPI_LUTKEY_RD(x)          (HW_QUADSPI_LUTKEY(x).U)
#define HW_QUADSPI_LUTKEY_WR(x, v)       (HW_QUADSPI_LUTKEY(x).U = (v))
#define HW_QUADSPI_LUTKEY_SET(x, v)      (HW_QUADSPI_LUTKEY_WR(x, HW_QUADSPI_LUTKEY_RD(x) |  (v)))
#define HW_QUADSPI_LUTKEY_CLR(x, v)      (HW_QUADSPI_LUTKEY_WR(x, HW_QUADSPI_LUTKEY_RD(x) & ~(v)))
#define HW_QUADSPI_LUTKEY_TOG(x, v)      (HW_QUADSPI_LUTKEY_WR(x, HW_QUADSPI_LUTKEY_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_LUTKEY bitfields
 */

/*!
 * @name Register QUADSPI_LUTKEY, field KEY[31:0] (RW)
 *
 * The key to lock or unlock the LUT. The KEY is 0x5AF05AF0. The read value is always 0x5AF05AF0
 */
/*@{*/
#define BP_QUADSPI_LUTKEY_KEY         (0U)      /*!< Bit position for QUADSPI_LUTKEY_KEY. */
#define BM_QUADSPI_LUTKEY_KEY         (0xFFFFFFFFU)  /*!< Bit mask for QUADSPI_LUTKEY_KEY. */
#define BS_QUADSPI_LUTKEY_KEY         (32U)  /*!< Bitfield size in bits for QUADSPI_LUTKEY_KEY. */

/*! @brief Read current value of the QUADSPI_LUTKEY_KEY field. */
#define BR_QUADSPI_LUTKEY_KEY(x)      (HW_QUADSPI_LUTKEY(x).U)

/*! @brief Format value for bitfield QUADSPI_LUTKEY_KEY. */
#define BF_QUADSPI_LUTKEY_KEY(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_LUTKEY_KEY) & BM_QUADSPI_LUTKEY_KEY)

/*! @brief Set the KEY field to a new value. */
#define BW_QUADSPI_LUTKEY_KEY(x, v)   (HW_QUADSPI_LUTKEY_WR(x, v))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_LCKCR - LUT Lock Configuration Register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_LCKCR - LUT Lock Configuration Register (RW)
 *
 * Reset value: 0x00000002U
 *
 * The LUT lock configuration register is used along with QSPI_LUTKEY register to lock or unlock the
 * LUT. This register has to be written immediately after QSPI_LUTKEY register for the lock or
 * unlock operation to be successful. Refer to for details. Setting both the LOCK and UNLOCK bits as
 * "00" or "11" is not allowed. Write:Just after writing the LUT Key Register (QSPI_LUTKEY)
 */
typedef union _hw_quadspi_lckcr
{
    uint32_t U;
    struct _hw_quadspi_lckcr_bitfields
    {
        uint32_t LOCK : 1; /*!< [0] Locks the LUT when the following condition is met: */
        uint32_t UNLOCK : 1; /*!< [1] Unlocks the LUT when the following two conditions are met: */
        uint32_t RESERVED0 : 30; /*!< [31:2]  */
    } B;
} hw_quadspi_lckcr_t;

/*!
 * @name Constants and macros for entire QUADSPI_LCKCR register
 */
/*@{*/
#define HW_QUADSPI_LCKCR_ADDR(x)        ((x) + 0x304U)
#define HW_QUADSPI_LCKCR(x)             (*(__IO hw_quadspi_lckcr_t *) HW_QUADSPI_LCKCR_ADDR(x))
#define HW_QUADSPI_LCKCR_RD(x)          (HW_QUADSPI_LCKCR(x).U)
#define HW_QUADSPI_LCKCR_WR(x, v)       (HW_QUADSPI_LCKCR(x).U = (v))
#define HW_QUADSPI_LCKCR_SET(x, v)      (HW_QUADSPI_LCKCR_WR(x, HW_QUADSPI_LCKCR_RD(x) |  (v)))
#define HW_QUADSPI_LCKCR_CLR(x, v)      (HW_QUADSPI_LCKCR_WR(x, HW_QUADSPI_LCKCR_RD(x) & ~(v)))
#define HW_QUADSPI_LCKCR_TOG(x, v)      (HW_QUADSPI_LCKCR_WR(x, HW_QUADSPI_LCKCR_RD(x) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_LCKCR bitfields
 */

/*!
 * @name Register QUADSPI_LCKCR, field LOCK[0] (RW)
 *
 * Locks the LUT when the following condition is met: This register is written just after the The
 * LUT key register was written with 0x5AF05AF0 key
 */
/*@{*/
#define BP_QUADSPI_LCKCR_LOCK         (0U)      /*!< Bit position for QUADSPI_LCKCR_LOCK. */
#define BM_QUADSPI_LCKCR_LOCK         (0x00000001U)  /*!< Bit mask for QUADSPI_LCKCR_LOCK. */
#define BS_QUADSPI_LCKCR_LOCK         (1U)  /*!< Bitfield size in bits for QUADSPI_LCKCR_LOCK. */

/*! @brief Read current value of the QUADSPI_LCKCR_LOCK field. */
#define BR_QUADSPI_LCKCR_LOCK(x)   (HW_QUADSPI_LCKCR(x).B.LOCK)

/*! @brief Format value for bitfield QUADSPI_LCKCR_LOCK. */
#define BF_QUADSPI_LCKCR_LOCK(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_LCKCR_LOCK) & BM_QUADSPI_LCKCR_LOCK)

/*! @brief Set the LOCK field to a new value. */
#define BW_QUADSPI_LCKCR_LOCK(x, v)   (HW_QUADSPI_LCKCR_WR(x, (HW_QUADSPI_LCKCR_RD(x) & ~BM_QUADSPI_LCKCR_LOCK) | BF_QUADSPI_LCKCR_LOCK(v)))
/*@}*/

/*!
 * @name Register QUADSPI_LCKCR, field UNLOCK[1] (RW)
 *
 * Unlocks the LUT when the following two conditions are met: 1. This register is written just after
 * the 2. The LUT key register was written with 0x5AF05AF0 key
 */
/*@{*/
#define BP_QUADSPI_LCKCR_UNLOCK         (1U)      /*!< Bit position for QUADSPI_LCKCR_UNLOCK. */
#define BM_QUADSPI_LCKCR_UNLOCK         (0x00000002U)  /*!< Bit mask for QUADSPI_LCKCR_UNLOCK. */
#define BS_QUADSPI_LCKCR_UNLOCK         (1U)  /*!< Bitfield size in bits for QUADSPI_LCKCR_UNLOCK. */

/*! @brief Read current value of the QUADSPI_LCKCR_UNLOCK field. */
#define BR_QUADSPI_LCKCR_UNLOCK(x)   (HW_QUADSPI_LCKCR(x).B.UNLOCK)

/*! @brief Format value for bitfield QUADSPI_LCKCR_UNLOCK. */
#define BF_QUADSPI_LCKCR_UNLOCK(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_LCKCR_UNLOCK) & BM_QUADSPI_LCKCR_UNLOCK)

/*! @brief Set the UNLOCK field to a new value. */
#define BW_QUADSPI_LCKCR_UNLOCK(x, v)   (HW_QUADSPI_LCKCR_WR(x, (HW_QUADSPI_LCKCR_RD(x) & ~BM_QUADSPI_LCKCR_UNLOCK) | BF_QUADSPI_LCKCR_UNLOCK(v)))
/*@}*/

/*******************************************************************************
 * HW_QUADSPI_LUTn - Look-up Table register
 ******************************************************************************/

/*!
 * @brief HW_QUADSPI_LUTn - Look-up Table register (RW)
 *
 * Reset value: 0xEEEAEF0AD1AE00000002AD08180403EECEU
 *
 * The LUT registers are a look-up-table for sequences of instructions. The programmable sequence
 * engine executes the instructions in these sequences to generate a valid serial flash transaction.
 * There are a total of 64 LUT registers. These 64 registers are divided into groups of 4 registers
 * that make a valid sequence. Therefore, QSPI_LUT[0], QSPI_LUT[4], QSPI_LUT[8] ..... QSPI_LUT[60]
 * are the starting registers of a valid sequence. Each of these sets of 4 registers can have a
 * maximum of 8 instructions. Reset value of the register shown below is only applicable to LUT 2 to
 * LUT64. A maximum of 16 sequences can be defined at one time. describes the LUT registers in
 * detail. Write:Once the LUT is unlocked
 */
typedef union _hw_quadspi_lutn
{
    uint32_t U;
    struct _hw_quadspi_lutn_bitfields
    {
        uint32_t OPRND0 : 8; /*!< [7:0] Operand for INSTR0. */
        uint32_t PAD0 : 2; /*!< [9:8] Pad information for INSTR0. */
        uint32_t INSTR0 : 6; /*!< [15:10] Instruction 0 */
        uint32_t OPRND1 : 8; /*!< [23:16] Operand for INSTR1. */
        uint32_t PAD1 : 2; /*!< [25:24] Pad information for INSTR1. */
        uint32_t INSTR1 : 6; /*!< [31:26] Instruction 1 */
    } B;
} hw_quadspi_lutn_t;

/*!
 * @name Constants and macros for entire QUADSPI_LUTn register
 */
/*@{*/
/*! @brief Number of instances of the QUADSPI_LUTn register. */
#define HW_QUADSPI_LUTn_COUNT     (64U)

#define HW_QUADSPI_LUTn_ADDR(x, n)     ((x) + 0x310U + (0x4U * (n)))
#define HW_QUADSPI_LUTn(x, n)          (*(__IO hw_quadspi_lutn_t *) HW_QUADSPI_LUTn_ADDR(x, n))
#define HW_QUADSPI_LUTn_RD(x, n)       (HW_QUADSPI_LUTn(x, n).U)
#define HW_QUADSPI_LUTn_WR(x, n, v)    (HW_QUADSPI_LUTn(x, n).U = (v))
#define HW_QUADSPI_LUTn_SET(x, n, v)   (HW_QUADSPI_LUTn_WR(x, n, HW_QUADSPI_LUTn_RD(x, n) |  (v)))
#define HW_QUADSPI_LUTn_CLR(x, n, v)   (HW_QUADSPI_LUTn_WR(x, n, HW_QUADSPI_LUTn_RD(x, n) & ~(v)))
#define HW_QUADSPI_LUTn_TOG(x, n, v)   (HW_QUADSPI_LUTn_WR(x, n, HW_QUADSPI_LUTn_RD(x, n) ^  (v)))
/*@}*/

/*
 * Constants & macros for individual QUADSPI_LUTn bitfields
 */

/*!
 * @name Register QUADSPI_LUTn, field OPRND0[7:0] (RW)
 */
/*@{*/
#define BP_QUADSPI_LUTn_OPRND0         (0U)      /*!< Bit position for QUADSPI_LUTn_OPRND0. */
#define BM_QUADSPI_LUTn_OPRND0         (0x000000FFU)  /*!< Bit mask for QUADSPI_LUTn_OPRND0. */
#define BS_QUADSPI_LUTn_OPRND0         (8U)  /*!< Bitfield size in bits for QUADSPI_LUTn_OPRND0. */

/*! @brief Read current value of the QUADSPI_LUTn_OPRND0 field. */
#define BR_QUADSPI_LUTn_OPRND0(x, n)   (HW_QUADSPI_LUTn(x, n).B.OPRND0)

/*! @brief Format value for bitfield QUADSPI_LUTn_OPRND0. */
#define BF_QUADSPI_LUTn_OPRND0(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_LUTn_OPRND0) & BM_QUADSPI_LUTn_OPRND0)

/*! @brief Set the OPRND0 field to a new value. */
#define BW_QUADSPI_LUTn_OPRND0(x, n, v)   (HW_QUADSPI_LUTn_WR(x, n, (HW_QUADSPI_LUTn_RD(x, n) & ~BM_QUADSPI_LUTn_OPRND0) | BF_QUADSPI_LUTn_OPRND0(v)))
/*@}*/

/*!
 * @name Register QUADSPI_LUTn, field PAD0[9:8] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - 8 Pads
 */
/*@{*/
#define BP_QUADSPI_LUTn_PAD0         (8U)      /*!< Bit position for QUADSPI_LUTn_PAD0. */
#define BM_QUADSPI_LUTn_PAD0         (0x00000300U)  /*!< Bit mask for QUADSPI_LUTn_PAD0. */
#define BS_QUADSPI_LUTn_PAD0         (2U)  /*!< Bitfield size in bits for QUADSPI_LUTn_PAD0. */

/*! @brief Read current value of the QUADSPI_LUTn_PAD0 field. */
#define BR_QUADSPI_LUTn_PAD0(x, n)   (HW_QUADSPI_LUTn(x, n).B.PAD0)

/*! @brief Format value for bitfield QUADSPI_LUTn_PAD0. */
#define BF_QUADSPI_LUTn_PAD0(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_LUTn_PAD0) & BM_QUADSPI_LUTn_PAD0)

/*! @brief Set the PAD0 field to a new value. */
#define BW_QUADSPI_LUTn_PAD0(x, n, v)   (HW_QUADSPI_LUTn_WR(x, n, (HW_QUADSPI_LUTn_RD(x, n) & ~BM_QUADSPI_LUTn_PAD0) | BF_QUADSPI_LUTn_PAD0(v)))
/*@}*/

/*!
 * @name Register QUADSPI_LUTn, field INSTR0[15:10] (RW)
 */
/*@{*/
#define BP_QUADSPI_LUTn_INSTR0         (10U)      /*!< Bit position for QUADSPI_LUTn_INSTR0. */
#define BM_QUADSPI_LUTn_INSTR0         (0x0000FC00U)  /*!< Bit mask for QUADSPI_LUTn_INSTR0. */
#define BS_QUADSPI_LUTn_INSTR0         (6U)  /*!< Bitfield size in bits for QUADSPI_LUTn_INSTR0. */

/*! @brief Read current value of the QUADSPI_LUTn_INSTR0 field. */
#define BR_QUADSPI_LUTn_INSTR0(x, n)   (HW_QUADSPI_LUTn(x, n).B.INSTR0)

/*! @brief Format value for bitfield QUADSPI_LUTn_INSTR0. */
#define BF_QUADSPI_LUTn_INSTR0(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_LUTn_INSTR0) & BM_QUADSPI_LUTn_INSTR0)

/*! @brief Set the INSTR0 field to a new value. */
#define BW_QUADSPI_LUTn_INSTR0(x, n, v)   (HW_QUADSPI_LUTn_WR(x, n, (HW_QUADSPI_LUTn_RD(x, n) & ~BM_QUADSPI_LUTn_INSTR0) | BF_QUADSPI_LUTn_INSTR0(v)))
/*@}*/

/*!
 * @name Register QUADSPI_LUTn, field OPRND1[23:16] (RW)
 */
/*@{*/
#define BP_QUADSPI_LUTn_OPRND1         (16U)      /*!< Bit position for QUADSPI_LUTn_OPRND1. */
#define BM_QUADSPI_LUTn_OPRND1         (0x00FF0000U)  /*!< Bit mask for QUADSPI_LUTn_OPRND1. */
#define BS_QUADSPI_LUTn_OPRND1         (8U)  /*!< Bitfield size in bits for QUADSPI_LUTn_OPRND1. */

/*! @brief Read current value of the QUADSPI_LUTn_OPRND1 field. */
#define BR_QUADSPI_LUTn_OPRND1(x, n)   (HW_QUADSPI_LUTn(x, n).B.OPRND1)

/*! @brief Format value for bitfield QUADSPI_LUTn_OPRND1. */
#define BF_QUADSPI_LUTn_OPRND1(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_LUTn_OPRND1) & BM_QUADSPI_LUTn_OPRND1)

/*! @brief Set the OPRND1 field to a new value. */
#define BW_QUADSPI_LUTn_OPRND1(x, n, v)   (HW_QUADSPI_LUTn_WR(x, n, (HW_QUADSPI_LUTn_RD(x, n) & ~BM_QUADSPI_LUTn_OPRND1) | BF_QUADSPI_LUTn_OPRND1(v)))
/*@}*/

/*!
 * @name Register QUADSPI_LUTn, field PAD1[25:24] (RW)
 *
 * Values:
 * - 00 - 1 Pad
 * - 01 - 2 Pads
 * - 10 - 4 Pads
 * - 11 - 8 Pads
 */
/*@{*/
#define BP_QUADSPI_LUTn_PAD1         (24U)      /*!< Bit position for QUADSPI_LUTn_PAD1. */
#define BM_QUADSPI_LUTn_PAD1         (0x03000000U)  /*!< Bit mask for QUADSPI_LUTn_PAD1. */
#define BS_QUADSPI_LUTn_PAD1         (2U)  /*!< Bitfield size in bits for QUADSPI_LUTn_PAD1. */

/*! @brief Read current value of the QUADSPI_LUTn_PAD1 field. */
#define BR_QUADSPI_LUTn_PAD1(x, n)   (HW_QUADSPI_LUTn(x, n).B.PAD1)

/*! @brief Format value for bitfield QUADSPI_LUTn_PAD1. */
#define BF_QUADSPI_LUTn_PAD1(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_LUTn_PAD1) & BM_QUADSPI_LUTn_PAD1)

/*! @brief Set the PAD1 field to a new value. */
#define BW_QUADSPI_LUTn_PAD1(x, n, v)   (HW_QUADSPI_LUTn_WR(x, n, (HW_QUADSPI_LUTn_RD(x, n) & ~BM_QUADSPI_LUTn_PAD1) | BF_QUADSPI_LUTn_PAD1(v)))
/*@}*/

/*!
 * @name Register QUADSPI_LUTn, field INSTR1[31:26] (RW)
 */
/*@{*/
#define BP_QUADSPI_LUTn_INSTR1         (26U)      /*!< Bit position for QUADSPI_LUTn_INSTR1. */
#define BM_QUADSPI_LUTn_INSTR1         (0xFC000000U)  /*!< Bit mask for QUADSPI_LUTn_INSTR1. */
#define BS_QUADSPI_LUTn_INSTR1         (6U)  /*!< Bitfield size in bits for QUADSPI_LUTn_INSTR1. */

/*! @brief Read current value of the QUADSPI_LUTn_INSTR1 field. */
#define BR_QUADSPI_LUTn_INSTR1(x, n)   (HW_QUADSPI_LUTn(x, n).B.INSTR1)

/*! @brief Format value for bitfield QUADSPI_LUTn_INSTR1. */
#define BF_QUADSPI_LUTn_INSTR1(v)      ((uint32_t)((uint32_t)(v) << BP_QUADSPI_LUTn_INSTR1) & BM_QUADSPI_LUTn_INSTR1)

/*! @brief Set the INSTR1 field to a new value. */
#define BW_QUADSPI_LUTn_INSTR1(x, n, v)   (HW_QUADSPI_LUTn_WR(x, n, (HW_QUADSPI_LUTn_RD(x, n) & ~BM_QUADSPI_LUTn_INSTR1) | BF_QUADSPI_LUTn_INSTR1(v)))
/*@}*/

/*******************************************************************************
 * hw_quadspi_t - module struct
 ******************************************************************************/
/*!
 * @brief All QUADSPI module registers.
 */
#pragma pack(1)
typedef struct _hw_quadspi
{
    __IO hw_quadspi_mcr_t MCR; /*!< [0x0] Module Configuration Register */
         uint32_t _reserved0;
    __IO hw_quadspi_ipcr_t IPCR; /*!< [0x8] IP Configuration Register */
    __IO hw_quadspi_flshcr_t FLSHCR; /*!< [0xC] Flash Configuration Register */
    __IO hw_quadspi_buf0cr_t BUF0CR; /*!< [0x10] Buffer0 Configuration Register */
    __IO hw_quadspi_buf1cr_t BUF1CR; /*!< [0x14] Buffer1 Configuration Register */
    __IO hw_quadspi_buf2cr_t BUF2CR; /*!< [0x18] Buffer2 Configuration Register */
    __IO hw_quadspi_buf3cr_t BUF3CR; /*!< [0x1C] Buffer3 Configuration Register */
    __IO hw_quadspi_bfgencr_t BFGENCR; /*!< [0x20] Buffer Generic Configuration Register */
    __IO hw_quadspi_soccr_t SOCCR; /*!< [0x24] SOC Configuration Register */
         uint32_t _reserved1[2];
    __IO hw_quadspi_buf0ind_t BUF0IND; /*!< [0x30] Buffer0 Top Index Register */
    __IO hw_quadspi_buf1ind_t BUF1IND; /*!< [0x34] Buffer1 Top Index Register */
    __IO hw_quadspi_buf2ind_t BUF2IND; /*!< [0x38] Buffer2 Top Index Register */
         uint32_t _reserved2[49];
    __IO hw_quadspi_sfar_t SFAR; /*!< [0x100] Serial Flash Address Register */
    __IO hw_quadspi_sfacr_t SFACR; /*!< [0x104] Serial Flash Address Configuration Register */
    __IO hw_quadspi_smpr_t SMPR; /*!< [0x108] Sampling Register */
    __I  hw_quadspi_rbsr_t RBSR; /*!< [0x10C] RX Buffer Status Register */
    __IO hw_quadspi_rbct_t RBCT; /*!< [0x110] RX Buffer Control Register */
         uint32_t _reserved3[15];
    __I  hw_quadspi_tbsr_t TBSR; /*!< [0x150] TX Buffer Status Register */
    __IO hw_quadspi_tbdr_t TBDR; /*!< [0x154] TX Buffer Data Register */
    __IO hw_quadspi_tbct_t TBCT; /*!< [0x158] Tx Buffer Control Register */
    __I  hw_quadspi_sr_t SR; /*!< [0x15C] Status Register */
    __IO hw_quadspi_fr_t FR; /*!< [0x160] Flag Register */
    __IO hw_quadspi_rser_t RSER; /*!< [0x164] Interrupt and DMA Request Select and Enable Register */
    __I  hw_quadspi_spndst_t SPNDST; /*!< [0x168] Sequence Suspend Status Register */
    __IO hw_quadspi_sptrclr_t SPTRCLR; /*!< [0x16C] Sequence Pointer Clear Register */
         uint32_t _reserved4[4];
    __IO hw_quadspi_sfa1ad_t SFA1AD; /*!< [0x180] Serial Flash A1 Top Address */
    __IO hw_quadspi_sfa2ad_t SFA2AD; /*!< [0x184] Serial Flash A2 Top Address */
    __IO hw_quadspi_sfb1ad_t SFB1AD; /*!< [0x188] Serial Flash B1Top Address */
    __IO hw_quadspi_sfb2ad_t SFB2AD; /*!< [0x18C] Serial Flash B2Top Address */
    __IO hw_quadspi_dlpr_t DLPR; /*!< [0x190] Data Learn Pattern Register */
         uint32_t _reserved5[27];
    __IO hw_quadspi_rbdrn_t RBDRn[32]; /*!< [0x200] RX Buffer Data Register */
         uint32_t _reserved6[32];
    __IO hw_quadspi_lutkey_t LUTKEY; /*!< [0x300] LUT Key Register */
    __IO hw_quadspi_lckcr_t LCKCR; /*!< [0x304] LUT Lock Configuration Register */
         uint32_t _reserved7[2];
    __IO hw_quadspi_lutn_t LUTn[64]; /*!< [0x310] Look-up Table register */
} hw_quadspi_t;
#pragma pack()


/*! @brief Macro to access all QUADSPI registers. */
/*! @param x QUADSPI module instance base address. */
/*! @return Reference (not a pointer) to the registers struct. To get a pointer to the struct,
 *     use the '&' operator, like <code>&HW_QUADSPI(QUADSPI0_BASE)</code>. */
#define HW_QUADSPI(x)      (*(hw_quadspi_t *)(x))

#endif /* __HW_QUADSPI_REGISTERS_H__ */
/* v30/140722/1.3.1 */
/* EOF */
